# coding: utf-8
from __future__ import unicode_literals


rules = {'ADJ': {'-': [('', False)],
         '-baserade': [('-baserad', False)],
         '-baserat': [('-baserad', False)],
         '-formad': [('-formad', False)],
         '-format': [('-formad', False)],
         '-skadad': [('-skadad', False)],
         '-skadade': [('-skadad', False)],
         ':e': [(':e', False)],
         ':t': [(':t', False)],
         'Xformad': [('Xformad', True)],
         'Xformat': [('Xformad', True)],
         'a': [('', False)],
         'abaserade': [('abaserad', False)],
         'abaserat': [('abaserad', False)],
         'abba': [('abba', False)],
         'abra': [('aber', False)],
         'abras': [('aber', False)],
         'abyggd': [('abyggd', False)],
         'abyggt': [('abyggd', False)],
         'accepterade': [('acceptera', True)],
         'accepterat': [('acceptera', True)],
         'acerad': [('acerad', False)],
         'acerade': [('acerad', False)],
         'ackt': [('ack', False)],
         'ad': [('ad', False)],
         'ada': [('ad', False)],
         'adad': [('adad', False)],
         'adade': [('adad', False)],
         'adan': [('adan', False)],
         'adana': [('adan', False)],
         'adande': [('adande', False)],
         'adant': [('adan', False)],
         'adare': [('ad', False)],
         'adas': [('ad', False)],
         'adaste': [('ad', False)],
         'ade': [('ad', False)],
         'aderade': [('aderad', False)],
         'aderats': [('aderad', False)],
         'ades': [('ad', False)],
         'adgat': [('adgad', False)],
         'adlat': [('adlad', False)],
         'adresserade': [('adressera', True)],
         'ads': [('ad', False)],
         'afas': [('af', False)],
         'aformad': [('aformad', False)],
         'aformat': [('aformad', False)],
         'aftat': [('aftad', False)],
         'afts': [('af', False)],
         'aga': [('ag', False)],
         'agad': [('agad', False)],
         'agade': [('agad', False)],
         'agande': [('agande', False)],
         'agants': [('agant', False)],
         'agare': [('ag', False)],
         'agares': [('ag', False)],
         'agas': [('ag', False)],
         'agast': [('ag', False)],
         'agaste': [('ag', False)],
         'agastes': [('ag', False)],
         'agasts': [('ag', False)],
         'agats': [('agad', False)],
         'age': [('ag', False)],
         'agen': [('agen', False)],
         'agerad': [('agerad', False)],
         'ages': [('ag', False)],
         'agets': [('agen', False)],
         'agjorda': [('agjord', False)],
         'aglatt': [('aglad', False)],
         'aglatts': [('aglad', False)],
         'agna': [('agen', False)],
         'agnare': [('agen', False)],
         'agnares': [('agen', False)],
         'agnas': [('agen', False)],
         'agnast': [('agen', False)],
         'agnaste': [('agen', False)],
         'agnastes': [('agen', False)],
         'agnasts': [('agen', False)],
         'agnat': [('agnad', False)],
         'agne': [('agen', False)],
         'agnes': [('agen', False)],
         'agrant': [('agrant', False)],
         'agrants': [('agrann', False)],
         'agrare': [('agrar', True)],
         'agrares': [('agrar', True)],
         'agre': [('ager', False)],
         'agres': [('ager', False)],
         'ags': [('ag', False)],
         'agt': [('agd', False)],
         'agts': [('ag', False)],
         'agående': [('agående', False)],
         'aheligaste': [('aheligaste', False)],
         'aiserat': [('aiserad', False)],
         'aje': [('aj', False)],
         'ajt': [('ajt', False)],
         'ajts': [('aj', False)],
         'aka': [('ak', False)],
         'akad': [('akad', False)],
         'akade': [('akad', False)],
         'akande': [('akande', False)],
         'akats': [('akad', False)],
         'akes': [('ak', False)],
         'aket': [('aken', False)],
         'aklöst': [('aklös', False)],
         'aknat': [('aknad', False)],
         'aknes': [('aken', False)],
         'akt': [('akt', False)],
         'akta': [('akta', False)],
         'aktre': [('aktre', True)],
         'aktres': [('aktre', True)],
         'akts': [('ak', False)],
         'ala': [('al', False)],
         'alad': [('alad', False)],
         'alade': [('alad', False)],
         'alande': [('alande', False)],
         'alants': [('alant', False)],
         'alare': [('al', False)],
         'alares': [('al', False)],
         'alas': [('al', False)],
         'alast': [('al', False)],
         'alaste': [('al', False)],
         'alastes': [('al', False)],
         'alasts': [('al', False)],
         'alat': [('alad', False)],
         'alats': [('alad', False)],
         'ale': [('al', False)],
         'alent': [('alent', False)],
         'alents': [('alent', False)],
         'alerad': [('alerad', False)],
         'alerade': [('alerad', False)],
         'ales': [('al', False)],
         'alet': [('alen', False)],
         'alets': [('alen', False)],
         'aligare': [('alig', False)],
         'aligaste': [('alig', False)],
         'alika': [('alik', False)],
         'alikts': [('alik', False)],
         'aliserade': [('aliserad', False)],
         'aliserande': [('aliserande', False)],
         'allas': [('all', False)],
         'allda': [('alld', False)],
         'alls': [('alls', False)],
         'allt': [('all', False)],
         'allts': [('alld', False)],
         'alne': [('alen', False)],
         'als': [('al', False)],
         'alstrad': [('alstra', True)],
         'altat': [('altad', False)],
         'altes': [('alt', False)],
         'alts': [('al', False)],
         'alvt': [('alv', False)],
         'alärt': [('alär', False)],
         'alärts': [('alär', False)],
         'alätt': [('alätt', False)],
         'alös': [('alös', False)],
         'alösts': [('alös', False)],
         'ama': [('am', False)],
         'amad': [('amad', False)],
         'amade': [('amad', False)],
         'amants': [('amant', False)],
         'amare': [('am', False)],
         'amares': [('am', False)],
         'amas': [('am', False)],
         'amast': [('am', False)],
         'amaste': [('am', False)],
         'amastes': [('am', False)],
         'amasts': [('am', False)],
         'amats': [('amad', False)],
         'ame': [('am', False)],
         'ames': [('am', False)],
         'amma': [('am', False)],
         'ammalt': [('ammal', False)],
         'ammalts': [('ammald', False)],
         'ammat': [('ammad', False)],
         'ams': [('am', False)],
         'amts': [('am', False)],
         'an': [('an', False)],
         'an-': [('an', False)],
         'ana': [('an', False)],
         'anad': [('anad', False)],
         'anade': [('anad', False)],
         'anande': [('anande', False)],
         'anare': [('an', False)],
         'anares': [('an', False)],
         'anas': [('an', False)],
         'anast': [('an', False)],
         'anaste': [('an', False)],
         'anastes': [('an', False)],
         'anasts': [('an', False)],
         'anats': [('anad', False)],
         'anda': [('anda', False)],
         'ande': [('ande', False)],
         'andes': [('andes', False)],
         'andlade': [('andlad', False)],
         'andrad': [('andrad', False)],
         'andrade': [('andrad', False)],
         'andre': [('andra', False)],
         'ands': [('ands', False)],
         'ane': [('an', False)],
         'anerad': [('anerad', False)],
         'anerade': [('anerad', False)],
         'anes': [('an', False)],
         'anförd': [('anförd', False)],
         'anförda': [('anförd', False)],
         'anfört': [('anför', False)],
         'anförts': [('anför', False)],
         'anga': [('ange', False)],
         'angare': [('ange', False)],
         'angares': [('ange', False)],
         'angas': [('ange', False)],
         'angast': [('ange', False)],
         'angaste': [('ange', False)],
         'angastes': [('ange', False)],
         'angasts': [('ange', False)],
         'ange': [('ange', False)],
         'anges': [('ange', False)],
         'anget': [('ange', False)],
         'angets': [('ange', False)],
         'angjord': [('angjord', False)],
         'angt': [('ange', False)],
         'angts': [('ange', False)],
         'ankommande': [('ankomma', True)],
         'ankt': [('ank', False)],
         'anlagda': [('lägga_an', True)],
         'anmäld': [('anmäla', True)],
         'anmälda': [('anmäla', True)],
         'anna': [('ann', False)],
         'annas': [('ann', False)],
         'annastes': [('ann', False)],
         'annat': [('annan', True)],
         'anne': [('ann', False)],
         'annes': [('ann', False)],
         'anordnad': [('anordna', True)],
         'anordnade': [('anordna', True)],
         'anpassat': [('anpassa', True)],
         'anrikat': [('anrika', True)],
         'ans': [('an', False)],
         'anskad': [('anskad', False)],
         'anskade': [('anskad', False)],
         'anskriven': [('anskriven', True)],
         'anslutet': [('ansluta', True)],
         'anslutna': [('ansluta', True)],
         'ant': [('an', False)],
         'antagna': [('anta', True)],
         'antrad': [('antrad', False)],
         'ants': [('ant', False)],
         'apad': [('apad', False)],
         'apade': [('apad', False)],
         'apande': [('apande', False)],
         'apart': [('apart', True)],
         'aparts': [('apart', True)],
         'aperade': [('aperad', False)],
         'aperats': [('aperad', False)],
         'aperbare': [('aperbar', False)],
         'aperbares': [('aperbar', False)],
         'apers': [('aper', False)],
         'aplans': [('aplans', False)],
         'aplat': [('aplad', False)],
         'appat': [('appad', False)],
         'apporterade': [('apporterad', False)],
         'apterat': [('apterad', False)],
         'ara': [('ar', False)],
         'arad': [('arad', False)],
         'arade': [('arad', False)],
         'arades': [('arad', False)],
         'arande': [('arande', False)],
         'arant': [('arant', False)],
         'arants': [('arant', False)],
         'arare': [('ar', False)],
         'arares': [('ar', False)],
         'aras': [('ar', False)],
         'arast': [('ar', False)],
         'araste': [('ar', False)],
         'arastes': [('ar', False)],
         'arasts': [('ar', False)],
         'arats': [('arad', False)],
         'arbare': [('arbar', False)],
         'arbares': [('arbar', False)],
         'arbetande': [('arbeta', False)],
         'are': [('', False)],
         'arent': [('arent', False)],
         'arents': [('arent', False)],
         'arerade': [('arerad', False)],
         'ares': [('', False)],
         'aret': [('aren', False)],
         'arets': [('aren', False)],
         'areviga': [('areviga', False)],
         'arevigas': [('areviga', False)],
         'arevigaste': [('arevigaste', False)],
         'arevigastes': [('arevigaste', False)],
         'arie': [('arie', False)],
         'arierande': [('ariera', False)],
         'arkt': [('ark', False)],
         'arlikt': [('arlik', False)],
         'arlämnad': [('arlämnad', False)],
         'arlöst': [('arlös', False)],
         'armat': [('armad', False)],
         'armt': [('arm', False)],
         'arna': [('aren', False)],
         'arnare': [('aren', False)],
         'arnares': [('aren', False)],
         'arnas': [('aren', False)],
         'arnast': [('aren', False)],
         'arnaste': [('aren', False)],
         'arnastes': [('aren', False)],
         'arnasts': [('aren', False)],
         'arne': [('aren', False)],
         'arnes': [('aren', False)],
         'arns': [('arns', False)],
         'arre': [('arr', False)],
         'arres': [('arr', False)],
         'ars': [('ar', False)],
         'arse': [('arse', False)],
         'art': [('art', False)],
         'arts': [('ar', False)],
         'arva': [('arva', False)],
         'arögt': [('arögd', False)],
         'arött': [('aröd', False)],
         'arötts': [('aröd', False)],
         'as': [('', False)],
         'asad': [('asad', False)],
         'asade': [('asad', False)],
         'asalt': [('asal', False)],
         'asalts': [('asal', False)],
         'asande': [('asande', False)],
         'aserade': [('aserad', False)],
         'asittande': [('asittande', False)],
         'askat': [('askad', False)],
         'assat': [('assad', False)],
         'ast': [('', False)],
         'astante': [('astant', False)],
         'aste': [('', False)],
         'astes': [('', False)],
         'asts': [('', False)],
         'asänt': [('asänd', False)],
         'ata': [('at', False)],
         'atad': [('atad', False)],
         'atade': [('atad', False)],
         'atalts': [('atal', False)],
         'atants': [('atant', False)],
         'atas': [('at', False)],
         'ate': [('at', False)],
         'aterad': [('aterad', False)],
         'aterade': [('aterad', False)],
         'aterats': [('aterad', False)],
         'ates': [('at', False)],
         'atigande': [('atigande', False)],
         'atilts': [('atil', False)],
         'atiserande': [('atiserande', False)],
         'ative': [('ativ', False)],
         'atlöst': [('atlös', False)],
         'ats': [('ad', False)],
         'atterat': [('atterad', False)],
         'atts': [('att', False)],
         'aturorienterande': [('aturorienterande', False)],
         'auterat': [('auterad', False)],
         'ava': [('av', False)],
         'avande': [('avande', False)],
         'avat': [('avat', False)],
         'avats': [('avad', False)],
         'ave': [('av', False)],
         'avidare': [('avid', False)],
         'aviga': [('avig', False)],
         'avigas': [('avig', False)],
         'avigastes': [('avig', False)],
         'avigts': [('avig', False)],
         'avisad': [('avisad', False)],
         'avisade': [('avisad', False)],
         'avklarad': [('klara_av', True)],
         'avkopplat': [('avkoppla', True)],
         'avlönat': [('avlöna', True)],
         'avlöst': [('avlös', False)],
         'avlösts': [('avlös', False)],
         'avs': [('av', False)],
         'avsaltat': [('avsalta', True)],
         'avskuren': [('skära_av', True)],
         'avsänd': [('avsända', True)],
         'avt': [('avd', False)],
         'avts': [('av', False)],
         'avverkade': [('avverka', True)],
         'ays': [('ay', False)],
         'ba': [('ba', False)],
         'babla': [('babel', False)],
         'bakat': [('bakad', False)],
         'bakersta': [('bakersta', True), ('bakre', True)],
         'bakta': [('bakt', False)],
         'bakts': [('bakt', False)],
         'balls': [('ball', True)],
         'ballts': [('ball', True)],
         'balt': [('bal', False)],
         'banga': [('bang', True)],
         'bangare': [('bang', True)],
         'bangares': [('bang', True)],
         'bangas': [('bang', True)],
         'bangast': [('bang', True)],
         'bangaste': [('bang', True)],
         'bangastes': [('bang', True)],
         'bangasts': [('bang', True)],
         'bange': [('bang', True)],
         'banges': [('bang', True)],
         'bangt': [('bang', True)],
         'bangts': [('bang', True)],
         'bannat': [('bannad', False)],
         'bants': [('ban', False)],
         'bare': [('bar', False)],
         'bares': [('bar', False)],
         'bart': [('bar', False)],
         'baserade': [('basera', True)],
         'baserat': [('basera', True)],
         'bastade': [('bastad', False)],
         'bat': [('bad', False)],
         'bats': [('bat', False)],
         'bbade': [('bbad', False)],
         'bbare': [('bb', False)],
         'bbares': [('bb', False)],
         'bbaserade': [('bbaserad', False)],
         'bbaserat': [('bbaserad', False)],
         'bbats': [('bbad', False)],
         'beckad': [('beckad', False)],
         'beckade': [('beckad', False)],
         'bedd': [('bedd', False)],
         'bedda': [('bedd', False)],
         'befolkade': [('befolka', True)],
         'befriad': [('befria', True)],
         'befrämjande': [('befrämja', True)],
         'begränsande': [('begränsa', True)],
         'begärts': [('begärd', False)],
         'behandlade': [('behandla', False)],
         'belt': [('bel', False)],
         'belyst': [('belysa', True)],
         'bemälda': [('bemäld', False)],
         'bemäldas': [('bemäld', False)],
         'bemälde': [('bemälde', True)],
         'bemäldes': [('bemäld', False)],
         'ben': [('bel', False)],
         'ben-': [('bel', False)],
         'bens': [('bel', False)],
         'bent': [('bent', False)],
         'bents': [('bent', False)],
         'ber': [('ber', False)],
         'berat': [('berad', False)],
         'bert': [('ber', False)],
         'berörda': [('berörd', False)],
         'berördas': [('berörd', False)],
         'berörde': [('berörd', True)],
         'berördes': [('berörd', True)],
         'beströtts': [('beströdd', False)],
         'beställt': [('beställt', True)],
         'bet': [('bel', False)],
         'betalda': [('betala', True)],
         'betalt': [('betala', True)],
         'betalts': [('betald', False)],
         'bets': [('bel', False)],
         'bett': [('bedd', False)],
         'betts': [('bedd', False)],
         'bevarade': [('bevara', True)],
         'bgjorda': [('bgjord', False)],
         'bgående': [('bgående', False)],
         'bialiserade': [('bialiserad', False)],
         'biat': [('biat', False)],
         'bigt': [('big', False)],
         'bildande': [('bildande', False)],
         'biliserat': [('biliserad', False)],
         'bilt': [('bil', False)],
         'bjuden': [('bjuden', False)],
         'bjärt': [('bjärt', True)],
         'bla': [('bel', False)],
         'blad': [('blad', False)],
         'blade': [('blad', False)],
         'blande': [('blande', False)],
         'blare': [('bel', False)],
         'blares': [('bel', False)],
         'blas': [('bel', False)],
         'blat': [('blad', False)],
         'blats': [('blad', False)],
         'ble': [('bel', False)],
         'blekt': [('blek', False)],
         'blekts': [('blek', False)],
         'blerad': [('blerad', False)],
         'blerade': [('blerad', False)],
         'bles': [('bel', False)],
         'bligare': [('blig', False)],
         'bligaste': [('blig', False)],
         'bligat': [('bligat', False)],
         'blika': [('blik', False)],
         'blikts': [('blik', False)],
         'blints': [('blind', False)],
         'bliven': [('bliven', False)],
         'blivna': [('bliven', False)],
         'blåst': [('blåst', False)],
         'blått': [('blå', False)],
         'blåtts': [('blå', False)],
         'blös': [('blös', False)],
         'blösts': [('blös', False)],
         'blöt': [('blöt', False)],
         'blöts': [('blöt', False)],
         'blött': [('blöt', True)],
         'blötts': [('blöt', True)],
         'bna': [('bel', False)],
         'bnas': [('bel', False)],
         'bne': [('bel', False)],
         'bnes': [('bel', False)],
         'bnästa': [('bnäst', False)],
         'bnästas': [('bnäst', False)],
         'bnäste': [('bnäst', False)],
         'bnästes': [('bnäst', False)],
         'bofast': [('bofast', True)],
         'bofaste': [('bofast', True)],
         'bofastes': [('bofast', True)],
         'bofasts': [('bofast', True)],
         'bolt': [('bol', False)],
         'bolts': [('bol', False)],
         'borrande': [('borrande', False)],
         'borterade': [('borterad', False)],
         'bortsett': [('bortse', True), ('bortsett', True)],
         'botande': [('bota', True)],
         'botts': [('bodd', False)],
         'bra': [('bra', False)],
         'brant': [('brant', False)],
         'brants': [('brant', True)],
         'brare': [('ber', False)],
         'brares': [('ber', False)],
         'bras': [('bra', True)],
         'breds': [('bred', False)],
         'brerade': [('brerad', False)],
         'bret': [('bred', False)],
         'brets': [('bred', False)],
         'brett': [('bred', True)],
         'bretts': [('bred', True)],
         'brukade': [('brukad', False)],
         'brunt': [('brun', False)],
         'brunts': [('brun', False)],
         'bryggts': [('bryggd', False)],
         'brytt': [('brydd', True)],
         'bräckts': [('bräckt', False)],
         'bränt': [('bränd', False)],
         'brått': [('bråd', True)],
         'bråtts': [('bråd', True)],
         'bstrakt': [('bstrakt', False)],
         'bstrakts': [('bstrakt', False)],
         'bsurt': [('bsurd', False)],
         'bsurts': [('bsurd', False)],
         'bt': [('b', False)],
         'btilts': [('btil', False)],
         'btänkt': [('btänkt', False)],
         'bubbade': [('bubbad', False)],
         'buerade': [('buerad', False)],
         'bulerande': [('bulera', False)],
         'bult': [('bul', False)],
         'bust': [('bust', False)],
         'buste': [('bust', False)],
         'busts': [('bust', False)],
         'bverkande': [('bverkande', False)],
         'bväxande': [('bväxande', False)],
         'byggd': [('bygga', True)],
         'byggt': [('bygga', True)],
         'bytt': [('bytt', False)],
         'bytte': [('bytt', False)],
         'bängts': [('bäng', True)],
         'bärgade': [('bärga', True)],
         'bäst': [('god', True), ('bäst', True), ('bra', True)],
         'bästa': [('bäst', True), ('bra', True), ('god', True)],
         'bästas': [('bäst', True), ('god', True), ('bra', True)],
         'bäste': [('bra', True), ('god', True), ('bäst', True)],
         'bästes': [('bäst', True), ('god', True), ('bra', True)],
         'bästs': [('god', True), ('bäst', True), ('bra', True)],
         'bättre': [('god', True), ('bra', True)],
         'bättres': [('god', True), ('bra', True)],
         'båda': [('båda', True)],
         'bålts': [('båld', True)],
         'böjda': [('böjd', False)],
         'bördes': [('bördes', False)],
         'calt': [('cal', False)],
         'cannat': [('cannad', False)],
         'cena': [('cen', False)],
         'cene': [('cen', False)],
         'cens': [('cen', False)],
         'cent': [('cent', False)],
         'cents': [('cent', False)],
         'cerat': [('cerad', False)],
         'ceriserat': [('ceriserad', False)],
         'ches': [('ch', False)],
         'chts': [('ch', False)],
         'cialiserade': [('cialiserad', False)],
         'cierad': [('cierad', False)],
         'cilla': [('cill', False)],
         'cille': [('cill', False)],
         'cilles': [('cill', False)],
         'cillts': [('cill', False)],
         'cilt': [('cil', False)],
         'ciserat': [('ciserad', False)],
         'cka': [('ck', False)],
         'ckad': [('ckad', False)],
         'ckade': [('ckad', False)],
         'ckande': [('ckande', False)],
         'ckats': [('ckad', False)],
         'ckes': [('ck', False)],
         'cket': [('cken', False)],
         'cklöst': [('cklös', False)],
         'cknat': [('cknad', False)],
         'cknes': [('cken', False)],
         'ckrat': [('ckrad', False)],
         'ckre': [('cker', False)],
         'ckres': [('cker', False)],
         'ckts': [('ck', False)],
         'ckurat': [('ckurat', False)],
         'crad': [('crad', False)],
         'crade': [('crad', False)],
         'crades': [('crad', False)],
         'crats': [('crad', False)],
         'ct': [('c', False)],
         'dabla': [('dabel', False)],
         'dagrant': [('dagrann', False)],
         'dags': [('dags', False)],
         'dalt': [('dal', False)],
         'dan': [('dan', True)],
         'dana': [('n', False)],
         'danlagda': [('danlagd', False)],
         'danpassat': [('danpassad', False)],
         'dant': [('dant', False)],
         'dante': [('dant', False)],
         'dants': [('dan', False)],
         'dat': [('dad', False)],
         'date': [('date', False)],
         'dbaserade': [('dbaserad', False)],
         'dbaserat': [('dbaserad', False)],
         'dcentrerade': [('dcentrerad', False)],
         'dd': [('dd', False)],
         'dda': [('dd', False)],
         'ddad': [('ddad', False)],
         'ddade': [('ddad', False)],
         'ddande': [('ddande', False)],
         'ddare': [('dd', False)],
         'ddas': [('dd', False)],
         'ddaste': [('dd', False)],
         'dde': [('dd', False)],
         'dderade': [('dderad', False)],
         'dderats': [('dderad', False)],
         'ddes': [('dd', False)],
         'ddlat': [('ddlad', False)],
         'ddrat': [('ddrad', False)],
         'dds': [('dd', False)],
         'ddömda': [('ddömd', False)],
         'delad': [('delad', True)],
         'delade': [('delad', True)],
         'delat': [('delad', False)],
         'delt': [('del', False)],
         'delts': [('delt', False)],
         'dement': [('dement', False)],
         'dements': [('dement', False)],
         'dens': [('den', False)],
         'dent': [('dent', False)],
         'dents': [('dent', False)],
         'deponerade': [('deponera', True)],
         'derande': [('dera', False)],
         'derat': [('derad', False)],
         'derbeskyddade': [('derbeskyddad', False)],
         'derkastade': [('derkasta', False)],
         'derligare': [('derlig', False)],
         'dernas': [('dernas', False)],
         'derne': [('dern', False)],
         'ders': [('ders', False)],
         'dersökta': [('dersöka', False)],
         'dest': [('dest', False)],
         'desta': [('dest', False)],
         'dests': [('dest', False)],
         'dextra': [('dexter', False)],
         'dformad': [('dformad', False)],
         'dformat': [('dformad', False)],
         'dfängts': [('dfängd', False)],
         'dfäst': [('dfästa', False)],
         'dfästa': [('dfästa', False)],
         'dfört': [('dförd', False)],
         'dförts': [('dförd', False)],
         'dgad': [('dgad', False)],
         'dgade': [('dgad', False)],
         'dgat': [('dga', False)],
         'dgats': [('dgad', False)],
         'dgjorda': [('dgjord', False)],
         'dgulares': [('dgul', False)],
         'dgående': [('dgående', False)],
         'dgången': [('dgången', False)],
         'dhäckande': [('dhäckande', False)],
         'diad': [('diad', False)],
         'diats': [('diad', False)],
         'dierad': [('dierad', False)],
         'dierande': [('dierande', False)],
         'difierad': [('difierad', False)],
         'digat': [('digad', False)],
         'digt': [('dig', False)],
         'dikat': [('dikad', False)],
         'dimensionerad': [('dimensionera', False)],
         'dinga': [('ding', True)],
         'dingare': [('ding', True)],
         'dingares': [('ding', True)],
         'dingast': [('ding', True)],
         'dingastes': [('ding', True)],
         'dingasts': [('ding', True)],
         'diserat': [('diserad', False)],
         'diskuterat': [('diskutera', True)],
         'djande': [('djande', False)],
         'dkad': [('dkad', False)],
         'dkade': [('dkad', False)],
         'dkallad': [('dkallad', False)],
         'dkats': [('dkad', False)],
         'dklippta': [('dklippt', False)],
         'dla': [('del', False)],
         'dlad': [('dlad', False)],
         'dlade': [('dlad', False)],
         'dlande': [('dlande', False)],
         'dlare': [('del', False)],
         'dlares': [('del', False)],
         'dlas': [('del', False)],
         'dlats': [('dlad', False)],
         'dle': [('del', False)],
         'dles': [('del', False)],
         'dligare': [('dlig', False)],
         'dligaste': [('dlig', False)],
         'dligats': [('dligad', False)],
         'dlika': [('dlik', False)],
         'dlikts': [('dlik', False)],
         'dlätt': [('dlätt', False)],
         'dlätts': [('dlätt', False)],
         'dlös': [('dlös', False)],
         'dlösts': [('dlös', False)],
         'dnande': [('dnande', False)],
         'dnats': [('dnad', False)],
         'dnära': [('dnära', False)],
         'dnästa': [('dnäst', False)],
         'dnästas': [('dnäst', False)],
         'dnäste': [('dnäst', False)],
         'dnästes': [('dnäst', False)],
         'dolents': [('dolent', False)],
         'dolt': [('dold', False)],
         'dolts': [('dold', False)],
         'dont': [('don', False)],
         'donts': [('don', False)],
         'dopat': [('dopad', False)],
         'doppad': [('doppa', True)],
         'dosams': [('dosam', False)],
         'dra': [('dra', False)],
         'drad': [('drad', False)],
         'drade': [('drad', False)],
         'drades': [('drad', False)],
         'drande': [('drande', False)],
         'dras': [('dra', False)],
         'drats': [('drad', False)],
         'drerade': [('drerad', False)],
         'dres': [('dre', False)],
         'drikes': [('drik', False)],
         'drikts': [('drik', False)],
         'dräknat': [('dräknad', False)],
         'drätt': [('drät', False)],
         'drätts': [('drät', False)],
         'drött': [('dröd', False)],
         'drötts': [('dröd', False)],
         'dsad': [('dsad', False)],
         'dsade': [('dsad', False)],
         'dsakade': [('dsakad', False)],
         'dsamma': [('dsam', False)],
         'dsams': [('dsam', False)],
         'dskadad': [('dskadad', False)],
         'dskadade': [('dskadad', False)],
         'dskalad': [('dskalad', False)],
         'dskat': [('dskad', False)],
         'dskrivet': [('dskriven', False)],
         'dskyddad': [('dskyddad', False)],
         'dskyddade': [('dskyddad', False)],
         'dskällt': [('dskälld', False)],
         'dskällts': [('dskälld', False)],
         'dslös': [('dslös', False)],
         'dsmorda': [('dsmord', False)],
         'dsnare': [('dsen', False)],
         'dsnares': [('dsen', False)],
         'dstrött': [('dstrött', False)],
         'dströtts': [('dstrött', False)],
         'dstämd': [('dstämd', False)],
         'dstörande': [('dstörande', False)],
         'dstött': [('dstött', False)],
         'dt': [('d', False)],
         'dtryckt': [('dtryckt', False)],
         'dtvingad': [('dtvingad', False)],
         'dubbade': [('dubba', True)],
         'duerade': [('duerad', False)],
         'dvarmt': [('dvarm', False)],
         'dverkande': [('dverkande', False)],
         'dvist': [('dvis', False)],
         'dvists': [('dvis', False)],
         'dvit': [('dvit', False)],
         'dvitt': [('dvit', False)],
         'dvitts': [('dvit', False)],
         'dvunnet': [('dvunnen', False)],
         'dvänt': [('dvänd', False)],
         'dvänts': [('dvänd', False)],
         'dväxande': [('dväxande', False)],
         'dyrt': [('dyr', False)],
         'dyrts': [('dyr', False)],
         'dämd': [('dämd', False)],
         'dämpande': [('dämpande', False)],
         'dämts': [('dämd', False)],
         'dängt': [('dängd', False)],
         'dänkt': [('dänkt', False)],
         'dänt': [('dän', False)],
         'dänts': [('dän', False)],
         'dära': [('där', False)],
         'därt': [('där', False)],
         'däst': [('däst', True)],
         'dästa': [('däst', True)],
         'dästas': [('däst', True)],
         'däste': [('däst', True)],
         'dästes': [('däst', True)],
         'dödade': [('döda', True)],
         'döde': [('död', False)],
         'dögts': [('dögd', False)],
         'dömda': [('döma', True)],
         'dömt': [('dömd', False)],
         'dömts': [('dömd', False)],
         'dött': [('död', False)],
         'dötts': [('död', False)],
         'dövt': [('döv', False)],
         'e': [('', False)],
         'eabla': [('eabel', False)],
         'ealt': [('eal', False)],
         'eants': [('ean', False)],
         'earat': [('earad', False)],
         'earbetande': [('earbetande', False)],
         'eat': [('ead', False)],
         'ebaserade': [('ebaserad', False)],
         'ebaserat': [('ebaserad', False)],
         'ebliven': [('ebli', False)],
         'eblivna': [('ebli', False)],
         'ebra': [('eber', False)],
         'ebras': [('eber', False)],
         'ebyggd': [('ebyggd', False)],
         'ebyggt': [('ebyggd', False)],
         'eckad': [('ecka', False)],
         'eckade': [('ecka', False)],
         'ed': [('ed', False)],
         'eda': [('ed', False)],
         'edad': [('edad', False)],
         'edade': [('edad', False)],
         'edande': [('edande', False)],
         'edare': [('ed', False)],
         'edas': [('ed', False)],
         'edaste': [('ed', False)],
         'ede': [('ed', False)],
         'eden': [('eden', False)],
         'ederade': [('ederad', False)],
         'ederats': [('ederad', False)],
         'edes': [('ed', False)],
         'edfäst': [('edfäst', True)],
         'edfästa': [('edfäst', True)],
         'edgat': [('edgad', False)],
         'edlat': [('edlad', False)],
         'edrat': [('edrad', False)],
         'edre': [('edre', False)],
         'eds': [('ed', False)],
         'edömda': [('edömd', False)],
         'ee': [('ee', False)],
         'eellare': [('eell', False)],
         'eellares': [('eell', False)],
         'eende': [('eende', False)],
         'eerat': [('eerad', False)],
         'eet': [('eet', False)],
         'eformad': [('eformad', False)],
         'eformat': [('eformad', False)],
         'efängts': [('efängd', False)],
         'eförebyggande': [('eförebyggande', False)],
         'ega': [('eg', False)],
         'egad': [('egad', False)],
         'egade': [('egad', False)],
         'egaliserade': [('egaliserad', False)],
         'egant': [('egan', False)],
         'egants': [('egant', False)],
         'egare': [('eg', False)],
         'egares': [('eg', False)],
         'egas': [('eg', False)],
         'egast': [('eg', False)],
         'egaste': [('eg', False)],
         'egastes': [('eg', False)],
         'egasts': [('eg', False)],
         'egats': [('egad', False)],
         'ege': [('eg', False)],
         'egen': [('egen', False)],
         'egerad': [('egerad', False)],
         'eges': [('eg', False)],
         'eget': [('egen', False)],
         'egets': [('egen', False)],
         'eglatt': [('eglad', False)],
         'eglatts': [('eglad', False)],
         'egna': [('egen', True)],
         'egnare': [('egen', False)],
         'egnares': [('egen', False)],
         'egnas': [('egen', False)],
         'egnast': [('egen', False)],
         'egnaste': [('egen', False)],
         'egnastes': [('egen', True)],
         'egnasts': [('egen', False)],
         'egne': [('egen', False)],
         'egnes': [('egen', True)],
         'egott': [('egod', False)],
         'egrade': [('egra', False)],
         'egs': [('eg', False)],
         'egts': [('eg', False)],
         'egulares': [('egul', False)],
         'egärt': [('egärd', False)],
         'egärts': [('egär', False)],
         'egående': [('egående', False)],
         'egången': [('egången', False)],
         'eiga': [('eige', False)],
         'eigare': [('eige', False)],
         'eigares': [('eige', False)],
         'eigas': [('eige', False)],
         'eigast': [('eige', False)],
         'eigaste': [('eige', False)],
         'eigastes': [('eige', False)],
         'eigasts': [('eige', False)],
         'eige': [('eige', False)],
         'eiges': [('eige', False)],
         'eiget': [('eige', False)],
         'eigets': [('eige', False)],
         'eigt': [('eige', False)],
         'eigts': [('eige', False)],
         'einrikes': [('einrik', False)],
         'eiserat': [('eiserad', False)],
         'eje': [('ej', False)],
         'ejt': [('ejd', False)],
         'ejts': [('ej', False)],
         'eka': [('ek', False)],
         'ekad': [('ekad', False)],
         'ekade': [('ekad', False)],
         'ekande': [('ekande', False)],
         'ekats': [('ekad', False)],
         'ekes': [('ek', False)],
         'eklöst': [('eklös', False)],
         'eknat': [('eknad', False)],
         'ekt': [('ekt', False)],
         'ekts': [('ek', False)],
         'ekärts': [('ekär', False)],
         'ela': [('el', False)],
         'elad': [('elad', False)],
         'elade': [('elad', False)],
         'elande': [('elande', False)],
         'elare': [('el', False)],
         'elares': [('el', False)],
         'elas': [('el', False)],
         'elast': [('el', False)],
         'elaste': [('el', False)],
         'elastes': [('el', False)],
         'elasts': [('el', False)],
         'elats': [('elad', False)],
         'ele': [('el', False)],
         'elerad': [('elerad', False)],
         'elerade': [('elerad', False)],
         'eles': [('el', False)],
         'elet': [('elen', False)],
         'elets': [('elen', False)],
         'eligare': [('elig', False)],
         'eligaste': [('elig', False)],
         'elika': [('elik', False)],
         'elikat': [('elikat', False)],
         'elint': [('elin', False)],
         'ellas': [('ell', False)],
         'ellt': [('ell', False)],
         'ellärt': [('ellär', False)],
         'elne': [('elen', False)],
         'elrätt': [('elrätt', False)],
         'elrätts': [('elrät', False)],
         'els': [('el', False)],
         'eltes': [('elt', False)],
         'elts': [('el', False)],
         'elvant': [('elvan', False)],
         'elvants': [('elvan', False)],
         'elända': [('elända', True)],
         'elös': [('elös', False)],
         'elösts': [('elös', False)],
         'ema': [('em', False)],
         'emad': [('emad', False)],
         'emade': [('emad', False)],
         'emare': [('em', False)],
         'emares': [('em', False)],
         'emas': [('em', False)],
         'emast': [('em', False)],
         'emaste': [('em', False)],
         'emastes': [('em', False)],
         'emasts': [('em', False)],
         'emats': [('emad', False)],
         'eme': [('em', False)],
         'ement': [('emen', False)],
         'ements': [('emen', False)],
         'emes': [('em', False)],
         'emma': [('em', False)],
         'emmat': [('emmad', False)],
         'ems': [('em', False)],
         'emts': [('em', False)],
         'emält': [('emäld', False)],
         'emälta': [('emälta', False)],
         'emältas': [('emälta', False)],
         'emälte': [('emälta', False)],
         'emärkt': [('emärkt', False)],
         'emärkta': [('emärkt', False)],
         'emärts': [('emär', False)],
         'en': [('en', False)],
         'en-': [('en', False)],
         'ena': [('ena', True)],
         'enad': [('enad', False)],
         'enade': [('enad', False)],
         'enande': [('enande', False)],
         'enare': [('en', False)],
         'enares': [('en', False)],
         'enas': [('en', False)],
         'enast': [('en', False)],
         'enaste': [('en', False)],
         'enastes': [('en', False)],
         'enasts': [('en', False)],
         'enats': [('enad', False)],
         'enda': [('enda', True)],
         'endas': [('enda', True)],
         'endaste': [('endaste', True)],
         'ende': [('enda', True)],
         'endes': [('enda', True)],
         'ene': [('ena', True)],
         'enerad': [('enerad', False)],
         'enerade': [('enerad', False)],
         'enes': [('en', False)],
         'enfört': [('enför', False)],
         'enförts': [('enför', False)],
         'enklad': [('enklad', False)],
         'enklare': [('enkel', False)],
         'enna': [('enn', False)],
         'ennas': [('enn', False)],
         'ennastes': [('enn', False)],
         'ennat': [('ennad', False)],
         'enne': [('enn', False)],
         'ennes': [('enn', False)],
         'enodlad': [('enodla', False)],
         'enodlat': [('enodlad', False)],
         'enoterad': [('enoterad', False)],
         'ens': [('ens', True)],
         'ensionerad': [('ensionerad', False)],
         'enskad': [('enskad', False)],
         'enskade': [('enskad', False)],
         'entants': [('entan', False)],
         'entima': [('entima', False)],
         'entrad': [('entrad', False)],
         'enämnda': [('enämnd', False)],
         'enämndas': [('enämnd', False)],
         'enämndes': [('enämnd', False)],
         'eolare': [('eolar', False)],
         'eolares': [('eolar', False)],
         'epad': [('epad', False)],
         'epade': [('epad', False)],
         'epande': [('epande', False)],
         'eperade': [('eperad', False)],
         'eperats': [('eperad', False)],
         'eperbare': [('eperbar', False)],
         'eperbares': [('eperbar', False)],
         'eplacerad': [('eplacerad', False)],
         'eplacerade': [('eplacerad', False)],
         'eppat': [('eppad', False)],
         'erad': [('erad', False)],
         'erade': [('erad', False)],
         'erades': [('erad', False)],
         'erande': [('erande', False)],
         'erant': [('erant', False)],
         'erants': [('erant', False)],
         'erare': [('er', False)],
         'erares': [('er', False)],
         'eras': [('er', False)],
         'erast': [('er', False)],
         'eraste': [('er', False)],
         'erastes': [('er', False)],
         'erasts': [('er', False)],
         'erats': [('erad', False)],
         'erbare': [('erbar', False)],
         'erbares': [('erbar', False)],
         'erbeskyddade': [('erbeskydda', False)],
         'ere': [('er', False)],
         'eredande': [('eredande', False)],
         'erens': [('erens', False)],
         'erent': [('eren', False)],
         'erents': [('erenn', False)],
         'ererade': [('ererad', False)],
         'eres': [('er', False)],
         'erett': [('eredd', False)],
         'ergent': [('ergen', False)],
         'ergents': [('ergen', False)],
         'erikats': [('erikad', False)],
         'erikes': [('erik', False)],
         'erikts': [('erik', False)],
         'eriterande': [('eriterande', False)],
         'erkastade': [('erkastad', False)],
         'erlämnad': [('erlämnad', False)],
         'erlöst': [('erlös', False)],
         'ermt': [('erm', False)],
         'ernas': [('ern', False)],
         'erne': [('erne', False)],
         'erobare': [('erob', False)],
         'erobares': [('erob', False)],
         'errans': [('errans', False)],
         'ers': [('er', False)],
         'ersalt': [('ersalt', False)],
         'ersalts': [('ersalt', False)],
         'ersatta': [('ersatt', False)],
         'ersta': [('re', False)],
         'erstas': [('re', False)],
         'erste': [('re', False)],
         'erstes': [('re', False)],
         'ersänt': [('ersända', False)],
         'ersökta': [('ersökt', False)],
         'ert': [('ert', False)],
         'erts': [('er', False)],
         'eräknat': [('eräknad', False)],
         'eränts': [('erän', False)],
         'erått': [('eråda', False)],
         'erötts': [('eröd', False)],
         'es': [('', False)],
         'esa': [('es', False)],
         'esad': [('esad', False)],
         'esade': [('esad', False)],
         'esamma': [('esam', False)],
         'esams': [('esam', False)],
         'esande': [('esande', False)],
         'escent': [('escent', False)],
         'escents': [('escent', False)],
         'ese': [('es', False)],
         'esent': [('esent', False)],
         'esents': [('esent', False)],
         'esett': [('esedd', False)],
         'eskadad': [('eskadad', False)],
         'eskadade': [('eskadad', False)],
         'eskrivna': [('eskriva', False)],
         'eskyddad': [('eskyddad', False)],
         'eskyddade': [('eskyddad', False)],
         'eskyddande': [('eskyddande', False)],
         'eskärt': [('eskärd', False)],
         'eskärts': [('eskärd', False)],
         'eslös': [('eslös', False)],
         'esparat': [('esparad', False)],
         'essat': [('essad', False)],
         'esslös': [('esslö', False)],
         'est': [('es', False)],
         'esta': [('ycken', False)],
         'estabiliserat': [('estabiliserad', False)],
         'estolts': [('estolt', False)],
         'estritt': [('estridd', False)],
         'estritts': [('estridd', False)],
         'estrött': [('eströdd', False)],
         'eströtts': [('estrött', False)],
         'ests': [('es', False)],
         'eställande': [('eställande', False)],
         'estämd': [('estämd', False)],
         'estört': [('estört', False)],
         'estörts': [('estört', False)],
         'et': [('en', False)],
         'eta': [('et', False)],
         'etad': [('etad', False)],
         'etade': [('etad', False)],
         'etagande': [('etagande', False)],
         'etalade': [('etalad', False)],
         'etalts': [('etal', False)],
         'etande': [('etande', False)],
         'etas': [('et', False)],
         'ete': [('et', False)],
         'eterad': [('eterad', False)],
         'eterade': [('eterad', False)],
         'eterats': [('eterad', False)],
         'etes': [('et', False)],
         'etet': [('eten', False)],
         'etna': [('eten', False)],
         'etryckt': [('etryckt', False)],
         'eträngt': [('eträngd', False)],
         'etrött': [('etrött', False)],
         'ets': [('en', False)],
         'ett': [('ett', True)],
         'etta': [('etta', False)],
         'etterat': [('etterad', False)],
         'ettlösts': [('ettlös', False)],
         'etts': [('et', False)],
         'etvingad': [('etvingad', False)],
         'etäckt': [('etäckt', False)],
         'etäckts': [('etäckt', False)],
         'etänkt': [('etänkt', False)],
         'etärt': [('etär', False)],
         'etärts': [('etär', False)],
         'eva': [('ev', False)],
         'evalda': [('evald', False)],
         'evalt': [('evald', False)],
         'evande': [('evande', False)],
         'evant': [('evant', False)],
         'evants': [('evant', False)],
         'evats': [('evad', False)],
         'eve': [('ev', False)],
         'evens': [('even', False)],
         'eviga': [('evig', True)],
         'evigas': [('evig', True)],
         'evigaste': [('evig', True)],
         'evigastes': [('evig', True)],
         'evigts': [('evig', False)],
         'evisad': [('evisad', False)],
         'evisade': [('evisad', False)],
         'evitt': [('evit', False)],
         'evitts': [('evit', False)],
         'evs': [('ev', False)],
         'evt': [('evd', False)],
         'evts': [('ev', False)],
         'evänt': [('evänt', False)],
         'evärt': [('evärd', False)],
         'exerad': [('exerad', False)],
         'exerade': [('exerad', False)],
         'extra': [('extra', True)],
         'exts': [('ex', False)],
         'eära': [('eär', False)],
         'eärt': [('eär', False)],
         'fagrare': [('fager', False)],
         'fagrares': [('fager', False)],
         'fagt': [('fag', False)],
         'fallt': [('falld', False)],
         'falt': [('fal', False)],
         'fants': [('fan', False)],
         'farat': [('farad', False)],
         'fas': [('fas', False)],
         'fast': [('fast', False)],
         'fastas': [('fast', False)],
         'faste': [('fast', False)],
         'fastes': [('fast', False)],
         'fasts': [('fast', False)],
         'fat': [('fad', False)],
         'fatt': [('fatt', False)],
         'fatta': [('fatt', False)],
         'fattande': [('fattande', False)],
         'fd': [('fd', True)],
         'fektive': [('fektiv', False)],
         'fekts': [('fekt', False)],
         'felat': [('felad', False)],
         'fena': [('fena', True)],
         'fer': [('fer', False)],
         'fera': [('fer', False)],
         'ferat': [('ferad', False)],
         'ferent': [('ferent', False)],
         'ferents': [('ferent', False)],
         'fert': [('fer', False)],
         'fest': [('fest', False)],
         'festa': [('fest', False)],
         'fests': [('fest', False)],
         'fet': [('fet', False)],
         'fets': [('fet', True)],
         'fett': [('fet', True)],
         'ffas': [('ff', False)],
         'ffast': [('ff', False)],
         'ffaste': [('ff', False)],
         'ffastes': [('ff', False)],
         'ffasts': [('ff', False)],
         'fflat': [('fflad', False)],
         'fflats': [('fflad', False)],
         'ffts': [('ff', False)],
         'fierad': [('fierad', False)],
         'figt': [('fig', False)],
         'fikt': [('fik', False)],
         'filare': [('filar', False)],
         'filares': [('filar', False)],
         'filt': [('fil', False)],
         'finat': [('finad', False)],
         'fint': [('fin', False)],
         'fints': [('fin', False)],
         'fjärts': [('fjär', True)],
         'flad': [('flad', False)],
         'flade': [('flad', False)],
         'flande': [('flande', False)],
         'flat': [('flat', True)],
         'flats': [('flat', True)],
         'flera': [('mången', True), ('flera', True)],
         'flerad': [('flerad', False)],
         'flerade': [('flerad', False)],
         'flesta': [('mången', True)],
         'fligare': [('flig', False)],
         'fligaste': [('flig', False)],
         'flikats': [('flikad', True)],
         'flugna': [('flugen', False)],
         'flugnare': [('flugen', False)],
         'flugnares': [('flugen', False)],
         'flugnas': [('flugen', False)],
         'flugnast': [('flugen', False)],
         'flugnaste': [('flugen', False)],
         'flugnastes': [('flugen', False)],
         'flugnasts': [('flugen', False)],
         'flugne': [('flugen', False)],
         'flugnes': [('flugen', False)],
         'flutet': [('fluten', False)],
         'flutna': [('fluten', False)],
         'flygande': [('flyga', True)],
         'flytande': [('flyta', True)],
         'flängd': [('flängd', False)],
         'flängda': [('flängd', False)],
         'flängt': [('fläng', True)],
         'flängts': [('fläng', True)],
         'flös': [('flös', False)],
         'fogat': [('fogad', False)],
         'folkade': [('folkad', False)],
         'font': [('fon', False)],
         'fonts': [('fon', False)],
         'fore': [('for', False)],
         'formad': [('forma', True)],
         'formade': [('formad', False)],
         'formulerad': [('formulera', True)],
         'forna': [('forn', True)],
         'fornare': [('forn', True)],
         'fornares': [('forn', True)],
         'fornas': [('forn', True)],
         'fornast': [('forn', True)],
         'fornaste': [('forn', True)],
         'fornastes': [('forn', True)],
         'fornasts': [('forn', True)],
         'forne': [('forn', True)],
         'fornes': [('forn', True)],
         'fort': [('for', False)],
         'forts': [('for', False)],
         'fota': [('fota', False)],
         'frad': [('frad', False)],
         'frade': [('frad', False)],
         'frades': [('frad', False)],
         'framförd': [('framföra', True)],
         'framställt': [('framställa', True)],
         'frande': [('frande', False)],
         'frats': [('frad', False)],
         'frent': [('fren', False)],
         'frents': [('fren', False)],
         'frerade': [('frerad', False)],
         'fritt': [('fri', False)],
         'fritts': [('fri', False)],
         'fryst': [('fryst', True)],
         'fräckt': [('fräck', True)],
         'fränts': [('frän', True)],
         'frätts': [('frätt', False)],
         'fsad': [('fsad', False)],
         'fsade': [('fsad', False)],
         'ft': [('f', False)],
         'fta': [('ft', False)],
         'ftad': [('ftad', False)],
         'ftade': [('ftad', False)],
         'ftande': [('ftande', False)],
         'ftas': [('ft', False)],
         'fte': [('ft', False)],
         'ftes': [('ft', False)],
         'ftlöst': [('ftlös', False)],
         'ftrikt': [('ftrik', False)],
         'fts': [('ft', False)],
         'fult': [('ful', True)],
         'funna': [('funnen', False)],
         'funnas': [('funnen', False)],
         'funnastes': [('funnen', False)],
         'funne': [('funnen', False)],
         'funnes': [('funnen', False)],
         'funnet': [('funnen', False)],
         'fyllt': [('fylld', False)],
         'fägnad': [('fägnad', False)],
         'fällande': [('fällande', False)],
         'fällt': [('fälld', False)],
         'fängt': [('fängd', False)],
         'fängts': [('fäng', False)],
         'färdad': [('färdad', False)],
         'färgade': [('färgad', False)],
         'färmare': [('färm', True)],
         'färmares': [('färm', True)],
         'färmast': [('färm', True)],
         'färmaste': [('färm', True)],
         'färmastes': [('färm', True)],
         'färmasts': [('färm', True)],
         'färmts': [('färm', True)],
         'fäst': [('fäst', False)],
         'fästa': [('fäst', False)],
         'fästas': [('fäst', False)],
         'fäste': [('fäst', False)],
         'fästes': [('fäst', False)],
         'fådda': [('fådd', False)],
         'fåmält': [('fåmält', True), ('fåmäld', True)],
         'fåmälts': [('fåmäld', True), ('fåmält', True)],
         'fångade': [('fånga', True)],
         'fången': [('fången', False)],
         'fått': [('fådd', False)],
         'fåtts': [('fådd', False)],
         'föga': [('föga', True)],
         'följande': [('följande', False)],
         'fönat': [('fönad', False)],
         'förankrat': [('förankra', True)],
         'förbrukade': [('förbruka', True)],
         'förd': [('förd', False)],
         'förda': [('förd', False)],
         'fördas': [('förd', False)],
         'förde': [('förd', False)],
         'fördelade': [('fördela', True)],
         'fördelat': [('fördela', True)],
         'fördes': [('förd', False)],
         'fördjupad': [('fördjupa', True)],
         'förebyggande': [('förebygga', True)],
         'förenade': [('förena', True), ('förenade', True)],
         'förenklad': [('förenkla', True)],
         'förklarad': [('förklarad', True)],
         'förknippat': [('förknippa', True)],
         'förlängd': [('förlänga', True)],
         'förlängda': [('förlänga', True)],
         'förnedrande': [('förnedra', True)],
         'förorsakade': [('förorsaka', True)],
         'förre': [('förra', True)],
         'förres': [('förra', True)],
         'första': [('första', False)],
         'förstas': [('första', False)],
         'förste': [('första', False)],
         'förstes': [('första', True)],
         'förstorade': [('förstora', True)],
         'försvinnande': [('försvinnande', True), ('försvinna', True)],
         'försäkrad': [('försäkra', True)],
         'försäkrades': [('försäkra', True)],
         'fört': [('för', False)],
         'förtretad': [('förtreta', True)],
         'förts': [('för', False)],
         'förvärvsarbetande': [('förvärvsarbeta', True), ('förvärvsarbetande', True)],
         'förändrad': [('förändra', True)],
         'förändrade': [('förändra', True)],
         'förändrat': [('förändra', True)],
         'föst': [('föst', False)],
         'fösts': [('föst', False)],
         'fötts': [('född', False)],
         'galt': [('gal', False)],
         'gammalts': [('gammal', False)],
         'ganrikat': [('ganrikad', False)],
         'gant': [('gant', False)],
         'gante': [('gant', False)],
         'garanterad': [('garantera', True)],
         'garat': [('garad', False)],
         'gastas': [('gast', False)],
         'gat': [('gad', False)],
         'gavlönat': [('gavlönad', False)],
         'gbehandlade': [('gbehandlad', False)],
         'gbyggd': [('gbyggd', False)],
         'gbyggt': [('gbyggd', False)],
         'gd': [('gd', False)],
         'gda': [('gd', False)],
         'gdare': [('gd', False)],
         'gdas': [('gd', False)],
         'gdaste': [('gd', False)],
         'gde': [('gd', False)],
         'gdelade': [('gdelad', False)],
         'gdes': [('gd', False)],
         'gds': [('gd', False)],
         'gelrätts': [('gelrätt', False)],
         'gen': [('gen', True)],
         'gena': [('gen', False)],
         'gene': [('gen', False)],
         'genodlad': [('genodlad', False)],
         'genomförd': [('genomföra', True)],
         'gens': [('gen', False)],
         'gent': [('gen', True)],
         'genterad': [('genterad', False)],
         'genterade': [('genterad', False)],
         'gents': [('gen', True)],
         'ger': [('ger', False)],
         'gerat': [('gerad', False)],
         'gerligare': [('gerlig', False)],
         'gert': [('ger', False)],
         'gflytande': [('gflytande', False)],
         'gformad': [('gformad', False)],
         'gformat': [('gformad', False)],
         'gga': [('gg', False)],
         'ggad': [('ggad', False)],
         'ggade': [('ggad', False)],
         'ggande': [('ggande', False)],
         'ggare': [('gg', False)],
         'ggares': [('gg', False)],
         'ggas': [('gg', False)],
         'ggast': [('gg', False)],
         'ggaste': [('gg', False)],
         'ggastes': [('gg', False)],
         'ggasts': [('gg', False)],
         'ggats': [('ggad', False)],
         'gge': [('gg', False)],
         'ggen': [('ggen', False)],
         'gges': [('gg', False)],
         'gget': [('ggen', False)],
         'ggets': [('ggen', False)],
         'gglatt': [('gglad', False)],
         'gglatts': [('gglad', False)],
         'ggna': [('ggen', False)],
         'ggnare': [('ggen', False)],
         'ggnares': [('ggen', False)],
         'ggnas': [('ggen', False)],
         'ggnast': [('ggen', False)],
         'ggnaste': [('ggen', False)],
         'ggnastes': [('ggen', False)],
         'ggnasts': [('ggen', False)],
         'ggne': [('ggen', False)],
         'ggnes': [('ggen', False)],
         'ggrants': [('ggrann', False)],
         'ggs': [('gg', False)],
         'ggts': [('gg', False)],
         'ggående': [('ggående', False)],
         'ghalt': [('ghalt', False)],
         'ghalts': [('ghalt', False)],
         'ght': [('ght', False)],
         'gierad': [('gierad', False)],
         'gigat': [('gigad', False)],
         'gigt': [('gig', False)],
         'gilla': [('gill', False)],
         'gille': [('gill', False)],
         'gilles': [('gill', False)],
         'gillts': [('gill', False)],
         'gilt': [('gil', False)],
         'gint': [('gin', False)],
         'gints': [('gin', False)],
         'giserat': [('giserad', False)],
         'given': [('given', False)],
         'givet': [('given', False)],
         'givna': [('given', False)],
         'gjord': [('gjord', False)],
         'gjorda': [('göra', True)],
         'gkört': [('gkörd', False)],
         'gkörts': [('gkörd', False)],
         'glad': [('glad', False)],
         'glade': [('glad', False)],
         'glande': [('glande', False)],
         'glat': [('glad', False)],
         'glats': [('glad', False)],
         'glatt': [('glatt', True), ('glad', True)],
         'glatts': [('glatt', True), ('glad', True)],
         'glerad': [('glerad', False)],
         'glerade': [('glerad', False)],
         'glerande': [('glerande', False)],
         'gles': [('gles', True)],
         'glest': [('gles', True)],
         'glests': [('gles', True)],
         'gligare': [('glig', False)],
         'gligaste': [('glig', False)],
         'glika': [('glik', False)],
         'glikts': [('glik', False)],
         'gliserade': [('gliserad', False)],
         'glänts': [('glänt', False)],
         'glärt': [('glärd', False)],
         'glös': [('glös', False)],
         'glösts': [('glös', False)],
         'gmalt': [('gmald', False)],
         'gmält': [('gmäld', False)],
         'gn': [('gn', False)],
         'gn-': [('gn', False)],
         'gnad': [('gnad', False)],
         'gnade': [('gnad', False)],
         'gnande': [('gnande', False)],
         'gnats': [('gnad', False)],
         'gnerad': [('gnerad', False)],
         'gnerade': [('gnerad', False)],
         'gns': [('gn', False)],
         'gnt': [('gn', False)],
         'gnts': [('gn', False)],
         'gnästa': [('gnäst', False)],
         'gnästas': [('gnäst', False)],
         'gnäste': [('gnäst', False)],
         'gnästes': [('gnäst', False)],
         'gonde': [('gonde', False)],
         'gos': [('go', True)],
         'gott': [('gott', True), ('god', True)],
         'gotts': [('god', False)],
         'gprytt': [('gprydd', False)],
         'gprytts': [('gprydd', False)],
         'grad': [('grad', False)],
         'grade': [('grad', False)],
         'grades': [('grad', False)],
         'grafast': [('graf', False)],
         'grafaste': [('graf', False)],
         'grafastes': [('graf', False)],
         'grafasts': [('graf', False)],
         'grakts': [('grak', False)],
         'grant': [('grann', True)],
         'grants': [('grann', True)],
         'grare': [('ger', False)],
         'grats': [('grad', False)],
         'gre': [('g', False)],
         'gregerad': [('gregerad', False)],
         'grenade': [('grenad', True)],
         'grerade': [('grerad', False)],
         'gres': [('g', False)],
         'grikes': [('grik', False)],
         'grikts': [('grik', False)],
         'grupperade': [('gruppera', True)],
         'grymts': [('grym', True)],
         'gräknat': [('gräknad', False)],
         'gränt': [('gränd', False)],
         'grätt': [('grät', False)],
         'grätts': [('grät', False)],
         'grävt': [('grävd', False)],
         'grått': [('grå', False)],
         'gråtts': [('grå', False)],
         'grönt': [('grön', False)],
         'grönts': [('grön', False)],
         'grött': [('gröd', False)],
         'gsamma': [('gsam', False)],
         'gsams': [('gsam', False)],
         'gserade': [('gserad', False)],
         'gsittande': [('gsittande', False)],
         'gskaftad': [('gskaftad', False)],
         'gskiftande': [('gskiftande', False)],
         'gskrivet': [('gskriven', False)],
         'gslös': [('gslös', False)],
         'gsnare': [('gsen', False)],
         'gsnares': [('gsen', False)],
         'gsställande': [('gställande', False)],
         'gst': [('g', False)],
         'gsta': [('g', False)],
         'gstas': [('g', False)],
         'gste': [('gste', False)],
         'gstes': [('g', False)],
         'gstrött': [('gstrött', False)],
         'gströtts': [('gstrött', False)],
         'gsts': [('g', False)],
         'gstäckt': [('gstäckt', False)],
         'gstämd': [('gstämd', False)],
         'gt': [('g', False)],
         'gta': [('gt', False)],
         'gtad': [('gtad', False)],
         'gtade': [('gtad', False)],
         'gtande': [('gtande', False)],
         'gtas': [('gt', False)],
         'gte': [('gt', False)],
         'gterad': [('gterad', False)],
         'gterade': [('gterad', False)],
         'gterats': [('gterad', False)],
         'gtes': [('gt', False)],
         'gtilts': [('gtil', False)],
         'gts': [('gd', False)],
         'gtänkt': [('gtänkt', False)],
         'guerade': [('guerad', False)],
         'gulare': [('gul', True)],
         'gulares': [('gul', True)],
         'gult': [('gul', False)],
         'guterat': [('guterad', False)],
         'gvigt': [('gvigd', False)],
         'gvigts': [('gvigd', False)],
         'gvist': [('gvis', False)],
         'gvunnet': [('gvunnen', False)],
         'gyllne': [('gyllne', True)],
         'gyllt': [('gylld', False)],
         'gynts': [('gyn', False)],
         'gällts': [('gäll', True)],
         'gära': [('gär', False)],
         'gärdad': [('gärdad', False)],
         'gärde': [('gärd', False)],
         'gärt': [('gär', False)],
         'gående': [('gå', True)],
         'gången': [('gång', True)],
         'gögts': [('gögd', False)],
         'gökad': [('gökad', False)],
         'gökade': [('gökad', False)],
         'gökat': [('gökad', False)],
         'gömda': [('gömd', False)],
         'gömt': [('gömd', False)],
         'gömts': [('gömd', False)],
         'gött': [('gött', True), ('gödd', True)],
         'götts': [('gödd', True)],
         'hakat': [('hakad', False)],
         'halstrad': [('halstrad', False)],
         'halt': [('hal', True), ('halt', True)],
         'halts': [('hal', True), ('halt', True)],
         'hanterad': [('hanterad', False)],
         'hastade': [('hastad', False)],
         'hat': [('had', False)],
         'havts': [('havd', False)],
         'heckad': [('heckad', False)],
         'heckade': [('heckad', False)],
         'hedrande': [('hedrande', True)],
         'helat': [('helad', False)],
         'heligaste': [('helig', True)],
         'helt': [('hel', True)],
         'hemma': [('hemma', True)],
         'her': [('her', False)],
         'herande': [('hera', False)],
         'herat': [('herad', False)],
         'herent': [('herent', False)],
         'herents': [('herent', False)],
         'hes': [('hes', True)],
         'het': [('het', True)],
         'hets': [('het', False)],
         'hetsande': [('hetsande', False)],
         'hett': [('het', False)],
         'higt': [('hig', False)],
         'hippt': [('hipp', True)],
         'hippts': [('hipp', True)],
         'hite': [('hite', False)],
         'hivat': [('hivad', False)],
         'hjärtas': [('hjärtas', True)],
         'hklares': [('hklar', False)],
         'hligare': [('hlig', False)],
         'hligaste': [('hlig', False)],
         'hopat': [('hopad', False)],
         'hoppad': [('hoppad', False)],
         'hprytt': [('hprydd', False)],
         'hprytts': [('hprydd', False)],
         'ht': [('h', False)],
         'hta': [('ht', False)],
         'htas': [('ht', False)],
         'hte': [('ht', False)],
         'htes': [('ht', False)],
         'hts': [('ht', False)],
         'hult': [('huld', True)],
         'hults': [('huld', True)],
         'hundrade': [('hundrade', True)],
         'hyllts': [('hyllt', False)],
         'hyrt': [('hyrd', False)],
         'hyrts': [('hyrd', False)],
         'hyst': [('hyst', False)],
         'hysts': [('hyst', False)],
         'häckande': [('häcka', True)],
         'hägnad': [('hägna', True)],
         'hällt': [('hälld', False)],
         'hämnad': [('hämnad', False)],
         'hämtade': [('hämta', True)],
         'hämtat': [('hämta', True)],
         'hängt': [('hängd', False)],
         'hänt': [('hänt', False)],
         'hänvisad': [('hänvisa', True)],
         'härdad': [('härdad', False)],
         'hävts': [('hävd', False)],
         'hållande': [('hållande', False)],
         'hårlösts': [('hårlös', True)],
         'högt': [('hög', False)],
         'höjda': [('höja', True)],
         'hörd': [('hörd', False)],
         'hörda': [('hörd', False)],
         'hördas': [('hörd', False)],
         'hörde': [('hörd', False)],
         'hördes': [('hörd', False)],
         'hövts': [('hövd', False)],
         'iabla': [('iabel', False)],
         'ialt': [('ial', False)],
         'iant': [('iant', False)],
         'iante': [('iant', False)],
         'iat': [('iad', False)],
         'iats': [('iat', False)],
         'ibefriad': [('ibefriad', False)],
         'ice': [('ic', False)],
         'icerad': [('icerad', False)],
         'icerade': [('icerad', False)],
         'ickt': [('ick', False)],
         'id': [('id', False)],
         'ida': [('id', False)],
         'idad': [('idad', False)],
         'idade': [('idad', False)],
         'idande': [('idande', False)],
         'idare': [('id', False)],
         'idas': [('id', False)],
         'idaste': [('id', False)],
         'ide': [('id', False)],
         'iden': [('iden', False)],
         'iderade': [('iderad', False)],
         'iderats': [('iderad', False)],
         'ides': [('id', False)],
         'idest': [('ides', False)],
         'idests': [('ides', False)],
         'idgad': [('idga', False)],
         'ids': [('id', False)],
         'ie': [('ie', False)],
         'iellare': [('iell', False)],
         'iellares': [('iell', False)],
         'ient': [('ienn', False)],
         'ienterad': [('ienterad', False)],
         'ienterade': [('ienterad', False)],
         'ients': [('ienn', False)],
         'ierat': [('ierad', False)],
         'iett': [('iett', False)],
         'ietta': [('iett', False)],
         'ietts': [('iett', False)],
         'ift': [('ift', False)],
         'iftat': [('iftad', False)],
         'ifylld': [('fylla_i', True)],
         'ifört': [('iförd', True)],
         'iförts': [('iförd', True)],
         'iga': [('ig', False)],
         'igad': [('igad', False)],
         'igade': [('igad', False)],
         'igande': [('igande', False)],
         'igants': [('igant', False)],
         'igare': [('ig', False)],
         'igares': [('ig', False)],
         'igas': [('ig', False)],
         'igast': [('ig', False)],
         'igaste': [('ig', False)],
         'igastes': [('ig', False)],
         'igasts': [('ig', False)],
         'igats': [('igad', False)],
         'ige': [('ig', False)],
         'igen': [('igen', False)],
         'igenkända': [('känna_igen', True)],
         'igent': [('igen', False)],
         'igents': [('igen', False)],
         'igerad': [('igerad', False)],
         'iges': [('ig', False)],
         'iget': [('igen', False)],
         'igets': [('igen', False)],
         'igförklarad': [('igförklara', False)],
         'iggjorda': [('iggöra', False)],
         'iggt': [('igg', False)],
         'igjorda': [('igjord', False)],
         'igna': [('igen', False)],
         'ignare': [('igen', False)],
         'ignares': [('igen', False)],
         'ignas': [('igen', False)],
         'ignast': [('igen', False)],
         'ignaste': [('igen', False)],
         'ignastes': [('igen', False)],
         'ignasts': [('igen', False)],
         'ignat': [('ignad', False)],
         'igne': [('igen', False)],
         'ignes': [('igen', False)],
         'igott': [('igott', False)],
         'igotts': [('igott', False)],
         'igrares': [('iger', False)],
         'igre': [('iger', False)],
         'igres': [('iger', False)],
         'igs': [('ig', False)],
         'igstes': [('igste', False)],
         'igts': [('ig', False)],
         'igående': [('igående', False)],
         'igången': [('igången', False)],
         'ika': [('ik', False)],
         'ikad': [('ikad', False)],
         'ikade': [('ikad', False)],
         'ikaliserade': [('ikaliserad', False)],
         'ikande': [('ikande', False)],
         'ikats': [('ikad', False)],
         'ikes': [('ik', False)],
         'iket': [('iken', False)],
         'iklöst': [('iklös', False)],
         'iknat': [('iknad', False)],
         'iknes': [('iken', False)],
         'ikrat': [('ikrad', False)],
         'ikt': [('ikt', False)],
         'iktande': [('ikta', False)],
         'ikts': [('ik', False)],
         'ila': [('il', False)],
         'ilad': [('ilad', False)],
         'ilade': [('ilad', False)],
         'ilande': [('ilande', False)],
         'ilare': [('il', False)],
         'ilares': [('il', False)],
         'ilas': [('il', False)],
         'ilast': [('il', False)],
         'ilaste': [('il', False)],
         'ilastes': [('il', False)],
         'ilasts': [('il', False)],
         'ilat': [('ilad', False)],
         'ilats': [('ilad', False)],
         'ile': [('il', False)],
         'ilerad': [('ilerad', False)],
         'ilerade': [('ilerad', False)],
         'iles': [('il', False)],
         'iligare': [('ilig', False)],
         'iligaste': [('ilig', False)],
         'iliserade': [('iliserad', False)],
         'iliserande': [('iliserande', False)],
         'illa': [('illa', False)],
         'illas': [('ill', False)],
         'illda': [('illd', False)],
         'ille': [('iten', False)],
         'illes': [('iten', False)],
         'illt': [('ill', False)],
         'illts': [('illd', False)],
         'illärt': [('illär', False)],
         'ils': [('il', False)],
         'ilt': [('ild', False)],
         'iltat': [('iltad', False)],
         'iltes': [('ilt', False)],
         'ilts': [('il', False)],
         'ilärt': [('ilär', False)],
         'ilärts': [('ilär', False)],
         'ilös': [('ilös', False)],
         'ilösts': [('ilös', False)],
         'ima': [('im', False)],
         'imad': [('imad', False)],
         'imade': [('imad', False)],
         'imalts': [('imal', False)],
         'imare': [('im', False)],
         'imares': [('im', False)],
         'imas': [('im', False)],
         'imast': [('im', False)],
         'imaste': [('im', False)],
         'imastes': [('im', False)],
         'imasts': [('im', False)],
         'imat': [('imat', False)],
         'imats': [('imad', False)],
         'ime': [('im', False)],
         'imes': [('im', False)],
         'immat': [('immad', False)],
         'ims': [('im', False)],
         'imts': [('im', False)],
         'imulerad': [('imulerad', False)],
         'imulerade': [('imulerad', False)],
         'imärkt': [('imärkt', False)],
         'imärkta': [('imärkt', False)],
         'imärts': [('imär', False)],
         'in': [('in', False)],
         'in-': [('in', False)],
         'ina': [('in', False)],
         'inad': [('inad', False)],
         'inade': [('inad', False)],
         'inande': [('inande', False)],
         'inare': [('in', False)],
         'inares': [('in', False)],
         'inas': [('in', False)],
         'inast': [('in', False)],
         'inaste': [('in', False)],
         'inastes': [('in', False)],
         'inasts': [('in', False)],
         'inat': [('inat', False)],
         'inats': [('inad', False)],
         'inde': [('ind', False)],
         'indrad': [('indrad', False)],
         'indrade': [('indrad', False)],
         'industrialiserade': [('industrialisera', True)],
         'ine': [('in', False)],
         'inerad': [('inerad', False)],
         'inerade': [('inerad', False)],
         'ines': [('in', False)],
         'inflyttad': [('inflytta', True)],
         'infogat': [('infogad', False)],
         'införd': [('införa', True)],
         'införda': [('införd', False)],
         'inga': [('inga', False)],
         'ingare': [('ingare', False)],
         'ingares': [('ingare', False)],
         'ingast': [('ingast', False)],
         'ingaste': [('ing', False)],
         'ingastes': [('ingast', False)],
         'ingasts': [('ingast', False)],
         'ingd': [('ingd', False)],
         'ingda': [('ingd', False)],
         'ingts': [('ingd', False)],
         'ingulare': [('ingul', False)],
         'ingulares': [('ingular', False)],
         'inkt': [('ink', False)],
         'inkts': [('inkt', False)],
         'inlöst': [('inlöst', False)],
         'inlösts': [('inlöst', False)],
         'inna': [('inn', False)],
         'innas': [('inn', False)],
         'innastes': [('inn', False)],
         'innat': [('innad', False)],
         'inne': [('inne', True)],
         'innehållande': [('innehålla', True)],
         'innes': [('inn', False)],
         'inordnad': [('inordnad', False)],
         'inpräglade': [('inprägla', True)],
         'inrapporterade': [('inrapportera', True)],
         'inrikes': [('inrikes', True)],
         'ins': [('in', False)],
         'inskriven': [('inskriva', True)],
         'instruerade': [('instruera', True)],
         'int': [('inn', False)],
         'intensifierad': [('intensifiera', True)],
         'ints': [('inn', False)],
         'invigda': [('inviga', True)],
         'invigts': [('invigd', False)],
         'inära': [('inär', False)],
         'inäras': [('inär', False)],
         'inäre': [('inär', False)],
         'inäres': [('inär', False)],
         'inärts': [('inär', False)],
         'iolett': [('iolett', False)],
         'ioletts': [('iolett', False)],
         'ionde': [('ionde', False)],
         'ionärt': [('ionär', False)],
         'ionärts': [('ionär', False)],
         'iore': [('ior', False)],
         'iort': [('ior', False)],
         'iorts': [('ior', False)],
         'ipad': [('ipad', False)],
         'ipade': [('ipad', False)],
         'ipande': [('ipande', False)],
         'iparts': [('ipar', False)],
         'ipasserande': [('ipasserande', False)],
         'ipelts': [('ipel', False)],
         'iperade': [('iperad', False)],
         'iperats': [('iperad', False)],
         'iperbare': [('iperbar', False)],
         'iperbares': [('iperbar', False)],
         'iplöst': [('iplös', False)],
         'ippat': [('ippad', False)],
         'ippt': [('ippt', False)],
         'ippts': [('ippt', False)],
         'iprytt': [('iprydd', False)],
         'iprytts': [('iprydd', False)],
         'ira': [('ir', False)],
         'irad': [('irad', False)],
         'irade': [('irad', False)],
         'irades': [('irad', False)],
         'irande': [('irande', False)],
         'irare': [('ir', False)],
         'irares': [('ir', False)],
         'iras': [('ir', False)],
         'irast': [('ir', False)],
         'iraste': [('ir', False)],
         'irastes': [('ir', False)],
         'irasts': [('ir', False)],
         'irats': [('irad', False)],
         'ire': [('ir', False)],
         'irerade': [('irerad', False)],
         'ires': [('ir', False)],
         'irikes': [('irik', False)],
         'irikts': [('irik', False)],
         'irs': [('ir', False)],
         'irts': [('ir', False)],
         'irögt': [('irögd', False)],
         'is': [('is', False)],
         'isa': [('is', False)],
         'isad': [('isad', False)],
         'isade': [('isad', False)],
         'isande': [('isande', False)],
         'isant': [('isant', False)],
         'isants': [('isant', False)],
         'ise': [('is', False)],
         'iserade': [('iserad', False)],
         'iserande': [('iserande', False)],
         'isett': [('isedd', False)],
         'iskalad': [('iskalad', False)],
         'iskat': [('iskad', False)],
         'iskens': [('isken', False)],
         'iskrivet': [('iskriven', False)],
         'isparats': [('isparat', False)],
         'issat': [('issad', False)],
         'ist': [('is', False)],
         'ista': [('ista', False)],
         'istante': [('istant', False)],
         'istas': [('ista', False)],
         'iste': [('ista', False)],
         'istes': [('ista', False)],
         'istrad': [('istrad', False)],
         'istrande': [('istrande', False)],
         'ists': [('is', False)],
         'istäckt': [('istäckt', True)],
         'istörd': [('istörd', False)],
         'it': [('it', False)],
         'ita': [('it', False)],
         'itad': [('itad', False)],
         'itade': [('itad', False)],
         'itagna': [('itagen', False)],
         'italts': [('ital', False)],
         'itande': [('itande', False)],
         'itants': [('itant', False)],
         'itas': [('it', False)],
         'ite': [('it', False)],
         'iterad': [('iterad', False)],
         'iterade': [('iterad', False)],
         'iterats': [('iterad', False)],
         'itersta': [('itre', False)],
         'iterstas': [('itre', False)],
         'ites': [('it', False)],
         'itet': [('iten', False)],
         'itida': [('itid', False)],
         'itima': [('itim', False)],
         'itive': [('itiv', False)],
         'itna': [('iten', False)],
         'itonde': [('itond', False)],
         'itont': [('itond', False)],
         'itonts': [('itond', False)],
         'its': [('it', False)],
         'itsamma': [('itsamma', False)],
         'itterat': [('itterad', False)],
         'itterats': [('itterat', False)],
         'ittersta': [('ittersta', False)],
         'itterstas': [('ittersta', False)],
         'itärt': [('itär', False)],
         'itärts': [('itär', False)],
         'iva': [('iv', False)],
         'ivande': [('ivande', False)],
         'ivat': [('ivat', False)],
         'ivats': [('ivad', False)],
         'ive': [('iv', False)],
         'ivens': [('iven', False)],
         'iverse': [('iverse', False)],
         'iviga': [('ivig', False)],
         'ivigas': [('ivig', False)],
         'ivigastes': [('ivig', False)],
         'ivigts': [('ivig', False)],
         'ivilt': [('ivil', False)],
         'ivilts': [('ivil', False)],
         'ivlöst': [('ivlös', False)],
         'ivlösts': [('ivlös', False)],
         'ivrigt': [('ivrig', False)],
         'ivs': [('iv', False)],
         'ivts': [('iv', False)],
         'ixerad': [('ixerad', False)],
         'ixerade': [('ixerad', False)],
         'ixts': [('ix', False)],
         'iära': [('iär', False)],
         'iärt': [('iär', False)],
         'iört': [('iör', False)],
         'iörts': [('iör', False)],
         'jakat': [('jakad', False)],
         'jalt': [('jal', False)],
         'jant': [('jant', False)],
         'jante': [('jant', False)],
         'janterad': [('janterad', False)],
         'jat': [('jad', False)],
         'jd': [('jd', False)],
         'jda': [('jd', False)],
         'jdad': [('jdad', False)],
         'jdade': [('jdad', False)],
         'jdare': [('jd', False)],
         'jdas': [('jd', False)],
         'jdaste': [('jd', False)],
         'jde': [('jd', False)],
         'jdes': [('jd', False)],
         'jdrat': [('jdrad', False)],
         'jds': [('jd', False)],
         'je': [('je', False)],
         'jektive': [('jektiv', False)],
         'jerat': [('jerad', False)],
         'jerens': [('jeren', False)],
         'jerents': [('jeren', False)],
         'jigt': [('jig', False)],
         'jkad': [('jkad', False)],
         'jkade': [('jkad', False)],
         'jkats': [('jkad', False)],
         'jlad': [('jlad', False)],
         'jlade': [('jlad', False)],
         'jlat': [('jlad', False)],
         'jlats': [('jlad', False)],
         'jligare': [('jlig', False)],
         'jligaste': [('jlig', False)],
         'jligats': [('jligad', False)],
         'joderat': [('joderad', False)],
         'jordens': [('jordens', True)],
         'jorts': [('jord', False)],
         'jpad': [('jpad', False)],
         'jpade': [('jpad', False)],
         'jrikes': [('jrik', False)],
         'jrikts': [('jrik', False)],
         'jsad': [('jsad', False)],
         'jsade': [('jsad', False)],
         'jsamma': [('jsam', False)],
         'jsams': [('jsam', False)],
         'jsnare': [('jsen', False)],
         'jsnares': [('jsen', False)],
         'jt': [('j', False)],
         'jta': [('jt', False)],
         'jtad': [('jtad', False)],
         'jtade': [('jtad', False)],
         'jtas': [('jt', False)],
         'jte': [('jt', False)],
         'jtes': [('jt', False)],
         'jts': [('jd', False)],
         'judda': [('judd', False)],
         'junde': [('junde', False)],
         'just': [('just', False)],
         'juste': [('juste', True), ('just', True)],
         'justs': [('just', True)],
         'jutts': [('judd', False)],
         'juva': [('juva', False)],
         'jvilt': [('jvild', False)],
         'jyst': [('jyst', False)],
         'jysts': [('jyst', False)],
         'jällts': [('jäll', False)],
         'jält': [('jäl', False)],
         'jämfört': [('jämföra', True)],
         'jämnad': [('jämnad', False)],
         'jämnts': [('jämn', True)],
         'jänt': [('jänt', False)],
         'jära': [('jär', False)],
         'järt': [('jär', False)],
         'järtas': [('järt', False)],
         'järtes': [('järt', False)],
         'järts': [('järt', False)],
         'järvt': [('järv', False)],
         'järvts': [('järv', False)],
         'jäst': [('jäst', False)],
         'jästa': [('jäst', False)],
         'jästas': [('jäst', False)],
         'jäste': [('jäst', False)],
         'jästes': [('jäst', False)],
         'kabla': [('kabel', False)],
         'kada': [('kada', False)],
         'kakat': [('kakad', False)],
         'kallad': [('kalla', True)],
         'kalls': [('kall', False)],
         'kallts': [('kall', False)],
         'kalt': [('kal', False)],
         'kannat': [('kannad', False)],
         'kanpassat': [('kanpassad', False)],
         'kant': [('kant', False)],
         'kante': [('kant', False)],
         'kanterad': [('kanterad', False)],
         'karat': [('karad', False)],
         'karierande': [('karierande', False)],
         'kars': [('kars', False)],
         'kastade': [('kastad', False)],
         'kat': [('kad', False)],
         'katt': [('kadd', False)],
         'katts': [('kadd', False)],
         'kavats': [('kavat', True)],
         'kavt': [('kav', False)],
         'kavts': [('kavd', False)],
         'kbaserade': [('kbaserad', False)],
         'kbaserat': [('kbaserad', False)],
         'kbyggd': [('kbyggd', False)],
         'kbyggt': [('kbyggd', False)],
         'kdödade': [('kdödad', False)],
         'kejt': [('kej', False)],
         'kelrätt': [('kelrät', False)],
         'kelt': [('kel', False)],
         'kens': [('ken', False)],
         'ker': [('ker', False)],
         'kerat': [('kerad', False)],
         'kert': [('ker', False)],
         'kett': [('kett', False)],
         'ketta': [('kett', False)],
         'ketts': [('kett', False)],
         'kevt': [('kev', False)],
         'kflytande': [('kflytande', False)],
         'kformad': [('kformad', False)],
         'kformat': [('kformad', False)],
         'kfört': [('kförd', False)],
         'kförts': [('kförd', False)],
         'kgulares': [('kgul', False)],
         'khalt': [('khal', False)],
         'khalts': [('khal', False)],
         'kheligaste': [('khelig', False)],
         'kigt': [('kig', False)],
         'kikat': [('kikad', False)],
         'kilt': [('kil', False)],
         'kilts': [('kild', False)],
         'kinskriven': [('kinskriven', False)],
         'kiserat': [('kiserad', False)],
         'kivat': [('kivad', False)],
         'kkärts': [('kkär', False)],
         'kla': [('kel', False)],
         'klad': [('klad', False)],
         'klade': [('klad', False)],
         'klande': [('klande', False)],
         'klarad': [('klarad', False)],
         'klare': [('klar', True)],
         'klares': [('klar', True)],
         'klas': [('kel', False)],
         'klat': [('klad', False)],
         'klats': [('klad', False)],
         'klatts': [('klatt', False)],
         'kle': [('kel', False)],
         'kledd': [('kledd', False)],
         'kledda': [('kledd', False)],
         'klent': [('klen', False)],
         'kles': [('kel', False)],
         'klett': [('kledd', False)],
         'kletts': [('kledd', False)],
         'kligare': [('klig', False)],
         'kligaste': [('klig', False)],
         'kligats': [('kligad', False)],
         'klika': [('klik', False)],
         'klikts': [('klik', False)],
         'klint': [('klin', False)],
         'klippta': [('klippa', True)],
         'klängd': [('klängd', False)],
         'klängda': [('klängd', False)],
         'klängts': [('klängd', False)],
         'klätt': [('klädd', False)],
         'klätts': [('klädd', False)],
         'klös': [('klös', False)],
         'klöst': [('klöst', False)],
         'klösts': [('klös', False)],
         'kmalt': [('kmald', False)],
         'kmycket': [('kmycken', False)],
         'knad': [('knad', False)],
         'knade': [('knad', False)],
         'knande': [('knande', False)],
         'knats': [('knad', False)],
         'knäppt': [('knäpp', True)],
         'knäppts': [('knäpp', True)],
         'knästa': [('knäst', False)],
         'knästas': [('knäst', False)],
         'knäste': [('knäst', False)],
         'knästes': [('knäst', False)],
         'kokts': [('kokt', False)],
         'kolkade': [('kolkad', False)],
         'kommande': [('kommande', False)],
         'koncentrerade': [('koncentrera', True)],
         'kontants': [('kontant', False)],
         'kopat': [('kopad', False)],
         'koppad': [('koppad', False)],
         'kopplat': [('kopplad', False)],
         'korkad': [('korkad', True)],
         'kort': [('kort', False)],
         'korterade': [('korterad', False)],
         'korts': [('kort', True)],
         'kosams': [('kosam', False)],
         'kotts': [('kodd', False)],
         'krad': [('krad', False)],
         'krade': [('krad', False)],
         'krades': [('krad', False)],
         'krakts': [('krak', False)],
         'krande': [('krande', False)],
         'krare': [('ker', False)],
         'krares': [('ker', False)],
         'krats': [('krad', False)],
         'kre': [('kre', False)],
         'krents': [('kren', False)],
         'krerade': [('krerad', False)],
         'kres': [('kre', False)],
         'kretad': [('kretad', False)],
         'krikes': [('krik', False)],
         'krikts': [('krik', False)],
         'kringgärdad': [('kringgärda', True)],
         'krytts': [('kry', True)],
         'kräckts': [('kräckt', False)],
         'krängts': [('krängd', False)],
         'kränkande': [('kränkande', True)],
         'krävt': [('krävd', False)],
         'krått': [('krå', False)],
         'krött': [('kröd', False)],
         'krötts': [('kröd', False)],
         'ksamma': [('ksam', False)],
         'ksams': [('ksam', False)],
         'ksens': [('ksens', False)],
         'kskadad': [('kskadad', False)],
         'kskadade': [('kskadad', False)],
         'kskrivet': [('kskriven', False)],
         'kslös': [('kslös', False)],
         'kställande': [('kställande', False)],
         'kstött': [('kstödd', False)],
         'kstötts': [('kstödd', False)],
         'kt': [('k', False)],
         'kta': [('kt', False)],
         'ktad': [('ktad', False)],
         'ktade': [('ktad', False)],
         'ktagande': [('ktagande', False)],
         'ktalade': [('ktalad', False)],
         'ktalts': [('ktal', False)],
         'ktande': [('ktande', False)],
         'ktas': [('kt', False)],
         'kte': [('kt', False)],
         'kterad': [('kterad', False)],
         'kterade': [('kterad', False)],
         'kterande': [('kterande', False)],
         'kterats': [('kterad', False)],
         'kters': [('kter', False)],
         'ktersta': [('ktre', False)],
         'kterstas': [('ktre', False)],
         'ktes': [('kt', False)],
         'ktilts': [('ktil', False)],
         'ktive': [('ktiv', False)],
         'ktlöst': [('ktlös', False)],
         'ktra': [('kter', False)],
         'ktre': [('kter', False)],
         'ktres': [('kter', False)],
         'ktrött': [('ktrött', False)],
         'kts': [('kt', False)],
         'ktäckt': [('ktäck', False)],
         'ktäckts': [('ktäck', False)],
         'ktänkt': [('ktänkt', False)],
         'kuerade': [('kuerad', False)],
         'kulare': [('kular', False)],
         'kulares': [('kular', False)],
         'kults': [('kult', False)],
         'kurat': [('kurad', False)],
         'kurats': [('kurat', False)],
         'kurt': [('kur', False)],
         'kute': [('kut', False)],
         'kvalda': [('kvald', False)],
         'kvalt': [('kvald', False)],
         'kvat': [('kvat', False)],
         'kvidare': [('kvid', False)],
         'kvist': [('kvist', False)],
         'kvit': [('kvit', False)],
         'kvitt': [('kvitt', True)],
         'kvitts': [('kvit', False)],
         'kvänt': [('kvänd', False)],
         'kvänts': [('kvänd', False)],
         'kvärt': [('kvärd', False)],
         'kyggts': [('kygg', False)],
         'kyllt': [('kylld', False)],
         'kymts': [('kymd', False)],
         'kyrts': [('kyr', False)],
         'kyttad': [('kyttad', False)],
         'kytts': [('kydd', False)],
         'käckts': [('käck', True)],
         'kägda': [('kägd', False)],
         'kägt': [('kägd', False)],
         'kämd': [('kämd', False)],
         'kämtade': [('kämtad', False)],
         'kämts': [('kämd', False)],
         'känd': [('känd', False)],
         'kända': [('känd', False)],
         'känkt': [('känkt', False)],
         'känts': [('känd', False)],
         'kära': [('kär', False)],
         'kärde': [('kärd', False)],
         'kärrad': [('kärrad', False)],
         'kärt': [('kär', True)],
         'kärts': [('kär', True)],
         'kärvt': [('kärv', True)],
         'kärvts': [('kärv', True)],
         'kögts': [('kögd', False)],
         'könat': [('könad', False)],
         'körd': [('körd', False)],
         'körda': [('körd', False)],
         'kördas': [('körd', False)],
         'körde': [('körd', False)],
         'kördes': [('körd', False)],
         'kört': [('körd', True)],
         'körts': [('körd', True)],
         'kött': [('kött', False)],
         'kövts': [('kövd', False)],
         'la': [('mal', False)],
         'labba': [('labb', False)],
         'laga': [('laga', False)],
         'lagrad': [('lagra', True)],
         'lagrants': [('lagrant', False)],
         'lags': [('lags', False)],
         'lagts': [('lagd', False)],
         'lakat': [('lakad', False)],
         'lakt': [('lak', False)],
         'lankommande': [('lankommande', False)],
         'lankts': [('lank', False)],
         'lanpassat': [('lanpassad', False)],
         'lans': [('lans', False)],
         'lant': [('lant', False)],
         'lante': [('lant', False)],
         'lanterad': [('lanterad', False)],
         'lants': [('lan', False)],
         'larat': [('larad', False)],
         'larbetande': [('larbetande', False)],
         'lart': [('lar', False)],
         'las': [('mal', False)],
         'laserat': [('laserad', False)],
         'last': [('el', False)],
         'lastade': [('lastad', False)],
         'laste': [('el', False)],
         'lastes': [('el', False)],
         'lasts': [('el', False)],
         'lat': [('lat', True)],
         'lats': [('lat', False)],
         'latt': [('latt', False)],
         'latta': [('latt', False)],
         'lavat': [('lavad', False)],
         'lavlönat': [('lavlönad', False)],
         'lbehandlade': [('lbehandlad', False)],
         'lbelyst': [('lbelyst', False)],
         'lbeställt': [('lbeställd', False)],
         'lbetalda': [('lbetald', False)],
         'lbetalt': [('lbetald', False)],
         'lbevarade': [('lbevarad', False)],
         'lblekt': [('lblekt', False)],
         'lblekts': [('lblekt', False)],
         'lbyggd': [('lbyggd', False)],
         'lbyggt': [('lbyggd', False)],
         'lbärgade': [('lbärgad', False)],
         'ld': [('ld', False)],
         'lda': [('ld', False)],
         'ldad': [('ldad', False)],
         'ldade': [('ldad', False)],
         'ldare': [('ld', False)],
         'ldas': [('ld', False)],
         'ldaste': [('ld', False)],
         'lde': [('ld', False)],
         'lden': [('lden', False)],
         'ldens': [('ldens', False)],
         'lderade': [('lderad', False)],
         'lderats': [('lderad', False)],
         'ldes': [('ld', False)],
         'ldrat': [('ldrad', False)],
         'lds': [('ld', False)],
         'le': [('le', True)],
         'ledd': [('leda', True)],
         'ledda': [('leda', True)],
         'leds': [('leds', True), ('led', True)],
         'legaliserade': [('legalisera', True)],
         'legant': [('legant', False)],
         'legärt': [('legär', True)],
         'leiga': [('leig', False)],
         'leigare': [('leig', False)],
         'leigares': [('leig', False)],
         'leigas': [('leig', False)],
         'leigast': [('leig', False)],
         'leigaste': [('leig', False)],
         'leigastes': [('leig', False)],
         'leigasts': [('leig', False)],
         'leige': [('leig', False)],
         'leiges': [('leig', False)],
         'leigt': [('leig', False)],
         'leigts': [('leig', False)],
         'lejts': [('lejd', False)],
         'lekande': [('leka', True)],
         'lekt': [('lekt', True)],
         'lektive': [('lektiv', False)],
         'lellare': [('lell', False)],
         'lellares': [('lell', False)],
         'lena': [('len', True)],
         'lene': [('len', False)],
         'lens': [('len', False)],
         'lent': [('len', True)],
         'lents': [('len', True)],
         'ler': [('ler', False)],
         'lerat': [('lerad', False)],
         'lersta': [('lersta', False)],
         'lerstas': [('lersta', False)],
         'lerts': [('lert', False)],
         'les': [('le', True)],
         'lesserade': [('lesserad', False)],
         'lest': [('lest', False)],
         'lesta': [('lest', False)],
         'lests': [('lest', False)],
         'let': [('let', False)],
         'letalt': [('letal', True)],
         'lets': [('let', False)],
         'lett': [('le', True), ('led', True)],
         'letta': [('lett', False)],
         'letts': [('le', True), ('led', True)],
         'levts': [('levd', False)],
         'lflytande': [('lflytande', False)],
         'lformad': [('lformad', False)],
         'lformat': [('lformad', False)],
         'lformulerad': [('lformulerad', False)],
         'lfte': [('lfte', False)],
         'lförankrat': [('lförankrad', False)],
         'lförd': [('lföra', False)],
         'lfördelade': [('lfördelad', False)],
         'lfördelat': [('lfördelad', False)],
         'lgad': [('lgad', False)],
         'lgade': [('lgad', False)],
         'lgats': [('lgad', False)],
         'lgerad': [('lgerad', False)],
         'lgjorda': [('lgjord', False)],
         'lgott': [('lgod', False)],
         'lgulares': [('lgul', False)],
         'lgärts': [('lgär', False)],
         'lgående': [('lgående', False)],
         'lgången': [('lgången', False)],
         'lgött': [('lgödd', False)],
         'liad': [('liad', False)],
         'liats': [('liad', False)],
         'lierad': [('lierad', False)],
         'lifierad': [('lifierad', False)],
         'ligat': [('ligad', False)],
         'ligats': [('ligat', False)],
         'ligent': [('ligent', False)],
         'ligents': [('ligent', False)],
         'liggjorda': [('liggjord', False)],
         'ligna': [('lign', False)],
         'lignare': [('lign', False)],
         'lignares': [('lign', False)],
         'lignas': [('lign', False)],
         'lignast': [('lign', False)],
         'lignaste': [('lign', False)],
         'lignastes': [('lign', False)],
         'lignasts': [('lign', False)],
         'ligne': [('lign', False)],
         'lignes': [('lign', False)],
         'ligt': [('lig', False)],
         'lika': [('lika', True), ('lik', True)],
         'likat': [('likad', False)],
         'likats': [('likat', False)],
         'likt': [('lik', False)],
         'liktande': [('liktande', False)],
         'likts': [('lik', True)],
         'lila': [('lila', True)],
         'lilla': [('liten', True)],
         'lillas': [('liten', False)],
         'lingad': [('lingad', False)],
         'lingulares': [('lingul', True)],
         'linkts': [('link', False)],
         'lint': [('lind', False)],
         'lints': [('lin', False)],
         'liserat': [('liserad', False)],
         'list': [('list', False)],
         'lista': [('list', False)],
         'listas': [('list', False)],
         'liste': [('list', False)],
         'listes': [('list', False)],
         'lists': [('list', False)],
         'litsamma': [('litsam', False)],
         'litt': [('lid', False)],
         'litterat': [('litterat', False)],
         'litts': [('lid', False)],
         'livat': [('livad', True)],
         'live': [('live', True)],
         'livet': [('liven', False)],
         'livs': [('livs', True)],
         'ljande': [('ljande', False)],
         'ljt': [('ljd', False)],
         'ljust': [('ljus', True)],
         'ljusts': [('ljus', False)],
         'ljuva': [('ljuv', False)],
         'ljärts': [('ljär', False)],
         'lkad': [('lkad', False)],
         'lkade': [('lkad', False)],
         'lkande': [('lkande', False)],
         'lkats': [('lkad', False)],
         'lklare': [('lklar', False)],
         'lklares': [('lklar', False)],
         'lklippta': [('lklippt', False)],
         'lknäppt': [('lknäppt', False)],
         'lknäppts': [('lknäppt', False)],
         'lkvitt': [('lkvit', False)],
         'lla': [('ll', False)],
         'llad': [('llad', False)],
         'llade': [('llad', False)],
         'llagrad': [('llagrad', False)],
         'llande': [('llande', False)],
         'llare': [('ll', False)],
         'llares': [('ll', False)],
         'llast': [('ll', False)],
         'llaste': [('ll', False)],
         'llastes': [('ll', False)],
         'llasts': [('ll', False)],
         'llat': [('llad', False)],
         'llats': [('llad', False)],
         'lle': [('ll', False)],
         'llena': [('llena', False)],
         'llene': [('llene', False)],
         'llent': [('llent', False)],
         'llents': [('llent', False)],
         'llerad': [('llerad', False)],
         'llerade': [('llerad', False)],
         'llerande': [('llerande', False)],
         'lles': [('ll', False)],
         'llet': [('llen', False)],
         'llets': [('llen', False)],
         'lligare': [('llig', False)],
         'lligaste': [('llig', False)],
         'lligats': [('lligad', False)],
         'llika': [('llik', False)],
         'llikts': [('llik', False)],
         'llint': [('llin', False)],
         'lliserade': [('lliserad', False)],
         'llne': [('llen', False)],
         'lls': [('ll', False)],
         'llte': [('llte', False)],
         'lltes': [('llt', False)],
         'llts': [('ll', False)],
         'llvande': [('llvand', False)],
         'llärt': [('llärd', False)],
         'llärts': [('llär', False)],
         'llös': [('llös', False)],
         'llösts': [('llös', False)],
         'lmad': [('lmad', False)],
         'lmade': [('lmad', False)],
         'lmats': [('lmad', False)],
         'lnad': [('lnad', False)],
         'lnade': [('lnad', False)],
         'lnats': [('lnad', False)],
         'lnärt': [('lnärd', False)],
         'loderat': [('loderad', False)],
         'logat': [('logad', False)],
         'lokaliserade': [('lokalisera', True)],
         'lokt': [('lok', False)],
         'lolöst': [('lolös', False)],
         'lolösts': [('lolös', False)],
         'lont': [('lond', False)],
         'lonts': [('lond', False)],
         'lopad': [('lopa', False)],
         'lopade': [('lopa', False)],
         'loppad': [('loppad', False)],
         'lordnade': [('lordnad', False)],
         'lordnat': [('lordnad', False)],
         'lorsakade': [('lorsakad', False)],
         'losams': [('losam', False)],
         'lott': [('lott', False)],
         'lperade': [('lperad', False)],
         'lperats': [('lperad', False)],
         'lperbare': [('lperbar', False)],
         'lperbares': [('lperbar', False)],
         'lplacerad': [('lplacerad', False)],
         'lplacerade': [('lplacerad', False)],
         'lplöst': [('lplös', False)],
         'lprytt': [('lprydd', False)],
         'lprytts': [('lprydd', False)],
         'lpterat': [('lpterad', False)],
         'lrad': [('lrad', False)],
         'lrade': [('lrad', False)],
         'lrades': [('lrad', False)],
         'lrats': [('lrad', False)],
         'lreglerad': [('lreglerad', False)],
         'lrenade': [('lrenad', False)],
         'lrikes': [('lrik', False)],
         'lrikts': [('lrik', False)],
         'lrunts': [('lrund', False)],
         'lrött': [('lröd', False)],
         'lrötts': [('lröd', False)],
         'lsad': [('lsad', False)],
         'lsade': [('lsad', False)],
         'lsamma': [('lsam', False)],
         'lsams': [('lsam', False)],
         'lsett': [('lsedd', False)],
         'lsittande': [('lsittande', False)],
         'lskadad': [('lskadad', False)],
         'lskadade': [('lskadad', False)],
         'lskat': [('lskad', False)],
         'lskens': [('lsken', False)],
         'lskrivet': [('lskriven', False)],
         'lsköns': [('lsköns', False)],
         'lslätt': [('lslätt', False)],
         'lslätts': [('lslätt', False)],
         'lslös': [('lslös', False)],
         'lsmorda': [('lsmord', False)],
         'lsnare': [('lsen', False)],
         'lsnares': [('lsen', False)],
         'lstimulerande': [('lstimulerande', False)],
         'lstrad': [('lstrad', False)],
         'lstrande': [('lstrande', False)],
         'lstämd': [('lstämd', False)],
         'lsvitt': [('lsvid', False)],
         'lsvitts': [('lsvid', False)],
         'lta': [('lt', False)],
         'ltad': [('ltad', False)],
         'ltade': [('ltad', False)],
         'ltagande': [('ltagande', False)],
         'ltagna': [('ltagen', False)],
         'ltans': [('ltan', False)],
         'ltant': [('ltan', False)],
         'ltas': [('lt', False)],
         'lte': [('lt', False)],
         'lterad': [('lterad', False)],
         'lterade': [('lterad', False)],
         'lterande': [('lterande', False)],
         'lterats': [('lterad', False)],
         'ltet': [('lten', False)],
         'ltlöst': [('ltlös', False)],
         'ltna': [('lten', False)],
         'ltrikt': [('ltrik', False)],
         'ltryckt': [('ltryckt', False)],
         'lträngt': [('lträngd', False)],
         'lträtts': [('lträdd', False)],
         'ltrött': [('ltrött', False)],
         'lts': [('ld', False)],
         'ltunts': [('ltunn', False)],
         'ltänkt': [('ltänkt', False)],
         'ltärt': [('ltär', False)],
         'ltärts': [('ltär', False)],
         'lubbade': [('lubbad', False)],
         'luerade': [('luerad', False)],
         'lugna': [('lugn', False)],
         'lugnare': [('lugn', False)],
         'lugnares': [('lugn', True)],
         'lugnas': [('lugn', True)],
         'lugnast': [('lugn', True)],
         'lugnaste': [('lugn', True)],
         'lugnastes': [('lugn', True)],
         'lugnasts': [('lugn', False)],
         'lugne': [('lugn', False)],
         'lugnes': [('lugn', True)],
         'lunare': [('lunar', True)],
         'lunares': [('lunar', True)],
         'lurat': [('lurad', False)],
         'lustad': [('lustad', False)],
         'lustade': [('lustad', False)],
         'lute': [('lut', False)],
         'luterat': [('luterad', False)],
         'lutformad': [('lutformad', False)],
         'lutformade': [('lutformad', False)],
         'lutformat': [('lutformad', False)],
         'lutrustad': [('lutrustad', False)],
         'lutrustade': [('lutrustad', False)],
         'lva': [('lv', False)],
         'lvande': [('lvande', False)],
         'lvant': [('lvand', False)],
         'lvants': [('lvand', False)],
         'lvarmt': [('lvarm', False)],
         'lvats': [('lvad', False)],
         'lve': [('lv', False)],
         'lverkande': [('lverkande', False)],
         'lvist': [('lvis', False)],
         'lvists': [('lvis', False)],
         'lvit': [('lvit', False)],
         'lvits': [('lvit', False)],
         'lvitt': [('lvit', False)],
         'lvitts': [('lvit', False)],
         'lvrigt': [('lvrig', False)],
         'lvs': [('lv', False)],
         'lvts': [('lv', False)],
         'lvänt': [('lvänd', False)],
         'lvänts': [('lvänd', False)],
         'lyggts': [('lygg', False)],
         'lynt': [('lynt', False)],
         'lysts': [('lyst', False)],
         'lytt': [('lytt', False)],
         'lytte': [('lytt', True)],
         'läckande': [('läckande', False)],
         'läckt': [('läckt', False)],
         'lägda': [('lägd', False)],
         'läggande': [('läggande', False)],
         'lägt': [('lägd', False)],
         'läkta': [('läkt', False)],
         'lämd': [('lämd', False)],
         'lämnad': [('lämnad', False)],
         'lämts': [('lämd', False)],
         'länd': [('länd', False)],
         'lända': [('länd', False)],
         'längt': [('längd', False)],
         'länkande': [('länkande', False)],
         'läns': [('läns', True)],
         'länsande': [('länsande', False)],
         'länt': [('länt', False)],
         'läntade': [('läntad', False)],
         'länts': [('länd', False)],
         'lära': [('lär', False)],
         'lärde': [('lärd', False)],
         'lärt': [('lärd', True)],
         'lärts': [('lärd', False)],
         'läst': [('läst', False)],
         'lästa': [('läst', False)],
         'lästas': [('läst', False)],
         'läste': [('läst', False)],
         'lästes': [('läst', False)],
         'lätt': [('lätt', True)],
         'lätte': [('lätt', True)],
         'lätts': [('lätt', True)],
         'lådda': [('lådd', False)],
         'lående': [('lående', False)],
         'långa': [('lång', False)],
         'långs': [('lång', False)],
         'lånt': [('lånt', True)],
         'lånts': [('lånt', True)],
         'låst': [('låsa', True)],
         'lått': [('lådd', False)],
         'låtts': [('lådd', False)],
         'låvarmt': [('låvarm', False)],
         'lögts': [('lögd', False)],
         'löjda': [('löjd', False)],
         'lömda': [('lömd', False)],
         'lömt': [('lömd', False)],
         'lömts': [('lömd', False)],
         'lönat': [('lönad', False)],
         'lönt': [('lönt', True)],
         'lönts': [('lönt', False)],
         'lört': [('lört', False)],
         'lörts': [('lört', False)],
         'lös': [('lös', True)],
         'lösande': [('lösande', True)],
         'löst': [('lös', True)],
         'lösts': [('lös', True)],
         'löt': [('lös', False)],
         'löts': [('lös', False)],
         'mabla': [('mabel', False)],
         'made': [('made', False)],
         'maga': [('maga', False)],
         'magrad': [('magrad', False)],
         'magrare': [('mager', True)],
         'magrares': [('mager', True)],
         'maka': [('maka', False)],
         'makat': [('makad', False)],
         'malda': [('mald', False)],
         'malt': [('mal', False)],
         'malts': [('mald', False)],
         'mandes': [('mande', False)],
         'manfört': [('manförd', False)],
         'manförts': [('manförd', False)],
         'manlagda': [('manlagd', False)],
         'mannat': [('mannad', False)],
         'mans': [('mans', False)],
         'mant': [('mant', False)],
         'mantagna': [('mantagen', False)],
         'mante': [('mant', False)],
         'mants': [('man', False)],
         'marbetande': [('marbetande', False)],
         'mare': [('', False)],
         'mares': [('', False)],
         'marts': [('mart', False)],
         'mas': [('', False)],
         'mast': [('', False)],
         'masta': [('a', False)],
         'mastade': [('mastad', False)],
         'mastas': [('a', False)],
         'maste': [('', False)],
         'mastes': [('', False)],
         'masts': [('', False)],
         'mat': [('mad', False)],
         'matt': [('matt', False)],
         'matta': [('matt', True)],
         'mbade': [('mbad', False)],
         'mbaserade': [('mbaserad', False)],
         'mbaserat': [('mbaserad', False)],
         'mbats': [('mbad', False)],
         'mblötts': [('mblöt', False)],
         'mbrett': [('mbred', False)],
         'md': [('md', False)],
         'mda': [('md', False)],
         'mdare': [('md', False)],
         'mdas': [('md', False)],
         'mdaste': [('md', False)],
         'mde': [('md', False)],
         'mdes': [('md', False)],
         'mdiskuterat': [('mdiskuterad', False)],
         'mds': [('md', False)],
         'me': [('', False)],
         'mellare': [('mell', False)],
         'mellares': [('mell', False)],
         'mena': [('men', False)],
         'menade': [('mena', True)],
         'mene': [('men', False)],
         'mens': [('men', False)],
         'ment': [('ment', False)],
         'menterad': [('menterad', False)],
         'menterade': [('menterad', False)],
         'ments': [('ment', False)],
         'mer': [('mycket', True)],
         'mera': [('mycket', True)],
         'merat': [('merad', False)],
         'mergent': [('mergent', False)],
         'mergents': [('mergent', False)],
         'merligare': [('merlig', False)],
         'mert': [('mer', False)],
         'merts': [('mert', False)],
         'mes': [('', False)],
         'mflat': [('mflat', False)],
         'mflyttad': [('mflyttad', False)],
         'mformad': [('mformad', False)],
         'mformat': [('mformad', False)],
         'mfördelade': [('mfördelad', False)],
         'mfördelat': [('mfördelad', False)],
         'mfört': [('mförd', False)],
         'mförts': [('mförd', False)],
         'mgjorda': [('mgjord', False)],
         'mgott': [('mgod', False)],
         'mgrupperade': [('mgrupperad', False)],
         'mgulares': [('mgul', False)],
         'mgående': [('mgående', False)],
         'mhägnad': [('mhägnad', False)],
         'mierad': [('mierad', False)],
         'mifierad': [('mifierad', False)],
         'migt': [('mig', False)],
         'mila': [('mila', False)],
         'milda': [('mild', False)],
         'milts': [('mild', False)],
         'mimat': [('mimad', False)],
         'mindre': [('liten', True)],
         'mindres': [('liten', True)],
         'minnes': [('minnes', False)],
         'minrikes': [('minrik', False)],
         'minskad': [('minska', True)],
         'minskade': [('minska', True)],
         'minskat': [('minska', True)],
         'minst': [('liten', True)],
         'minsta': [('liten', True)],
         'minstas': [('liten', True)],
         'minste': [('liten', True)],
         'minstes': [('liten', True)],
         'minsts': [('liten', True)],
         'mint': [('mind', False)],
         'mints': [('mind', False)],
         'miserat': [('miserad', False)],
         'mitt': [('midd', False)],
         'mitterats': [('mitterad', False)],
         'mitts': [('midd', False)],
         'mjt': [('mjd', False)],
         'mkad': [('mkad', False)],
         'mkade': [('mkad', False)],
         'mkallad': [('mkallad', False)],
         'mkats': [('mkad', False)],
         'mkärts': [('mkär', False)],
         'mkörts': [('mkörd', False)],
         'mlad': [('mlad', False)],
         'mlade': [('mlad', False)],
         'mlande': [('mlande', False)],
         'mlat': [('mlad', False)],
         'mlats': [('mlad', False)],
         'mle': [('mmal', False)],
         'mles': [('mmal', False)],
         'mligare': [('mlig', False)],
         'mligaste': [('mlig', False)],
         'mlika': [('mlik', False)],
         'mlikts': [('mlik', False)],
         'mlyst': [('mlyst', False)],
         'mlös': [('mlös', False)],
         'mlösande': [('mlösande', False)],
         'mlösts': [('mlös', False)],
         'mmad': [('mmad', False)],
         'mmade': [('mmad', False)],
         'mmande': [('mmande', False)],
         'mmats': [('mmad', False)],
         'mmoderat': [('mmoderad', False)],
         'mmoderats': [('mmoderad', False)],
         'mmöblerade': [('mmöblerad', False)],
         'mn': [('mn', False)],
         'mn-': [('mn', False)],
         'mna': [('mmen', False)],
         'mnad': [('mnad', False)],
         'mnade': [('mnad', False)],
         'mnande': [('mnande', False)],
         'mnare': [('mn', False)],
         'mnares': [('mmen', False)],
         'mnas': [('mmen', False)],
         'mnast': [('mmen', False)],
         'mnaste': [('mmen', False)],
         'mnastes': [('mn', False)],
         'mnasts': [('mmen', False)],
         'mnats': [('mnad', False)],
         'mne': [('mmen', False)],
         'mnerad': [('mnerad', False)],
         'mnerade': [('mnerad', False)],
         'mnes': [('mmen', False)],
         'mns': [('mn', False)],
         'mnämnda': [('mnämnd', False)],
         'mnämndas': [('mnämnd', False)],
         'mnämndes': [('mnämnd', False)],
         'moderat': [('moderat', True)],
         'moderats': [('moderat', True)],
         'mognats': [('mognad', False)],
         'montant': [('montan', False)],
         'moppad': [('moppad', False)],
         'mordnade': [('mordnad', False)],
         'mordnat': [('mordnad', False)],
         'morterade': [('morterad', False)],
         'morts': [('mord', False)],
         'mpa': [('mp', False)],
         'mpad': [('mpad', False)],
         'mpade': [('mpad', False)],
         'mpakt': [('mpakt', False)],
         'mpare': [('mp', False)],
         'mpares': [('mp', False)],
         'mpe': [('mp', False)],
         'mpelts': [('mpel', False)],
         'mperade': [('mperad', False)],
         'mperats': [('mperad', False)],
         'mperbare': [('mperbar', False)],
         'mperbares': [('mperbar', False)],
         'mpers': [('mper', False)],
         'mplacerad': [('mplacerad', False)],
         'mplacerade': [('mplacerad', False)],
         'mplat': [('mplad', False)],
         'mponerade': [('mponerad', False)],
         'mprytt': [('mprydd', False)],
         'mprytts': [('mprydd', False)],
         'mpt': [('mp', False)],
         'mpterat': [('mpterad', False)],
         'mpts': [('mp', False)],
         'mrad': [('mrad', False)],
         'mrade': [('mrad', False)],
         'mrades': [('mrad', False)],
         'mrande': [('mrande', False)],
         'mrats': [('mrad', False)],
         'mre': [('mre', False)],
         'mres': [('a', False)],
         'mrikes': [('mrik', False)],
         'mrikts': [('mrik', False)],
         'mräknat': [('mräknad', False)],
         'msad': [('msad', False)],
         'msade': [('msad', False)],
         'msatt': [('msätta', False)],
         'msittande': [('msittande', False)],
         'mskrivet': [('mskriven', False)],
         'mslös': [('mslös', False)],
         'msnare': [('msen', False)],
         'msnares': [('msen', False)],
         'mst': [('a', False)],
         'msta': [('a', False)],
         'mstas': [('a', False)],
         'mste': [('a', False)],
         'mstes': [('a', False)],
         'mstrad': [('mstrad', False)],
         'mstritt': [('mstridd', False)],
         'mstritts': [('mstridd', False)],
         'mstämd': [('mstämd', False)],
         'mt': [('m', False)],
         'mtad': [('mtad', False)],
         'mtade': [('mtad', False)],
         'mtalade': [('mtalad', False)],
         'mtaxerad': [('mtaxerad', False)],
         'mtaxerade': [('mtaxerad', False)],
         'mtive': [('mtiv', False)],
         'mtryckt': [('mtryckt', False)],
         'mträngt': [('mträngd', False)],
         'mtrött': [('mtrött', False)],
         'mtänkt': [('mtänkt', False)],
         'mult': [('mul', False)],
         'mumma': [('mumma', True)],
         'munts': [('mun', False)],
         'murat': [('murad', False)],
         'muterat': [('muterad', False)],
         'mvants': [('mvan', False)],
         'mvisad': [('mvisad', False)],
         'mvisade': [('mvisad', False)],
         'mvist': [('mvis', False)],
         'mvists': [('mvis', False)],
         'mvänt': [('mvänd', False)],
         'mvänts': [('mvänd', False)],
         'mvärt': [('mvärd', False)],
         'mycket': [('mycket', True)],
         'mynt': [('mynt', False)],
         'mägt': [('mägd', False)],
         'mäld': [('mäld', False)],
         'mälda': [('mäld', False)],
         'mäldas': [('mäld', False)],
         'mälde': [('mäld', False)],
         'mäldes': [('mäld', False)],
         'mällande': [('mällande', False)],
         'mält': [('mält', False)],
         'mälta': [('mält', False)],
         'mältas': [('mält', False)],
         'mälte': [('mält', False)],
         'mältes': [('mälta', False)],
         'mälts': [('mäld', False)],
         'mändrade': [('mändrad', False)],
         'mändrat': [('mändrad', False)],
         'mängt': [('mängd', False)],
         'mänt': [('män', False)],
         'mänts': [('män', False)],
         'mära': [('mär', False)],
         'märkt': [('märka', True)],
         'märkta': [('märka', True)],
         'märre': [('märre', False)],
         'märres': [('märre', False)],
         'märt': [('mär', False)],
         'märtas': [('märt', False)],
         'märtes': [('märt', False)],
         'märts': [('märt', False)],
         'mätt': [('mätt', False)],
         'mätte': [('mätt', False)],
         'mådda': [('mådd', False)],
         'mående': [('mående', False)],
         'måtts': [('mådd', False)],
         'möblerade': [('möblera', True)],
         'mögts': [('mögd', False)],
         'mört': [('mör', True)],
         'mörts': [('mör', True)],
         'mötande': [('möta', True)],
         'mött': [('mött', False)],
         'na': [('en', False)],
         'nabba': [('nabb', False)],
         'nabla': [('nabel', False)],
         'nagts': [('nagd', False)],
         'nallad': [('nallad', False)],
         'nalls': [('nall', False)],
         'nalt': [('nal', False)],
         'nant': [('nant', False)],
         'nante': [('nant', False)],
         'narat': [('narad', False)],
         'nare': [('en', False)],
         'nares': [('en', False)],
         'nart': [('nar', False)],
         'nas': [('en', False)],
         'nast': [('en', False)],
         'naste': [('en', False)],
         'nastes': [('en', False)],
         'nasts': [('en', False)],
         'nat': [('nad', False)],
         'navts': [('navd', False)],
         'nbaserade': [('nbaserad', False)],
         'nbaserat': [('nbaserad', False)],
         'nbehandlade': [('nbehandlad', False)],
         'nbelyst': [('nbelyst', False)],
         'nbemälda': [('nbemälda', False)],
         'nbemäldas': [('nbemälda', False)],
         'nbemälde': [('nbemälda', False)],
         'nbemäldes': [('nbemälda', False)],
         'nbyggd': [('nbyggd', False)],
         'nbyggt': [('nbyggd', False)],
         'ncerad': [('ncerad', False)],
         'ncerade': [('ncerad', False)],
         'nd': [('nd', False)],
         'nda': [('nd', False)],
         'ndad': [('ndad', False)],
         'ndade': [('ndad', False)],
         'ndande': [('ndande', False)],
         'ndants': [('ndant', False)],
         'ndare': [('nd', False)],
         'ndas': [('nd', False)],
         'ndaste': [('nd', False)],
         'ndelt': [('ndelt', False)],
         'nden': [('nden', False)],
         'nderade': [('nderad', False)],
         'nderats': [('nderad', False)],
         'ndes': [('nd', False)],
         'ndlat': [('ndlad', False)],
         'ndrat': [('ndrad', False)],
         'ndre': [('ndre', False)],
         'ndres': [('ndra', False)],
         'nds': [('nd', False)],
         'ne': [('en', False)],
         'nelat': [('nelad', False)],
         'nellare': [('nell', False)],
         'nellares': [('nell', False)],
         'nens': [('nen', False)],
         'nent': [('nent', False)],
         'nents': [('nent', False)],
         'nerat': [('nerad', False)],
         'nere': [('nere', True)],
         'nerligare': [('nerlig', False)],
         'nersta': [('nersta', False)],
         'nerstas': [('nersta', False)],
         'nerts': [('nert', False)],
         'nes': [('en', False)],
         'nett': [('nett', False)],
         'netta': [('nett', False)],
         'netts': [('nett', False)],
         'nfattande': [('nfatta', False)],
         'nformad': [('nformad', False)],
         'nformat': [('nformad', False)],
         'nfriad': [('nfriad', False)],
         'nfångade': [('nfångad', False)],
         'nfört': [('nförd', False)],
         'nförts': [('nförd', False)],
         'nförändrad': [('nförändrad', False)],
         'nförändrade': [('nförändrad', False)],
         'nförändrat': [('nförändrad', False)],
         'nga': [('ng', False)],
         'ngad': [('ngad', False)],
         'ngade': [('ngad', False)],
         'ngande': [('ngande', False)],
         'ngare': [('ng', False)],
         'ngares': [('ng', False)],
         'ngas': [('ng', False)],
         'ngast': [('ng', False)],
         'ngastes': [('ng', False)],
         'ngasts': [('ng', False)],
         'ngats': [('ngad', False)],
         'nge': [('ng', False)],
         'ngen': [('ngen', False)],
         'ngent': [('ngent', False)],
         'ngents': [('ngent', False)],
         'ngerad': [('ngerad', False)],
         'nges': [('ng', False)],
         'nget': [('ngen', False)],
         'ngets': [('ngen', False)],
         'ngiven': [('nge', False)],
         'ngivet': [('nge', False)],
         'ngivna': [('nge', False)],
         'ngjord': [('ngöra', False)],
         'ngjorda': [('ngjord', False)],
         'ngna': [('ngen', False)],
         'ngnare': [('ngen', False)],
         'ngnares': [('ngen', False)],
         'ngnas': [('ngen', False)],
         'ngnast': [('ngen', False)],
         'ngnaste': [('ngen', False)],
         'ngnastes': [('ngen', False)],
         'ngnasts': [('ngen', False)],
         'ngne': [('ngen', False)],
         'ngnes': [('ngen', False)],
         'ngott': [('ngod', False)],
         'ngrant': [('ngrann', False)],
         'ngrants': [('ngrann', False)],
         'ngränsande': [('ngränsande', False)],
         'ngs': [('ng', False)],
         'ngt': [('ngd', False)],
         'ngts': [('ng', False)],
         'ngulares': [('ngul', False)],
         'ngående': [('ngående', False)],
         'ngången': [('ngången', False)],
         'nhandlade': [('nhandlad', False)],
         'nheligaste': [('nhelig', False)],
         'nhägnad': [('nhägnad', False)],
         'nhämtade': [('nhämtad', False)],
         'nhämtat': [('nhämtad', False)],
         'nhållande': [('nhålla', False)],
         'niad': [('niad', False)],
         'niats': [('niad', False)],
         'nierad': [('nierad', False)],
         'nifierad': [('nifierad', False)],
         'nigna': [('nign', False)],
         'nignare': [('nign', False)],
         'nignares': [('nign', False)],
         'nignas': [('nign', False)],
         'nignast': [('nign', False)],
         'nignaste': [('nign', False)],
         'nignastes': [('nign', False)],
         'nignasts': [('nign', False)],
         'nigne': [('nign', False)],
         'nignes': [('nign', False)],
         'nigt': [('nig', False)],
         'nikt': [('nik', False)],
         'nilt': [('nil', False)],
         'nint': [('nin', False)],
         'nints': [('nin', False)],
         'niserat': [('niserad', False)],
         'nivat': [('nivad', False)],
         'njande': [('njande', False)],
         'njt': [('njd', False)],
         'njärts': [('njär', False)],
         'nka': [('nk', False)],
         'nkad': [('nkad', False)],
         'nkade': [('nkad', False)],
         'nkallad': [('nkallad', False)],
         'nkande': [('nkande', False)],
         'nkats': [('nkad', False)],
         'nkavts': [('nkav', False)],
         'nkes': [('nk', False)],
         'nket': [('nken', False)],
         'nkilts': [('nkil', False)],
         'nklare': [('nklar', False)],
         'nklares': [('nkel', False)],
         'nklöst': [('nklös', False)],
         'nknat': [('nknad', False)],
         'nknes': [('nken', False)],
         'nkrat': [('nkrad', False)],
         'nkt': [('nkt', False)],
         'nkärts': [('nkär', False)],
         'nkört': [('nkörd', False)],
         'nkörts': [('nkörd', False)],
         'nlett': [('nleda', False)],
         'nligare': [('nlig', False)],
         'nligaste': [('nlig', False)],
         'nligats': [('nligad', False)],
         'nlika': [('nlik', False)],
         'nlikts': [('nlik', False)],
         'nlyst': [('nlyst', False)],
         'nlänt': [('nländ', False)],
         'nlärt': [('nlärd', False)],
         'nlätts': [('nlätt', False)],
         'nlös': [('nlös', False)],
         'nlöst': [('nlös', False)],
         'nlösts': [('nlös', False)],
         'nmält': [('nmäld', False)],
         'nmärkt': [('nmärkt', False)],
         'nmärkta': [('nmärkt', False)],
         'nn': [('nn', False)],
         'nn-': [('nn', False)],
         'nnad': [('nnad', False)],
         'nnade': [('nnad', False)],
         'nnande': [('nnande', False)],
         'nnare': [('nn', False)],
         'nnares': [('nn', False)],
         'nnast': [('nn', False)],
         'nnaste': [('nn', False)],
         'nnasts': [('nn', False)],
         'nnats': [('nnad', False)],
         'nnerad': [('nnerad', False)],
         'nnerade': [('nnerad', False)],
         'nnoterad': [('nnoterad', False)],
         'nns': [('nn', False)],
         'nnämndes': [('nnämnd', False)],
         'nodlade': [('nodlad', False)],
         'noga': [('noga', False)],
         'nomfört': [('nomförd', False)],
         'nomförts': [('nomförd', False)],
         'nons': [('nons', False)],
         'nopat': [('nopad', False)],
         'noppad': [('noppad', False)],
         'nordnade': [('nordnad', False)],
         'nordnat': [('nordnad', False)],
         'nore': [('nor', False)],
         'nort': [('nor', False)],
         'norts': [('nor', False)],
         'noterad': [('notera', True)],
         'notts': [('nodd', False)],
         'npassat': [('npassad', False)],
         'npraktiserande': [('npraktiserande', False)],
         'nre': [('nre', False)],
         'nres': [('nre', False)],
         'nrett': [('nredd', False)],
         'nrikats': [('nrikad', False)],
         'nrikes': [('nrik', False)],
         'nrikts': [('nrik', False)],
         'nrymt': [('nrymd', False)],
         'nräknat': [('nräknad', False)],
         'nrött': [('nröd', False)],
         'nrötts': [('nröd', False)],
         'nsad': [('nsad', False)],
         'nsade': [('nsad', False)],
         'nsakade': [('nsakad', False)],
         'nsamma': [('nsam', False)],
         'nsams': [('nsam', False)],
         'nsande': [('nsande', False)],
         'nsant': [('nsant', False)],
         'nsants': [('nsant', False)],
         'nserade': [('nserad', False)],
         'nsett': [('nsedd', False)],
         'nsides': [('nsides', False)],
         'nskadad': [('nskadad', False)],
         'nskadade': [('nskadad', False)],
         'nskalad': [('nskalad', False)],
         'nskat': [('nskad', False)],
         'nskrivet': [('nskriven', False)],
         'nskyddad': [('nskyddad', False)],
         'nskyddade': [('nskyddad', False)],
         'nslaget': [('nslagen', False)],
         'nslös': [('nslös', False)],
         'nstante': [('nstant', False)],
         'nstiftat': [('nstiftad', False)],
         'nstrad': [('nstrad', False)],
         'nstrikt': [('nstrik', False)],
         'nstrikts': [('nstrik', False)],
         'nsträngt': [('nsträngd', False)],
         'nsträngts': [('nsträngd', False)],
         'nställt': [('nställd', False)],
         'nstämd': [('nstämd', False)],
         'nstörande': [('nstörande', False)],
         'nstött': [('nstött', False)],
         'nsänt': [('nsänd', False)],
         'nta': [('nt', False)],
         'ntad': [('ntad', False)],
         'ntade': [('ntad', False)],
         'ntagande': [('ntagande', False)],
         'ntagna': [('ntagen', False)],
         'ntalts': [('ntal', False)],
         'ntande': [('ntande', False)],
         'ntans': [('ntan', False)],
         'ntant': [('ntan', False)],
         'ntas': [('nt', False)],
         'nte': [('nt', False)],
         'nterad': [('nterad', False)],
         'nterade': [('nterad', False)],
         'nterats': [('nterad', False)],
         'nters': [('nter', False)],
         'ntes': [('nt', False)],
         'ntilts': [('ntil', False)],
         'ntima': [('ntim', False)],
         'ntive': [('ntiv', False)],
         'ntra': [('nter', False)],
         'ntre': [('nter', False)],
         'ntres': [('nter', False)],
         'ntrikt': [('ntrik', False)],
         'ntryckt': [('ntryckt', False)],
         'nträngt': [('nträngd', False)],
         'ntrött': [('ntrött', False)],
         'ntsamma': [('ntsamma', False)],
         'ntt': [('nt', False)],
         'ntts': [('nt', False)],
         'ntärt': [('ntär', False)],
         'ntärts': [('ntär', False)],
         'nubbade': [('nubbad', False)],
         'nuerade': [('nuerad', False)],
         'numrerade': [('numrera', True)],
         'nuterat': [('nuterad', False)],
         'nvant': [('nvand', False)],
         'nvants': [('nvand', False)],
         'nvarmt': [('nvarm', False)],
         'nvigas': [('nvig', False)],
         'nvigt': [('nvigd', False)],
         'nvigts': [('nvig', False)],
         'nvisad': [('nvisad', False)],
         'nvisade': [('nvisad', False)],
         'nvist': [('nvis', False)],
         'nvit': [('nvit', False)],
         'nvits': [('nvit', False)],
         'nvitt': [('nvit', False)],
         'nvitts': [('nvit', False)],
         'nvänt': [('nvänd', False)],
         'nväntade': [('nväntad', False)],
         'nvänts': [('nvänd', False)],
         'nvärt': [('nvärd', False)],
         'nyckt': [('nyckt', False)],
         'nyggts': [('nygg', False)],
         'nymt': [('nym', False)],
         'nyrt': [('nyrd', False)],
         'nyrts': [('nyrd', False)],
         'nys': [('ny', False)],
         'nyssnämnde': [('nyssnämnd', True), ('nyssnämnda', True)],
         'nyssnämndes': [('nyssnämnda', True), ('nyssnämnd', True)],
         'nytt': [('ny', False)],
         'nytts': [('ny', False)],
         'näckt': [('näckt', False)],
         'nägda': [('nägd', False)],
         'nägt': [('nägd', False)],
         'nällts': [('näll', False)],
         'nämnda': [('nämna', True)],
         'nämndas': [('nämnda', False)],
         'nämnde': [('nämnd', False)],
         'nämnt': [('nämnd', False)],
         'nämsta': [('näm', False)],
         'nämstas': [('näm', False)],
         'nämsts': [('näm', False)],
         'nämt': [('näm', False)],
         'nändrade': [('nändrad', False)],
         'nära': [('nära', True)],
         'näras': [('nära', True)],
         'närde': [('närd', False)],
         'näre': [('nära', True)],
         'näres': [('nära', True)],
         'närt': [('när', False)],
         'närts': [('närd', False)],
         'näst': [('näst', False)],
         'nästa': [('nästa', True)],
         'nästas': [('nästa', True)],
         'näste': [('nästa', True)],
         'nästes': [('nästa', True)],
         'nätt': [('nätt', True)],
         'nätte': [('nätt', True)],
         'nävt': [('näv', False)],
         'nådda': [('nådd', False)],
         'nålt': [('nål', False)],
         'nåra': [('nåra', False)],
         'nått': [('nådd', False)],
         'nåtts': [('nådd', False)],
         'nöde': [('nöd', False)],
         'nögts': [('nögd', False)],
         'nöjda': [('nöjd', False)],
         'nörd': [('nörd', False)],
         'nörda': [('nörd', False)],
         'nördas': [('nörd', False)],
         'nörde': [('nörd', False)],
         'nördes': [('nörd', False)],
         'nött': [('nödd', True), ('nött', True)],
         'nötts': [('nödd', True), ('nött', True)],
         'oaccepterade': [('oaccepterad', True)],
         'oaccepterat': [('oaccepterad', True)],
         'oadresserade': [('oadresserad', True)],
         'oalstrad': [('oalstrad', True)],
         'oanfört': [('oanförd', True)],
         'oanförts': [('oanförd', True)],
         'oankrat': [('oankrad', True)],
         'oanmäld': [('oanmäld', True)],
         'oanmälda': [('oanmäld', True)],
         'oanordnad': [('oanordnad', True)],
         'oanordnade': [('oanordnad', True)],
         'oanpassat': [('oanpassad', True)],
         'oanrikat': [('oanrikad', True)],
         'oaserat': [('oaserad', False)],
         'oat': [('oad', False)],
         'oavat': [('oavad', True)],
         'oavklarad': [('oavklarad', True)],
         'oavkopplat': [('oavkopplad', True)],
         'oavlönat': [('oavlönad', True)],
         'oavlöst': [('oavlöst', True)],
         'oavlösts': [('oavlöst', True)],
         'oavsaltat': [('oavsaltad', True)],
         'oavsänd': [('oavsänd', True)],
         'oavverkade': [('oavverkad', True)],
         'oba': [('ob', False)],
         'obare': [('ob', False)],
         'obares': [('ob', False)],
         'obaserade': [('obaserad', True)],
         'obaserat': [('obaserad', False)],
         'obat': [('obat', False)],
         'obefolkade': [('obefolkad', True)],
         'obefriad': [('obefriad', True)],
         'obefrämjande': [('obefrämjande', False)],
         'obehandlade': [('obehandlad', True)],
         'obelyst': [('obelyst', True)],
         'obemälde': [('obemäld', True)],
         'obeskyddade': [('obeskyddad', True)],
         'obeställt': [('obeställd', True)],
         'obetalda': [('obetald', True)],
         'obetalt': [('obetald', True)],
         'obevarade': [('obevarad', True)],
         'oblekt': [('oblekt', True)],
         'oblekts': [('oblekt', True)],
         'oblött': [('oblött', True)],
         'oblötts': [('oblött', True)],
         'obra': [('ober', False)],
         'obras': [('ober', False)],
         'obyggd': [('obyggd', True)],
         'obyggt': [('obyggd', True)],
         'obärgade': [('obärgad', True)],
         'ocentrerade': [('ocentrerad', True)],
         'ocerad': [('ocerad', False)],
         'ocerade': [('ocerad', False)],
         'ocknes': [('ocknes', False)],
         'ockt': [('ock', False)],
         'od': [('od', False)],
         'oda': [('od', False)],
         'odad': [('odad', False)],
         'odade': [('odad', False)],
         'odande': [('odande', False)],
         'odare': [('od', False)],
         'odas': [('od', False)],
         'odaste': [('od', False)],
         'ode': [('od', False)],
         'odeponerade': [('odeponerad', True)],
         'oderade': [('oderad', False)],
         'oderats': [('oderad', False)],
         'odernas': [('odern', False)],
         'odes': [('od', False)],
         'odimensionerad': [('odimensionerad', True)],
         'odiskuterat': [('odiskuterad', True)],
         'odlade': [('odla', True)],
         'odlat': [('odlad', False)],
         'odoppad': [('odoppad', True)],
         'odrat': [('odrad', False)],
         'odresserade': [('odresserad', True)],
         'ods': [('od', False)],
         'odubbade': [('odubbad', True)],
         'odödade': [('odödad', True)],
         'odömda': [('odömd', True)],
         'oende': [('oende', False)],
         'ofas': [('of', False)],
         'ofilare': [('ofil', False)],
         'ofilares': [('ofil', False)],
         'oflyttad': [('oflyttad', True)],
         'oflängt': [('oflängd', True)],
         'oflängts': [('oflängd', True)],
         'oformad': [('oformad', True)],
         'oformat': [('oformad', True)],
         'oformulerad': [('oformulerad', True)],
         'oframförd': [('oframförd', True)],
         'oframställt': [('oframställd', True)],
         'ofriad': [('ofriad', True)],
         'ofrämjande': [('ofrämjande', False)],
         'ofts': [('of', False)],
         'ofångade': [('ofångad', True)],
         'oförankrat': [('oförankrad', True)],
         'oförbrukade': [('oförbrukad', True)],
         'ofördelade': [('ofördelad', True)],
         'ofördelat': [('ofördelad', True)],
         'ofördjupad': [('ofördjupad', True)],
         'oförenklad': [('oförenklad', True)],
         'oförklarad': [('oförklarad', True)],
         'oförknippat': [('oförknippad', True)],
         'oförlängd': [('oförlängd', True)],
         'oförlängda': [('oförlängd', True)],
         'oförmögna': [('oförmögen', True)],
         'oförnedrande': [('oförnedrande', False)],
         'oförorsakade': [('oförorsakad', True)],
         'oförstorade': [('oförstorad', True)],
         'oförsäkrad': [('oförsäkrad', True)],
         'oförsäkrade': [('oförsäkrad', True)],
         'oförsäkrades': [('oförsäkrad', True)],
         'ofört': [('oförd', True), ('oför', True)],
         'oförtretad': [('oförtretad', True)],
         'oförts': [('oförd', True), ('oför', True)],
         'oförändrad': [('oförändrad', True)],
         'oförändrade': [('oförändrad', True)],
         'oförändrat': [('oförändrad', True)],
         'oga': [('og', False)],
         'ogad': [('ogad', False)],
         'ogade': [('ogad', False)],
         'ogants': [('ogant', False)],
         'ogaranterad': [('ogaranterad', True)],
         'ogare': [('og', False)],
         'ogares': [('og', False)],
         'ogas': [('og', False)],
         'ogast': [('og', False)],
         'ogaste': [('og', False)],
         'ogastes': [('og', False)],
         'ogasts': [('og', False)],
         'ogats': [('ogad', False)],
         'oge': [('og', False)],
         'ogen': [('ogen', False)],
         'ogenomförd': [('ogenomförd', True)],
         'ogent': [('ogen', False)],
         'ogents': [('ogen', False)],
         'ogerad': [('ogerad', False)],
         'oges': [('og', False)],
         'oget': [('ogen', False)],
         'ogets': [('ogen', False)],
         'ogjorda': [('ogjord', True)],
         'ogna': [('ogen', False)],
         'ognare': [('ogen', False)],
         'ognares': [('ogen', False)],
         'ognas': [('ogen', False)],
         'ognast': [('ogen', False)],
         'ognaste': [('ogen', False)],
         'ognastes': [('ogen', False)],
         'ognasts': [('ogen', False)],
         'ognat': [('ognad', False)],
         'ognats': [('ognat', False)],
         'ogne': [('ogen', False)],
         'ognes': [('ogen', False)],
         'ogrupperade': [('ogrupperad', True)],
         'ogs': [('og', False)],
         'ogts': [('og', False)],
         'ohandlade': [('ohandlad', True)],
         'oheligaste': [('ohelig', True)],
         'ohägnad': [('ohägnad', True)],
         'ohämtade': [('ohämtad', True)],
         'ohämtat': [('ohämtad', True)],
         'ohänvisad': [('ohänvisad', True)],
         'ohöjda': [('ohöjd', True)],
         'oindustrialiserade': [('oindustrialiserad', True)],
         'oinflyttad': [('oinflyttad', True)],
         'oinförd': [('oinförd', True)],
         'oinpräglade': [('oinpräglad', True)],
         'oinrapporterade': [('oinrapporterad', True)],
         'oinstruerade': [('oinstruerad', True)],
         'ointensifierad': [('ointensifierad', True)],
         'oinvigda': [('oinvigd', True)],
         'oiserat': [('oiserad', False)],
         'oje': [('oj', False)],
         'ojts': [('oj', False)],
         'ojuste': [('ojuste', True), ('ojust', True)],
         'ojämfört': [('ojämförd', True)],
         'oka': [('ok', False)],
         'okad': [('okad', False)],
         'okade': [('okad', False)],
         'okaliserade': [('okaliserad', False)],
         'okallad': [('okallad', True)],
         'okats': [('okad', False)],
         'okes': [('ok', False)],
         'oket': [('oken', False)],
         'oklare': [('oklar', True)],
         'oklares': [('oklar', True)],
         'oklippta': [('oklippt', True)],
         'oklösts': [('oklöst', True)],
         'oknat': [('oknad', False)],
         'oknes': [('oken', False)],
         'oknäppt': [('oknäppt', True)],
         'oknäppts': [('oknäppt', True)],
         'okoncentrerade': [('okoncentrerad', True)],
         'okre': [('oker', False)],
         'okres': [('oker', False)],
         'okringgärdad': [('okringgärdad', True)],
         'okt': [('okt', False)],
         'okts': [('ok', False)],
         'okurats': [('okurad', True)],
         'okört': [('okörd', True)],
         'ola': [('ol', False)],
         'olad': [('olad', False)],
         'olade': [('olad', False)],
         'olagrad': [('olagrad', True)],
         'olande': [('olande', False)],
         'olare': [('ol', False)],
         'olares': [('ol', False)],
         'olas': [('ol', False)],
         'olast': [('ol', False)],
         'olaste': [('ol', False)],
         'olastes': [('ol', False)],
         'olasts': [('ol', False)],
         'olat': [('olad', False)],
         'olats': [('olad', False)],
         'ole': [('ol', False)],
         'oledd': [('oledd', False)],
         'oledda': [('oledd', False)],
         'olegaliserade': [('olegaliserad', True)],
         'olent': [('olent', False)],
         'olents': [('olenn', False)],
         'olerad': [('olerad', False)],
         'olerade': [('olerad', False)],
         'olerande': [('olerande', False)],
         'oles': [('ol', False)],
         'olett': [('oledd', False)],
         'oletts': [('oledd', False)],
         'oligare': [('olig', False)],
         'oligaste': [('olig', False)],
         'olika': [('olik', True)],
         'olikats': [('olikad', True)],
         'olikts': [('olik', False)],
         'oliserade': [('oliserad', False)],
         'ollerande': [('ollera', False)],
         'ollärt': [('ollär', False)],
         'olokaliserade': [('olokaliserad', True)],
         'ols': [('ol', False)],
         'olt': [('olt', False)],
         'oltes': [('olt', False)],
         'olyst': [('olyst', True)],
         'oläkta': [('oläkt', True)],
         'olängd': [('olängd', True)],
         'olängda': [('olängd', True)],
         'olängts': [('olängd', True)],
         'olärt': [('olärd', True)],
         'olärts': [('olärd', True)],
         'olåst': [('olåst', True)],
         'olös': [('olös', False)],
         'olöst': [('olöst', True)],
         'olösts': [('olöst', True)],
         'oma': [('om', False)],
         'omad': [('omad', False)],
         'omade': [('omad', False)],
         'omalts': [('omal', False)],
         'omans': [('oman', False)],
         'omant': [('oman', False)],
         'omare': [('om', False)],
         'omares': [('om', False)],
         'omas': [('om', False)],
         'omast': [('om', False)],
         'omaste': [('om', False)],
         'omastes': [('om', False)],
         'omasts': [('om', False)],
         'omats': [('omad', False)],
         'ome': [('om', False)],
         'omer': [('omer', False)],
         'omera': [('omer', False)],
         'omerts': [('omer', False)],
         'omes': [('om', False)],
         'omförd': [('omförd', False)],
         'omfört': [('omför', False)],
         'omförts': [('omför', False)],
         'ominskad': [('ominskad', True)],
         'ominskade': [('ominskad', True)],
         'ominskat': [('ominskad', True)],
         'omma': [('om', False)],
         'ommat': [('ommad', False)],
         'omnare': [('ommen', False)],
         'omnastes': [('ommen', False)],
         'oms': [('om', False)],
         'omts': [('om', False)],
         'omärkt': [('omärkt', True)],
         'omärkta': [('omärkt', True)],
         'omärts': [('omär', False)],
         'omöblerade': [('omöblerad', True)],
         'on': [('on', False)],
         'on-': [('on', False)],
         'ona': [('on', False)],
         'onad': [('onad', False)],
         'onade': [('onad', False)],
         'onande': [('onande', False)],
         'onare': [('on', False)],
         'onares': [('on', False)],
         'onas': [('on', False)],
         'onast': [('on', False)],
         'onaste': [('on', False)],
         'onastes': [('on', False)],
         'onasts': [('on', False)],
         'onats': [('onad', False)],
         'onde': [('ond', False)],
         'one': [('on', False)],
         'onents': [('onents', False)],
         'onerad': [('onerad', False)],
         'onerade': [('onerad', False)],
         'ones': [('on', False)],
         'ongaste': [('ong', False)],
         'ongt': [('ong', False)],
         'ongulare': [('ongul', False)],
         'onoterad': [('onoterad', True)],
         'ons': [('on', False)],
         'onstruerade': [('onstruerad', False)],
         'ont': [('ont', True), ('ond', True)],
         'ontant': [('ontant', False)],
         'ontants': [('ontan', False)],
         'onte': [('onte', False)],
         'onts': [('ond', True)],
         'onumrerade': [('onumrerad', True)],
         'onämnda': [('onämnd', True)],
         'onämndas': [('onämnd', True)],
         'onämndes': [('onämnd', True)],
         'onära': [('onär', False)],
         'onäras': [('onär', False)],
         'onäre': [('onär', False)],
         'onäres': [('onär', False)],
         'onärt': [('onärd', True)],
         'onärts': [('onärd', True)],
         'onött': [('onött', True)],
         'onötts': [('onött', True)],
         'oodlad': [('oodlad', True)],
         'oodlade': [('oodlad', True)],
         'oolt': [('ool', False)],
         'oolts': [('ool', False)],
         'oomfört': [('oomförd', True)],
         'oomförts': [('oomförd', True)],
         'oordnade': [('oordnad', True)],
         'oordnat': [('oordnad', False)],
         'oorsakade': [('oorsakad', True)],
         'opa': [('op', False)],
         'opad': [('opad', False)],
         'opade': [('opad', False)],
         'opakts': [('opak', True)],
         'oparat': [('oparad', True)],
         'oparats': [('oparad', True)],
         'opare': [('op', False)],
         'opares': [('op', False)],
         'opassat': [('opassad', True)],
         'opat': [('opa', False)],
         'ope': [('op', False)],
         'operade': [('operad', False)],
         'operats': [('operad', False)],
         'operbare': [('operbar', False)],
         'operbares': [('operbar', False)],
         'opers': [('oper', False)],
         'oplacerad': [('oplacerad', True)],
         'oplacerade': [('oplacerad', True)],
         'oponerade': [('oponerad', False)],
         'oppat': [('oppad', False)],
         'opplösande': [('opplösande', False)],
         'opplösts': [('opplös', False)],
         'opresenterad': [('opresenterad', True)],
         'opresenterade': [('opresenterad', True)],
         'oprytt': [('oprydd', True)],
         'oprytts': [('oprydd', True)],
         'opräglade': [('opräglad', True)],
         'opt': [('op', False)],
         'opterat': [('opterad', False)],
         'opts': [('op', False)],
         'opublicerad': [('opublicerad', True)],
         'opulveriserat': [('opulveriserad', True)],
         'ora': [('or', False)],
         'orad': [('orad', False)],
         'orade': [('orad', False)],
         'orades': [('orad', False)],
         'orande': [('orande', False)],
         'orant': [('orant', False)],
         'orants': [('orant', False)],
         'orapporterade': [('orapporterad', True)],
         'orare': [('or', False)],
         'orares': [('or', False)],
         'oras': [('or', False)],
         'orast': [('or', False)],
         'oraste': [('or', False)],
         'orastes': [('or', False)],
         'orasts': [('or', False)],
         'orats': [('orad', False)],
         'ordens': [('orden', False)],
         'ordnad': [('ordnad', False)],
         'ordnade': [('ordna', True)],
         'ordnat': [('ordna', True)],
         'ore': [('ore', False)],
         'oredovisade': [('oredovisad', True)],
         'oregerad': [('oregerad', True)],
         'oreglerad': [('oreglerad', True)],
         'orenade': [('orenad', False)],
         'orenande': [('orenande', False)],
         'orent': [('oren', True)],
         'orents': [('oren', True)],
         'orepresenterad': [('orepresenterad', True)],
         'orepresenterade': [('orepresenterad', True)],
         'orerade': [('orerad', False)],
         'ores': [('or', False)],
         'oret': [('oren', False)],
         'oretad': [('oretad', True)],
         'orets': [('oren', False)],
         'orienterande': [('orienterande', False)],
         'orikes': [('orik', False)],
         'orikts': [('orik', False)],
         'ormat': [('ormad', False)],
         'ormt': [('orm', False)],
         'orna': [('oren', False)],
         'ornare': [('oren', False)],
         'ornares': [('oren', False)],
         'ornas': [('oren', False)],
         'ornast': [('oren', False)],
         'ornaste': [('oren', False)],
         'ornastes': [('oren', False)],
         'ornasts': [('oren', False)],
         'orne': [('oren', False)],
         'ornes': [('oren', False)],
         'oroad': [('oroa', True)],
         'orra': [('orra', False)],
         'orrande': [('orra', False)],
         'orre': [('orr', False)],
         'orres': [('orr', False)],
         'ors': [('or', False)],
         'ort': [('ord', False)],
         'orts': [('orts', False)],
         'orymt': [('orymd', True)],
         'oräckts': [('oräckt', True)],
         'oräknat': [('oräknad', True)],
         'orögt': [('orögd', False)],
         'os': [('os', False)],
         'osa': [('os', False)],
         'osad': [('osad', False)],
         'osade': [('osad', False)],
         'osakade': [('osakad', True)],
         'osaltat': [('osaltad', True)],
         'osamma': [('osam', False)],
         'osammanfogat': [('osammanfogad', True)],
         'osammanförda': [('osammanförd', True)],
         'osamordnad': [('osamordnad', True)],
         'osams': [('osams', True)],
         'osande': [('osande', False)],
         'osankt': [('osankt', False)],
         'osankts': [('osankt', False)],
         'osant': [('osann', True)],
         'osants': [('osann', True)],
         'ose': [('os', False)],
         'oserade': [('oserad', False)],
         'osett': [('osedd', True)],
         'osintrad': [('osintrad', True)],
         'oskadad': [('oskadad', True)],
         'oskadade': [('oskadad', True)],
         'oskaftad': [('oskaftad', True)],
         'oskalad': [('oskalad', True)],
         'oskrivet': [('oskriven', True)],
         'oskyddad': [('oskyddad', True)],
         'oskyddade': [('oskyddad', True)],
         'osmorda': [('osmord', True)],
         'osparat': [('osparad', True)],
         'ospektive': [('ospektiv', False)],
         'ospärrad': [('ospärrad', True)],
         'ossat': [('ossad', False)],
         'ost': [('os', False)],
         'ostabiliserat': [('ostabiliserad', True)],
         'ostandardiserat': [('ostandardiserad', True)],
         'ostimulerade': [('ostimulerad', True)],
         'ostrad': [('ostrad', False)],
         'ostrött': [('oströd', False)],
         'oströtts': [('oströd', False)],
         'osts': [('os', False)],
         'ostämd': [('ostämd', True)],
         'ostörd': [('ostörd', True)],
         'osårad': [('osårad', True)],
         'ot': [('ot', False)],
         'ota': [('ot', False)],
         'otad': [('otad', False)],
         'otade': [('otad', False)],
         'otalts': [('otal', False)],
         'otande': [('otande', False)],
         'otas': [('ot', False)],
         'otaxerad': [('otaxerad', True)],
         'otaxerade': [('otaxerad', True)],
         'ote': [('ot', False)],
         'oterad': [('oterad', False)],
         'oterade': [('oterad', False)],
         'oterats': [('oterad', False)],
         'otes': [('ot', False)],
         'otformad': [('otformad', False)],
         'otformade': [('otformad', False)],
         'otiserande': [('otiserande', False)],
         'otive': [('otiv', False)],
         'otlöst': [('otlös', False)],
         'otryckt': [('otryckt', True)],
         'oträtt': [('oträt', False)],
         'ots': [('ot', False)],
         'otsatt': [('otsatt', False)],
         'otsatta': [('otsatt', False)],
         'ott': [('odd', False)],
         'otterat': [('otterad', False)],
         'otterligare': [('otterlig', False)],
         'ottlösts': [('ottlös', False)],
         'otts': [('ott', False)],
         'otäckt': [('otäck', True)],
         'otäckts': [('otäck', True)],
         'ouerade': [('ouerad', False)],
         'ouppvärderade': [('ouppvärderad', True)],
         'ours': [('ours', False)],
         'outerat': [('outerad', False)],
         'outförd': [('outförd', True)],
         'outfört': [('outförd', True)],
         'outförts': [('outförd', True)],
         'outgivet': [('outgiven', True)],
         'ova': [('ov', False)],
         'ovalt': [('oval', True)],
         'ovalts': [('oval', True)],
         'ovande': [('ovande', False)],
         'ovant': [('ovan', False)],
         'ovants': [('ovan', True)],
         'ovats': [('ovad', False)],
         'ove': [('ov', False)],
         'ovens': [('oven', False)],
         'overt': [('overt', False)],
         'oviga': [('ovig', False)],
         'ovigt': [('ovigd', True), ('ovig', True)],
         'ovigts': [('ovig', True), ('ovigd', True)],
         'ovisad': [('ovisad', False)],
         'ovist': [('ovis', False)],
         'ovists': [('ovis', True)],
         'ovlöst': [('ovlös', False)],
         'ovlösts': [('ovlös', False)],
         'ovs': [('ov', False)],
         'ovts': [('ov', False)],
         'oväntade': [('oväntad', True)],
         'ovärt': [('ovärd', False)],
         'oxerad': [('oxerad', False)],
         'oxerade': [('oxerad', False)],
         'oxts': [('ox', False)],
         'oögts': [('oögd', False)],
         'oöversatta': [('oöversatt', True)],
         'oövervägt': [('oövervägd', True)],
         'pa': [('pa', False)],
         'pabla': [('pabel', False)],
         'pakt': [('pak', False)],
         'pakta': [('pakt', False)],
         'pakts': [('pakt', False)],
         'pallad': [('pallad', False)],
         'palt': [('pal', False)],
         'pande': [('pa', False)],
         'pankts': [('pank', False)],
         'panpassat': [('panpassad', False)],
         'pant': [('pant', False)],
         'pante': [('pant', False)],
         'parat': [('parat', True)],
         'parats': [('parat', True)],
         'pare': [('par', False)],
         'pares': [('par', False)],
         'part': [('par', False)],
         'parts': [('pard', False)],
         'passerande': [('passera', True)],
         'pat': [('pad', False)],
         'pbehandlade': [('pbehandlad', False)],
         'pblött': [('pblött', False)],
         'pblötts': [('pblött', False)],
         'pbyggd': [('pbyggd', False)],
         'pbyggt': [('pbyggd', False)],
         'pe': [('pe', False)],
         'pehållande': [('pehållande', False)],
         'pekts': [('pekt', False)],
         'pelat': [('pelad', False)],
         'pelt': [('pel', False)],
         'pelts': [('pelt', False)],
         'pens': [('pen', False)],
         'per': [('per', False)],
         'perat': [('perad', False)],
         'perats': [('perat', False)],
         'perent': [('perenn', True)],
         'periserat': [('periserad', False)],
         'perligare': [('perlig', False)],
         'pers': [('pers', False)],
         'perse': [('pers', False)],
         'perst': [('pers', False)],
         'persta': [('perst', False)],
         'perstas': [('perst', False)],
         'perste': [('perst', False)],
         'perstes': [('perst', False)],
         'persts': [('pers', False)],
         'pert': [('per', False)],
         'petalt': [('petal', False)],
         'pfryst': [('pfrysa', False)],
         'pfört': [('pförd', False)],
         'pförts': [('pförd', False)],
         'pgjorda': [('pgjord', False)],
         'pgående': [('pgående', False)],
         'phalt': [('phal', False)],
         'phalts': [('phal', False)],
         'phetsande': [('phetsa', False)],
         'phöjda': [('phöjd', False)],
         'pierad': [('pierad', False)],
         'pifierad': [('pifierad', False)],
         'pigt': [('pig', False)],
         'pikat': [('pikad', False)],
         'pillt': [('pilld', False)],
         'pinat': [('pinad', False)],
         'pint': [('pin', False)],
         'pints': [('pin', False)],
         'piserat': [('piserad', False)],
         'pklippta': [('pklippt', False)],
         'pknäppt': [('pknäppt', False)],
         'pknäppts': [('pknäppt', False)],
         'pkurats': [('pkurad', False)],
         'pkört': [('pkörd', False)],
         'pkörts': [('pkörd', False)],
         'pla': [('pel', False)],
         'placerad': [('placera', True)],
         'placerade': [('placera', True)],
         'plad': [('plad', False)],
         'plade': [('plad', False)],
         'plakat': [('plakat', True)],
         'plans': [('plan', True)],
         'plant': [('plan', True)],
         'plare': [('pel', False)],
         'plares': [('pel', False)],
         'plas': [('pel', False)],
         'plats': [('plad', False)],
         'platts': [('platt', True)],
         'ple': [('pel', False)],
         'plerad': [('plerad', False)],
         'plerade': [('plerad', False)],
         'ples': [('pel', False)],
         'plett': [('plett', False)],
         'pletts': [('plett', False)],
         'plicerad': [('plicerad', False)],
         'pligare': [('plig', False)],
         'pligaste': [('plig', False)],
         'plika': [('plik', False)],
         'plyst': [('plyst', False)],
         'plös': [('plös', False)],
         'plösande': [('plösande', False)],
         'plösts': [('plös', False)],
         'pnad': [('pnad', False)],
         'pnade': [('pnad', False)],
         'pnande': [('pnande', False)],
         'pnats': [('pnad', False)],
         'pnästa': [('pnäst', False)],
         'pnästas': [('pnäst', False)],
         'pnäste': [('pnäst', False)],
         'pnästes': [('pnäst', False)],
         'podlad': [('podlad', False)],
         'podlade': [('podlad', False)],
         'polare': [('polar', True)],
         'polares': [('polar', False)],
         'polärt': [('polär', False)],
         'polärts': [('polär', True)],
         'pontant': [('pontan', False)],
         'poppad': [('poppad', False)],
         'porda': [('pord', False)],
         'porterade': [('porterad', False)],
         'ports': [('pord', False)],
         'posant': [('posant', False)],
         'posants': [('posant', False)],
         'poströstande': [('poströstande', True), ('poströsta', True)],
         'ppa': [('pp', False)],
         'ppad': [('ppad', False)],
         'ppade': [('ppad', False)],
         'ppande': [('ppande', False)],
         'ppare': [('pp', False)],
         'ppares': [('pp', False)],
         'ppe': [('pp', False)],
         'ppelts': [('ppel', False)],
         'pperade': [('pperad', False)],
         'pperats': [('pperad', False)],
         'pperbare': [('pperbar', False)],
         'pperbares': [('pperbar', False)],
         'ppers': [('pper', False)],
         'pperst': [('pperst', False)],
         'ppersts': [('pperst', False)],
         'pplat': [('pplad', False)],
         'pplöst': [('pplös', False)],
         'pplösts': [('pplöst', False)],
         'pponerade': [('pponerad', False)],
         'ppt': [('pp', False)],
         'ppts': [('pp', False)],
         'ppvärderade': [('ppvärderad', False)],
         'prad': [('prad', False)],
         'prade': [('prad', False)],
         'prades': [('prad', False)],
         'praktiserande': [('praktisera', True)],
         'prakts': [('prak', False)],
         'prare': [('per', False)],
         'prares': [('per', False)],
         'prats': [('prad', False)],
         'pretad': [('pretad', False)],
         'pridande': [('pridande', False)],
         'pritt': [('pridd', False)],
         'prymt': [('prymd', False)],
         'prytt': [('pryd', True), ('prydd', True)],
         'prytts': [('pryd', True), ('prydd', True)],
         'prängts': [('prängd', False)],
         'prätts': [('prätt', False)],
         'prött': [('pröd', False)],
         'prötts': [('pröd', False)],
         'psad': [('psad', False)],
         'psade': [('psad', False)],
         'psamma': [('psam', False)],
         'psams': [('psam', False)],
         'pslaget': [('pslagen', False)],
         'pspärrad': [('pspärrad', False)],
         'pt': [('pt', False)],
         'pta': [('pt', False)],
         'ptagande': [('ptagande', False)],
         'ptagna': [('ptagen', False)],
         'ptas': [('pt', False)],
         'ptaxerad': [('ptaxerad', False)],
         'ptaxerade': [('ptaxerad', False)],
         'pte': [('pt', False)],
         'pterad': [('pterad', False)],
         'pterade': [('pterad', False)],
         'pterats': [('pterad', False)],
         'ptes': [('pt', False)],
         'ptive': [('ptiv', False)],
         'ptorkad': [('ptorkad', False)],
         'pts': [('pt', False)],
         'ptäckt': [('ptäckt', False)],
         'ptäckts': [('ptäckt', False)],
         'ptänkt': [('ptänkt', False)],
         'publicerad': [('publicera', True)],
         'pulveriserat': [('pulverisera', True)],
         'punna': [('punnen', False)],
         'punnas': [('punnen', False)],
         'punnastes': [('punnen', False)],
         'punne': [('punnen', False)],
         'punnes': [('punnen', False)],
         'punnet': [('punnen', False)],
         'purt': [('pur', True)],
         'puterat': [('puterad', False)],
         'putt': [('putt', True)],
         'pvist': [('pvis', False)],
         'pvists': [('pvis', False)],
         'pvit': [('pvis', False)],
         'pvits': [('pvis', False)],
         'pvärt': [('pvärd', False)],
         'pyrt': [('pyrd', False)],
         'pyrts': [('pyrd', False)],
         'pänd': [('pänd', False)],
         'pända': [('pänd', False)],
         'päntade': [('päntad', False)],
         'pänts': [('pänd', False)],
         'pådda': [('pådd', False)],
         'pårlösts': [('pårlös', False)],
         'pått': [('pådd', False)],
         'påtts': [('pådd', False)],
         'pögts': [('pögd', False)],
         'pökad': [('pökad', False)],
         'pökade': [('pökad', False)],
         'pökat': [('pökad', False)],
         'ra': [('er', False)],
         'rabba': [('rabb', False)],
         'rabla': [('rabel', False)],
         'rafast': [('rafast', False)],
         'rafaste': [('rafast', False)],
         'rafastes': [('rafast', False)],
         'rafasts': [('rafast', False)],
         'raget': [('ragen', False)],
         'ragt': [('ragt', False)],
         'ragts': [('ragt', False)],
         'rajt': [('raj', False)],
         'rakat': [('rakad', False)],
         'rakt': [('rak', False)],
         'rakta': [('rakt', False)],
         'rakts': [('rak', True)],
         'raliserande': [('ralisera', False)],
         'ralt': [('ral', False)],
         'rankts': [('rank', False)],
         'ranmäld': [('ranmäld', False)],
         'ranmälda': [('ranmäld', False)],
         'rans': [('rans', False)],
         'rante': [('rant', False)],
         'rare': [('rar', True)],
         'rares': [('rar', True)],
         'rart': [('rar', False)],
         'ras': [('er', False)],
         'raserat': [('raserad', False)],
         'rast': [('er', False)],
         'rastade': [('rastad', False)],
         'raste': [('er', False)],
         'rastes': [('er', False)],
         'rasts': [('er', False)],
         'rat': [('rad', False)],
         'ravat': [('ravad', False)],
         'ravt': [('rav', False)],
         'rba': [('rb', False)],
         'rbaserade': [('rbaserad', False)],
         'rbaserat': [('rbaserad', False)],
         'rbefolkade': [('rbefolkad', False)],
         'rbehandlade': [('rbehandlad', False)],
         'rbemälde': [('rbemäld', False)],
         'rblekt': [('rblekt', False)],
         'rblekts': [('rblekt', False)],
         'rbrett': [('rbred', False)],
         'rbyggd': [('rbyggd', False)],
         'rbyggt': [('rbyggd', False)],
         'rcerad': [('rcerad', False)],
         'rcerade': [('rcerad', False)],
         'rd': [('rd', False)],
         'rda': [('rd', False)],
         'rdad': [('rdad', False)],
         'rdade': [('rdad', False)],
         'rdande': [('rdande', False)],
         'rdants': [('rdant', False)],
         'rdare': [('rd', False)],
         'rdas': [('rd', False)],
         'rdaste': [('rd', False)],
         'rde': [('rd', False)],
         'rdelade': [('rdelad', False)],
         'rden': [('rden', False)],
         'rderade': [('rderad', False)],
         'rderats': [('rderad', False)],
         'rdes': [('rd', False)],
         'rdfört': [('rdför', False)],
         'rdförts': [('rdför', False)],
         'rdlat': [('rdlad', False)],
         'rdnat': [('rdnad', False)],
         'rdrat': [('rdrad', False)],
         'rdrätt': [('rdrätt', False)],
         'rdrätts': [('rdrätt', False)],
         'rds': [('rd', False)],
         'rdömda': [('rdömd', False)],
         're': [('er', False)],
         'redande': [('reda', False)],
         'redd': [('redd', False)],
         'redda': [('redd', False)],
         'redovisade': [('redovisa', True)],
         'reds': [('reds', False)],
         'regerad': [('regera', True)],
         'reglerad': [('reglera', True)],
         'reglerade': [('reglerad', False)],
         'rekts': [('rekt', False)],
         'rellare': [('rell', False)],
         'rellares': [('rell', False)],
         'rena': [('ren', False)],
         'renande': [('rena', False)],
         'rene': [('ren', False)],
         'renodlat': [('renodla', True)],
         'rens': [('ren', False)],
         'rent': [('ren', True)],
         'rents': [('ren', True)],
         'representerad': [('representera', True)],
         'representerade': [('representera', True)],
         'rerat': [('rerad', False)],
         'res': [('er', False)],
         'ressande': [('ressande', False)],
         'resserade': [('resserad', False)],
         'rest': [('rest', False)],
         'resta': [('rest', False)],
         'restrött': [('restrött', True)],
         'rests': [('rest', False)],
         'reställt': [('reställd', False)],
         'ret': [('ret', False)],
         'rets': [('ret', False)],
         'retts': [('redd', False)],
         'reviga': [('revig', True)],
         'revigas': [('revig', True)],
         'revigaste': [('revig', True)],
         'revigastes': [('revig', True)],
         'rfas': [('rf', False)],
         'rfast': [('rf', False)],
         'rfaste': [('rf', False)],
         'rfastes': [('rf', False)],
         'rfasts': [('rf', False)],
         'rflyttad': [('rflyttad', False)],
         'rformad': [('rformad', False)],
         'rformat': [('rformad', False)],
         'rformulerad': [('rformulerad', False)],
         'rfts': [('rf', False)],
         'rfångade': [('rfångad', False)],
         'rfördelade': [('rfördelad', False)],
         'rfördelat': [('rfördelad', False)],
         'rfört': [('rförd', False)],
         'rförts': [('rförd', False)],
         'rga': [('rg', False)],
         'rgad': [('rgad', False)],
         'rgade': [('rgad', False)],
         'rgare': [('rg', False)],
         'rgares': [('rg', False)],
         'rgas': [('rg', False)],
         'rgast': [('rg', False)],
         'rgaste': [('rg', False)],
         'rgastes': [('rg', False)],
         'rgasts': [('rg', False)],
         'rgats': [('rgad', False)],
         'rge': [('rg', False)],
         'rgen': [('rgen', False)],
         'rgerad': [('rgerad', False)],
         'rges': [('rg', False)],
         'rget': [('rgen', False)],
         'rgets': [('rgen', False)],
         'rgjorda': [('rgjord', False)],
         'rglatt': [('rglad', False)],
         'rglatts': [('rglad', False)],
         'rgna': [('rgen', False)],
         'rgnare': [('rgen', False)],
         'rgnares': [('rgen', False)],
         'rgnas': [('rgen', False)],
         'rgnast': [('rgen', False)],
         'rgnaste': [('rgen', False)],
         'rgnastes': [('rgen', False)],
         'rgnasts': [('rgen', False)],
         'rgnat': [('rgnad', False)],
         'rgne': [('rgen', False)],
         'rgnes': [('rgen', False)],
         'rgott': [('rgod', False)],
         'rgs': [('rg', False)],
         'rgts': [('rg', False)],
         'rgulares': [('rgul', False)],
         'rgående': [('rgående', False)],
         'rgången': [('rgången', False)],
         'rhandlade': [('rhandlad', False)],
         'rhöjda': [('rhöjd', False)],
         'riad': [('riad', False)],
         'rialiserade': [('rialiserad', False)],
         'riats': [('riad', False)],
         'rie': [('ri', False)],
         'rierad': [('rierad', False)],
         'rifierad': [('rifierad', False)],
         'rigat': [('rigad', False)],
         'rigt': [('rig', False)],
         'rikande': [('rika', False)],
         'rikat': [('rikad', False)],
         'rikats': [('rikat', False)],
         'rikes': [('rik', True)],
         'rikt': [('rik', False)],
         'rikts': [('rik', True)],
         'riliserat': [('riliserad', False)],
         'rilt': [('ril', False)],
         'rima': [('rima', False)],
         'ringad': [('ringad', False)],
         'ringaste': [('ringast', True)],
         'rinnande': [('rinnande', False)],
         'rinnehållande': [('rinnehållande', False)],
         'rint': [('rin', False)],
         'rints': [('rin', False)],
         'ris': [('ri', False)],
         'rise': [('rise', False)],
         'riserat': [('riserad', False)],
         'rist': [('rist', False)],
         'rista': [('rist', False)],
         'ristas': [('rist', False)],
         'riste': [('rist', False)],
         'ristes': [('rist', False)],
         'rists': [('rist', False)],
         'riterande': [('ritera', False)],
         'ritts': [('ridd', False)],
         'rivats': [('rivat', False)],
         'riven': [('riven', False)],
         'rivet': [('riven', False)],
         'rivna': [('riven', False)],
         'rjande': [('rjande', False)],
         'rjt': [('rjd', False)],
         'rka': [('rk', False)],
         'rkad': [('rkad', False)],
         'rkade': [('rkad', False)],
         'rkallad': [('rkallad', False)],
         'rkande': [('rkande', False)],
         'rkats': [('rkad', False)],
         'rkes': [('rk', False)],
         'rket': [('rken', False)],
         'rklare': [('rklar', False)],
         'rklöst': [('rklös', False)],
         'rknat': [('rknad', False)],
         'rknes': [('rken', False)],
         'rkt': [('rkt', False)],
         'rkts': [('rk', False)],
         'rkört': [('rkörd', False)],
         'rkörts': [('rkörd', False)],
         'rledd': [('rledd', False)],
         'rledda': [('rledd', False)],
         'rlents': [('rlen', False)],
         'rlett': [('rledd', False)],
         'rletts': [('rledd', False)],
         'rligare': [('rlig', False)],
         'rligaste': [('rlig', False)],
         'rligats': [('rligad', False)],
         'rlika': [('rlik', False)],
         'rlikt': [('rlikt', False)],
         'rlikts': [('rlik', False)],
         'rlyst': [('rlyst', False)],
         'rläggande': [('rlägga', False)],
         'rlängts': [('rlängd', False)],
         'rlätt': [('rlätt', False)],
         'rlätts': [('rlätt', False)],
         'rlös': [('rlös', False)],
         'rlösande': [('rlösande', False)],
         'rlöst': [('rlöst', False)],
         'rlösts': [('rlös', False)],
         'rma': [('rm', False)],
         'rmad': [('rmad', False)],
         'rmade': [('rmad', False)],
         'rmalts': [('rmal', False)],
         'rmande': [('rmande', False)],
         'rmants': [('rmant', False)],
         'rmare': [('rm', False)],
         'rmares': [('rm', False)],
         'rmas': [('rm', False)],
         'rmast': [('rm', False)],
         'rmaste': [('rm', False)],
         'rmastes': [('rm', False)],
         'rmasts': [('rm', False)],
         'rmats': [('rmad', False)],
         'rme': [('rm', False)],
         'rmenade': [('rmenad', False)],
         'rmer': [('rmer', False)],
         'rmera': [('rmera', False)],
         'rmert': [('rmert', False)],
         'rmes': [('rm', False)],
         'rminskad': [('rminskad', False)],
         'rminskade': [('rminskad', False)],
         'rminskat': [('rminskad', False)],
         'rmre': [('ra', False)],
         'rms': [('rm', False)],
         'rmsts': [('ra', False)],
         'rmts': [('rm', False)],
         'rmulerade': [('rmulerad', False)],
         'rmält': [('rmäld', False)],
         'rmärkt': [('rmärkt', False)],
         'rmärkta': [('rmärkt', False)],
         'rn': [('rn', False)],
         'rn-': [('rn', False)],
         'rna': [('rn', False)],
         'rnad': [('rnad', False)],
         'rnade': [('rnad', False)],
         'rnare': [('rn', False)],
         'rnares': [('rn', False)],
         'rnast': [('rn', False)],
         'rnaste': [('rn', False)],
         'rnastes': [('rn', False)],
         'rnasts': [('rn', False)],
         'rnats': [('rnad', False)],
         'rne': [('rn', False)],
         'rnerad': [('rnerad', False)],
         'rnerade': [('rnerad', False)],
         'rnes': [('rn', False)],
         'rngulare': [('rngul', False)],
         'rnklares': [('rnklar', False)],
         'rns': [('rn', False)],
         'rnt': [('rn', False)],
         'rnts': [('rn', False)],
         'rnärt': [('rnärd', False)],
         'rnött': [('rnött', False)],
         'rnötts': [('rnött', False)],
         'road': [('road', True)],
         'robare': [('robar', False)],
         'robares': [('robar', False)],
         'roderat': [('roderad', False)],
         'rogat': [('rogad', False)],
         'rognat': [('rognat', False)],
         'rokt': [('rok', False)],
         'rolöst': [('rolös', True)],
         'rolösts': [('rolös', False)],
         'ront': [('ron', False)],
         'ronts': [('ron', False)],
         'ropat': [('ropad', False)],
         'roppad': [('roppad', False)],
         'rordnade': [('rordnad', False)],
         'rordnat': [('rordnad', False)],
         'rosa': [('rosa', True)],
         'rosant': [('rosant', False)],
         'rosants': [('rosant', False)],
         'rotts': [('rodd', False)],
         'rpa': [('rp', False)],
         'rpad': [('rpad', False)],
         'rpade': [('rpad', False)],
         'rpare': [('rp', False)],
         'rpares': [('rp', False)],
         'rpassat': [('rpassad', False)],
         'rpe': [('rp', False)],
         'rperade': [('rperad', False)],
         'rperats': [('rperad', False)],
         'rperbare': [('rperbar', False)],
         'rperbares': [('rperbar', False)],
         'rprytt': [('rprydd', False)],
         'rprytts': [('rprydd', False)],
         'rpräglade': [('rpräglad', False)],
         'rpt': [('rp', False)],
         'rpts': [('rp', False)],
         'rra': [('rr', False)],
         'rrad': [('rrad', False)],
         'rrade': [('rrad', False)],
         'rrades': [('rrad', False)],
         'rrande': [('rrande', False)],
         'rrant': [('rran', False)],
         'rrants': [('rran', False)],
         'rrare': [('rr', False)],
         'rrares': [('rr', False)],
         'rras': [('rr', False)],
         'rrast': [('rr', False)],
         'rraste': [('rr', False)],
         'rrastes': [('rr', False)],
         'rrasts': [('rr', False)],
         'rrats': [('rrad', False)],
         'rrbare': [('rrbar', False)],
         'rrbares': [('rrbar', False)],
         'rrepresenterad': [('rrepresenterad', False)],
         'rrepresenterade': [('rrepresenterad', False)],
         'rrerade': [('rrerad', False)],
         'rrikes': [('rrik', False)],
         'rrikts': [('rrik', False)],
         'rrs': [('rr', False)],
         'rrts': [('rr', False)],
         'rrymt': [('rrymd', False)],
         'rrätt': [('rrät', False)],
         'rrätts': [('rrät', False)],
         'rrögt': [('rrögd', False)],
         'rrönt': [('rrön', False)],
         'rrönts': [('rrön', False)],
         'rrött': [('rröd', False)],
         'rrötts': [('rröd', False)],
         'rsa': [('rs', False)],
         'rsabla': [('rsabel', False)],
         'rsad': [('rsad', False)],
         'rsade': [('rsad', False)],
         'rsakade': [('rsakad', False)],
         'rsalt': [('rsal', False)],
         'rsalts': [('rsal', False)],
         'rsamma': [('rsam', False)],
         'rsams': [('rsam', False)],
         'rsbästa': [('rsbästa', False)],
         'rserade': [('rserad', False)],
         'rsett': [('rsedd', False)],
         'rsittande': [('rsittande', False)],
         'rskaftad': [('rskaftad', False)],
         'rskat': [('rskad', False)],
         'rskens': [('rsken', False)],
         'rskridande': [('rskridande', False)],
         'rskrivet': [('rskriven', False)],
         'rskyddad': [('rskyddad', False)],
         'rskyddade': [('rskyddad', False)],
         'rskällt': [('rskälld', False)],
         'rskällts': [('rskälld', False)],
         'rslutet': [('rsluta', False)],
         'rslös': [('rslös', False)],
         'rsmorda': [('rsmord', False)],
         'rsmått': [('rsmådd', False)],
         'rstbemälde': [('rstbemälde', False)],
         'rstimulerade': [('rstimulerad', False)],
         'rstnämnda': [('rstnämnd', False)],
         'rstnämndas': [('rstnämnd', False)],
         'rstnämndes': [('rstnämnd', False)],
         'rstrött': [('rströdd', False)],
         'rstämd': [('rstämd', False)],
         'rstådda': [('rstådd', False)],
         'rstörd': [('rstörd', False)],
         'rstött': [('rstödd', False)],
         'rstötts': [('rstödd', False)],
         'rsänt': [('rsänd', False)],
         'rt': [('r', False)],
         'rta': [('rt', False)],
         'rtad': [('rtad', False)],
         'rtade': [('rtad', False)],
         'rtagna': [('rtagen', False)],
         'rtalade': [('rtalad', False)],
         'rtalts': [('rtal', False)],
         'rtande': [('rtande', False)],
         'rtas': [('rt', False)],
         'rtaxerad': [('rtaxerad', False)],
         'rtaxerade': [('rtaxerad', False)],
         'rte': [('rt', False)],
         'rterad': [('rterad', False)],
         'rterade': [('rterad', False)],
         'rterats': [('rterad', False)],
         'rtersta': [('rtre', False)],
         'rterstas': [('rtre', False)],
         'rtes': [('rt', False)],
         'rtformad': [('rtformad', False)],
         'rtformade': [('rtformad', False)],
         'rtförd': [('rtförd', False)],
         'rtilts': [('rtil', False)],
         'rtive': [('rtiv', False)],
         'rtlöst': [('rtlös', False)],
         'rtorkad': [('rtorkad', False)],
         'rtrikt': [('rtrik', False)],
         'rtrustad': [('rtrustad', False)],
         'rtrustade': [('rtrustad', False)],
         'rtryckt': [('rtryckt', False)],
         'rträngt': [('rträngd', False)],
         'rtrött': [('rtrött', False)],
         'rtskilda': [('rtskild', False)],
         'rtunt': [('rtun', False)],
         'rtunts': [('rtun', False)],
         'rtäckt': [('rtäckt', False)],
         'rtäckts': [('rtäckt', False)],
         'rtänkt': [('rtänkt', False)],
         'rtärt': [('rtärd', False)],
         'rubbade': [('rubbad', False)],
         'ruerade': [('ruerad', False)],
         'runda': [('rund', False)],
         'runna': [('runnen', False)],
         'runnas': [('runnen', False)],
         'runnastes': [('runnen', False)],
         'runne': [('runnen', False)],
         'runnes': [('runnen', False)],
         'runnet': [('runnen', False)],
         'runt': [('rund', False)],
         'runts': [('rund', True)],
         'rupt': [('rupt', False)],
         'rupts': [('rupt', False)],
         'rustad': [('rustad', False)],
         'rustade': [('rustad', False)],
         'rutsedd': [('rutsedd', False)],
         'rutt': [('rutt', False)],
         'rva': [('rv', False)],
         'rvant': [('rvant', False)],
         'rvants': [('rvant', False)],
         'rvarade': [('rvarad', False)],
         'rvats': [('rvad', False)],
         'rve': [('rv', False)],
         'rviga': [('rvig', False)],
         'rvigas': [('rvig', False)],
         'rvigastes': [('rvig', False)],
         'rvigts': [('rvig', False)],
         'rvilt': [('rvil', False)],
         'rvilts': [('rvil', False)],
         'rvisad': [('rvisad', False)],
         'rvisade': [('rvisad', False)],
         'rvist': [('rvis', False)],
         'rvists': [('rvis', False)],
         'rvit': [('rvit', False)],
         'rvits': [('rvit', False)],
         'rvitt': [('rvit', False)],
         'rvitts': [('rvit', False)],
         'rvlöst': [('rvlös', False)],
         'rvlösts': [('rvlös', False)],
         'rvs': [('rv', False)],
         'rvunnet': [('rvunnen', False)],
         'rvänt': [('rvänd', False)],
         'rväntade': [('rväntad', False)],
         'rvänts': [('rvänd', False)],
         'rvärt': [('rvärd', False)],
         'ryckt': [('ryckt', False)],
         'ryddad': [('ryddad', False)],
         'ryddade': [('ryddad', False)],
         'ryggande': [('ryggande', False)],
         'ryggt': [('ryggd', False)],
         'ryggts': [('rygg', False)],
         'rymt': [('rym', False)],
         'rymts': [('rymd', False)],
         'rynt': [('rynt', False)],
         'rys': [('ry', False)],
         'rysts': [('ryst', False)],
         'rytt': [('ry', False)],
         'rytterligare': [('rytterlig', False)],
         'rytts': [('rydd', False)],
         'räckt': [('räckt', False)],
         'räckts': [('räck', False)],
         'räknat': [('räkna', True)],
         'rällts': [('räll', False)],
         'rämd': [('rämd', False)],
         'rämmat': [('rämmat', False)],
         'rämnad': [('rämnad', False)],
         'rämst': [('rämst', False)],
         'rämste': [('rämst', False)],
         'rämstes': [('rämst', False)],
         'rämts': [('rämd', False)],
         'ränd': [('ränd', False)],
         'rända': [('ränd', False)],
         'rängt': [('rängd', False)],
         'ränkt': [('ränkt', False)],
         'ränt': [('rän', False)],
         'räntade': [('räntad', False)],
         'ränts': [('ränd', False)],
         'rära': [('rär', False)],
         'rärt': [('rär', False)],
         'rärvt': [('rärvd', False)],
         'räst': [('räst', False)],
         'rästa': [('räst', False)],
         'rästas': [('räst', False)],
         'räste': [('räst', False)],
         'rästes': [('räst', False)],
         'rätt': [('rätt', False)],
         'rätte': [('rätt', False)],
         'rätts': [('rätt', True)],
         'rävt': [('räv', False)],
         'rävts': [('rävd', False)],
         'rågande': [('råga', False)],
         'rånga': [('rång', False)],
         'rångade': [('rångad', False)],
         'rångs': [('rång', False)],
         'rått': [('rå', True)],
         'råtts': [('rå', True)],
         'röde': [('röd', False)],
         'rögt': [('rög', False)],
         'rögts': [('rögd', False)],
         'röjda': [('röjd', False)],
         'rökad': [('rökad', False)],
         'rökade': [('rökad', False)],
         'rökat': [('rökad', False)],
         'rökta': [('rökt', False)],
         'römda': [('römd', False)],
         'römt': [('römd', False)],
         'römts': [('römd', False)],
         'rönt': [('rönt', False)],
         'rönts': [('rönt', False)],
         'rörd': [('rörd', False)],
         'rörda': [('rörd', False)],
         'rördas': [('rörd', False)],
         'rörde': [('rörd', False)],
         'rördes': [('rörd', False)],
         'röt': [('röd', False)],
         'röts': [('röd', False)],
         'rött': [('röd', True)],
         'rötts': [('röd', True)],
         'röversatta': [('röversatt', False)],
         'rövre': [('rov', False)],
         'rövres': [('rov', False)],
         's': [('', False)],
         'sabla': [('sabla', True)],
         'saftad': [('saftad', False)],
         'sagts': [('sagd', False)],
         'sakat': [('sakad', False)],
         'salt': [('salt', True)],
         'salts': [('salt', False)],
         'sammalt': [('sammald', True)],
         'sammanfogat': [('sammanfoga', True)],
         'sammanförda': [('sammanföra', True)],
         'samordnad': [('samordna', True)],
         'sams': [('sams', False)],
         'sande': [('sa', False)],
         'sankt': [('sankt', True), ('sank', True)],
         'sankts': [('sank', True), ('sankt', True)],
         'sannat': [('sannad', False)],
         'sanpassat': [('sanpassad', False)],
         'sant': [('sann', True)],
         'sante': [('sant', False)],
         'sants': [('sann', True)],
         'sarbetande': [('sarbetande', False)],
         'sat': [('sad', False)],
         'satt': [('satt', False)],
         'satta': [('satt', False)],
         'sbaserade': [('sbaserad', False)],
         'sbaserat': [('sbaserad', False)],
         'sbefolkade': [('sbefolkad', False)],
         'sbefrämjande': [('sbefrämjande', False)],
         'sbegränsande': [('sbegränsande', False)],
         'sbemälda': [('sbemälda', False)],
         'sbemäldas': [('sbemälda', False)],
         'sbemälde': [('sbemälda', False)],
         'sbemäldes': [('sbemälda', False)],
         'sberörda': [('sberörda', False)],
         'sberördas': [('sberörda', False)],
         'sberörde': [('sberörda', False)],
         'sberördes': [('sberörda', False)],
         'sbrett': [('sbred', False)],
         'sbäst': [('sbäst', False)],
         'sbästa': [('sbäst', False)],
         'sbästas': [('sbäst', False)],
         'sbäste': [('sbäst', False)],
         'sbästes': [('sbäst', False)],
         'sbästs': [('sbäst', False)],
         'scent': [('scen', False)],
         'scents': [('scen', False)],
         'scerad': [('scerad', False)],
         'scerade': [('scerad', False)],
         'sdömda': [('sdömd', False)],
         'se': [('se', False)],
         'sedd': [('sedd', False)],
         'sedda': [('sedd', False)],
         'segrade': [('segrad', False)],
         'selat': [('selad', False)],
         'sellare': [('sell', False)],
         'sellares': [('sell', False)],
         'selt': [('sel', False)],
         'sena': [('sen', True)],
         'senare': [('senare', True), ('sen', True)],
         'sende': [('sende', False)],
         'sene': [('sen', True)],
         'sens': [('sen', False)],
         'sent': [('sen', True)],
         'senterad': [('senterad', False)],
         'senterade': [('senterad', False)],
         'sents': [('sen', True)],
         'serat': [('serad', False)],
         'serens': [('seren', True)],
         'serents': [('seren', True)],
         'serligare': [('serlig', False)],
         'sett': [('se', True)],
         'setts': [('sedd', False)],
         'sformad': [('sformad', False)],
         'sformat': [('sformad', False)],
         'sfrämjande': [('sfrämjande', False)],
         'sförebyggande': [('sförebyggande', False)],
         'sförändrad': [('sförändrad', False)],
         'sförändrade': [('sförändrad', False)],
         'sförändrat': [('sförändrad', False)],
         'sgent': [('sgen', False)],
         'sglatt': [('sglad', False)],
         'sglatts': [('sglad', False)],
         'sgott': [('sgod', False)],
         'sgrant': [('sgrann', False)],
         'sgrants': [('sgrann', False)],
         'sgulares': [('sgul', False)],
         'sgående': [('sgående', False)],
         'shalt': [('shal', False)],
         'shalts': [('shal', False)],
         'sialiserade': [('sialiserad', False)],
         'sides': [('sid', True)],
         'sidlänt': [('sidländ', True), ('sidlänt', True)],
         'sidlänts': [('sidlänt', True), ('sidländ', True)],
         'sierad': [('sierad', False)],
         'sifierad': [('sifierad', False)],
         'sigent': [('sigent', False)],
         'sigents': [('sigent', False)],
         'sigt': [('sig', False)],
         'siliserat': [('siliserad', False)],
         'silt': [('sil', False)],
         'singulare': [('singular', True)],
         'sinnande': [('sinnande', False)],
         'sint': [('sint', False)],
         'sintrad': [('sintra', True)],
         'sints': [('sint', False)],
         'sionerad': [('sionerad', False)],
         'sippt': [('sipp', True)],
         'sippts': [('sipp', True)],
         'sistnämnda': [('sistnämnda', True), ('sistnämnd', True)],
         'sistnämndas': [('sistnämnda', True), ('sistnämnd', True)],
         'sistnämnde': [('sistnämnd', True), ('sistnämnda', True)],
         'sistnämndes': [('sistnämnda', True), ('sistnämnd', True)],
         'sitt': [('sid', False)],
         'sittande': [('sitta', True)],
         'sitts': [('sid', True)],
         'sjukpenningförsäkrade': [('sjukpenningförsäkrad', True), ('sjukpenningförsäkra', True)],
         'ska': [('sk', False)],
         'skad': [('skad', False)],
         'skadad': [('skada', True)],
         'skadade': [('skada', True)],
         'skade': [('skad', False)],
         'skaftad': [('skafta', True)],
         'skalad': [('skala', True)],
         'skallad': [('skallad', False)],
         'skande': [('skande', False)],
         'skats': [('skad', False)],
         'skavt': [('skavd', False)],
         'skens': [('skens', False)],
         'skes': [('sk', False)],
         'sket': [('sken', False)],
         'skiftande': [('skifta', True)],
         'skilda': [('skild', True)],
         'skilt': [('skild', False)],
         'sklare': [('sklar', False)],
         'sklares': [('sklar', False)],
         'sknat': [('sknad', False)],
         'sknes': [('sken', False)],
         'skridande': [('skrida', False)],
         'skriven': [('skriven', False)],
         'skrivet': [('skriva', True)],
         'skrivna': [('skriven', False)],
         'skränkande': [('skränka', False)],
         'skts': [('sk', False)],
         'skurats': [('skurad', False)],
         'skyddad': [('skydda', True)],
         'skyddade': [('skydda', True)],
         'skyddande': [('skydda', True)],
         'skällt': [('skäll', True)],
         'skällts': [('skäll', True)],
         'skärt': [('skär', True)],
         'skärts': [('skär', False)],
         'sköns': [('skön', True)],
         'skört': [('skör', True)],
         'skörts': [('skör', False)],
         'sla': [('sel', False)],
         'slad': [('slad', False)],
         'slade': [('slad', False)],
         'slaget': [('slagen', True)],
         'slande': [('slande', False)],
         'slare': [('sel', False)],
         'slares': [('sel', False)],
         'slas': [('sel', False)],
         'slat': [('slad', False)],
         'slats': [('slad', False)],
         'sle': [('sel', False)],
         'sledd': [('sledd', False)],
         'sledda': [('sledd', False)],
         'slent': [('slen', False)],
         'slents': [('slen', False)],
         'sles': [('sel', False)],
         'slett': [('sledd', False)],
         'sletts': [('sledd', False)],
         'sligare': [('slig', False)],
         'sligaste': [('slig', False)],
         'sligats': [('sligad', False)],
         'slika': [('slik', False)],
         'slikts': [('slik', False)],
         'slutet': [('sluten', False)],
         'slutna': [('sluten', False)],
         'slängd': [('slängd', True)],
         'slängda': [('slängd', True)],
         'slängts': [('slängd', True)],
         'slätt': [('slät', True)],
         'slätts': [('slät', True)],
         'slös': [('slö', True)],
         'slösts': [('slös', False)],
         'slött': [('slö', False)],
         'slötts': [('slö', False)],
         'smalts': [('smal', False)],
         'smande': [('smande', False)],
         'smorda': [('smörja', True)],
         'smältes': [('smält', False)],
         'smälts': [('smält', False)],
         'smärkt': [('smärkt', False)],
         'smärkta': [('smärkt', False)],
         'smärt': [('smärt', True)],
         'små': [('liten', False)],
         'små-': [('liten', True)],
         'smås': [('liten', True)],
         'smått': [('smått', True)],
         'snad': [('snad', False)],
         'snade': [('snad', False)],
         'snare': [('snar', False)],
         'snares': [('snar', True)],
         'snats': [('snad', False)],
         'snett': [('sned', True)],
         'snetts': [('sned', True)],
         'snoterad': [('snoterad', False)],
         'snämnda': [('snämnda', False)],
         'snära': [('snära', False)],
         'snästa': [('snäst', False)],
         'snästas': [('snäst', False)],
         'snäste': [('snäst', False)],
         'snästes': [('snäst', False)],
         'soförmögna': [('soförmögen', False)],
         'solare': [('solar', True)],
         'solares': [('solar', True)],
         'solent': [('solenn', True)],
         'solkade': [('solkad', False)],
         'soläkta': [('soläkta', True)],
         'solärt': [('solär', True)],
         'solärts': [('solär', True)],
         'sont': [('son', False)],
         'sonts': [('son', False)],
         'sopat': [('sopad', False)],
         'sorsakade': [('sorsakad', False)],
         'sorterade': [('sorterad', False)],
         'sosams': [('sosam', False)],
         'spad': [('spad', False)],
         'spade': [('spad', False)],
         'spakts': [('spak', True)],
         'spande': [('spande', False)],
         'sparat': [('sparat', False)],
         'sparats': [('sparad', False)],
         'spart': [('spard', False)],
         'spektive': [('spektive', False)],
         'spelt': [('spelt', False)],
         'sperat': [('sperat', False)],
         'splat': [('splad', False)],
         'sponerade': [('sponerad', False)],
         'spräglade': [('spräglad', False)],
         'spärrad': [('spärra', True)],
         'spätt': [('späd', True)],
         'spätts': [('späd', True)],
         'srad': [('srad', False)],
         'srade': [('srad', False)],
         'srades': [('srad', False)],
         'srakts': [('srak', False)],
         'srats': [('srad', False)],
         'sreglerade': [('sreglera', False)],
         'srent': [('sren', False)],
         'srents': [('sren', False)],
         'srikes': [('srik', False)],
         'srikts': [('srik', False)],
         'srött': [('sröd', False)],
         'srötts': [('sröd', False)],
         'ss': [('ss', False)],
         'ssa': [('ss', False)],
         'ssabla': [('ssabel', False)],
         'ssad': [('ssad', False)],
         'ssade': [('ssad', False)],
         'ssalt': [('ssal', False)],
         'ssalts': [('ssal', False)],
         'ssande': [('ssande', False)],
         'ssant': [('ssant', False)],
         'ssants': [('ssant', False)],
         'sse': [('ss', False)],
         'sserade': [('sserad', False)],
         'sskadad': [('sskadad', False)],
         'sskadade': [('sskadad', False)],
         'sskrivet': [('sskriven', False)],
         'sskyddad': [('sskyddad', False)],
         'sskyddade': [('sskyddad', False)],
         'sskyddande': [('sskyddande', False)],
         'sslös': [('sslös', False)],
         'ssnare': [('ssen', False)],
         'ssnares': [('ssen', False)],
         'sst': [('ss', False)],
         'sstimulerande': [('sstimulerande', False)],
         'sstolts': [('sstolt', False)],
         'ssts': [('ss', False)],
         'sstäckts': [('sstäck', False)],
         'sställande': [('sställande', False)],
         'sstörd': [('sstörd', False)],
         'ssurts': [('ssur', False)],
         'st': [('st', False)],
         'sta': [('st', False)],
         'stabiliserat': [('stabilisera', True)],
         'stad': [('stad', False)],
         'stade': [('stad', False)],
         'stagande': [('stagande', False)],
         'stalts': [('stal', False)],
         'standardiserat': [('standardisera', True)],
         'stande': [('stande', False)],
         'stante': [('stante', False)],
         'stants': [('stant', False)],
         'stas': [('st', False)],
         'stbemälde': [('stbemälda', False)],
         'ste': [('st', False)],
         'stellare': [('stellar', True)],
         'stellares': [('stellar', True)],
         'sterad': [('sterad', False)],
         'sterade': [('sterad', False)],
         'sterande': [('sterande', False)],
         'sterats': [('sterad', False)],
         'sters': [('ster', False)],
         'stes': [('st', False)],
         'stet': [('sten', False)],
         'stföljande': [('stföljande', False)],
         'stiftat': [('stifta', True)],
         'stigande': [('stiga', True)],
         'stilt': [('stilt', False)],
         'stimulerade': [('stimulera', True)],
         'stimulerande': [('stimulera', True)],
         'stive': [('stiv', False)],
         'stlöst': [('stlös', False)],
         'stna': [('sten', False)],
         'stnämnde': [('stnämnd', False)],
         'stolts': [('stolts', True), ('stolt', True)],
         'stra': [('ster', False)],
         'strakt': [('strak', True)],
         'strakts': [('strak', True)],
         'strande': [('stra', False)],
         'stre': [('ster', False)],
         'stres': [('ster', False)],
         'strikt': [('strikt', True)],
         'strikts': [('strikt', True)],
         'stritt': [('strid', True)],
         'stritts': [('strid', True)],
         'strofast': [('strof', False)],
         'strofaste': [('strof', False)],
         'strofastes': [('strof', False)],
         'strofasts': [('strof', False)],
         'struerade': [('struerad', False)],
         'strängt': [('sträng', True)],
         'strängts': [('sträng', True)],
         'strött': [('strödd', True)],
         'strötts': [('strödd', False)],
         'sts': [('st', False)],
         'stslaget': [('stslå', False)],
         'stäckt': [('stäck', False)],
         'stäckts': [('stäckt', False)],
         'ställda': [('ställd', False)],
         'ställt': [('ställd', True)],
         'stämd': [('stämma', True)],
         'stänkt': [('stänkt', False)],
         'stådda': [('stå', False)],
         'störande': [('störa', True)],
         'störd': [('störa', True)],
         'stört': [('störd', False)],
         'störts': [('störd', False)],
         'stött': [('stött', True)],
         'stötts': [('stött', False)],
         'sunda': [('sund', False)],
         'sunt': [('sund', False)],
         'sunts': [('sund', True)],
         'superbare': [('superb', True)],
         'superbares': [('superb', True)],
         'suppdelad': [('suppdelad', False)],
         'suppdelat': [('suppdelad', False)],
         'supplösande': [('supplösande', False)],
         'surat': [('surad', False)],
         'surt': [('sur', False)],
         'surts': [('sur', True)],
         'sutrustad': [('sutrustad', False)],
         'sutrustade': [('sutrustad', False)],
         'svalt': [('sval', True)],
         'svalts': [('sval', True)],
         'svant': [('svan', False)],
         'svants': [('svan', False)],
         'svarade': [('svarad', False)],
         'sverkande': [('sverkande', False)],
         'svidare': [('svid', False)],
         'svist': [('svis', False)],
         'svists': [('svis', False)],
         'svit': [('svit', False)],
         'svits': [('svit', False)],
         'svitt': [('svit', False)],
         'svitts': [('svit', False)],
         'svunnet': [('svunnen', True)],
         'svärt': [('svärd', False)],
         'synt': [('synt', False)],
         'syperbare': [('syperb', True)],
         'syperbares': [('syperb', True)],
         'sytts': [('sydd', False)],
         'sägda': [('sägd', False)],
         'sägt': [('sägd', False)],
         'sällts': [('säll', True)],
         'sämre': [('dålig', True)],
         'sämres': [('dålig', True)],
         'sämst': [('dålig', True)],
         'sämsta': [('dålig', True)],
         'sämstas': [('dålig', True)],
         'sämste': [('dålig', True)],
         'sämstes': [('dålig', True)],
         'sämsts': [('dålig', True)],
         'sänd': [('sänd', False)],
         'sända': [('sänd', False)],
         'sänkande': [('sänkande', False)],
         'sänkt': [('sänkt', False)],
         'sänts': [('sänd', False)],
         'sådda': [('sådd', False)],
         'sålts': [('såld', True)],
         'sårad': [('såra', True)],
         'sått': [('sådd', False)],
         'såtts': [('sådd', False)],
         'sögts': [('sögd', False)],
         'sökta': [('sökt', True)],
         'sött': [('söt', False)],
         'sötts': [('söt', False)],
         'sövts': [('sövd', False)],
         't-teoretiskt': [('-teoretisk', False)],
         'tabla': [('tabel', False)],
         'tagande': [('ta', False)],
         'taget': [('tagen', True)],
         'tagna': [('tagen', True)],
         'tajts': [('tajt', True)],
         'taka': [('taka', False)],
         'takta': [('takt', False)],
         'takts': [('takt', False)],
         'talade': [('tala', True)],
         'talda': [('tald', False)],
         'talt': [('tal', False)],
         'talts': [('tald', False)],
         'tande': [('ta', False)],
         'tannat': [('tannad', False)],
         'tans': [('tans', False)],
         'tanslutet': [('tansluten', False)],
         'tanslutna': [('tansluten', False)],
         'tant': [('tant', False)],
         'tante': [('tant', False)],
         'tants': [('tan', False)],
         'tastade': [('tastad', False)],
         'tat': [('tad', False)],
         'tatt': [('tadd', False)],
         'tatts': [('tadd', False)],
         'tavat': [('tavad', False)],
         'taxerad': [('taxera', True)],
         'taxerade': [('taxera', True)],
         'tbaserade': [('tbaserad', False)],
         'tbaserat': [('tbaserad', False)],
         'tbefolkade': [('tbefolkad', False)],
         'tbefrämjande': [('tbefrämjande', False)],
         'tbehandlade': [('tbehandlad', False)],
         'tbemälda': [('tbemälda', False)],
         'tbemäldas': [('tbemälda', False)],
         'tbemäldes': [('tbemälda', False)],
         'tbeställt': [('tbeställd', False)],
         'tbildande': [('tbilda', False)],
         'tbrett': [('tbredd', False)],
         'tbretts': [('tbredd', False)],
         'tbyggd': [('tbyggd', False)],
         'tbyggt': [('tbyggd', False)],
         'te': [('te', False)],
         'tebra': [('tebra', False)],
         'tektive': [('tektiv', False)],
         'tekts': [('tekt', False)],
         'tellare': [('tell', False)],
         'tellares': [('tell', False)],
         'telt': [('tel', False)],
         'tens': [('ten', False)],
         'tent': [('tent', False)],
         'tenterad': [('tenterad', False)],
         'tenterade': [('tenterad', False)],
         'tents': [('tent', False)],
         'ter': [('ter', False)],
         'terat': [('terad', False)],
         'teriserat': [('teriserad', False)],
         'terligare': [('terlig', False)],
         'terne': [('tern', False)],
         'terrans': [('terran', False)],
         'ters': [('ters', False)],
         'tersänt': [('tersänd', False)],
         'tert': [('ter', False)],
         'teviga': [('eviga', False)],
         'tevigas': [('eviga', False)],
         'tevigaste': [('evigaste', False)],
         'tevigastes': [('evigaste', False)],
         'tflygande': [('tflygande', False)],
         'tflytande': [('tflytande', False)],
         'tformat': [('tformad', False)],
         'tfrämjande': [('tfrämjande', False)],
         'tfångade': [('tfångad', False)],
         'tföljande': [('tfölja', False)],
         'tförebyggande': [('tförebyggande', False)],
         'tförklarad': [('tförklarad', False)],
         'tfört': [('tförd', False)],
         'tförts': [('tförd', False)],
         'tgad': [('tgad', False)],
         'tgade': [('tgad', False)],
         'tgats': [('tgad', False)],
         'tgjorda': [('tgjord', False)],
         'tglatt': [('tglad', False)],
         'tglatts': [('tglad', False)],
         'tgående': [('tgående', False)],
         'tgången': [('tgången', False)],
         'thalt': [('thal', False)],
         'thalts': [('thal', False)],
         'tida': [('tida', False)],
         'tierad': [('tierad', False)],
         'tifierad': [('tifierad', False)],
         'tigat': [('tigad', False)],
         'tigförklarad': [('tigförklarad', False)],
         'tigt': [('tig', False)],
         'tikt': [('tik', False)],
         'tiliserat': [('tiliserad', False)],
         'tillt': [('tillt', False)],
         'tilt': [('til', False)],
         'tilts': [('tilt', False)],
         'tima': [('tima', False)],
         'timats': [('timat', False)],
         'tinats': [('tinat', False)],
         'tingad': [('tingad', False)],
         'tingulares': [('tingul', False)],
         'tinkt': [('tinkt', False)],
         'tinne': [('tinn', False)],
         'tionerad': [('tionerad', False)],
         'tiserat': [('tiserad', False)],
         'tittande': [('tittande', False)],
         'tjuste': [('tjust', False)],
         'tklare': [('tklar', False)],
         'tklares': [('tklar', False)],
         'tklippta': [('tklippt', False)],
         'tkärts': [('tkär', False)],
         'tkört': [('tkörd', False)],
         'tkörts': [('tkörd', False)],
         'tlad': [('tlad', False)],
         'tlade': [('tlad', False)],
         'tlande': [('tlande', False)],
         'tlat': [('tlad', False)],
         'tlats': [('tlad', False)],
         'tledd': [('tledd', False)],
         'tledda': [('tledd', False)],
         'tleds': [('tled', False)],
         'tlett': [('tled', False)],
         'tletts': [('tled', False)],
         'tligare': [('tlig', False)],
         'tligaste': [('tlig', False)],
         'tligats': [('tligad', False)],
         'tlika': [('tlik', False)],
         'tlikts': [('tlik', False)],
         'tlokaliserade': [('tlokaliserad', False)],
         'tlåst': [('tlåst', False)],
         'tlös': [('tlös', False)],
         'tlösande': [('tlösande', False)],
         'tlösts': [('tlös', False)],
         'tmärkt': [('tmärkt', False)],
         'tmärkta': [('tmärkt', False)],
         'tnad': [('tnad', False)],
         'tnade': [('tnad', False)],
         'tnats': [('tnad', False)],
         'tnämnda': [('tnämnd', False)],
         'tnämndas': [('tnämnd', False)],
         'tnämndes': [('tnämnd', False)],
         'tnästa': [('tnäst', False)],
         'tnästas': [('tnäst', False)],
         'tnäste': [('tnäst', False)],
         'tnästes': [('tnäst', False)],
         'tnött': [('tnött', False)],
         'tnötts': [('tnött', False)],
         'tocknes': [('tocken', True)],
         'todlad': [('todlad', False)],
         'todlade': [('todlad', False)],
         'toförmögna': [('tförmögen', False)],
         'tolkade': [('tolkad', False)],
         'tolärt': [('tolär', False)],
         'tolärts': [('tolär', False)],
         'tonde': [('tonde', False)],
         'tont': [('ton', False)],
         'tonts': [('ton', False)],
         'toppad': [('toppad', False)],
         'tore': [('tor', False)],
         'torkad': [('torka', True)],
         'tormad': [('tormad', False)],
         'tormade': [('tormad', False)],
         'torra': [('torr', False)],
         'tort': [('tor', False)],
         'torterade': [('torterad', False)],
         'torts': [('tor', False)],
         'tosams': [('tosam', False)],
         'tovigt': [('tovig', True)],
         'tovigts': [('tovig', True)],
         'tplacerad': [('tplacerad', False)],
         'tplacerade': [('tplacerad', False)],
         'tponerade': [('tponerad', False)],
         'tpraktiserande': [('tpraktiserande', False)],
         'tprytt': [('tprydd', False)],
         'tprytts': [('tprydd', False)],
         'tpräglade': [('tpräglad', False)],
         'trad': [('trad', False)],
         'trade': [('trad', False)],
         'trades': [('trad', False)],
         'trande': [('trande', False)],
         'trare': [('ter', False)],
         'trares': [('ter', False)],
         'trats': [('trad', False)],
         'tre': [('tre', False)],
         'treglerad': [('treglerad', False)],
         'trerade': [('trerad', False)],
         'tres': [('tre', False)],
         'tressande': [('tressa', False)],
         'tretad': [('tretad', False)],
         'trett': [('tredd', False)],
         'tridande': [('tridande', False)],
         'trikat': [('trikat', False)],
         'trikes': [('trik', False)],
         'trikts': [('trik', False)],
         'trint': [('trind', True)],
         'trints': [('trind', True)],
         'trofast': [('trofast', True)],
         'trofaste': [('trofast', True)],
         'trofastes': [('trofast', True)],
         'trofasts': [('trofast', True)],
         'tryckt': [('tryckt', True)],
         'tryggt': [('trygg', True)],
         'träckts': [('träckt', False)],
         'träknat': [('träknad', False)],
         'trängt': [('trängd', True)],
         'trängts': [('trängd', False)],
         'trätt': [('trädd', False)],
         'trätts': [('trät', False)],
         'trävts': [('träv', False)],
         'trögts': [('trög', True)],
         'trömt': [('tröm', False)],
         'trömts': [('tröm', False)],
         'trött': [('trött', True)],
         'trötts': [('trött', False)],
         'ts': [('', False)],
         'tsad': [('tsad', False)],
         'tsade': [('tsad', False)],
         'tsaltat': [('tsaltad', False)],
         'tsamma': [('tsam', False)],
         'tsams': [('tsam', False)],
         'tsande': [('tsande', False)],
         'tsatt': [('tsätta', False)],
         'tsatta': [('tsätta', False)],
         'tserade': [('tserad', False)],
         'tsittande': [('tsittande', False)],
         'tskadad': [('tskadad', False)],
         'tskadade': [('tskadad', False)],
         'tskat': [('tskad', False)],
         'tskilda': [('tskilja', False)],
         'tskrivet': [('tskriven', False)],
         'tskränkande': [('tskränkande', False)],
         'tskällt': [('tskälld', False)],
         'tskällts': [('tskälld', False)],
         'tslaget': [('tslagen', False)],
         'tslös': [('tslös', False)],
         'tspätt': [('tspädd', False)],
         'tspätts': [('tspädd', False)],
         'tstigande': [('tstigande', False)],
         'tställda': [('tställa', False)],
         'tstörd': [('tstörd', False)],
         'tstött': [('tstött', False)],
         'tt': [('tt', False)],
         'tta': [('tt', False)],
         'ttad': [('ttad', False)],
         'ttade': [('ttad', False)],
         'ttalade': [('ttalad', False)],
         'ttande': [('ttande', False)],
         'ttas': [('tt', False)],
         'ttaxerad': [('ttaxerad', False)],
         'ttaxerade': [('ttaxerad', False)],
         'tte': [('tt', False)],
         'tterad': [('tterad', False)],
         'tterade': [('tterad', False)],
         'tterats': [('tterad', False)],
         'tters': [('tter', False)],
         'ttersta': [('ttre', False)],
         'tterstas': [('ttre', False)],
         'ttes': [('tt', False)],
         'ttet': [('tten', False)],
         'ttlett': [('ttledd', False)],
         'ttletts': [('ttledd', False)],
         'ttlöst': [('ttlös', False)],
         'ttlösts': [('ttlöst', False)],
         'ttna': [('tten', False)],
         'ttra': [('tter', False)],
         'ttre': [('tter', False)],
         'ttres': [('tter', False)],
         'ttrikt': [('ttrik', False)],
         'ttryckt': [('ttrycka', False)],
         'tträtt': [('tträtt', False)],
         'tträtts': [('tträtt', False)],
         'ttställda': [('ttställd', False)],
         'ttäckt': [('ttäckt', False)],
         'ttäckts': [('ttäckt', False)],
         'ttänkt': [('ttänkt', False)],
         'tubbade': [('tubbad', False)],
         'tuerade': [('tuerad', False)],
         'tunnare': [('tunn', False)],
         'tunnares': [('tunn', False)],
         'tunnast': [('tunn', False)],
         'tunnaste': [('tunn', False)],
         'tunnasts': [('tunn', False)],
         'tunt': [('tunn', False)],
         'tunts': [('tunn', True)],
         'turorienterande': [('turorientera', False)],
         'tvalda': [('tvald', False)],
         'tvalt': [('tvald', False)],
         'tverkande': [('tverkande', False)],
         'tvingad': [('tvinga', False)],
         'tvist': [('tvis', False)],
         'tvists': [('tvis', False)],
         'tvit': [('tvit', False)],
         'tvits': [('tvit', False)],
         'tvitt': [('tvit', False)],
         'tvitts': [('tvit', False)],
         'tvunnet': [('tvunnen', False)],
         'tvägt': [('tvägd', False)],
         'tvänt': [('tvänd', False)],
         'tvänts': [('tvänd', False)],
         'tvärt': [('tvär', True)],
         'tvärts': [('tvär', True)],
         'tyckt': [('tyckt', False)],
         'tyggts': [('tygg', False)],
         'tymt': [('tym', False)],
         'tyrt': [('tyrd', False)],
         'tyrts': [('tyrd', False)],
         'tyst': [('tyst', False)],
         'tysts': [('tyst', False)],
         'tytts': [('tydd', False)],
         'täckande': [('täckande', False)],
         'täckt': [('täck', True), ('täckt', True)],
         'täckts': [('täckt', True), ('täck', True)],
         'tägda': [('tägd', False)],
         'tägt': [('tägd', False)],
         'tämd': [('tämd', False)],
         'tämts': [('tämd', False)],
         'tänd': [('tänd', False)],
         'tända': [('tänd', False)],
         'tängt': [('tängd', False)],
         'tänkande': [('tänkande', False)],
         'tänkt': [('tänka', True)],
         'tänts': [('tänd', False)],
         'tära': [('tär', False)],
         'tärde': [('tärd', False)],
         'tärkt': [('tärkt', False)],
         'tärt': [('tärd', True)],
         'tärts': [('tärd', False)],
         'tätts': [('tät', False)],
         'tående': [('tående', False)],
         'tårlösts': [('tårlös', True)],
         'tått': [('tådd', False)],
         'tåtts': [('tådd', False)],
         'tögts': [('tögd', False)],
         'töjda': [('töjd', False)],
         'tökad': [('tökad', False)],
         'tökade': [('tökad', False)],
         'tökat': [('tökad', False)],
         'tömda': [('tömd', False)],
         'tömt': [('tömd', False)],
         'tömts': [('tömd', False)],
         'törda': [('törd', False)],
         'tördas': [('törd', False)],
         'törde': [('törd', False)],
         'tördes': [('törd', False)],
         'töversatta': [('töversatt', False)],
         'ualt': [('ual', False)],
         'uant': [('uant', False)],
         'uante': [('uant', False)],
         'uat': [('uad', False)],
         'ubra': [('uber', False)],
         'ubras': [('uber', False)],
         'ucerad': [('ucerad', False)],
         'ucerade': [('ucerad', False)],
         'udad': [('udad', False)],
         'udade': [('udad', False)],
         'udande': [('udande', False)],
         'udda': [('udda', True)],
         'uden': [('uden', False)],
         'uderade': [('uderad', False)],
         'uderande': [('uderande', False)],
         'uderats': [('uderad', False)],
         'udlat': [('udlad', False)],
         'udrat': [('udrad', False)],
         'ue': [('ue', False)],
         'uellare': [('uell', False)],
         'uellares': [('uell', False)],
         'uent': [('uent', False)],
         'uents': [('uent', False)],
         'uerat': [('uerad', False)],
         'uerligare': [('uerlig', False)],
         'uftat': [('uftad', False)],
         'uga': [('ug', False)],
         'ugad': [('ugad', False)],
         'ugade': [('ugad', False)],
         'ugande': [('ugande', False)],
         'ugare': [('ug', False)],
         'ugares': [('ug', False)],
         'ugas': [('ug', False)],
         'ugast': [('ug', False)],
         'ugaste': [('ug', False)],
         'ugastes': [('ug', False)],
         'ugasts': [('ug', False)],
         'ugats': [('ugad', False)],
         'uge': [('ug', False)],
         'ugen': [('ugen', False)],
         'ugerad': [('ugerad', False)],
         'uges': [('ug', False)],
         'uget': [('ugen', False)],
         'ugets': [('ugen', False)],
         'uggt': [('ugg', False)],
         'ugna': [('ugen', False)],
         'ugnare': [('ugen', False)],
         'ugnares': [('ugen', False)],
         'ugnas': [('ugen', False)],
         'ugnast': [('ugen', False)],
         'ugnaste': [('ugen', False)],
         'ugnastes': [('ugen', False)],
         'ugnasts': [('ugen', False)],
         'ugnat': [('ugnad', False)],
         'ugne': [('ugen', False)],
         'ugnes': [('ugen', False)],
         'ugs': [('ug', False)],
         'ugts': [('ug', False)],
         'uint': [('uin', False)],
         'uints': [('uin', False)],
         'uka': [('uk', False)],
         'ukad': [('ukad', False)],
         'ukade': [('ukad', False)],
         'ukande': [('ukande', False)],
         'ukats': [('ukad', False)],
         'ukes': [('uk', False)],
         'uket': [('uken', False)],
         'uknat': [('uknad', False)],
         'uknes': [('uken', False)],
         'ukts': [('uk', False)],
         'ula': [('ul', False)],
         'ulare': [('ul', False)],
         'ulares': [('ul', False)],
         'ulas': [('ul', False)],
         'ulast': [('ul', False)],
         'ulaste': [('ul', False)],
         'ulastes': [('ul', False)],
         'ulasts': [('ul', False)],
         'ulblekt': [('ulblek', False)],
         'ulblekts': [('ulblek', False)],
         'uldens': [('ulden', False)],
         'ule': [('ul', False)],
         'ulent': [('ulent', False)],
         'ulents': [('ulent', False)],
         'ulerad': [('ulerad', False)],
         'ulerade': [('ulerad', False)],
         'ules': [('ul', False)],
         'ulet': [('ulen', False)],
         'ulets': [('ulen', False)],
         'uligare': [('ulig', False)],
         'uligaste': [('ulig', False)],
         'ulint': [('ulin', False)],
         'ullas': [('ull', False)],
         'ullt': [('ull', False)],
         'ullärts': [('ullärd', False)],
         'ulne': [('ulen', False)],
         'uls': [('ul', False)],
         'ult': [('ult', False)],
         'ultat': [('ultad', False)],
         'ultes': [('ult', False)],
         'ults': [('ul', False)],
         'ulärt': [('ulär', False)],
         'ulärts': [('ulär', False)],
         'ulös': [('ulös', False)],
         'ulösts': [('ulös', False)],
         'uma': [('um', False)],
         'umans': [('uman', False)],
         'umant': [('uman', False)],
         'umas': [('um', False)],
         'ume': [('um', False)],
         'umes': [('um', False)],
         'umma': [('um', False)],
         'ummande': [('umma', False)],
         'ummat': [('ummad', False)],
         'umnare': [('ummen', False)],
         'umnastes': [('ummen', False)],
         'ums': [('um', False)],
         'umts': [('um', False)],
         'umulerad': [('umulerad', False)],
         'umulerade': [('umulerad', False)],
         'un': [('un', False)],
         'un-': [('un', False)],
         'una': [('un', False)],
         'unare': [('un', False)],
         'unares': [('un', False)],
         'unas': [('un', False)],
         'unast': [('un', False)],
         'unaste': [('un', False)],
         'unastes': [('un', False)],
         'unasts': [('un', False)],
         'unda': [('unda', False)],
         'unde': [('und', False)],
         'undrad': [('undrad', False)],
         'undrade': [('undrad', False)],
         'undres': [('undre', True)],
         'une': [('un', False)],
         'unerad': [('unerad', False)],
         'unerade': [('unerad', False)],
         'unes': [('un', False)],
         'ungaste': [('ung', False)],
         'ungt': [('ung', False)],
         'unklad': [('unklad', False)],
         'unklare': [('unkel', False)],
         'unkts': [('unkt', False)],
         'unna': [('unn', False)],
         'unnare': [('unnen', False)],
         'unnares': [('unnen', False)],
         'unnas': [('unn', False)],
         'unnast': [('unnen', False)],
         'unnaste': [('unnen', False)],
         'unnastes': [('unn', False)],
         'unnasts': [('unnen', False)],
         'unnat': [('unnad', False)],
         'unne': [('unn', False)],
         'unnes': [('unn', False)],
         'uns': [('un', False)],
         'unt': [('un', False)],
         'unvigt': [('unvig', False)],
         'upa': [('up', False)],
         'upad': [('upad', False)],
         'upade': [('upad', False)],
         'upande': [('upande', False)],
         'upare': [('up', False)],
         'upares': [('up', False)],
         'upe': [('up', False)],
         'uperade': [('uperad', False)],
         'uperats': [('uperad', False)],
         'uperbare': [('uperbar', False)],
         'uperbares': [('uperbar', False)],
         'uppat': [('uppad', False)],
         'uppdelad': [('uppdela', True)],
         'uppdelat': [('uppdela', True)],
         'upplevda': [('uppleva', True)],
         'upplösande': [('upplösa', True)],
         'upplöst': [('upplöst', True)],
         'uppvärderade': [('uppvärdera', True)],
         'upt': [('up', False)],
         'upts': [('up', False)],
         'ura': [('ur', False)],
         'urad': [('urad', False)],
         'urade': [('urad', False)],
         'urades': [('urad', False)],
         'urant': [('urant', False)],
         'urants': [('urant', False)],
         'urare': [('ur', False)],
         'urares': [('ur', False)],
         'uras': [('ur', False)],
         'urast': [('ur', False)],
         'uraste': [('ur', False)],
         'urastes': [('ur', False)],
         'urasts': [('ur', False)],
         'urats': [('urad', False)],
         'ure': [('ur', False)],
         'urerade': [('urerad', False)],
         'ures': [('ur', False)],
         'uret': [('uren', False)],
         'urets': [('uren', False)],
         'uris': [('uris', False)],
         'urlöst': [('urlös', False)],
         'urna': [('uren', False)],
         'urnare': [('uren', False)],
         'urnares': [('uren', False)],
         'urnas': [('uren', False)],
         'urnast': [('uren', False)],
         'urnaste': [('uren', False)],
         'urnastes': [('uren', False)],
         'urnasts': [('uren', False)],
         'urne': [('uren', False)],
         'urnes': [('uren', False)],
         'urs': [('ur', False)],
         'urt': [('urt', False)],
         'urts': [('ur', False)],
         'urögt': [('urögd', False)],
         'urött': [('uröd', False)],
         'urötts': [('uröd', False)],
         'us': [('us', False)],
         'usa': [('us', False)],
         'usad': [('usad', False)],
         'usade': [('usad', False)],
         'usalt': [('usal', False)],
         'usalts': [('usal', False)],
         'usande': [('usande', False)],
         'use': [('us', False)],
         'userade': [('userad', False)],
         'uskat': [('uskad', False)],
         'uslätt': [('uslätt', False)],
         'uslätts': [('uslätt', False)],
         'usnare': [('usen', False)],
         'usnares': [('usen', False)],
         'ussat': [('ussad', False)],
         'ust': [('us', False)],
         'ustrad': [('ustrad', False)],
         'ustrikt': [('ustrik', False)],
         'ustrikts': [('ustrik', False)],
         'usts': [('us', False)],
         'ut': [('ut', False)],
         'uta': [('ut', False)],
         'utad': [('utad', False)],
         'utade': [('utad', False)],
         'utalts': [('utal', False)],
         'utande': [('utande', False)],
         'utans': [('utan', False)],
         'utant': [('utan', False)],
         'utas': [('ut', False)],
         'ute': [('ute', True)],
         'uterad': [('uterad', False)],
         'uterade': [('uterad', False)],
         'uterats': [('uterad', False)],
         'utes': [('ut', False)],
         'utet': [('uten', False)],
         'utformad': [('utforma', True)],
         'utformade': [('utforma', True)],
         'utformat': [('utforma', True)],
         'utförd': [('utföra', True)],
         'utfört': [('utför', False)],
         'utförts': [('utför', False)],
         'utgivet': [('utge', True)],
         'utilts': [('util', False)],
         'utive': [('utiv', False)],
         'utlöst': [('utlös', False)],
         'utna': [('uten', False)],
         'utnämnde': [('utnämnd', False)],
         'utrikes': [('utrikes', True)],
         'utrofast': [('utrof', False)],
         'utrofaste': [('utrof', False)],
         'utrofastes': [('utrof', False)],
         'utrofasts': [('utrof', False)],
         'utrustad': [('utrusta', True)],
         'utrustade': [('utrusta', True)],
         'uts': [('ut', False)],
         'utsatt': [('utsatt', True)],
         'utsatta': [('utsatt', False)],
         'utsedd': [('utse', True)],
         'utsett': [('utsedd', False)],
         'utställda': [('utställd', True)],
         'utt': [('udd', False)],
         'uttagna': [('ta_ut', True)],
         'utterat': [('utterad', False)],
         'utts': [('utt', False)],
         'utökad': [('utöka', True)],
         'uvats': [('uvad', False)],
         'uve': [('uv', False)],
         'uvens': [('uven', False)],
         'uviga': [('uvig', False)],
         'uvigas': [('uvig', False)],
         'uvigastes': [('uvig', False)],
         'uvigts': [('uvig', False)],
         'uvs': [('uv', False)],
         'uvts': [('uv', False)],
         'vagt': [('vag', False)],
         'vakat': [('vakad', False)],
         'valda': [('välja', True)],
         'valt': [('välja', True)],
         'valts': [('vald', False)],
         'vanda': [('vand', False)],
         'vande': [('vand', False)],
         'vandes': [('vand', False)],
         'vands': [('vand', False)],
         'vant': [('van', True)],
         'vante': [('vant', False)],
         'vants': [('van', True)],
         'varat': [('varad', False)],
         'varmt': [('varm', True)],
         'varts': [('vart', False)],
         'vat': [('vad', False)],
         'vats': [('vat', False)],
         'vavt': [('vav', False)],
         'vbeställt': [('vbeställd', False)],
         'vcentrerade': [('vcentrerad', False)],
         'vd': [('vd', False)],
         'vda': [('vd', False)],
         'vdad': [('vdad', False)],
         'vdade': [('vdad', False)],
         'vdan': [('vdan', False)],
         'vdana': [('vdan', False)],
         'vdant': [('vdan', False)],
         'vdare': [('vd', False)],
         'vdas': [('vd', False)],
         'vdaste': [('vd', False)],
         'vde': [('vd', False)],
         'vdelade': [('vdelad', False)],
         'vdes': [('vd', False)],
         'vds': [('vd', False)],
         'vdömda': [('vdömd', False)],
         'vegants': [('vegan', True)],
         'vekt': [('vek', True)],
         'velare': [('velar', True)],
         'velares': [('velar', True)],
         'vens': [('vens', False)],
         'vent': [('vent', False)],
         'venterad': [('venterad', False)],
         'venterade': [('venterad', False)],
         'vents': [('vent', False)],
         'ver': [('ver', False)],
         'verat': [('verad', False)],
         'vergent': [('vergent', False)],
         'vergents': [('vergent', False)],
         'verkade': [('verkad', False)],
         'verkande': [('verka', True)],
         'verlämnad': [('verlämna', False)],
         'vers': [('vers', False)],
         'versalt': [('versal', False)],
         'versalts': [('versal', False)],
         'verse': [('vers', False)],
         'verst': [('vers', False)],
         'versts': [('vers', False)],
         'vert': [('ver', False)],
         'verts': [('vert', False)],
         'vetes': [('vetes', False)],
         'vett': [('vett', False)],
         'vetta': [('vett', False)],
         'vetts': [('vett', False)],
         'vflytande': [('vflytande', False)],
         'vflyttad': [('vflyttad', False)],
         'vformad': [('vformad', False)],
         'vformat': [('vformad', False)],
         'vfört': [('vförd', False)],
         'vförts': [('vförd', False)],
         'vgiven': [('vge', False)],
         'vgjorda': [('vgjord', False)],
         'vgott': [('vgod', False)],
         'vgången': [('vgången', False)],
         'vhandlade': [('vhandlad', False)],
         'vhämtade': [('vhämtad', False)],
         'vhämtat': [('vhämtad', False)],
         'vialiserade': [('vialiserad', False)],
         'vice': [('vice', True)],
         'vidare': [('vidare', True), ('vid', True)],
         'vierad': [('vierad', False)],
         'viftande': [('viftande', False)],
         'viga': [('vig', True)],
         'vigas': [('vig', True)],
         'vigaste': [('vig', True)],
         'vigastes': [('vig', True)],
         'vigat': [('vigad', False)],
         'vigda': [('vigd', False)],
         'vigt': [('vig', False)],
         'vigts': [('vig', True)],
         'vikts': [('vikt', False)],
         'vilda': [('vild', False)],
         'viliserat': [('viliserad', False)],
         'villa': [('vill', False)],
         'ville': [('vill', False)],
         'villes': [('vill', False)],
         'villts': [('vill', False)],
         'vilt': [('vild', True)],
         'vilts': [('vild', False)],
         'vinat': [('vinad', False)],
         'vingad': [('vingad', False)],
         'vinnande': [('vinnande', False)],
         'vint': [('vind', True)],
         'vints': [('vind', True)],
         'viserat': [('viserad', False)],
         'vist': [('vis', True)],
         'vista': [('vist', False)],
         'vistas': [('vist', False)],
         'viste': [('vist', False)],
         'vistes': [('vist', False)],
         'vists': [('vis', True)],
         'vit': [('vit', True)],
         'vits': [('vit', True)],
         'vitt': [('vid', True), ('vit', True)],
         'vitterats': [('vitterad', False)],
         'vitts': [('vid', True), ('vit', True)],
         'vklare': [('vklar', False)],
         'vklares': [('vklar', False)],
         'vla': [('vla', False)],
         'vlad': [('vlad', False)],
         'vlade': [('vlad', False)],
         'vlagrad': [('vlagrad', False)],
         'vlande': [('vlande', False)],
         'vlat': [('vlad', False)],
         'vlats': [('vlad', False)],
         'vligare': [('vlig', False)],
         'vligaste': [('vlig', False)],
         'vlika': [('vlik', False)],
         'vlyst': [('vlyst', False)],
         'vlös': [('vlös', False)],
         'vnad': [('vnad', False)],
         'vnade': [('vnad', False)],
         'vnats': [('vnad', False)],
         'voderat': [('voderad', False)],
         'vokt': [('vok', False)],
         'volt': [('vol', False)],
         'volts': [('vol', False)],
         'vpassat': [('vpassad', False)],
         'vrad': [('vrad', False)],
         'vrade': [('vrad', False)],
         'vrades': [('vrad', False)],
         'vrare': [('ver', False)],
         'vrares': [('ver', False)],
         'vrats': [('vrad', False)],
         'vreds': [('vred', True)],
         'vreglerad': [('vreglerad', False)],
         'vrerade': [('vrerad', False)],
         'vrikes': [('vrik', False)],
         'vrikts': [('vrik', False)],
         'vräknat': [('vräknad', False)],
         'vrängts': [('vrängd', False)],
         'vsamma': [('vsam', False)],
         'vsams': [('vsam', False)],
         'vsett': [('vsedd', False)],
         'vsides': [('vsides', False)],
         'vskadad': [('vskadad', False)],
         'vskadade': [('vskadad', False)],
         'vskrivet': [('vskriven', False)],
         'vskyddad': [('vskyddad', False)],
         'vskyddade': [('vskyddad', False)],
         'vskyddande': [('vskyddande', False)],
         'vspärrad': [('vspärrad', False)],
         'vstämd': [('vstämd', False)],
         'vstörd': [('vstörd', False)],
         'vsänt': [('vsänd', False)],
         'vt': [('v', False)],
         'vtagande': [('vtagande', False)],
         'vtalade': [('vtalad', False)],
         'vtäckt': [('vtäckt', False)],
         'vtäckts': [('vtäckt', False)],
         'vulare': [('vular', False)],
         'vulares': [('vular', False)],
         'vunna': [('vunnen', False)],
         'vunnas': [('vunnen', False)],
         'vunnastes': [('vunnen', False)],
         'vunne': [('vunnen', False)],
         'vunnes': [('vunnen', False)],
         'vunnet': [('vinna', True)],
         'vupplevda': [('vupplevd', False)],
         'vvalda': [('vvald', False)],
         'vvalt': [('vvald', False)],
         'vvant': [('vvand', False)],
         'vvants': [('vvand', False)],
         'vvarade': [('vvarad', False)],
         'vvisad': [('vvisad', False)],
         'vvisade': [('vvisad', False)],
         'vvägt': [('vvägd', False)],
         'vvänt': [('vvänd', False)],
         'vvänts': [('vvänd', False)],
         'vvärt': [('vvärd', False)],
         'vytterligare': [('vytterlig', False)],
         'väckande': [('väckande', False)],
         'väckt': [('väckt', False)],
         'vägda': [('vägd', False)],
         'vällt': [('välld', False)],
         'välvt': [('välvd', False)],
         'vämt': [('väm', False)],
         'vänd': [('vänd', False)],
         'vända': [('vänd', False)],
         'vängt': [('vängd', False)],
         'vänt': [('vän', True)],
         'väntade': [('vänta', True)],
         'vänts': [('vän', True)],
         'vära': [('vär', False)],
         'värde': [('värd', False)],
         'värderade': [('värderad', False)],
         'värkt': [('värkt', False)],
         'värmt': [('värmd', False)],
         'värre': [('ond', True)],
         'värres': [('ond', True)],
         'värst': [('ond', True), ('värst', True)],
         'värsta': [('värsta', True), ('ond', True)],
         'värstas': [('ond', True)],
         'värste': [('ond', True)],
         'värstes': [('ond', True)],
         'värsts': [('ond', True)],
         'värt': [('värt', True), ('värd', True)],
         'värts': [('värd', False)],
         'väst': [('väst', False)],
         'västa': [('väst', False)],
         'västas': [('väst', False)],
         'väste': [('väst', False)],
         'västes': [('väst', False)],
         'vävts': [('vävd', False)],
         'växande': [('växa', True)],
         'vårlöst': [('vårlöst', False)],
         'vårt': [('vår', False)],
         'vårts': [('vår', False)],
         'vått': [('våt', False)],
         'våtts': [('våt', False)],
         'xakta': [('xakt', False)],
         'xakts': [('xakt', False)],
         'xalt': [('xal', False)],
         'xat': [('xad', False)],
         'xens': [('xen', False)],
         'xerat': [('xerad', False)],
         'xformad': [('xformad', False)],
         'xformat': [('xformad', True)],
         'xigt': [('xig', False)],
         'xlad': [('xlad', False)],
         'xlade': [('xlad', False)],
         'xlande': [('xlande', False)],
         'xlat': [('xlad', False)],
         'xlats': [('xlad', False)],
         'xligare': [('xlig', False)],
         'xligaste': [('xlig', False)],
         'xlös': [('xlös', False)],
         'xlösts': [('xlös', False)],
         'xponerade': [('xponerad', False)],
         'xt': [('x', False)],
         'xta': [('xt', False)],
         'xtas': [('xt', False)],
         'xte': [('xt', False)],
         'xters': [('xter', False)],
         'xtes': [('xt', False)],
         'xtilts': [('xtil', False)],
         'xtre': [('xter', False)],
         'xtres': [('xter', False)],
         'xts': [('xt', False)],
         'yant': [('yant', False)],
         'yante': [('yant', False)],
         'yat': [('yad', False)],
         'yblötts': [('yblöt', False)],
         'ybyggd': [('ybyggd', False)],
         'ybyggt': [('ybyggd', False)],
         'yckts': [('yckt', False)],
         'yd': [('yd', False)],
         'yda': [('yd', False)],
         'ydande': [('ydande', False)],
         'ydare': [('yd', False)],
         'ydas': [('yd', False)],
         'ydaste': [('yd', False)],
         'yde': [('yd', False)],
         'ydes': [('yd', False)],
         'yds': [('yd', False)],
         'yft': [('yft', False)],
         'yftat': [('yftad', False)],
         'yfångade': [('yfångad', False)],
         'yga': [('yg', False)],
         'ygad': [('ygad', False)],
         'ygade': [('ygad', False)],
         'ygande': [('ygande', False)],
         'ygare': [('yg', False)],
         'ygares': [('yg', False)],
         'ygas': [('yg', False)],
         'ygast': [('yg', False)],
         'ygaste': [('yg', False)],
         'ygastes': [('yg', False)],
         'ygasts': [('yg', False)],
         'ygats': [('ygad', False)],
         'yge': [('yg', False)],
         'yges': [('yg', False)],
         'yggd': [('yggd', False)],
         'yggt': [('ygg', False)],
         'yggts': [('yggd', False)],
         'ygjorda': [('ygjord', False)],
         'yglatt': [('yglad', False)],
         'yglatts': [('yglad', False)],
         'ygs': [('yg', False)],
         'ygts': [('yg', False)],
         'ygången': [('ygången', False)],
         'yigt': [('yig', False)],
         'yinflyttad': [('yinflyttad', False)],
         'ykad': [('ykad', False)],
         'ykade': [('ykad', False)],
         'ykande': [('ykande', False)],
         'ykats': [('ykad', False)],
         'yket': [('yken', False)],
         'yklippta': [('yklippt', False)],
         'yknes': [('yken', False)],
         'ylerad': [('ylerad', False)],
         'ylerade': [('ylerad', False)],
         'yligare': [('ylig', False)],
         'yligaste': [('ylig', False)],
         'ylika': [('ylik', False)],
         'ylikts': [('ylik', False)],
         'yllda': [('ylld', False)],
         'yllne': [('yllen', True)],
         'yllt': [('yllt', False)],
         'yllte': [('yllt', False)],
         'yllts': [('ylld', False)],
         'ylt': [('yld', False)],
         'yltat': [('yltad', False)],
         'ylärt': [('ylär', False)],
         'ylärts': [('ylär', False)],
         'yma': [('ym', False)],
         'ymare': [('ym', False)],
         'ymares': [('ym', False)],
         'ymas': [('ym', False)],
         'ymast': [('ym', False)],
         'ymaste': [('ym', False)],
         'ymastes': [('ym', False)],
         'ymasts': [('ym', False)],
         'yme': [('ym', False)],
         'ymes': [('ym', False)],
         'ymma': [('ym', False)],
         'ymmat': [('ymmad', False)],
         'ympt': [('ympt', False)],
         'ympts': [('ympt', False)],
         'yms': [('ym', False)],
         'ymt': [('ymd', False)],
         'ymtat': [('ymtad', False)],
         'ymts': [('ym', False)],
         'yn': [('yn', False)],
         'yn-': [('yn', False)],
         'yna': [('yn', False)],
         'ynad': [('ynad', False)],
         'ynade': [('ynad', False)],
         'ynare': [('yn', False)],
         'ynares': [('yn', False)],
         'ynas': [('yn', False)],
         'ynast': [('yn', False)],
         'ynaste': [('yn', False)],
         'ynastes': [('yn', False)],
         'ynasts': [('yn', False)],
         'ynats': [('ynad', False)],
         'yne': [('yn', False)],
         'ynes': [('yn', False)],
         'yngd': [('yngd', False)],
         'yngda': [('yngd', False)],
         'yngre': [('ung', False)],
         'yngres': [('ung', True)],
         'yngst': [('ung', False)],
         'yngsta': [('ung', False)],
         'yngstas': [('ung', True)],
         'yngste': [('ung', True)],
         'yngstes': [('ung', False)],
         'yngsts': [('ung', False)],
         'yngts': [('yngd', False)],
         'ynka': [('ynka', True)],
         'ynklad': [('ynklad', False)],
         'ynnat': [('ynnad', False)],
         'yns': [('yn', False)],
         'ynt': [('yn', False)],
         'ynts': [('ynt', False)],
         'yodlade': [('yodlad', False)],
         'ypa': [('yp', False)],
         'ypande': [('ypande', False)],
         'ypare': [('yp', False)],
         'ypares': [('yp', False)],
         'ype': [('yp', False)],
         'yperade': [('yperad', False)],
         'yperats': [('yperad', False)],
         'yperbare': [('yperbar', False)],
         'yperbares': [('yperbar', False)],
         'ypt': [('yp', False)],
         'ypterat': [('ypterad', False)],
         'ypts': [('yp', False)],
         'yra': [('yr', False)],
         'yrad': [('yrad', False)],
         'yrade': [('yrad', False)],
         'yrades': [('yrad', False)],
         'yrande': [('yrande', False)],
         'yrare': [('yr', False)],
         'yrares': [('yr', False)],
         'yras': [('yr', False)],
         'yrast': [('yr', False)],
         'yraste': [('yr', False)],
         'yrastes': [('yr', True)],
         'yrasts': [('yr', False)],
         'yrats': [('yrad', False)],
         'yrbare': [('yrbar', False)],
         'yrbares': [('yrbar', False)],
         'yrdelat': [('yrdelad', False)],
         'yre': [('yr', True)],
         'yrerade': [('yrerad', False)],
         'yres': [('yr', False)],
         'yrikts': [('yrik', False)],
         'yrkta': [('yrkt', False)],
         'yrkts': [('yrkt', False)],
         'yrs': [('yr', False)],
         'yrt': [('yr', True)],
         'yrts': [('yr', True)],
         'ys': [('ys', False)],
         'ysa': [('ys', False)],
         'ysad': [('ysad', False)],
         'ysade': [('ysad', False)],
         'ysande': [('ysande', False)],
         'yse': [('ys', False)],
         'yserade': [('yserad', False)],
         'yskat': [('yskad', False)],
         'yskrivet': [('yskriven', False)],
         'yssat': [('yssad', False)],
         'ysst': [('ysst', False)],
         'yssts': [('ysst', False)],
         'yst': [('ys', False)],
         'ystrad': [('ystrad', False)],
         'ysts': [('ys', False)],
         'yt': [('y', False)],
         'ytande': [('ytande', False)],
         'yterad': [('yterad', False)],
         'yterade': [('yterad', False)],
         'yterats': [('yterad', False)],
         'yters': [('yter', False)],
         'ytet': [('yten', False)],
         'ytna': [('yten', False)],
         'ytra': [('yter', False)],
         'ytre': [('yter', False)],
         'ytres': [('yter', False)],
         'ytt': [('ydd', False)],
         'yttande': [('ytta', False)],
         'ytte': [('ytte', False)],
         'ytterligare': [('ytterligare', True), ('ytterlig', True)],
         'yttre': [('yttre', True)],
         'yttres': [('yttre', True)],
         'ytts': [('ytt', False)],
         'yutgivet': [('yutgiven', False)],
         'yva': [('yv', False)],
         'yvalda': [('yvald', False)],
         'yvalt': [('yvald', False)],
         'yvats': [('yvad', False)],
         'yve': [('yv', False)],
         'yviga': [('yvig', True)],
         'yvigts': [('yvig', True)],
         'yvs': [('yv', False)],
         'yvts': [('yv', False)],
         'yvunnet': [('yvunnen', False)],
         'yvärt': [('yvärd', False)],
         'ze': [('ze', False)],
         'zifierad': [('zifierad', False)],
         'zigt': [('zig', False)],
         'äat': [('äad', False)],
         'äckande': [('äcka', False)],
         'äckt': [('äck', False)],
         'äckts': [('äckt', False)],
         'äd': [('äd', False)],
         'äda': [('äd', False)],
         'ädad': [('ädad', False)],
         'ädade': [('ädad', False)],
         'ädande': [('ädande', False)],
         'ädare': [('äd', False)],
         'ädas': [('äd', False)],
         'ädaste': [('äd', False)],
         'äde': [('äd', False)],
         'ädelts': [('ädel', False)],
         'äden': [('äden', False)],
         'äderade': [('äderad', False)],
         'äderats': [('äderad', False)],
         'ädes': [('äd', False)],
         'ädlat': [('ädlad', False)],
         'ädrat': [('ädrad', False)],
         'äds': [('äd', False)],
         'äftat': [('äftad', False)],
         'äga': [('äga', False)],
         'ägad': [('ägad', False)],
         'ägade': [('ägad', False)],
         'ägande': [('ägande', False)],
         'ägats': [('ägad', False)],
         'ägda': [('ägda', False)],
         'ägen': [('ägen', False)],
         'äget': [('ägen', False)],
         'ägets': [('ägen', False)],
         'ägna': [('ägen', False)],
         'ägnad': [('ägnad', True)],
         'ägnare': [('ägen', False)],
         'ägnares': [('ägen', False)],
         'ägnas': [('ägen', False)],
         'ägnast': [('ägen', False)],
         'ägnaste': [('ägen', False)],
         'ägnastes': [('ägen', False)],
         'ägnasts': [('ägen', False)],
         'ägnat': [('ägnad', True)],
         'ägne': [('ägen', False)],
         'ägnes': [('ägen', False)],
         'ägre': [('åg', False)],
         'ägres': [('åg', False)],
         'ägst': [('åg', False)],
         'ägsta': [('åg', False)],
         'ägstas': [('åg', False)],
         'ägste': [('åg', False)],
         'ägstes': [('åg', False)],
         'ägsts': [('åg', False)],
         'ägt': [('äga', True)],
         'äigt': [('äig', False)],
         'äkad': [('äkad', False)],
         'äkade': [('äkad', False)],
         'äkats': [('äkad', False)],
         'äkla': [('äkla', False)],
         'äkrat': [('äkrad', False)],
         'äkre': [('äker', False)],
         'äkres': [('äker', False)],
         'äkt': [('äkt', False)],
         'äkta': [('äkta', True)],
         'äla': [('äl', False)],
         'älad': [('älad', False)],
         'älade': [('älad', False)],
         'älare': [('äl', False)],
         'älares': [('äl', False)],
         'älas': [('äl', False)],
         'älast': [('äl', False)],
         'älaste': [('äl', False)],
         'älastes': [('äl', False)],
         'älasts': [('äl', False)],
         'älat': [('älad', False)],
         'älats': [('älad', False)],
         'äldre': [('gammal', False)],
         'äldres': [('gammal', False)],
         'äldst': [('gammal', False)],
         'äldsta': [('gammal', True)],
         'äldstas': [('gammal', False)],
         'äldste': [('gammal', False)],
         'äldstes': [('gammal', True)],
         'äldsts': [('gammal', True)],
         'äle': [('äl', False)],
         'äles': [('äl', False)],
         'äligare': [('älig', False)],
         'äligaste': [('älig', False)],
         'ällande': [('älla', False)],
         'ällas': [('äll', False)],
         'ällda': [('älld', False)],
         'ällt': [('äll', False)],
         'ällts': [('älld', False)],
         'äls': [('äl', False)],
         'ältat': [('ältad', False)],
         'älts': [('äl', False)],
         'älvt': [('älv', False)],
         'älvts': [('älvd', False)],
         'äma': [('äm', False)],
         'ämad': [('ämad', False)],
         'ämade': [('ämad', False)],
         'ämare': [('äm', False)],
         'ämares': [('äm', False)],
         'ämas': [('äm', False)],
         'ämast': [('äm', False)],
         'ämasta': [('äm', False)],
         'ämastas': [('äm', False)],
         'ämaste': [('äm', False)],
         'ämastes': [('äm', False)],
         'ämasts': [('äm', False)],
         'ämats': [('ämad', False)],
         'äme': [('äm', False)],
         'ämes': [('äm', False)],
         'ämförd': [('ämförd', False)],
         'ämmat': [('ämmad', False)],
         'ämna': [('ämn', False)],
         'ämnares': [('ämn', False)],
         'ämnas': [('ämn', False)],
         'ämnast': [('ämn', False)],
         'ämnaste': [('ämn', False)],
         'ämnasts': [('ämn', False)],
         'ämne': [('ämn', False)],
         'ämnes': [('ämn', False)],
         'ämnt': [('ämn', False)],
         'ämnts': [('ämnd', False)],
         'ämpande': [('ämpa', False)],
         'äms': [('äm', False)],
         'ämst': [('äm', False)],
         'ämsta': [('ämst', False)],
         'ämstas': [('ämst', False)],
         'ämste': [('äm', False)],
         'ämstes': [('äm', False)],
         'ämsts': [('ämst', False)],
         'ämställt': [('ämställd', False)],
         'ämt': [('ämd', False)],
         'ämtat': [('ämtad', False)],
         'ämts': [('äm', False)],
         'än': [('än', False)],
         'än-': [('än', False)],
         'äna': [('än', False)],
         'änad': [('änad', False)],
         'änade': [('änad', False)],
         'änare': [('än', False)],
         'änares': [('än', False)],
         'änas': [('än', False)],
         'änast': [('än', False)],
         'änaste': [('än', False)],
         'änastes': [('än', False)],
         'änasts': [('än', False)],
         'änats': [('änad', False)],
         'ände': [('änd', False)],
         'ändrad': [('ändrad', False)],
         'ändrade': [('ändra', True)],
         'äne': [('än', False)],
         'änerad': [('änerad', False)],
         'änerade': [('änerad', False)],
         'änes': [('än', False)],
         'änförd': [('änförd', False)],
         'änförda': [('änförd', False)],
         'ängaste': [('äng', False)],
         'ängd': [('ängd', False)],
         'ängda': [('ängd', False)],
         'ängiven': [('ängiven', False)],
         'ängivet': [('ängiven', False)],
         'ängivna': [('ängiven', False)],
         'ängre': [('ång', False)],
         'ängres': [('ång', False)],
         'ängst': [('ång', False)],
         'ängsta': [('ång', False)],
         'ängstas': [('ång', False)],
         'ängste': [('ång', False)],
         'ängstes': [('ång', False)],
         'ängsts': [('ång', False)],
         'ängt': [('äng', False)],
         'ängts': [('ängd', False)],
         'änkts': [('änkt', False)],
         'änna': [('än', False)],
         'ännare': [('än', False)],
         'ännares': [('än', False)],
         'ännas': [('än', False)],
         'ännast': [('än', False)],
         'ännaste': [('än', False)],
         'ännastes': [('än', False)],
         'ännasts': [('än', False)],
         'änne': [('än', False)],
         'ännes': [('än', False)],
         'äns': [('än', False)],
         'änt': [('änd', False)],
         'änts': [('änt', False)],
         'äpad': [('äpad', False)],
         'äpade': [('äpad', False)],
         'äpande': [('äpande', False)],
         'äppat': [('äppad', False)],
         'äppt': [('äppt', False)],
         'äppta': [('äppt', False)],
         'äppts': [('äppt', False)],
         'ärad': [('ärad', False)],
         'ärade': [('ärad', False)],
         'ärades': [('ärad', False)],
         'ärande': [('ärande', False)],
         'ärare': [('är', False)],
         'ärares': [('är', False)],
         'äras': [('är', False)],
         'ärast': [('är', False)],
         'äraste': [('är', False)],
         'ärastes': [('är', False)],
         'ärasts': [('är', False)],
         'ärats': [('ärad', False)],
         'ärbare': [('ärbar', True)],
         'ärbares': [('ärbar', False)],
         'ärde': [('ärde', False)],
         'äre': [('är', False)],
         'ärerade': [('ärerad', False)],
         'äres': [('är', False)],
         'ärkta': [('ärkt', False)],
         'ärkts': [('ärkt', False)],
         'ärmare': [('ära', False)],
         'ärmares': [('ära', False)],
         'ärmast': [('ära', False)],
         'ärmaste': [('ära', False)],
         'ärmastes': [('ära', False)],
         'ärmasts': [('ära', False)],
         'ärmat': [('ärmad', False)],
         'ärmt': [('ärm', False)],
         'ärmts': [('ärmd', False)],
         'ärnas': [('ärn', False)],
         'ärpt': [('ärpt', False)],
         'ärpts': [('ärpt', False)],
         'ärrad': [('ärrad', True)],
         'ärre': [('å', False)],
         'ärres': [('å', False)],
         'ärs': [('är', False)],
         'ärst': [('å', False)],
         'ärsta': [('å', False)],
         'ärstas': [('å', False)],
         'ärste': [('å', False)],
         'ärstes': [('å', False)],
         'ärsts': [('å', False)],
         'ärtes': [('ärtes', False)],
         'ärts': [('är', False)],
         'ärvt': [('ärvd', True)],
         'ärvts': [('ärvd', False)],
         'äsad': [('äsad', False)],
         'äsade': [('äsad', False)],
         'äsande': [('äsande', False)],
         'äserade': [('äserad', False)],
         'äskadad': [('äskadad', False)],
         'äskadade': [('äskadad', False)],
         'äskat': [('äskad', False)],
         'äsnare': [('äsen', False)],
         'äsnares': [('äsen', False)],
         'ässat': [('ässad', False)],
         'ästra': [('ästra', False)],
         'ästrad': [('ästrad', False)],
         'ästrande': [('ästrande', False)],
         'ät': [('ät', False)],
         'äta': [('ät', False)],
         'ätad': [('ätad', False)],
         'ätade': [('ätad', False)],
         'ätande': [('ätande', False)],
         'ätas': [('ät', False)],
         'äte': [('ät', False)],
         'äterad': [('äterad', False)],
         'äterade': [('äterad', False)],
         'äterats': [('äterad', False)],
         'ätes': [('ät', False)],
         'ätet': [('äten', False)],
         'ätna': [('äten', False)],
         'äts': [('ät', False)],
         'ätt': [('ät', False)],
         'ätte': [('ätte', False)],
         'ätterat': [('ätterad', False)],
         'ätterligare': [('ätterlig', False)],
         'ättlöst': [('ättlöst', False)],
         'ätts': [('ätt', False)],
         'äva': [('äv', False)],
         'ävande': [('ävande', False)],
         'ävats': [('ävad', False)],
         'äve': [('äv', False)],
         'ävens': [('även', False)],
         'äviga': [('ävig', False)],
         'ävigas': [('ävig', False)],
         'ävigts': [('ävig', False)],
         'ävit': [('ävit', False)],
         'ävitt': [('ävit', False)],
         'ävitts': [('ävit', False)],
         'ävs': [('äv', False)],
         'ävt': [('ävd', False)],
         'ävts': [('äv', False)],
         'äxt': [('äxt', False)],
         'åat': [('åad', False)],
         'åbjuden': [('åbjuda', False)],
         'åd': [('åd', False)],
         'åda': [('åd', False)],
         'ådad': [('ådad', False)],
         'ådade': [('ådad', False)],
         'ådan': [('ån', False)],
         'ådande': [('ådande', False)],
         'ådant': [('ån', False)],
         'ådare': [('åd', False)],
         'ådas': [('åd', False)],
         'ådaste': [('åd', False)],
         'åde': [('åd', False)],
         'åderade': [('åderad', False)],
         'åderats': [('åderad', False)],
         'ådes': [('åd', False)],
         'åds': [('åd', False)],
         'ådsnare': [('ådsnar', False)],
         'ådsnares': [('ådsnar', False)],
         'åfängt': [('åfäng', False)],
         'åfört': [('åförd', False)],
         'åförts': [('åförd', False)],
         'åga': [('åg', False)],
         'ågad': [('ågad', False)],
         'ågade': [('ågad', False)],
         'ågande': [('ågande', False)],
         'ågas': [('åg', False)],
         'ågats': [('ågad', False)],
         'åge': [('åg', False)],
         'ågen': [('ågen', False)],
         'åges': [('åg', False)],
         'åget': [('ågen', False)],
         'ågets': [('ågen', False)],
         'ågna': [('ågen', False)],
         'ågnare': [('ågen', False)],
         'ågnares': [('ågen', False)],
         'ågnas': [('ågen', False)],
         'ågnast': [('ågen', False)],
         'ågnaste': [('ågen', False)],
         'ågnastes': [('ågen', False)],
         'ågnasts': [('ågen', False)],
         'ågnat': [('ågnad', False)],
         'ågne': [('ågen', False)],
         'ågnes': [('ågen', False)],
         'ågs': [('åg', False)],
         'ågts': [('åg', False)],
         'ågående': [('ågående', False)],
         'åigt': [('åig', False)],
         'åkad': [('åkad', False)],
         'åkade': [('åkad', False)],
         'åkallad': [('åkallad', False)],
         'åkande': [('åkande', False)],
         'åkats': [('åkad', False)],
         'åklöst': [('åklös', False)],
         'åkt': [('åkt', False)],
         'åkärts': [('åkär', False)],
         'åla': [('ål', False)],
         'ålad': [('ålad', False)],
         'ålade': [('ålad', False)],
         'ålande': [('ålande', False)],
         'ålare': [('ål', False)],
         'ålares': [('ål', False)],
         'ålas': [('ål', False)],
         'ålast': [('ål', False)],
         'ålaste': [('ål', False)],
         'ålastes': [('ål', False)],
         'ålasts': [('ål', False)],
         'ålat': [('ålad', False)],
         'ålats': [('ålad', False)],
         'åle': [('ål', False)],
         'åles': [('ål', False)],
         'åligare': [('ålig', False)],
         'åligaste': [('ålig', False)],
         'åls': [('ål', False)],
         'ålt': [('åld', False)],
         'ålts': [('ål', False)],
         'åmad': [('åmad', False)],
         'åmade': [('åmad', False)],
         'åmats': [('åmad', False)],
         'åmältes': [('åmält', False)],
         'ån': [('ån', False)],
         'ån-': [('ån', False)],
         'åna': [('ån', False)],
         'ånad': [('ånad', False)],
         'ånade': [('ånad', False)],
         'ånande': [('ånande', False)],
         'ånare': [('ån', False)],
         'ånares': [('ån', False)],
         'ånas': [('ån', False)],
         'ånast': [('ån', False)],
         'ånaste': [('ån', False)],
         'ånastes': [('ån', False)],
         'ånasts': [('ån', False)],
         'ånats': [('ånad', False)],
         'åne': [('ån', False)],
         'ånes': [('ån', False)],
         'ånga': [('ånga', False)],
         'ångaste': [('ång', False)],
         'ångs': [('ångs', False)],
         'ångt': [('ång', False)],
         'åns': [('ån', False)],
         'ånt': [('ån', False)],
         'ånts': [('ån', False)],
         'åpad': [('åpad', False)],
         'åpade': [('åpad', False)],
         'åpassat': [('åpassad', False)],
         'åra': [('år', False)],
         'årad': [('årad', False)],
         'årade': [('årad', False)],
         'årades': [('årad', False)],
         'årande': [('årande', False)],
         'årare': [('år', False)],
         'årares': [('år', False)],
         'åras': [('år', False)],
         'årast': [('år', False)],
         'åraste': [('år', False)],
         'årastes': [('år', False)],
         'årasts': [('år', False)],
         'årats': [('årad', False)],
         'årbare': [('årbar', False)],
         'årbares': [('årbar', False)],
         'årdnad': [('årdnad', False)],
         'årdnade': [('årdnad', False)],
         'åre': [('år', False)],
         'åres': [('år', False)],
         'årlöst': [('årlös', False)],
         'årlösts': [('årlöst', False)],
         'års': [('år', False)],
         'årt': [('ård', False)],
         'årts': [('ård', False)],
         'åräknat': [('åräknad', False)],
         'årögt': [('årögd', False)],
         'årömt': [('åröm', False)],
         'årömts': [('åröm', False)],
         'årött': [('åröd', False)],
         'årötts': [('åröd', False)],
         'åssat': [('åssad', False)],
         'åstrad': [('åstrad', False)],
         'åsurts': [('åsur', False)],
         'åt': [('åt', False)],
         'åta': [('åt', False)],
         'åtad': [('åtad', False)],
         'åtade': [('åtad', False)],
         'åtalade': [('åtalad', False)],
         'åtalt': [('åtald', False)],
         'åtande': [('åtande', False)],
         'åtas': [('åt', False)],
         'åte': [('åt', False)],
         'återad': [('återad', False)],
         'återade': [('återad', False)],
         'återats': [('återad', False)],
         'åtes': [('åt', False)],
         'åtet': [('åten', False)],
         'åtna': [('åten', False)],
         'åts': [('åt', False)],
         'åttlösts': [('åttlös', False)],
         'åtänkt': [('åtänkt', False)],
         'åvarmt': [('åvarmt', False)],
         'åvats': [('åvad', False)],
         'åverkande': [('åverkande', False)],
         'åvers': [('åver', False)],
         'åverts': [('åver', False)],
         'åvisad': [('åvisad', False)],
         'åvisade': [('åvisad', False)],
         'åvit': [('åvit', False)],
         'åvits': [('åvit', False)],
         'åvitt': [('åvit', False)],
         'åvitts': [('åvit', False)],
         'åvres': [('åver', False)],
         'åvärt': [('åvärd', False)],
         'åögts': [('åögd', False)],
         'éprytt': [('éprydd', False)],
         'éprytts': [('éprydd', False)],
         'érikes': [('érik', False)],
         'érikts': [('érik', False)],
         'öanpassat': [('öanpassad', False)],
         'öat': [('öad', False)],
         'öd': [('öd', False)],
         'öda': [('öd', False)],
         'ödad': [('ödad', False)],
         'ödade': [('ödad', False)],
         'ödande': [('ödande', False)],
         'ödare': [('öd', False)],
         'ödas': [('öd', False)],
         'ödaste': [('öd', False)],
         'öde': [('öde', True)],
         'ödes': [('öd', False)],
         'ödgat': [('ödgad', False)],
         'ödrat': [('ödrad', False)],
         'öds': [('öd', False)],
         'öende': [('öende', False)],
         'öga': [('ög', False)],
         'ögad': [('ögad', False)],
         'ögade': [('ögad', False)],
         'ögare': [('ög', False)],
         'ögares': [('ög', False)],
         'ögas': [('ög', False)],
         'ögast': [('ög', False)],
         'ögaste': [('ög', False)],
         'ögastes': [('ög', False)],
         'ögasts': [('ög', False)],
         'ögats': [('ögad', False)],
         'öge': [('ög', False)],
         'ögen': [('ögen', False)],
         'öges': [('ög', False)],
         'öget': [('ögen', False)],
         'ögets': [('ögen', False)],
         'ögna': [('ögen', False)],
         'ögnare': [('ögen', False)],
         'ögnares': [('ögen', False)],
         'ögnas': [('ögen', False)],
         'ögnast': [('ögen', False)],
         'ögnaste': [('ögen', False)],
         'ögnastes': [('ögen', False)],
         'ögnasts': [('ögen', False)],
         'ögne': [('ögen', False)],
         'ögnes': [('ögen', False)],
         'ögs': [('ög', False)],
         'ögste': [('ög', False)],
         'ögt': [('ögd', False)],
         'ögts': [('ög', False)],
         'ögående': [('ögående', False)],
         'öhalt': [('öhal', False)],
         'öhalts': [('öhal', False)],
         'öigt': [('öig', False)],
         'öjande': [('öjande', False)],
         'öjt': [('öjd', False)],
         'ökad': [('öka', True)],
         'ökade': [('öka', True)],
         'ökande': [('ökande', False)],
         'ökat': [('öka', True)],
         'ökats': [('ökad', False)],
         'ökt': [('ökt', False)],
         'ölad': [('ölad', False)],
         'ölade': [('ölad', False)],
         'ölat': [('ölad', False)],
         'ölats': [('ölad', False)],
         'öligare': [('ölig', False)],
         'öligaste': [('ölig', False)],
         'öma': [('öm', False)],
         'ömare': [('öm', False)],
         'ömares': [('öm', False)],
         'ömas': [('öm', False)],
         'ömast': [('öm', False)],
         'ömaste': [('öm', False)],
         'ömastes': [('öm', False)],
         'ömasts': [('öm', False)],
         'öme': [('öm', False)],
         'ömes': [('öm', False)],
         'ömma': [('öm', True)],
         'ömmat': [('ömmad', False)],
         'öms': [('öm', False)],
         'ömt': [('öm', True)],
         'ömts': [('öm', False)],
         'ön': [('ön', False)],
         'ön-': [('ön', False)],
         'öna': [('ön', False)],
         'önad': [('önad', False)],
         'önade': [('önad', False)],
         'önande': [('önande', False)],
         'önare': [('ön', False)],
         'önares': [('ön', False)],
         'önas': [('ön', False)],
         'önast': [('ön', False)],
         'önaste': [('ön', False)],
         'önastes': [('ön', False)],
         'önasts': [('ön', False)],
         'önats': [('önad', False)],
         'öndrad': [('öndrad', False)],
         'öndrade': [('öndrad', False)],
         'öne': [('ön', False)],
         'önes': [('ön', False)],
         'öngulare': [('öngul', False)],
         'öns': [('ön', False)],
         'önskad': [('önskad', False)],
         'önskade': [('önskad', False)],
         'önt': [('ön', False)],
         'önts': [('ön', False)],
         'öpad': [('öpad', False)],
         'öpade': [('öpad', False)],
         'öpande': [('öpande', False)],
         'öra': [('ör', False)],
         'örad': [('örad', False)],
         'örade': [('örad', False)],
         'örades': [('örad', False)],
         'örande': [('örande', False)],
         'örare': [('ör', False)],
         'örares': [('ör', False)],
         'öras': [('ör', False)],
         'örast': [('ör', False)],
         'öraste': [('ör', False)],
         'örastes': [('ör', False)],
         'örasts': [('ör', False)],
         'örats': [('örad', False)],
         'örbare': [('örbar', False)],
         'örbares': [('örbar', False)],
         'örbemälde': [('örbemälde', False)],
         'öre': [('ör', False)],
         'öres': [('ör', False)],
         'örikes': [('örik', False)],
         'örikts': [('örik', False)],
         'örkastade': [('örkastad', False)],
         'örkt': [('örk', False)],
         'örlikts': [('örlikt', False)],
         'örlösts': [('örlöst', False)],
         'örpt': [('örpt', False)],
         'örpts': [('örpt', False)],
         'örra': [('örra', False)],
         'örras': [('örra', False)],
         'örre': [('or', False)],
         'örres': [('or', False)],
         'örs': [('ör', False)],
         'örst': [('or', False)],
         'örsta': [('or', False)],
         'örstas': [('or', False)],
         'örste': [('or', False)],
         'örstes': [('or', False)],
         'örsts': [('or', False)],
         'ört': [('örd', False)],
         'örts': [('örd', False)],
         'örunt': [('örunt', False)],
         'örunts': [('örunt', False)],
         'örvist': [('örvist', False)],
         'örvists': [('örvist', False)],
         'ös': [('ös', False)],
         'ösa': [('ös', False)],
         'ösad': [('ösad', False)],
         'ösade': [('ösad', False)],
         'öse': [('ös', False)],
         'öskadad': [('öskadad', False)],
         'öskadade': [('öskadad', False)],
         'öskat': [('öskad', False)],
         'öst': [('ös', False)],
         'östra': [('östra', False)],
         'östrikt': [('östrik', False)],
         'östrikts': [('östrik', False)],
         'östs': [('ös', False)],
         'öt': [('öt', False)],
         'öta': [('öt', False)],
         'ötad': [('ötad', False)],
         'ötade': [('ötad', False)],
         'ötande': [('ötande', False)],
         'ötas': [('öt', False)],
         'öte': [('öt', False)],
         'ötes': [('öt', False)],
         'ötrött': [('ötrött', False)],
         'öts': [('öt', False)],
         'ött': [('ödd', False)],
         'öttlösts': [('öttlös', False)],
         'ötts': [('ött', False)],
         'ötäckt': [('ötäckt', False)],
         'ötäckts': [('ötäckt', False)],
         'öva': [('öv', False)],
         'övande': [('övande', False)],
         'övant': [('övan', False)],
         'övants': [('övan', False)],
         'övats': [('övad', False)],
         'öve': [('öv', False)],
         'översatta': [('översätta', True)],
         'övervägt': [('överväga', True)],
         'öviga': [('övig', False)],
         'övigas': [('övig', False)],
         'övigts': [('övig', False)],
         'övilt': [('övild', False)],
         'övit': [('övit', False)],
         'övits': [('övit', False)],
         'övitt': [('övit', False)],
         'övitts': [('övit', False)],
         'övre': [('övre', True)],
         'övres': [('övre', True)],
         'övrigt': [('övrig', True), ('övrigt', True)],
         'övs': [('öv', False)],
         'övst': [('ov', False)],
         'övsta': [('ov', False)],
         'övstas': [('ov', False)],
         'övste': [('ov', False)],
         'övstes': [('ov', False)],
         'övsts': [('ov', False)],
         'övt': [('övd', False)],
         'övts': [('öv', False)]},
 'ADJ_ADV': {'er': [('ycket', False)], 'st': [('e', False)]},
 'ADJ_NOUN': {'-': [('a', False)],
              'a': [('um', False)],
              'ar': [('', False)],
              'arna': [('', False)],
              'den': [('d', False)],
              'dern': [('r', False)],
              'dier': [('dium', False)],
              'eden': [('ede', False)],
              'en': [('en', False)],
              'engar': [('engar', False)],
              'erna': [('', False)],
              'es': [('es', False)],
              'et': [('', False)],
              'ier': [('ie', False)],
              'is': [('is', False)],
              'ken': [('ke', False)],
              'len': [('l', False)],
              'ler': [('l', False)],
              'llen': [('lle', False)],
              'mar': [('', False)],
              'mn': [('mn', False)],
              'n': [('', False)],
              'ngar': [('ng', False)],
              'ns': [('ns', False)],
              'or': [('or', False)],
              'rden': [('rde', False)],
              's': [('', False)],
              'sen': [('s', False)],
              'ter': [('ter', False)],
              'ts': [('', False)],
              'udier': [('udie', False)],
              'äder': [('ar', False)],
              'ägar': [('äg', False)],
              'änder': [('and', False)],
              'änderna': [('and', False)],
              'ändernas': [('and', False)],
              'ån': [('ån', False)],
              'år': [('år', True)],
              'ödrar': [('or', False)],
              'ödrarna': [('or', False)],
              'ön': [('ön', False)]},
 'ADJ_VERB': {'an': [('unna', False)],
              'as': [('as', False)],
              'r': [('', False)],
              's': [('as', False)],
              'är': [('vara', True)]},
 'ADP_ADJ': {'are': [('', False)],
             'de': [('', False)],
             'nde': [('', False)],
             'tt': [('tt', False)],
             'ästa': [('ra', False)],
             'övrigt': [('övrigt', True), ('övrig', True)]},
 'ADP_ADV': {'er': [('ycket', False)],
             'era': [('ycket', False)],
             'mindre': [('lite', True)],
             'minst': [('lite', True)],
             're': [('e', False)]},
 'ADP_DET': {'t': [('', False)], 'var': [('vara', True), ('var', True)]},
 'ADP_NOUN': {'-': [('a', False)],
              'ar': [('', False)],
              'arna': [('', False)],
              'dagens': [('dagens', True), ('dag', True)],
              'dern': [('r', False)],
              'e-': [('um', False)],
              'en': [('', False)],
              'engar': [('engar', False)],
              'er': [('', False)],
              'erna': [('', False)],
              'et': [('', False)],
              'far': [('far', True)],
              'gen': [('gen', False)],
              'ier': [('ie', False)],
              'is': [('is', True)],
              'it': [('it', False)],
              'js': [('js', False)],
              'karna': [('kare', False)],
              'ken': [('ke', False)],
              'kerna': [('kerna', False)],
              'ks': [('ks', False)],
              'let': [('le', False)],
              'ngar': [('ng', False)],
              'ns': [('', False)],
              'nvägarna': [('nvägare', False)],
              'rs': [('rs', False)],
              's': [('', False)],
              'tanken': [('tank', True), ('tanke', True)],
              'ter': [('ter', False)],
              'vägarna': [('väg', True)],
              'änder': [('and', False)],
              'änderna': [('and', False)],
              'ödrar': [('or', False)]},
 'ADP_NUM': {')': [('', False)]},
 'ADP_PROPN': {'s': [('', False)]},
 'ADP_VERB': {'s': [('a', False)]},
 'ADV': {'-': [('', False)],
         'afullt': [('afullt', False)],
         'agt': [('agd', False)],
         'akt': [('ak', False)],
         'allt': [('allt', False)],
         'alt': [('al', False)],
         'are': [('', False)],
         'ass': [('ass', False)],
         'at': [('at', False)],
         'ativt': [('ativ', False)],
         'bort': [('bort', True)],
         'bättre': [('bra', True)],
         'dant': [('dan', False)],
         'dare': [('dare', False)],
         'dast': [('dast', False)],
         'den': [('den', False)],
         'der': [('der', False)],
         'dera': [('dera', False)],
         'dess': [('den', True)],
         'digare': [('digare', False)],
         'digast': [('digast', False)],
         'dikt': [('dikt', True)],
         'dligt': [('dlig', False)],
         'drat': [('drat', False)],
         'döst': [('döst', False)],
         'elt': [('el', False)],
         'emt': [('em', False)],
         'en': [('en', True)],
         'enbart': [('enbart', True)],
         'ere': [('ere', False)],
         'erligt': [('erligt', False)],
         'ess': [('ess', False)],
         'est': [('ycket', False)],
         'et': [('et', False)],
         'evärt': [('evärd', False)],
         'falt': [('falt', False)],
         'fast': [('fast', True)],
         'fort': [('fort', False)],
         'fritt': [('fri', False)],
         'ft': [('ft', False)],
         'ftigt': [('ftig', False)],
         'fullt': [('full', False)],
         'gen': [('gen', False)],
         'gent': [('gent', False)],
         'got': [('gon', False)],
         'grant': [('grann', False)],
         'gsamt': [('gsam', False)],
         'hellre': [('gärna', True)],
         'helst': [('gärna', True)],
         'helt': [('helt', True)],
         'hårt': [('hård', True)],
         'igare': [('ig', False)],
         'igst': [('igst', False)],
         'igt': [('ig', False)],
         'ikt': [('ik', False)],
         'int': [('in', False)],
         'it': [('it', False)],
         'itet': [('itet', False)],
         'itivt': [('itiv', False)],
         'ivt': [('iv', False)],
         'iöst': [('iös', False)],
         'jert': [('jert', False)],
         'jest': [('jest', False)],
         'jfritt': [('jfritt', False)],
         'jligt': [('jlig', False)],
         'kant': [('kant', False)],
         'kat': [('kad', False)],
         'kbart': [('kbar', False)],
         'kert': [('kert', False)],
         'klart': [('klar', False)],
         'klat': [('kla', False)],
         'kligt': [('klig', False)],
         'kort': [('kort', True)],
         'krent': [('krent', False)],
         'kt': [('kt', False)],
         'ktast': [('kta', False)],
         'ktigt': [('ktig', False)],
         'ktivt': [('ktiv', False)],
         'lant': [('lant', False)],
         'lat': [('lad', False)],
         'lativt': [('lativt', False)],
         'lbart': [('lbar', False)],
         'len': [('len', False)],
         'ler': [('ler', False)],
         'lest': [('lest', False)],
         'ligast': [('ligast', False)],
         'litt': [('litt', False)],
         'llet': [('llet', False)],
         'lligast': [('llig', False)],
         'lligt': [('llig', False)],
         'llt': [('ll', False)],
         'lott': [('lott', False)],
         'lt': [('lt', False)],
         'längre': [('länge', True), ('längre', True)],
         'längst': [('längst', True), ('länge', True)],
         'löst': [('löst', False)],
         'mant': [('mant', False)],
         'mare': [('a', False)],
         'mast': [('a', False)],
         'mat': [('mad', False)],
         'ment': [('ment', False)],
         'mer': [('mycket', True), ('mer', True)],
         'mera': [('mycket', True), ('mera', True)],
         'mhelst': [('mhelst', False)],
         'mindre': [('föga', True), ('lite', True)],
         'minst': [('föga', True), ('lite', True), ('minst', True)],
         'mitt': [('mitt', True)],
         'mnt': [('mn', False)],
         'moftast': [('moftast', False)],
         'mre': [('a', False)],
         'mskt': [('mskt', False)],
         'mst': [('a', False)],
         'mt': [('mt', False)],
         'nare': [('nare', False)],
         'nart': [('nart', False)],
         'nast': [('nast', False)],
         'nativt': [('nativt', False)],
         'ner': [('ner', False)],
         'ngt': [('ng', False)],
         'nigt': [('nigt', False)],
         'nligt': [('nlig', False)],
         'nmer': [('nmer', False)],
         'nmera': [('nmera', False)],
         'nsamt': [('nsam', False)],
         'nt': [('nt', False)],
         'ntet': [('ntet', False)],
         'näst': [('näst', False)],
         'oftast': [('ofta', True)],
         'ogsamt': [('ogsamt', False)],
         'ore': [('ore', False)],
         'ort': [('ord', False)],
         'oss': [('oss', False)],
         'ot': [('ot', False)],
         'ott': [('od', False)],
         'past': [('past', False)],
         'penbart': [('penbar', False)],
         'pet': [('pen', False)],
         'pligt': [('plig', False)],
         'pt': [('pt', False)],
         'pänt': [('pänna', False)],
         'rant': [('rant', False)],
         'rare': [('rare', False)],
         'rast': [('rast', False)],
         'rat': [('ra', False)],
         'rent': [('ren', True)],
         'rest': [('rest', False)],
         'rhelst': [('rhelst', False)],
         'rigt': [('rigt', False)],
         'ritt': [('ritt', False)],
         'rkt': [('rk', False)],
         'rligt': [('rlig', False)],
         'rmera': [('rmera', False)],
         'rmt': [('rm', False)],
         'rsent': [('rsent', False)],
         'rskilt': [('rskilt', False)],
         'rt': [('rt', False)],
         'rtare': [('rt', False)],
         'rärt': [('rär', False)],
         'sbättre': [('sbättre', False)],
         'sen': [('sen', False)],
         'sent': [('sen', True)],
         'skilt': [('skild', False)],
         'skt': [('sk', False)],
         'sligt': [('slig', False)],
         'slöst': [('slös', False)],
         'st': [('st', False)],
         'svärre': [('svärre', False)],
         'sämre': [('illa', True)],
         'sämst': [('illa', True)],
         't': [('', False)],
         'tare': [('ta', False)],
         'tast': [('t', False)],
         'tat': [('tad', False)],
         'ter': [('ter', False)],
         'tera': [('tera', False)],
         'tet': [('ten', False)],
         'tfritt': [('tfritt', False)],
         'thelst': [('thelst', False)],
         'tigt': [('tigt', False)],
         'tint': [('tint', False)],
         'tligt': [('tlig', False)],
         'tmer': [('tmer', False)],
         'tmera': [('tmera', False)],
         'tmindre': [('tmindre', False)],
         'tort': [('tor', False)],
         'tre': [('tre', False)],
         'tt': [('tt', False)],
         'ttare': [('tt', False)],
         'uerligt': [('uerlig', False)],
         'umer': [('umer', False)],
         'umera': [('umera', False)],
         'upt': [('up', False)],
         'urat': [('urat', False)],
         'urt': [('ur', False)],
         'ut': [('ut', False)],
         'vart': [('vart', False)],
         'ver': [('ver', False)],
         'vilt': [('vilt', False)],
         'vint': [('vint', False)],
         'vitt': [('vitt', False)],
         'vligt': [('vlig', False)],
         'vt': [('vt', False)],
         'vänt': [('vänt', False)],
         'värre': [('illa', True)],
         'värst': [('illa', True)],
         'värt': [('värt', False)],
         'väst': [('väst', True)],
         'wint': [('wint', False)],
         'xakt': [('xakt', False)],
         'ygt': [('yg', False)],
         'yss': [('yss', False)],
         'ägen': [('äg', False)],
         'äkert': [('äker', False)],
         'ämst': [('ämst', False)],
         'änt': [('än', False)],
         'ärkt': [('ärkt', False)],
         'ärligt': [('ärligt', False)],
         'äst': [('ra', False)],
         'ävligt': [('ävligt', False)],
         'ågt': [('åg', False)],
         'åklart': [('åklart', False)],
         'ållet': [('ållen', False)],
         'åmera': [('åmera', False)],
         'ångt': [('ångt', False)],
         'årt': [('år', False)],
         'åt': [('åt', False)],
         'ögre': [('ög', False)],
         'ögst': [('ögst', False)],
         'ögt': [('ög', False)],
         'öre': [('öre', False)],
         'öst': [('öst', True)]},
 'ADV_ADJ': {'nt': [('nt', False)], 't': [('d', False)], 'tt': [('tt', False)], 'ättre': [('ra', False)]},
 'ADV_ADV': {'er': [('ycket', False)],
             'era': [('ycket', False)],
             'mindre': [('lite', True), ('liten', True)],
             're': [('e', False)],
             'st': [('e', False)]},
 'ADV_DET': {'t': [('', False)], 'var': [('vara', True), ('var', True)]},
 'ADV_NOUN': {'ar': [('ar', False)], 'en': [('', False)], 'r': [('', False)], 'år': [('år', True)]},
 'ADV_VERB': {'att': [('itta', False)],
              'atts': [('ätta', False)],
              'er': [('a', False)],
              'ev': [('iva', False)],
              'las': [('la', False)],
              'lts': [('lja', False)],
              'lär': [('lära', True)],
              'nas': [('na', False)],
              'nnas': [('nnas', False)],
              'ns': [('nas', False)],
              'ras': [('ra', False)],
              't': [('a', False)],
              'ts': [('ta', False)],
              'vs': [('va', False)],
              'är': [('vara', True)],
              'år': [('å', False)]},
 'AUX': {'a': [('ola', False)],
         'ade': [('a', False)],
         'all': [('ola', False)],
         'an': [('unna', False)],
         'ar': [('ara', False)],
         'de': [('a', False)],
         'en': [('a', False)],
         'er': [('a', False)],
         'ev': [('i', False)],
         'ha': [('ha', True)],
         'har': [('ha', True)],
         'ick': [('å', False)],
         'it': [('a', False)],
         'ja': [('ja', False)],
         'kar': [('ka', False)],
         'l': [('ja', False)],
         'le': [('ja', False)],
         'lär': [('lär', True)],
         'm': [('mma', False)],
         'ma': [('ma', False)],
         'na': [('na', False)],
         'nde': [('nna', False)],
         'orde': [('öra', False)],
         'ore': [('ara', False)],
         'r': [('', False)],
         'ra': [('ra', False)],
         't': [('', False)],
         'torde': [('torde', True)],
         'tt': [('', False)],
         'ulle': [('ola', False)],
         'va': [('va', False)],
         'vit': [('', False)],
         'är': [('vara', True)],
         'äro': [('vara', True)],
         'ör': [('öra', False)]},
 'AUX_ADJ': {'de': [('', False)], 't': [('d', False)], 'äst': [('ra', False)], 'ättre': [('ra', False)]},
 'AUX_ADV': {'er': [('ycket', False)], 'mindre': [('lite', True)], 'minst': [('lite', True)]},
 'AUX_DET': {'r': [('ra', False)]},
 'AUX_NOUN': {'-': [('', False)], 'dern': [('r', False)], 'n': [('', False)], 'nas': [('e', False)]},
 'AUX_VERB': {'as': [('as', False)],
              'las': [('la', False)],
              'tas': [('ta', True)],
              'tt': [('da', False)],
              'unnits': [('innas', False)],
              'vas': [('va', False)]},
 'CCONJ_ADJ': {'are': [('', False)], 'flera': [('mången', True), ('flera', True)], 'ättre': [('ra', False)]},
 'CCONJ_ADV': {'er': [('ycket', False)],
               'mindre': [('lite', True)],
               'minst': [('liten', True), ('lite', True)],
               'st': [('e', False)]},
 'CCONJ_DET': {'r': [('ra', False)]},
 'CCONJ_NOUN': {'ar': [('', False)],
                'en': [('', False)],
                'er': [('a', False)],
                'mn': [('mn', False)],
                'mnen': [('mn', False)],
                'n': [('', False)],
                'nen': [('ne', False)],
                'ödrar': [('or', False)]},
 'CCONJ_VERB': {'ad': [('e', False)],
                'as': [('a', False)],
                'r': [('', False)],
                's': [('as', False)],
                'ts': [('', False)],
                'unnits': [('inna', False)],
                'är': [('vara', True)]},
 'DET': {'a': [('en', False)],
         'allt': [('allt', True), ('all', True)],
         'da': [('da', False)],
         'de': [('en', True)],
         'den': [('en', True)],
         'det': [('en', True)],
         'dom': [('en', True)],
         'era': [('era', False)],
         'et': [('en', False)],
         'la': [('l', False)],
         'ma': [('ma', False)],
         'na': [('n', False)],
         'nna': [('nna', False)],
         'ot': [('on', False)],
         'ra': [('on', False)],
         'ssa': [('nna', False)],
         'tt': [('n', False)],
         'tta': [('nna', False)],
         'var': [('vara', True), ('var', True)]},
 'DET_ADJ': {'are': [('', False)],
             'förvärvsarbetande': [('förvärvsarbeta', True), ('förvärvsarbetande', True)],
             'nande': [('na', False)],
             'poströstande': [('poströstande', True), ('poströsta', True)],
             'värsta': [('ond', True)],
             'ästa': [('ra', False)],
             'ättre': [('ra', False)]},
 'DET_ADV': {'er': [('ycket', False)], 'mindre': [('liten', True), ('lite', True)]},
 'DET_NOUN': {'ar': [('', False)],
              'den': [('de', False)],
              'en': [('', False)],
              'er': [('um', False)],
              'gar': [('gar', False)],
              'is': [('is', False)],
              'len': [('le', False)],
              'ler': [('l', False)],
              'ns': [('ns', False)],
              'rts': [('rt', False)],
              's': [('', False)],
              'ts': [('ts', False)],
              'äder': [('ar', False)],
              'änder': [('and', False)],
              'änders': [('and', False)],
              'ån': [('ån', False)]},
 'NOUN': {"'rolls": [("'roll", False)],
          '-': [('', False)],
          '-a': [('-a', False)],
          '-a-': [('-a', False)],
          '-anden': [('-ande', False)],
          '-andens': [('-ande', False)],
          '-andets': [('-ande', False)],
          '-ar': [('', False)],
          '-arna': [('', False)],
          '-arnas': [('', False)],
          '-ars': [('', False)],
          '-back': [('-back', False)],
          '-back-': [('-back', False)],
          '-backen': [('-back', False)],
          '-backens': [('-back', False)],
          '-backs': [('-back', False)],
          '-bomb': [('-bomb', False)],
          '-bomber': [('-bomb', False)],
          '-bomberna': [('-bomb', False)],
          '-bombernas': [('-bomb', False)],
          '-bombers': [('-bomb', False)],
          '-bombs': [('-bomb', False)],
          '-bombs-': [('-bomb', False)],
          '-boxar': [('-box', False)],
          '-boxarna': [('-box', False)],
          '-boxarnas': [('-box', False)],
          '-broms': [('-broms', False)],
          '-bromsar': [('-broms', False)],
          '-bromsarna': [('-broms', False)],
          '-bromsarnas': [('-broms', False)],
          '-byx': [('-byxa', False)],
          '-byx-': [('-byxa', False)],
          '-byxorna': [('-byxa', False)],
          '-can': [('-can', False)],
          '-cans': [('-can', False)],
          '-cars': [('-car', False)],
          '-cas': [('-cas', False)],
          '-cat': [('-cat', False)],
          '-cat-': [('-cat', False)],
          '-cats': [('-cat', False)],
          '-chans': [('-cha', False)],
          '-chas': [('-cha', False)],
          '-dagar': [('-dag', False)],
          '-dagarna': [('-dag', False)],
          '-dagarnas': [('-dag', False)],
          '-dagars': [('-dag', False)],
          '-dagen': [('-dag', False)],
          '-dagens': [('-dag', False)],
          '-dags': [('-dag', False)],
          '-dags-': [('-dag', False)],
          '-eller': [('-eller', False)],
          '-en': [('', False)],
          '-ens': [('', False)],
          '-er': [('', False)],
          '-erna': [('', False)],
          '-ernas': [('', False)],
          '-ers': [('', False)],
          '-et': [('', False)],
          '-ets': [('', False)],
          '-faires-': [('-faire', False)],
          '-fakta': [('-fakta', False)],
          '-fis': [('-fi', False)],
          '-genus': [('-genus', False)],
          '-genus-': [('-genus', False)],
          '-gäng': [('-gäng', False)],
          '-gängen': [('-gäng', False)],
          '-gängens': [('-gäng', False)],
          '-gänget': [('-gäng', False)],
          '-gängets': [('-gäng', False)],
          '-gängs': [('-gäng', False)],
          '-gängs-': [('-gäng', False)],
          '-i-': [('-i', False)],
          '-ids': [('-id', False)],
          '-iens': [('-i', False)],
          '-in': [('-in', False)],
          '-ina': [('-in', False)],
          '-inas': [('-in', False)],
          '-inkomster': [('-inkomst', False)],
          '-ins': [('-i', False)],
          '-is': [('-i', False)],
          '-it': [('-i', False)],
          '-its': [('-i', False)],
          '-jon': [('-jo', False)],
          '-jons': [('-jo', False)],
          '-jornas': [('-jo', False)],
          '-jors': [('-jo', False)],
          '-jos': [('-jo', False)],
          '-jos-': [('-jo', False)],
          '-kasse': [('-kassa', False)],
          '-klav': [('-klav', False)],
          '-klav-': [('-klav', False)],
          '-klaven': [('-klav', False)],
          '-klavens': [('-klav', False)],
          '-klaver': [('-klav', False)],
          '-klavers': [('-klav', False)],
          '-klavs': [('-klav', False)],
          '-klavs-': [('-klav', False)],
          '-klinikerna': [('-klinik', False)],
          '-kock': [('-kock', False)],
          '-kocks': [('-kock', False)],
          '-kocks-': [('-kock', False)],
          '-krafter': [('-kraft', False)],
          '-krafts': [('-kraft', False)],
          '-krafts-': [('-kraft', False)],
          '-krets-': [('-krets', False)],
          '-kurv': [('-kurva', False)],
          '-kurv-': [('-kurva', False)],
          '-kurvor': [('-kurva', False)],
          '-kurvorna': [('-kurva', False)],
          '-kurvornas': [('-kurva', False)],
          '-kurvors': [('-kurva', False)],
          '-kurvs': [('-kurva', False)],
          '-kurvs-': [('-kurva', False)],
          '-lag': [('-lag', False)],
          '-lag-': [('-lag', False)],
          '-lagar': [('-lagare', False)],
          '-lagarna': [('-lagare', False)],
          '-lagarnas': [('-lagare', False)],
          '-lagen': [('-lag', False)],
          '-lagens': [('-lag', False)],
          '-laget': [('-lag', False)],
          '-lags': [('-lag', False)],
          '-lags-': [('-lag', False)],
          '-lamps': [('-lampa', False)],
          '-lamps-': [('-lampa', False)],
          '-landets': [('-land', False)],
          '-leg': [('-leg', False)],
          '-leg-': [('-leg', False)],
          '-leget': [('-leg', False)],
          '-legets': [('-leg', False)],
          '-legs': [('-leg', False)],
          '-legs-': [('-leg', False)],
          '-liner': [('-liner', False)],
          '-logiernas': [('-logi', False)],
          '-logiet': [('-logi', False)],
          '-lyftarnas': [('-lyft', False)],
          '-läcks': [('-läcka', False)],
          '-länder': [('-land', False)],
          '-länderna': [('-land', False)],
          '-ländernas': [('-land', False)],
          '-länders': [('-land', False)],
          '-major': [('-maja', False)],
          '-majors': [('-maja', False)],
          '-man': [('-man', False)],
          '-mannens': [('-man', False)],
          '-mans': [('-man', False)],
          '-master': [('-mast', False)],
          '-masters': [('-mast', False)],
          '-metoden': [('-metod', False)],
          '-metodens': [('-metod', False)],
          '-män': [('-man', False)],
          '-mäns': [('-man', False)],
          '-n': [('', False)],
          '-na': [('', False)],
          '-namn': [('-namn', False)],
          '-namnen': [('-namn', False)],
          '-namnens': [('-namn', False)],
          '-namns': [('-namn', False)],
          '-namns-': [('-namn', False)],
          '-nas': [('', False)],
          '-nordbor': [('-nordbor', False)],
          '-ns': [('', False)],
          '-nyheter': [('-nyhet', False)],
          '-nyheters': [('-nyhet', False)],
          '-off': [('-off', False)],
          '-off-': [('-off', False)],
          '-offer': [('-off', False)],
          '-offers': [('-off', False)],
          '-offs': [('-off', False)],
          '-offs-': [('-off', False)],
          '-piller': [('-piller', False)],
          '-pillers': [('-piller', False)],
          '-poster': [('-post', False)],
          '-posters': [('-post', False)],
          '-programmet': [('-program', False)],
          '-r': [('-r', False)],
          '-r-': [('-r', False)],
          '-ren': [('-r', False)],
          '-rens': [('-r', False)],
          '-ret': [('-r', False)],
          '-roms': [('-rom', False)],
          '-rull': [('-rulle', False)],
          '-rull-': [('-rulle', False)],
          '-rullarna': [('-rulle', False)],
          '-rulle': [('-rulle', False)],
          '-rulle-': [('-rulle', False)],
          '-rulls': [('-rulle', False)],
          '-rulls-': [('-rulle', False)],
          '-rökar': [('-rökare', False)],
          '-rökarna': [('-rökare', False)],
          '-rökarnas': [('-rökare', False)],
          '-s': [('', False)],
          '-sats': [('-sats', False)],
          '-sats-': [('-sats', False)],
          '-sen': [('', False)],
          '-sens': [('', False)],
          '-serierna': [('-serie', False)],
          '-seriernas': [('-serie', False)],
          '-skärmar': [('-skärm', False)],
          '-skärmarnas': [('-skärm', False)],
          '-släng': [('-släng', False)],
          '-släng-': [('-släng', False)],
          '-slängs': [('-släng', False)],
          '-sprit': [('-sprit', False)],
          '-sprits': [('-sprit', False)],
          '-sprits-': [('-sprit', False)],
          '-stylens': [('-style', False)],
          '-systemet': [('-systemet', False)],
          '-systemets': [('-systemet', False)],
          '-sändarna': [('-sändare', False)],
          '-t': [('', False)],
          '-tack': [('-tack', False)],
          '-tack-': [('-tack', False)],
          '-tacks': [('-tack', False)],
          '-tacks-': [('-tack', False)],
          '-talet': [('-tal', False)],
          '-testens': [('-test', False)],
          '-tittar': [('-tittare', False)],
          '-tittarna': [('-tittare', False)],
          '-tittarnas': [('-tittare', False)],
          '-ts': [('', False)],
          '-tummen': [('-tumme', False)],
          '-tummens': [('-tumme', False)],
          '-valen': [('-val', False)],
          '-valens': [('-val', False)],
          '-vals': [('-val', False)],
          '-vals-': [('-val', False)],
          '-vie': [('-vie', False)],
          '-vie-': [('-vie', False)],
          '-vien': [('-vie', False)],
          '-viens': [('-vie', False)],
          '-värden': [('-värde', False)],
          '-värdens': [('-värde', False)],
          '-vårar': [('-vårare', False)],
          '-vårarna': [('-vårare', False)],
          '-vårarnas': [('-vårare', False)],
          '.s': [('.', False)],
          '/s': [('/s', False)],
          '/s-': [('/s', False)],
          '/sek': [('/sek', False)],
          '/tim': [('/tim', False)],
          '/tim-': [('/tim', False)],
          '1s': [('1', False)],
          '2Os': [('2O', False)],
          '2s': [('2', False)],
          '3s': [('3', False)],
          '4s': [('4', False)],
          '5s': [('5', False)],
          '6s': [('6', False)],
          '8s': [('8', False)],
          '9s': [('9', False)],
          ':anden': [(':ande', False)],
          ':andens': [(':ande', False)],
          ':andets': [(':ande', False)],
          ':ar': [('', False)],
          ':arna': [('', False)],
          ':arnas': [('', False)],
          ':ars': [('', False)],
          ':en': [('', False)],
          ':ens': [('', False)],
          ':er': [('', False)],
          ':erna': [('', False)],
          ':ernas': [('', False)],
          ':ers': [('', False)],
          ':et': [('', False)],
          ':ets': [('', False)],
          ':n': [('', False)],
          ':na': [('', False)],
          ':nas': [('', False)],
          ':ns': [('', False)],
          ':s': [('', False)],
          ':sen': [('', False)],
          ':sens': [('', False)],
          ':t': [('', False)],
          ':ts': [('', False)],
          'A3-': [('A3', True)],
          'AOs': [('AO', False)],
          'Ac': [('Ac', True)],
          'Acs': [('Ac', True)],
          'Aen': [('A', False)],
          'Aens': [('A', False)],
          'Aer': [('A', False)],
          'Aers': [('A', False)],
          'Aets': [('A', False)],
          'Ag': [('Ag', True)],
          'Ag-': [('Ag', True)],
          'Ags': [('Ag', True)],
          'Am-': [('Am', True)],
          'Ams': [('Am', True)],
          'An': [('A', False)],
          'Ans': [('A', False)],
          'Ar': [('Ar', True)],
          'As': [('As', True)],
          'As-': [('As', True)],
          'Ass': [('As', True)],
          'At': [('At', True)],
          'Ats': [('At', True)],
          'Au': [('Au', True)],
          'Au-': [('Au', True)],
          'Aus': [('Au', True)],
          'BAs': [('BA', False)],
          'BAt': [('BA', False)],
          'BAts': [('BA', False)],
          'Ba': [('Ba', True)],
          'Ba-': [('Ba', True)],
          'Bar': [('B', False)],
          'Barnas': [('B', False)],
          'Bars': [('B', False)],
          'Bas': [('Ba', True)],
          'Be': [('Be', True)],
          'Be-': [('Be', True)],
          'Ben': [('B', False)],
          'Bens': [('B', False)],
          'Bes': [('Be', True)],
          'Bets': [('B', False)],
          'Bi': [('Bi', True)],
          'Bi-': [('Bi', True)],
          'Bis': [('Bi', True)],
          'Bk': [('Bk', True)],
          'Bk-': [('Bk', True)],
          'Bks': [('Bk', True)],
          'Bn': [('B', False)],
          'Bns': [('B', False)],
          'Br': [('Br', True)],
          'Br-': [('Br', True)],
          'Brs': [('Br', True)],
          'Bs': [('B', False)],
          'Bs-': [('B', False)],
          'Bt': [('B', False)],
          'Bts': [('B', False)],
          'Ca': [('Ca', True)],
          'Calzonen': [('Calzone', True)],
          'Calzonens': [('Calzone', True)],
          'Car': [('C', False)],
          'Carnas': [('C', False)],
          'Cars': [('C', False)],
          'Cas': [('Ca', True)],
          'Cd': [('Cd', True)],
          'Cd-': [('Cd', True)],
          'Cds': [('Cd', True)],
          'Ce': [('Ce', True)],
          'Ce-': [('Ce', True)],
          'Cen': [('C', False)],
          'Cens': [('C', False)],
          'Ces': [('Ce', True)],
          'Cf': [('Cf', True)],
          'Cf-': [('Cf', True)],
          'Cl': [('Cl', True)],
          'Cl-': [('Cl', True)],
          'Cls': [('Cl', False)],
          'Cm-': [('Cm', True)],
          'Cn': [('C', False)],
          'Cns': [('C', False)],
          'Cos': [('Co', True)],
          'Crs': [('Cr', True)],
          'Cs': [('Cs', True), ('C', True)],
          'Cs-': [('Cs', True)],
          'Css': [('Cs', True)],
          'Ct': [('C', False)],
          'Cts': [('C', False)],
          'Cu': [('Cu', True)],
          'Cus': [('Cu', True)],
          'DAs': [('DA', False)],
          'Dar': [('D', False)],
          'Darnas': [('D', False)],
          'Dars': [('D', False)],
          'Den': [('D', False)],
          'Dens': [('D', False)],
          'Der': [('D', False)],
          'Ders': [('D', False)],
          'Dn': [('D', False)],
          'Dns': [('D', False)],
          'Dr': [('Dr', True)],
          'Dr-': [('Dr', True)],
          'Ds': [('D', False)],
          'Dt': [('D', False)],
          'Dts': [('D', False)],
          'Dy': [('Dy', True)],
          'Dys': [('Dy', True)],
          'ECs': [('EC', False)],
          'EPn': [('EP', True)],
          'EPns': [('EP', True)],
          'Er': [('Er', True)],
          'Es-': [('Es', True)],
          'Ess': [('Es', True)],
          'Eus': [('Eu', True)],
          'FAs': [('FA', False)],
          'FOs': [('FO', False)],
          'Fe': [('Fe', True)],
          'Fe-': [('Fe', True)],
          'Fes': [('Fe', True)],
          'Fisk': [('Fisk', True)],
          'Fisk-': [('Fisk', True)],
          'Fiskarna': [('Fisk', True)],
          'Fm-': [('Fm', True)],
          'Fms': [('Fm', True)],
          'For': [('FA', False)],
          'Forna': [('FA', False)],
          'Fornas': [('FA', False)],
          'Fors': [('FA', False)],
          'Fr': [('Fr', True)],
          'Fr-': [('Fr', True)],
          'Fs': [('F', True)],
          'Ga': [('Ga', True)],
          'Gas': [('Ga', True)],
          'Gd': [('Gd', True)],
          'Gd-': [('Gd', True)],
          'Gds': [('Gd', True)],
          'Ge-': [('Ge', True)],
          'Ges': [('Ge', True)],
          'Gn': [('G', False)],
          'Gns': [('G', False)],
          'Gs': [('G', False)],
          'Gt': [('G', False)],
          'Gts': [('G', False)],
          'Gy': [('Gy', True)],
          'Gy-': [('Gy', True)],
          'H-': [('H', True)],
          'HCO3-': [('HCO3-', True)],
          'Hb': [('Hb', True)],
          'Hb-': [('Hb', True)],
          'Hbs': [('Hb', True)],
          'He': [('He', True)],
          'He-': [('He', True)],
          'Hen': [('H', False)],
          'Hens': [('H', False)],
          'Her': [('H', False)],
          'Hers': [('H', False)],
          'Hes': [('He', True)],
          'Hets': [('H', False)],
          'Hf': [('Hf', True)],
          'Hf-': [('Hf', True)],
          'Hfs': [('Hf', True)],
          'Hg-': [('Hg', True)],
          'Hgs': [('Hg', True)],
          'Hn': [('H', False)],
          'Hns': [('H', False)],
          'Hos': [('Ho', True)],
          'Hr-': [('Hr', True)],
          'Hs': [('H', False)],
          'Ht': [('H', False)],
          'Hts': [('H', False)],
          'ICs': [('IC', True)],
          'In-': [('In', True)],
          'Ir-': [('Ir', True)],
          'Is': [('I', True)],
          'JOs': [('JO', True)],
          'Jar': [('J', False)],
          'Jarnas': [('J', False)],
          'Jars': [('J', False)],
          'Jen': [('J', False)],
          'Jens': [('J', False)],
          'Jn': [('J', False)],
          'Jns': [('J', False)],
          'Js': [('J', False)],
          'KOH-': [('KOH', True)],
          'Kar': [('K', False)],
          'Karnas': [('K', False)],
          'Kars': [('K', False)],
          'Kb': [('Kb', True)],
          'Ken': [('K', False)],
          'Kens': [('K', False)],
          'Kevlar': [('Kevlar', True)],
          'Kr-': [('Kr', True)],
          'Ks': [('K', False)],
          'Ks-': [('K', False)],
          'LH-': [('LH', True)],
          'LPn': [('LP', True)],
          'LPns': [('LP', True)],
          'Lar': [('L', False)],
          'Larnas': [('L', False)],
          'Lars': [('L', False)],
          'Las': [('La', True)],
          'Ler': [('L', False)],
          'Lers': [('L', False)],
          'Li-': [('Li', True)],
          'Lis': [('Li', True)],
          'Ln': [('L', False)],
          'Lns': [('L', False)],
          'Ls': [('L', False)],
          'Lu': [('Lu', True)],
          'Lus': [('Lu', True)],
          'MCs': [('MC', True)],
          'Maten': [('Maten', False)],
          'Matens': [('Maten', False)],
          'Mb': [('Mb', True)],
          'Md': [('Md', True)],
          'Md-': [('Md', True)],
          'Mds': [('Md', True)],
          'Men': [('M', False)],
          'Mens': [('M', False)],
          'Mets': [('M', False)],
          'Mg-': [('Mg', True)],
          'Mgs': [('Mg', True)],
          'Mn-': [('Mn', True)],
          'Mns': [('Mn', True)],
          'Mos': [('Mo', True)],
          'Mp-': [('Mp', True)],
          'Mps': [('Mp', True)],
          'Mr': [('Mr', True)],
          'Mr-': [('Mr', True)],
          'Mrs': [('Mrs', True)],
          'Ms': [('M', False)],
          'NAs': [('NA', False)],
          'NAt': [('NA', False)],
          'NAts': [('NA', False)],
          'NOs': [('NO', True)],
          'NPn': [('NP', False)],
          'NPns': [('NP', False)],
          'Na-': [('Na', True)],
          'Nas': [('Na', True)],
          'Nb': [('Nb', True)],
          'Nbs': [('Nb', True)],
          'Nd': [('Nd', True)],
          'Nds': [('Nd', True)],
          'Ne': [('Ne', True)],
          'Ne-': [('Ne', True)],
          'Nes': [('Ne', True)],
          'Ni': [('Ni', True)],
          'Ni-': [('Ni', True)],
          'Nis': [('Ni', True)],
          'Nos': [('No', True)],
          'Np': [('Np', True)],
          'Np-': [('Np', True)],
          'Nps': [('Np', True)],
          'Ns': [('N', True)],
          'O3-': [('O3', False)],
          'OH-': [('OH-', True)],
          'Oen': [('O', False)],
          'Oens': [('O', False)],
          'Oets': [('O', False)],
          'On': [('O', False)],
          'Ons': [('O', False)],
          'Os': [('Os', True), ('O', True)],
          'Os-': [('Os', True)],
          'Osen': [('O', False)],
          'Osens': [('O', False)],
          'Ot': [('O', False)],
          'Ots': [('O', False)],
          'Ox': [('Oxe', True)],
          'Ox-': [('Oxe', True)],
          'Oxar': [('Oxe', True)],
          'Oxarna': [('Oxe', True)],
          'Oxarnas': [('Oxe', True)],
          'Oxen': [('Oxe', True)],
          'Oxens': [('Oxe', True)],
          'P3-': [('P3', False)],
          'PSn': [('PS', False)],
          'PSns': [('PS', False)],
          'Pas': [('Pa', True)],
          'Pb': [('Pb', True)],
          'Pb-': [('Pb', True)],
          'Pbs': [('Pb', True)],
          'Pd': [('Pd', True)],
          'Pd-': [('Pd', True)],
          'Pds': [('Pd', True)],
          'Pen': [('P', False)],
          'Pens': [('P', False)],
          'Pets': [('P', False)],
          'Phone': [('Phone', False)],
          'Phone-': [('Phone', False)],
          'Pm': [('Pm', True)],
          'Pn': [('Pn', True)],
          'Pn-': [('Pn', True)],
          'Pns': [('Pn', True)],
          'Pos': [('Po', True)],
          'Pr': [('Pr', True)],
          'Pr-': [('Pr', True)],
          'Ps': [('P', False)],
          'Ps-': [('P', False)],
          'Pt': [('Pt', True)],
          'Pts': [('Pt', True)],
          'Q3-': [('Q3', True)],
          'Qs': [('Q', False)],
          'Ra': [('Ra', True)],
          'Ra-': [('Ra', True)],
          'Ras': [('Ra', True)],
          'Rb': [('Rb', True)],
          'Rbs': [('Rb', True)],
          'Re': [('Re', True)],
          'Re-': [('Re', True)],
          'Res': [('Re', True)],
          'Rh': [('Rh', True)],
          'Rh-': [('Rh', True)],
          'Risk': [('Risk', True)],
          'Risk-': [('Risk', True)],
          'Rn-': [('Rn', True)],
          'Rolls': [('Rolls', True)],
          'Rolls-': [('Rolls', True)],
          'Rs': [('R', False)],
          'Ru': [('Ru', True)],
          'Rus': [('Ru', True)],
          'SH-': [('SH', False)],
          'Sar': [('S', False)],
          'Sarnas': [('S', False)],
          'Sars': [('S', False)],
          'Sb': [('Sb', True)],
          'Sb-': [('Sb', True)],
          'Sbs': [('Sb', True)],
          'Sc': [('Sc', True)],
          'Scs': [('Sc', True)],
          'Se': [('Se', True)],
          'Se-': [('Se', True)],
          'Sen': [('S', False)],
          'Sens': [('S', False)],
          'Ser': [('S', False)],
          'Sers': [('S', False)],
          'Ses': [('Se', True)],
          'Sets': [('S', False)],
          'Si-': [('Si', True)],
          'Sis': [('Si', True)],
          'Sjustjärnorna': [('Sjustjärnorna', True)],
          'Sjustjärnornas': [('Sjustjärnorna', True)],
          'Sm': [('Sm', True)],
          'Sm-': [('Sm', True)],
          'Sms': [('Sm', True)],
          'Sn': [('Sn', True)],
          'Sn-': [('Sn', True)],
          'Sns': [('Sn', True)],
          'Sr': [('Sr', True)],
          'Sr-': [('Sr', True)],
          'Ss': [('S', False)],
          'Sv-': [('Sv', False)],
          'TPn': [('TP', False)],
          'TPns': [('TP', False)],
          'Ta': [('Ta', True)],
          'Tas': [('Ta', True)],
          'Tbs': [('Tb', True)],
          'Te-': [('Te', True)],
          'Ten': [('T', False)],
          'Tens': [('T', False)],
          'Tes': [('Te', True)],
          'Tets': [('T', False)],
          'Tis': [('Ti', True)],
          'Tl': [('Tl', True)],
          'Tm': [('Tm', True)],
          'Tm-': [('Tm', True)],
          'Tn': [('T', False)],
          'Tns': [('T', False)],
          'Ts': [('T', False)],
          'Tt': [('T', False)],
          'Tts': [('T', False)],
          'Uno': [('Uno', True)],
          'Uno-': [('Uno', True)],
          'Unos': [('Uno', True)],
          'Us': [('U', True)],
          'V3-': [('V3', False)],
          'VCs': [('VC', False)],
          'Vn': [('V', False)],
          'Vns': [('V', False)],
          'Volvon': [('Volvo', True)],
          'Volvons': [('Volvo', True)],
          'Vs': [('V', False)],
          'Vågor': [('Våg', True)],
          'Vågorna': [('Våg', True)],
          'Vågornas': [('Våg', True)],
          'Vågors': [('Våg', True)],
          'WCs': [('WC', True)],
          'Ws': [('W', True)],
          'Xe': [('Xe', True)],
          'Xe-': [('Xe', True)],
          'Xes': [('Xe', True)],
          'Yb': [('Yb', True)],
          'Ybs': [('Yb', True)],
          'Ys': [('Y', True)],
          'Zn-': [('Zn', True)],
          'Zns': [('Zn', True)],
          'Zr': [('Zr', True)],
          'a': [('a', True)],
          'a-': [('a', True)],
          'a3-': [('a3', True)],
          'aCO3-': [('aCO3', False)],
          'aHCO3-': [('aHCO3', False)],
          'aa': [('aa', True)],
          'aalar': [('aal', False)],
          'aals': [('aal', False)],
          'aals-': [('aal', False)],
          'aalt-': [('aalt', False)],
          'aaltar': [('aalt', False)],
          'aaltarna': [('aalt', False)],
          'aaltarnas': [('aalt', False)],
          'aans': [('aans', False)],
          'aarv': [('aarv', False)],
          'aarven': [('aarv', False)],
          'aarvens': [('aarv', False)],
          'aarvs': [('aarv', False)],
          'aarvs-': [('aarv', False)],
          'ab': [('ab', False)],
          'ab-': [('ab', False)],
          'aback': [('abacke', False)],
          'aback-': [('abacke', False)],
          'abackar': [('abacke', False)],
          'abackarna': [('abacke', False)],
          'abackarnas': [('abacke', False)],
          'abackars': [('abacke', False)],
          'abacke': [('abacke', False)],
          'abacke-': [('abacke', False)],
          'abacken': [('abacke', False)],
          'abackens': [('aback', False)],
          'abacks': [('abacke', False)],
          'abacks-': [('abacke', False)],
          'abagar': [('abagare', False)],
          'abagarna': [('abagare', False)],
          'abagarnas': [('abagare', False)],
          'abal': [('abal', False)],
          'abal-': [('abal', False)],
          'abalen': [('abal', False)],
          'abalens': [('abal', False)],
          'abals': [('abal', False)],
          'abandets': [('aband', False)],
          'abar': [('ab', False)],
          'abarna': [('ab', False)],
          'abarnas': [('ab', False)],
          'abarren': [('abarr', False)],
          'abarrens': [('abarr', False)],
          'abars': [('ab', False)],
          'abas': [('abas', False)],
          'abasar': [('abas', False)],
          'abasars': [('abas', False)],
          'abass': [('abass', False)],
          'abass-': [('abass', False)],
          'abassen': [('abass', False)],
          'abassens': [('abass', False)],
          'abattens': [('abatt', False)],
          'abbar': [('abb', False)],
          'abbarna': [('abbe', False)],
          'abbarnas': [('abbe', False)],
          'abbars': [('abbe', False)],
          'abbe': [('abbe', False)],
          'abben': [('abb', False)],
          'abbens': [('abbe', False)],
          'abbierna': [('abbi', False)],
          'abbiernas': [('abbi', False)],
          'abbiers': [('abbi', False)],
          'abblar': [('abblare', False)],
          'abblarna': [('abblare', False)],
          'abblarnas': [('abblare', False)],
          'abblet': [('abbel', False)],
          'abblets': [('abbel', False)],
          'abbs': [('abbe', False)],
          'abel': [('abel', False)],
          'abel-': [('abel', False)],
          'abels': [('abel', False)],
          'abels-': [('abel', False)],
          'aben': [('ab', False)],
          'abens': [('ab', False)],
          'aber': [('aber', True)],
          'aberna': [('ab', False)],
          'abernas': [('ab', False)],
          'abers': [('aber', True)],
          'abet': [('ab', False)],
          'abet-': [('abet', False)],
          'abeten': [('abet', False)],
          'abetens': [('abet', False)],
          'abetes': [('abetes', False)],
          'abetes-': [('abetes', False)],
          'abetet': [('abet', False)],
          'abetets': [('abet', False)],
          'abets': [('ab', False)],
          'abets-': [('abet', False)],
          'abier': [('abium', False)],
          'abierna': [('abium', False)],
          'abiernas': [('abium', False)],
          'abiers': [('abium', False)],
          'abies': [('abies', False)],
          'abiet': [('abium', False)],
          'abiets': [('abium', False)],
          'abil-': [('abilia', False)],
          'abilars': [('abil', False)],
          'abils': [('abil', False)],
          'abils-': [('abil', False)],
          'abin': [('abin', False)],
          'abiner': [('abin', False)],
          'abinerna': [('abin', False)],
          'abinernas': [('abin', False)],
          'abiners': [('abin', False)],
          'abins': [('abin', False)],
          'abis': [('abis', False)],
          'abis-': [('abis', False)],
          'abister': [('abist', False)],
          'abisters': [('abist', False)],
          'abit': [('abit', False)],
          'abits': [('abit', False)],
          'abits-': [('abit', False)],
          'ablandet': [('abland', False)],
          'ablandets': [('abland', False)],
          'ablar': [('abel', False)],
          'ablarna': [('abel', False)],
          'ablarnas': [('abel', False)],
          'ablernas': [('abel', False)],
          'ablängar': [('ablängare', False)],
          'ablängarna': [('ablängare', False)],
          'ablängarnas': [('ablängare', False)],
          'ablåns': [('ablå', False)],
          'ablås': [('ablå', False)],
          'abol': [('abol', False)],
          'abolaget': [('abolag', False)],
          'abolen': [('abol', False)],
          'abolens': [('abol', False)],
          'abols': [('abol', False)],
          'abomb': [('abomb', False)],
          'abomber': [('abomb', False)],
          'abomberna': [('abomb', False)],
          'abombernas': [('abomb', False)],
          'abombers': [('abomb', False)],
          'abombs': [('abomb', False)],
          'abombs-': [('abomb', False)],
          'abon': [('abon', False)],
          'abond': [('abond', False)],
          'abond-': [('abond', False)],
          'abonden': [('abond', False)],
          'abondens': [('abond', False)],
          'abonds': [('abond', False)],
          'abonds-': [('abond', False)],
          'abons': [('abon', False)],
          'abor': [('abo', False)],
          'aboriginer': [('aborigin', True), ('aboriginer', True)],
          'aboriginerna': [('aborigin', True), ('aboriginer', True)],
          'aboriginernas': [('aboriginer', True), ('aborigin', True)],
          'aboriginers': [('aborigin', True), ('aboriginer', True)],
          'aborr': [('aborre', True)],
          'aborr-': [('aborre', True)],
          'aborrar': [('aborre', True)],
          'aborrarna': [('aborre', True)],
          'aborrarnas': [('aborre', True)],
          'aborrars': [('aborre', True)],
          'aborren': [('aborre', True)],
          'aborrens': [('aborre', True)],
          'aborrs': [('aborre', True)],
          'aborrs-': [('aborre', True)],
          'abors': [('abo', False)],
          'abot': [('abot', False)],
          'abots': [('abo', False)],
          'aboxar': [('abox', False)],
          'aboxarna': [('abox', False)],
          'aboxarnas': [('abox', False)],
          'abra': [('abra', False)],
          'abras': [('abra', False)],
          'abras-': [('abra', False)],
          'abrat': [('abra', False)],
          'abrats': [('abra', False)],
          'abren': [('aber', True)],
          'abret': [('aber', True)],
          'abrets': [('aber', True)],
          'abroder': [('abroder', False)],
          'abrodern': [('abroder', False)],
          'abroderns': [('abroder', False)],
          'abroders': [('abroder', False)],
          'abröder': [('abroder', False)],
          'abröderna': [('abroder', False)],
          'abrödernas': [('abroder', False)],
          'abröders': [('abroder', False)],
          'abs': [('ab', False)],
          'abs-': [('ab', False)],
          'absens': [('absens', True)],
          'abus': [('abu', False)],
          'abus-': [('abus', False)],
          'abusen': [('abus', False)],
          'abusens': [('abus', False)],
          'abyerna': [('aby', False)],
          'abyx': [('abyxa', False)],
          'abyx-': [('abyxa', False)],
          'abyxornas': [('abyxa', False)],
          'abälte': [('abälte', False)],
          'abärs': [('abär', False)],
          'abärs-': [('abär', False)],
          'abåg': [('abåge', False)],
          'abåg-': [('abåge', False)],
          'abågs': [('abåge', False)],
          'abågs-': [('abåge', False)],
          'abön': [('aböna', False)],
          'abön-': [('aböna', False)],
          'aböne': [('aböna', False)],
          'aböne-': [('aböna', False)],
          'aböns': [('aböna', False)],
          'aböns-': [('aböna', False)],
          'acar': [('ac', False)],
          'acarna': [('ac', False)],
          'acars': [('ac', False)],
          'acell': [('acell', False)],
          'acens': [('ac', False)],
          'acens-': [('acen', False)],
          'acent': [('acenta', False)],
          'acent-': [('acenta', False)],
          'acents': [('acenta', False)],
          'acents-': [('acenta', False)],
          'acern': [('acer', False)],
          'acerns': [('acer', False)],
          'achar': [('ach', False)],
          'acharnas': [('ach', False)],
          'achars': [('ach', False)],
          'ache': [('ache', False)],
          'ache-': [('ache', False)],
          'achen': [('ache', False)],
          'achens': [('ache', False)],
          'acher': [('ache', False)],
          'acherna': [('ache', False)],
          'achernas': [('ache', False)],
          'achers': [('ache', False)],
          'achmans': [('achma', False)],
          'acian': [('acia', False)],
          'acians': [('acia', False)],
          'acie-': [('acia', False)],
          'aciens': [('aci', False)],
          'acier': [('aci', False)],
          'acierna': [('aci', False)],
          'aciernas': [('aci', False)],
          'aciers': [('aci', False)],
          'acin': [('aci', False)],
          'acins': [('acin', False)],
          'acis': [('aci', False)],
          'acitet': [('acitet', False)],
          'acitets': [('acitet', False)],
          'ack': [('ack', False)],
          'ackan': [('acka', False)],
          'ackans': [('acka', False)],
          'ackar': [('ackare', False)],
          'ackarna': [('ackare', False)],
          'ackarnas': [('ack', False)],
          'ackars': [('acke', False)],
          'ackel': [('ackla', False)],
          'ackel-': [('ackla', False)],
          'ackelsens': [('ackelse', False)],
          'acker': [('acker', False)],
          'ackers': [('acker', False)],
          'ackersen': [('acker', False)],
          'ackersens': [('ackers', False)],
          'ackhamrarna': [('ackhammer', False)],
          'ackhamrarnas': [('ackhammer', False)],
          'ackhamrars': [('ackhammer', False)],
          'acklan': [('ackla', False)],
          'acklanden': [('acklande', False)],
          'acklandens': [('acklande', False)],
          'acklandet': [('acklande', False)],
          'acklandets': [('ackland', False)],
          'acklans': [('ackla', False)],
          'acklarna': [('ackel', False)],
          'ackle': [('ackla', False)],
          'acksen': [('acks', False)],
          'acolor': [('acola', False)],
          'acolorna': [('acola', False)],
          'acon': [('acon', False)],
          'aconen': [('acon', False)],
          'aconens': [('acon', False)],
          'acons': [('acon', False)],
          'acs-': [('ac', False)],
          'ad': [('ad', False)],
          'ad-': [('ad', False)],
          'adagar': [('adag', False)],
          'adagarna': [('adag', False)],
          'adagarnas': [('adag', False)],
          'adagars': [('adag', False)],
          'adagen': [('adag', False)],
          'adagens': [('adag', False)],
          'adags': [('adag', False)],
          'adags-': [('adag', False)],
          'adaler': [('adal', False)],
          'adalerna': [('adal', False)],
          'adalernas': [('adal', False)],
          'adalers': [('adal', False)],
          'adamen': [('adame', False)],
          'adamens': [('adam', False)],
          'adamer': [('adame', False)],
          'adamerna': [('adame', False)],
          'adamernas': [('adame', False)],
          'adamers': [('adame', False)],
          'adammen': [('adam', False)],
          'adammens': [('adam', False)],
          'adan': [('ada', False)],
          'adanden': [('adande', False)],
          'adandens': [('adande', False)],
          'adans': [('ada', False)],
          'adaren': [('adare', False)],
          'adars': [('ad', False)],
          'adbens': [('adben', False)],
          'adbit': [('adbit', False)],
          'add': [('adda', False)],
          'add-': [('add', False)],
          'adda': [('adda', False)],
          'addans': [('adda', False)],
          'addar': [('addare', False)],
          'addarna': [('add', False)],
          'addarnas': [('add', False)],
          'adder': [('adder', False)],
          'adders': [('adder', False)],
          'addock-': [('addock', False)],
          'addocks': [('addock', False)],
          'addrar': [('addrare', False)],
          'addrarna': [('addrare', False)],
          'addrarnas': [('adder', False)],
          'adds': [('adda', False)],
          'adds-': [('adda', False)],
          'ade': [('ada', False)],
          'ade-': [('ada', False)],
          'adel': [('adel', False)],
          'adel-': [('adel', False)],
          'adels': [('adel', False)],
          'adels-': [('adel', False)],
          'ademens': [('adem', False)],
          'aden': [('ad', False)],
          'adens': [('ad', False)],
          'ader': [('ad', False)],
          'aderits': [('aderi', False)],
          'adern': [('ader', False)],
          'aderna': [('ad', False)],
          'adernas': [('ad', False)],
          'aderns': [('ader', False)],
          'aders': [('ad', False)],
          'aders-': [('ader', False)],
          'adet': [('ad', False)],
          'adian': [('adian', False)],
          'adians': [('adian', False)],
          'adie': [('adie', False)],
          'adie-': [('adie', False)],
          'adien': [('adie', False)],
          'adiens': [('adie', False)],
          'adierna': [('adier', False)],
          'adiernas': [('adi', False)],
          'adies': [('adie', False)],
          'adiesarna': [('ady', False)],
          'adiesarnas': [('ady', False)],
          'adillen': [('adill', False)],
          'adillens': [('adill', False)],
          'adin': [('adin', False)],
          'ading': [('ading', False)],
          'ading-': [('ading', False)],
          'adingar': [('ading', False)],
          'adingarna': [('ading', False)],
          'adingarnas': [('ading', False)],
          'adingars': [('ading', False)],
          'adingen': [('ading', False)],
          'adingens': [('ading', False)],
          'adings': [('ading', False)],
          'adings-': [('ading', False)],
          'adins': [('adin', False)],
          'adion': [('adio', False)],
          'adions': [('adion', False)],
          'adior': [('adio', False)],
          'adiorna': [('adio', False)],
          'adiornas': [('adio', False)],
          'adiors': [('adio', False)],
          'adis': [('adis', False)],
          'adis-': [('adis', False)],
          'adjan': [('adja', False)],
          'adjans': [('adja', False)],
          'adkar-': [('adkar', False)],
          'adkaren': [('adkar', False)],
          'adklädes': [('adkläder', False)],
          'adkläds': [('adkläder', False)],
          'adkläds-': [('adkläder', False)],
          'adlar': [('adel', False)],
          'adlarna': [('adel', False)],
          'adlarnas': [('adel', False)],
          'adlars': [('adel', False)],
          'adline': [('adline', False)],
          'adlins': [('adlins', False)],
          'adnen': [('adion', False)],
          'adnens': [('adion', False)],
          'ado-': [('ado', False)],
          'adon': [('adon', False)],
          'adon-': [('adon', False)],
          'adona': [('ado', False)],
          'adonas': [('ado', False)],
          'adons': [('ado', False)],
          'ador': [('ada', False)],
          'adorer': [('ador', False)],
          'adorerna': [('ador', False)],
          'adorernas': [('ador', False)],
          'adorers': [('ador', False)],
          'adorna': [('ada', False)],
          'adornas': [('ada', False)],
          'adors': [('ada', False)],
          'ados': [('ado', False)],
          'ados-': [('ados', False)],
          'adosen': [('ados', False)],
          'adosens': [('ado', False)],
          'adot': [('ado', False)],
          'adra': [('adra', False)],
          'adran': [('adra', False)],
          'adrans': [('adra', False)],
          'adrar': [('ader', False)],
          'adrarna': [('ader', False)],
          'adrars': [('ader', False)],
          'adras': [('adra', False)],
          'adrer': [('ader', False)],
          'adrerna': [('ader', False)],
          'adrernas': [('ader', False)],
          'adrers': [('ader', False)],
          'adris': [('adris', False)],
          'adrorna': [('adra', False)],
          'ads': [('ad', False)],
          'ads-': [('ad', False)],
          'adsdagar': [('adsdag', False)],
          'adsdagarna': [('adsdag', False)],
          'adsdagarnas': [('adsdag', False)],
          'adsdagars': [('adsdag', False)],
          'adsdags': [('adsdag', False)],
          'adsdans': [('adsdag', False)],
          'adsdomar': [('adsdom', False)],
          'adsdomarna': [('adsdom', False)],
          'adsdomarnas': [('adsdom', False)],
          'adsen': [('ad', False)],
          'adsens': [('ad', False)],
          'adskalas': [('adskala', False)],
          'adske': [('adska', False)],
          'adske-': [('adska', False)],
          'adsklubb': [('adsklubb', False)],
          'adsklubb-': [('adsklubb', False)],
          'adsklubbs': [('adsklubb', False)],
          'adsklubbs-': [('adsklubb', False)],
          'adskor': [('adska', False)],
          'adskorna': [('adska', False)],
          'adskornas': [('adska', False)],
          'adskors': [('adska', False)],
          'adskrans': [('adskrans', False)],
          'adskrans-': [('adskrans', False)],
          'adskurs': [('adskurs', False)],
          'adslandets': [('adsland', False)],
          'adslån': [('adslån', False)],
          'adslåns': [('adslån', False)],
          'adsprivilegie': [('adsprivilegier', False)],
          'adsprivilegie-': [('adsprivilegier', False)],
          'adsprivilegier': [('adsprivilegier', False)],
          'adsprivilegierna': [('adsprivilegier', False)],
          'adsprivilegiers': [('adsprivilegier', False)],
          'adstalet': [('adstal', False)],
          'adua': [('adua', False)],
          'aduan': [('adua', False)],
          'aduans': [('adua', False)],
          'adue-': [('adua', False)],
          'aduor': [('adua', False)],
          'aduorna': [('adua', False)],
          'aduornas': [('adua', False)],
          'aduors': [('adua', False)],
          'adusk': [('aduska', False)],
          'adusk-': [('aduska', False)],
          'advägens': [('adväg', False)],
          'adyn': [('ady', False)],
          'adyns': [('ady', False)],
          'adyrkar': [('adyrkare', False)],
          'adyrkarna': [('adyrkare', False)],
          'adyrkarnas': [('adyrkare', False)],
          'adys': [('ady', False)],
          'ae': [('ae', False)],
          'ae-': [('ae', False)],
          'aed': [('aed', False)],
          'aeder': [('aeder', False)],
          'aeders': [('aeder', False)],
          'aeds': [('aed', False)],
          'aeds-': [('aed', False)],
          'aelers': [('ael', False)],
          'aellan': [('aella', False)],
          'aelle': [('aella', False)],
          'aelle-': [('aella', False)],
          'aellor': [('aella', False)],
          'aellorna': [('aella', False)],
          'aellornas': [('aella', False)],
          'aellors': [('aella', False)],
          'aells-': [('aella', False)],
          'aen': [('ae', False)],
          'aens': [('ae', False)],
          'aer': [('ae', False)],
          'aerna': [('ae', False)],
          'aernas': [('ae', False)],
          'aers': [('a', False)],
          'aes': [('ae', False)],
          'aes-': [('ae', False)],
          'aets': [('a', False)],
          'aetylen': [('aetyl', False)],
          'aetylens': [('aetyl', False)],
          'af': [('af', False)],
          'af-': [('af', False)],
          'afader': [('afar', False)],
          'afader-': [('afar', False)],
          'afadern': [('afader', False)],
          'afaderns': [('afader', False)],
          'afaders': [('afader', False)],
          'afaders-': [('afar', False)],
          'afan': [('afan', False)],
          'afan-': [('afan', False)],
          'afaner': [('afan', False)],
          'afaners': [('afan', False)],
          'afans': [('afan', False)],
          'afar': [('afar', False)],
          'afar-': [('afar', False)],
          'afarin': [('afari', False)],
          'afarins': [('afari', False)],
          'afarna': [('af', False)],
          'afars': [('af', False)],
          'afars-': [('afar', False)],
          'afel': [('afel', False)],
          'afel-': [('afel', False)],
          'afels': [('afel', False)],
          'afels-': [('afel', False)],
          'afem': [('afem', False)],
          'afem-': [('afem', False)],
          'afems': [('afem', False)],
          'afen': [('af', False)],
          'afen-': [('afen', False)],
          'afens': [('af', False)],
          'afer': [('af', False)],
          'afer-': [('afer', False)],
          'aferna': [('af', False)],
          'afernas': [('af', False)],
          'afers': [('af', False)],
          'afersens': [('afer', False)],
          'afet': [('afe', False)],
          'afets': [('afe', False)],
          'affar': [('affare', False)],
          'affarna': [('affare', False)],
          'affarnas': [('aff', False)],
          'affe': [('affe', False)],
          'affe-': [('affe', False)],
          'affekt': [('affekt', True)],
          'affekt-': [('affekt', True)],
          'affekter': [('affekt', True)],
          'affekternas': [('affekt', True)],
          'affekters': [('affekt', True)],
          'affekts': [('affekt', True)],
          'affekts-': [('affekt', True)],
          'affen': [('affe', False)],
          'affens': [('aff', False)],
          'affer': [('affer', False)],
          'affers': [('affer', False)],
          'affet': [('affe', False)],
          'affets': [('affe', False)],
          'affian': [('affia', False)],
          'affians': [('affian', False)],
          'affins': [('affin', False)],
          'afflors': [('afflor', False)],
          'affran': [('affran', False)],
          'affrans': [('affran', False)],
          'afier': [('afium', False)],
          'afierna': [('afium', False)],
          'afiernas': [('afium', False)],
          'afiers': [('afium', False)],
          'afiet': [('afium', False)],
          'afiets': [('afi', False)],
          'afilen': [('afil', False)],
          'afilens': [('afil', False)],
          'afis': [('afi', False)],
          'afis-': [('afi', False)],
          'afixar': [('afixare', False)],
          'afixarna': [('afixare', False)],
          'afixarnas': [('afixare', False)],
          'aflagg': [('aflagga', False)],
          'aflagg-': [('aflagga', False)],
          'aflaggs': [('aflagga', False)],
          'aflaggs-': [('aflagga', False)],
          'aflar': [('afel', False)],
          'aflarna': [('afel', False)],
          'aflarnas': [('afel', False)],
          'afler': [('afel', False)],
          'aflernas': [('afel', False)],
          'aflyt': [('afly', False)],
          'aflyts': [('afly', False)],
          'aflödet': [('aflöde', False)],
          'afon': [('afon', False)],
          'afonis': [('afoni', True)],
          'afor': [('afor', False)],
          'afor-': [('afor', False)],
          'afora': [('afora', False)],
          'aforana': [('afora', False)],
          'aforanas': [('afora', False)],
          'aforas': [('afora', False)],
          'aforer': [('afor', False)],
          'aforerna': [('afor', False)],
          'aforernas': [('afor', False)],
          'aforers': [('afor', False)],
          'afors': [('afor', False)],
          'afors-': [('afor', False)],
          'afsarnas': [('afs', False)],
          'aftan': [('afta', False)],
          'aftans': [('aftan', False)],
          'aftets': [('aft', False)],
          'afäder': [('afar', False)],
          'afäderna': [('afar', False)],
          'afädernas': [('afar', False)],
          'afäders': [('afar', False)],
          'aförlust-': [('aförlust', False)],
          'aförlusterna': [('aförlust', False)],
          'aförlusternas': [('aförlust', False)],
          'aförsäkringar': [('aförsäkring', False)],
          'aförsäkringarna': [('aförsäkring', False)],
          'aförsäkringarnas': [('aförsäkring', False)],
          'aförsäkringars': [('aförsäkring', False)],
          'ag': [('ag', False)],
          'ag-': [('ag', False)],
          'agagen': [('agage', False)],
          'agagens': [('agage', False)],
          'agaget': [('agage', False)],
          'agagets': [('agage', False)],
          'agan': [('aga', True)],
          'agandens': [('agande', False)],
          'agans': [('aga', False)],
          'agans-': [('agan', False)],
          'agar': [('agar', True)],
          'agar-': [('agar', True)],
          'agaren': [('agare', False)],
          'agars': [('agar', True)],
          'agas': [('aga', False)],
          'agat': [('agat', False)],
          'agat-': [('agat', False)],
          'agate': [('agata', False)],
          'agate-': [('agata', False)],
          'agaten': [('agat', False)],
          'agatens': [('agat', False)],
          'agater': [('agat', False)],
          'agaterna': [('agat', False)],
          'agaternas': [('agat', False)],
          'agaters': [('agat', True)],
          'agats': [('agat', True)],
          'agats-': [('agat', False)],
          'agcentrets': [('agcentrum', False)],
          'agdans': [('agdans', False)],
          'age': [('aga', False)],
          'age-': [('aga', False)],
          'agel': [('agel', False)],
          'agel-': [('agel', False)],
          'agelsen': [('agelse', False)],
          'agelsens': [('agelse', False)],
          'agements': [('agement', False)],
          'agems': [('agem', False)],
          'agen': [('ag', False)],
          'agener': [('agen', False)],
          'agenernas': [('agen', False)],
          'agens': [('agens', True), ('ag', True)],
          'agens-': [('agens', True)],
          'ager': [('age', False)],
          'ageriernas': [('ageri', False)],
          'agers': [('ag', False)],
          'agers-': [('ager', False)],
          'agersarna': [('ager', False)],
          'agersarnas': [('ager', False)],
          'aget': [('ag', False)],
          'agets': [('age', False)],
          'agettens': [('agett', False)],
          'agg': [('agg', True)],
          'agg-': [('agg', True)],
          'aggar': [('agg', False)],
          'aggarnas': [('agge', False)],
          'aggars': [('agge', False)],
          'aggdags-': [('aggdag', False)],
          'agge': [('agge', False)],
          'agge-': [('agge', False)],
          'aggen': [('agge', False)],
          'aggens': [('agge', False)],
          'aggets': [('agg', False)],
          'aggman': [('aggman', False)],
          'aggmans': [('aggman', False)],
          'aggs': [('agg', True)],
          'aggs-': [('agg', True)],
          'aghets': [('aghet', False)],
          'agier': [('agier', False)],
          'agierna': [('agier', False)],
          'agiernas': [('agier', False)],
          'agiers': [('agier', False)],
          'agillen': [('agille', False)],
          'agillet': [('agille', False)],
          'agillets': [('agille', False)],
          'agin': [('agi', False)],
          'agin-': [('agina', False)],
          'agine': [('agina', False)],
          'agine-': [('agina', False)],
          'agins': [('agi', False)],
          'agins-': [('agina', False)],
          'agion': [('agio', False)],
          'agions': [('agio', False)],
          'agis': [('agis', False)],
          'agis-': [('agis', False)],
          'agister': [('agister', False)],
          'agisters': [('agister', False)],
          'agkapp': [('agkapp', False)],
          'agkapps': [('agkapp', False)],
          'agkapps-': [('agkapp', False)],
          'agknip': [('agknip', False)],
          'agknips': [('agknip', False)],
          'agknips-': [('agknip', False)],
          'aglan': [('aglan', False)],
          'aglans': [('aglan', False)],
          'aglar': [('agel', False)],
          'aglarna': [('agel', False)],
          'aglarnas': [('agel', False)],
          'aglars': [('agel', False)],
          'agle': [('agle', False)],
          'agle-': [('agle', False)],
          'aglen': [('agel', False)],
          'aglens': [('agel', False)],
          'agles': [('agle', False)],
          'aglin': [('aglina', False)],
          'aglina': [('aglina', False)],
          'aglinas': [('aglina', False)],
          'aglins': [('aglina', False)],
          'aglott-': [('aglott', False)],
          'aglotts': [('aglott', False)],
          'aglotts-': [('aglott', False)],
          'agm': [('agma', False)],
          'agm-': [('agma', False)],
          'agman': [('agma', False)],
          'agmans': [('agma', False)],
          'agmat': [('agma', False)],
          'agmer': [('agma', False)],
          'agmerna': [('agma', False)],
          'agmernas': [('agma', False)],
          'agmers': [('agma', False)],
          'agms': [('agma', False)],
          'agms-': [('agm', False)],
          'agn': [('agnar', True), ('agn', True)],
          'agn-': [('agnar', True), ('agn', True)],
          'agnar': [('agnar', True)],
          'agnarna': [('agnar', True)],
          'agnarnas': [('agnar', True)],
          'agnars': [('agnar', True)],
          'agnen': [('agn', True)],
          'agnens': [('agn', True)],
          'agner': [('agne', False)],
          'agnerna': [('agne', False)],
          'agnet': [('agn', True)],
          'agnets': [('agn', True)],
          'agnosis': [('agnosi', False)],
          'agns': [('agnar', True), ('agn', True)],
          'agns-': [('agnar', True), ('agn', True)],
          'ago': [('ago', False)],
          'agod': [('agod', False)],
          'agod-': [('agod', False)],
          'agoden': [('agod', False)],
          'agodens': [('agod', False)],
          'agods': [('agod', False)],
          'agods-': [('agod', False)],
          'agog': [('agog', False)],
          'agog-': [('agog', False)],
          'agogs': [('agog', False)],
          'agogs-': [('agog', False)],
          'agon': [('ago', False)],
          'agonens': [('agon', False)],
          'agonier': [('agoni', True)],
          'agoniernas': [('agoni', True)],
          'agons': [('ago', False)],
          'agor': [('aga', False)],
          'agorna': [('aga', False)],
          'agornas': [('aga', False)],
          'agors': [('aga', False)],
          'agosarnas': [('ago', False)],
          'agot': [('ago', False)],
          'agots': [('ago', False)],
          'agrafen': [('agraf', False)],
          'agrafens': [('agraf', False)],
          'agran': [('agra', False)],
          'agranden': [('agrande', False)],
          'agrandens': [('agrande', False)],
          'agrandet': [('agrande', False)],
          'agrandets': [('agrande', False)],
          'agrans': [('agra', False)],
          'agrar': [('agrar', True)],
          'agrarna': [('ager', False)],
          'agrars': [('agrar', True)],
          'agras': [('agra', False)],
          'agras-': [('agra', False)],
          'agremang': [('agremang', True), ('agremanger', True)],
          'agremang-': [('agremang', True), ('agremanger', True)],
          'agremangs': [('agremang', True), ('agremanger', True)],
          'agremangs-': [('agremang', True), ('agremanger', True)],
          'agrems': [('agrem', False)],
          'agrems-': [('agrem', False)],
          'agren': [('ager', False)],
          'agrens': [('ager', False)],
          'agrep': [('agrep', False)],
          'agrepen': [('agrep', False)],
          'agrepens': [('agrep', False)],
          'agreps': [('agrep', False)],
          'agreps-': [('agrep', False)],
          'agrill': [('agrill', False)],
          'agrills': [('agrill', False)],
          'agrills-': [('agrill', False)],
          'agrums': [('agrum', False)],
          'agrums-': [('agrum', False)],
          'agrynet': [('agryn', False)],
          'agrynets': [('agryn', False)],
          'ags': [('ag', False)],
          'ags-': [('ag', False)],
          'agsdelar': [('agsdel', False)],
          'agsdelarna': [('agsdel', False)],
          'agsens': [('ag', False)],
          'agsframställningar': [('agsframställning', False)],
          'agsframställningarna': [('agsframställning', False)],
          'agsframställningars': [('agsframställning', False)],
          'agskasse': [('agskassa', False)],
          'agskostnader': [('agskostnad', False)],
          'agskostnaderna': [('agskostnad', False)],
          'agskostnadernas': [('agskostnad', False)],
          'agskostnaders': [('agskostnad', False)],
          'agskostnads': [('agskostnad', False)],
          'agskostnads-': [('agskostnad', False)],
          'agsprogrammet': [('agsprogram', False)],
          'agsprogrammets': [('agsprogram', False)],
          'agstens': [('agsten', False)],
          'agsverken': [('agsverke', False)],
          'agsverkens': [('agsverke', False)],
          'agsverket': [('agsverke', False)],
          'agsverkets': [('agsverk', False)],
          'agsverks': [('agsverke', False)],
          'agsverks-': [('agsverke', False)],
          'agsvägar': [('agsväg', False)],
          'agsvägarna': [('agsväg', False)],
          'agsvägarnas': [('agsväg', False)],
          'agsvägars': [('agsväg', False)],
          'agsvägs': [('agsväg', False)],
          'agsvägs-': [('agsväg', False)],
          'agsvärden': [('agsvärd', False)],
          'agsvärdens': [('agsvärde', False)],
          'agsvärdet': [('agsvärde', False)],
          'agsvärdets': [('agsvärd', False)],
          'agtanden': [('agtand', False)],
          'agtandens': [('agtand', False)],
          'agu-': [('agu', False)],
          'aguer': [('agu', False)],
          'aguerna': [('agu', False)],
          'agun': [('agun', False)],
          'aguns': [('agun', False)],
          'agvägar': [('agvägare', False)],
          'agvägarna': [('agvägare', False)],
          'agvägarnas': [('agvägare', False)],
          'agvård': [('agvård', False)],
          'agvårds': [('agvård', False)],
          'agvårds-': [('agvård', False)],
          'agär': [('agär', False)],
          'agär-': [('agär', False)],
          'agärs': [('agär', False)],
          'agärs-': [('agär', False)],
          'agångar': [('agång', False)],
          'agångarna': [('agång', False)],
          'agångarnas': [('agång', False)],
          'agås': [('agås', False)],
          'agås-': [('agås', False)],
          'agåsen': [('agås', False)],
          'agåsens': [('agås', False)],
          'agåve-': [('agåva', False)],
          'agåvors': [('agåva', False)],
          'ah': [('ah', False)],
          'ah-': [('ah', False)],
          'ahen': [('ah', False)],
          'ahens': [('ah', False)],
          'aher': [('ah', False)],
          'aherna': [('ah', False)],
          'ahernas': [('ah', False)],
          'ahers': [('ah', False)],
          'ahs-': [('ah', False)],
          'ahundars': [('ahund', False)],
          'ahus': [('ahus', False)],
          'ahytt': [('ahytt', False)],
          'ahytt-': [('ahytt', False)],
          'ahytts': [('ahytt', False)],
          'ahästarnas': [('ahäst', False)],
          'ahästars': [('ahäst', False)],
          'ahåken': [('ahåk', False)],
          'ahåkens': [('ahåk', False)],
          'ahörighets': [('ahörighet', False)],
          'ai-': [('ai', False)],
          'aiden': [('aid', False)],
          'aidens': [('aid', False)],
          'aids': [('aids', True)],
          'aids-': [('aids', True)],
          'aig': [('aiga', False)],
          'aig-': [('aiga', False)],
          'aigan': [('aiga', False)],
          'aigs': [('aiga', False)],
          'aigs-': [('aiga', False)],
          'aiker': [('aiker', False)],
          'aikerna': [('aiker', False)],
          'aikernas': [('aiker', False)],
          'aikers': [('aiker', False)],
          'aikus': [('aiku', False)],
          'ailandets': [('ailande', False)],
          'ailar': [('ailare', False)],
          'ailar-': [('ailare', False)],
          'ailarens': [('ailare', False)],
          'ailarna': [('ailare', False)],
          'ailarnas': [('ailare', False)],
          'ailer': [('ailer', False)],
          'ailerna': [('ailer', False)],
          'ailernas': [('ailer', False)],
          'ailers': [('ailer', False)],
          'aillens': [('aille', False)],
          'ailler': [('aille', False)],
          'aillerna': [('aille', False)],
          'aillernas': [('aille', False)],
          'aillers': [('aille', False)],
          'ain': [('ain', False)],
          'ainar': [('ainare', False)],
          'ainar-': [('ainare', False)],
          'ainarens': [('ainare', False)],
          'ainarna': [('ainare', False)],
          'ainer': [('ainer', False)],
          'ainerna': [('ainer', False)],
          'ainernas': [('ainer', False)],
          'ainers': [('ainer', False)],
          'ainets': [('ain', False)],
          'aing': [('aing', False)],
          'aingar': [('aing', False)],
          'aingarna': [('aing', False)],
          'aingarnas': [('aing', False)],
          'aingars': [('aing', False)],
          'aingen': [('aing', False)],
          'aingens': [('aing', False)],
          'aings': [('aing', False)],
          'aings-': [('aing', False)],
          'ainister': [('ainist', False)],
          'ainisters': [('ainist', False)],
          'ainkomst-': [('ainkomst', False)],
          'ainkomster': [('ainkomst', False)],
          'ainkomsterna': [('ainkomst', False)],
          'ainkomsternas': [('ainkomst', False)],
          'ainrar': [('ainer', False)],
          'ainrarna': [('ainer', False)],
          'ainrarnas': [('ainer', False)],
          'ainrars': [('ainer', False)],
          'ains': [('ain', False)],
          'aint': [('aint', False)],
          'aire': [('aire', False)],
          'aire-': [('aire', False)],
          'airer': [('air', False)],
          'airerna': [('air', False)],
          'airernas': [('air', True)],
          'airers': [('air', True)],
          'ais': [('ai', False)],
          'aise': [('aise', False)],
          'aise-': [('aise', False)],
          'aisen': [('aise', False)],
          'aisens': [('aise', False)],
          'aiser': [('aise', False)],
          'aiserna': [('aise', False)],
          'aisernas': [('aise', False)],
          'aisers': [('aise', False)],
          'aismer': [('aism', False)],
          'aismernas': [('aism', False)],
          'aisser': [('aisse', False)],
          'aisserna': [('aisse', False)],
          'aissernas': [('aisse', False)],
          'aissers': [('aisse', False)],
          'aist-': [('aist', False)],
          'aisten': [('aist', False)],
          'aistens': [('aist', False)],
          'aister': [('aist', False)],
          'aisterna': [('aist', False)],
          'aisternas': [('aist', False)],
          'aisters': [('aist', False)],
          'ait': [('ait', False)],
          'aiternas': [('ait', False)],
          'aits': [('ait', False)],
          'aj': [('aj', False)],
          'aj-': [('aj', False)],
          'aj:t': [('aj:t', False)],
          'ajaden': [('ajad', False)],
          'ajadens': [('ajad', False)],
          'ajan': [('aja', False)],
          'ajangs': [('ajang', False)],
          'ajans': [('ajans', False)],
          'ajans-': [('ajans', False)],
          'ajar': [('aj', False)],
          'ajarna': [('aj', False)],
          'ajarnas': [('aj', False)],
          'ajars': [('aj', False)],
          'ajas': [('ajas', False)],
          'ajas-': [('ajas', False)],
          'aje': [('aja', False)],
          'aje-': [('aja', False)],
          'ajen': [('aj', False)],
          'ajens': [('aj', False)],
          'ajer': [('aj', False)],
          'ajerna': [('aj', False)],
          'ajernas': [('aj', False)],
          'ajers': [('aj', False)],
          'ajet': [('aj', False)],
          'ajets': [('aj', False)],
          'ajfens': [('ajfena', False)],
          'ajj': [('ajj', False)],
          'ajje': [('ajje', False)],
          'ajje-': [('ajje', False)],
          'ajjen': [('ajje', False)],
          'ajjens': [('ajje', False)],
          'ajk': [('ajka', False)],
          'ajk-': [('ajka', False)],
          'ajkar': [('ajk', False)],
          'ajkarna': [('ajk', False)],
          'ajkarnas': [('ajk', False)],
          'ajkars': [('ajk', False)],
          'ajks': [('ajka', False)],
          'ajks-': [('ajk', False)],
          'ajorna': [('aja', False)],
          'ajornas': [('aja', False)],
          'ajors': [('aja', False)],
          'ajos': [('ajo', False)],
          'ajos-': [('ajo', False)],
          'ajrar': [('ajer', False)],
          'ajrarna': [('ajer', False)],
          'ajrarnas': [('ajrare', False)],
          'ajs': [('aj', False)],
          'ajs-': [('ajs', False)],
          'ajsar': [('ajsare', False)],
          'ajsar-': [('ajsare', False)],
          'ajsarna': [('ajsare', False)],
          'ajute': [('ajuta', False)],
          'ajute-': [('ajuta', False)],
          'ajuts': [('ajuta', False)],
          'ajuts-': [('ajuta', False)],
          'ak': [('ak', False)],
          'aka': [('akum', False)],
          'akadus': [('akadua', False)],
          'akadus-': [('akadua', False)],
          'akal': [('akal', False)],
          'akal-': [('akal', False)],
          'akals': [('akal', False)],
          'akalsong': [('akalsong', False)],
          'akalsong-': [('akalsong', False)],
          'akalsonger': [('akalsong', False)],
          'akalsongerna': [('akalsong', False)],
          'akalsongernas': [('akalsong', False)],
          'akalsongers': [('akalsong', False)],
          'akalsongs': [('akalsong', False)],
          'akammar': [('akammare', False)],
          'akan': [('akan', False)],
          'akan-': [('akan', False)],
          'akana': [('akum', False)],
          'akanas': [('akum', False)],
          'akanden': [('akande', False)],
          'akans': [('akan', False)],
          'akans-': [('akan', False)],
          'akaos': [('akao', False)],
          'akaos-': [('akao', False)],
          'akar': [('ak', False)],
          'akar-': [('akare', False)],
          'akare': [('akare', False)],
          'akaren': [('akare', False)],
          'akarens': [('akare', False)],
          'akarna': [('ak', False)],
          'akarnas': [('akare', False)],
          'akars': [('ak', False)],
          'akas': [('akum', False)],
          'akass': [('akass', False)],
          'akass-': [('akass', False)],
          'akassen': [('akass', False)],
          'akassens': [('akass', False)],
          'akat': [('aka', False)],
          'akaten': [('akat', False)],
          'akatens': [('akat', False)],
          'akatet': [('akat', False)],
          'akatets': [('akat', False)],
          'akats': [('aka', False)],
          'akats-': [('akat', False)],
          'akatt': [('akatt', False)],
          'akatt-': [('akatt', False)],
          'akatten': [('akatt', False)],
          'akattens': [('akatt', False)],
          'akatts': [('akatt', False)],
          'akatts-': [('akatt', False)],
          'akdelar': [('akdel', False)],
          'akdelarna': [('akdel', False)],
          'akdelarnas': [('akdel', False)],
          'akdomar': [('akdomare', False)],
          'akdomarna': [('akdomare', False)],
          'akdomarnas': [('akdomare', False)],
          'ake': [('aka', False)],
          'ake-': [('aka', False)],
          'akeks': [('akeka', False)],
          'akeks-': [('akeka', False)],
          'akel': [('akel', False)],
          'akel-': [('akel', False)],
          'akels': [('akel', False)],
          'akels-': [('akel', False)],
          'akelsen': [('akelse', False)],
          'akelsens': [('akelse', False)],
          'aken': [('ak', False)],
          'akens': [('ak', False)],
          'aker': [('ak', False)],
          'akerits': [('akeri', False)],
          'akerna': [('ak', False)],
          'akernas': [('ak', False)],
          'akers': [('ak', False)],
          'akersens': [('aker', False)],
          'akesen': [('akes', False)],
          'akesens': [('akes', False)],
          'aket': [('ak', False)],
          'akfots-': [('akfot', False)],
          'akfötter': [('akfot', False)],
          'akfötterna': [('akfot', False)],
          'akfötternas': [('akfot', False)],
          'akfötters': [('akfot', False)],
          'akier': [('akier', False)],
          'akierna': [('akier', False)],
          'akiernas': [('akier', False)],
          'akiers': [('akier', False)],
          'akin': [('aki', False)],
          'akins': [('akin', False)],
          'akis': [('aki', False)],
          'akist': [('akist', False)],
          'akist-': [('akista', False)],
          'akistan': [('akistan', False)],
          'akistans': [('akista', False)],
          'akkammar': [('akkam', False)],
          'akkors': [('akkors', False)],
          'akladdar': [('akladdare', False)],
          'akladdarna': [('akladdare', False)],
          'akladdarnas': [('akladdare', False)],
          'aklagets': [('aklag', False)],
          'aklamp': [('aklampa', False)],
          'aklamp-': [('aklampa', False)],
          'aklamps': [('aklampa', False)],
          'aklamps-': [('aklampa', False)],
          'aklandet': [('akland', False)],
          'aklandets': [('aklande', False)],
          'aklapp': [('aklapp', False)],
          'aklapp-': [('aklapp', False)],
          'aklapps': [('aklapp', False)],
          'aklapps-': [('aklapp', False)],
          'aklar': [('akel', False)],
          'aklarna': [('akel', False)],
          'aklarnas': [('akel', False)],
          'aklars': [('akel', False)],
          'aklen': [('akel', False)],
          'aklens': [('akel', False)],
          'aklernas': [('akel', False)],
          'aklet': [('akel', False)],
          'aklets': [('akel', False)],
          'akliniker': [('aklinik', False)],
          'aklinikerna': [('aklinik', False)],
          'aklinikernas': [('aklinik', False)],
          'aklinikers': [('aklinik', False)],
          'aklister': [('aklist', False)],
          'aklisters': [('aklist', False)],
          'akluck': [('aklucka', False)],
          'akluck-': [('aklucka', False)],
          'aklucks': [('aklucka', False)],
          'aklucks-': [('aklucka', False)],
          'aklädes': [('akläder', False)],
          'aklädes-': [('akläder', False)],
          'akman': [('akma', False)],
          'akmans': [('akma', False)],
          'aknatt': [('aknatt', False)],
          'aknatten': [('aknatt', False)],
          'aknattens': [('aknatt', False)],
          'aknatts': [('aknatt', False)],
          'aknatts-': [('aknatt', False)],
          'akne': [('akne', True)],
          'aknens': [('akne', True)],
          'akningar': [('akning', False)],
          'akningarna': [('akning', False)],
          'akningarnas': [('akning', False)],
          'akningars': [('akning', False)],
          'aknings': [('akning', False)],
          'aknings-': [('akning', False)],
          'ako-': [('ako', False)],
          'akocker': [('akocker', False)],
          'akockers': [('akocker', False)],
          'akolans': [('akola', False)],
          'akolor': [('akola', False)],
          'akolors': [('akola', False)],
          'akom': [('akom', False)],
          'akom-': [('akom', False)],
          'akomet': [('akom', False)],
          'akometer': [('akometer', False)],
          'akometers': [('akometer', False)],
          'akomets': [('akom', False)],
          'akoms': [('akom', False)],
          'akon': [('akon', False)],
          'akon-': [('akon', False)],
          'akondor': [('akonda', False)],
          'akondors': [('akonda', False)],
          'akons': [('ako', False)],
          'akonst-': [('akonst', False)],
          'akopp': [('akopp', False)],
          'akoppar': [('akopp', False)],
          'akoppars': [('akopp', False)],
          'akopps': [('akopp', False)],
          'akopps-': [('akopp', False)],
          'akor': [('aka', False)],
          'akord': [('akord', False)],
          'akord-': [('akord', False)],
          'akords': [('akord', False)],
          'akords-': [('akord', False)],
          'akoret': [('akoret', False)],
          'akorets': [('akoret', False)],
          'akorna': [('aka', False)],
          'akornas': [('aka', False)],
          'akors': [('akors', False)],
          'akors-': [('akors', False)],
          'akos': [('akos', False)],
          'akos-': [('ako', False)],
          'akrafts': [('akraft', False)],
          'akrafts-': [('akraft', False)],
          'akrans': [('akrans', False)],
          'akrans-': [('akrans', False)],
          'akrar': [('aker', False)],
          'akrarna': [('aker', False)],
          'akras': [('akras', False)],
          'akris': [('akris', False)],
          'akris-': [('akris', False)],
          'akrit': [('akrit', False)],
          'akrit-': [('akrit', False)],
          'akrits': [('akrits', False)],
          'akrits-': [('akrit', False)],
          'akron': [('akron', False)],
          'akron-': [('akron', False)],
          'akronan': [('akrona', False)],
          'akronans': [('akrona', False)],
          'akrons': [('akron', False)],
          'akrons-': [('akrona', False)],
          'aksaks': [('aksak', False)],
          'aksaks-': [('aksak', False)],
          'aksmäll': [('aksmälla', False)],
          'aksmäll-': [('aksmälla', False)],
          'aktan': [('akta', False)],
          'aktanas': [('aktum', False)],
          'aktankar': [('aktanke', False)],
          'aktankarna': [('aktanke', False)],
          'aktankarnas': [('aktanke', False)],
          'aktankars': [('aktanke', False)],
          'aktanken': [('aktanke', False)],
          'aktankens': [('aktanke', False)],
          'aktans': [('akta', False)],
          'aktar': [('aktare', False)],
          'aktar-': [('aktare', False)],
          'aktarens': [('aktare', False)],
          'aktarna': [('aktare', False)],
          'aktas': [('aktum', False)],
          'aktas-': [('akta', False)],
          'aktat': [('akta', False)],
          'aktats': [('akta', False)],
          'akten': [('akt', True)],
          'akter': [('akt', True), ('akter', True)],
          'akterier': [('akterie', False)],
          'akterierna': [('akteri', False)],
          'akteriernas': [('akteri', False)],
          'akteriers': [('akteri', False)],
          'akteriet': [('akteri', False)],
          'akteriets': [('akterium', False)],
          'akters': [('akt', True), ('akter', True)],
          'aktets': [('akt', False)],
          'aktiker': [('aktiker', False)],
          'aktikerna': [('aktiker', False)],
          'aktikernas': [('aktiker', False)],
          'aktikers': [('aktiker', False)],
          'aktin': [('aktin', False)],
          'aktins': [('akti', False)],
          'aktioner': [('aktion', False)],
          'aktionerna': [('aktion', False)],
          'aktionernas': [('aktion', True)],
          'aktioners': [('aktion', False)],
          'aktions': [('aktion', False)],
          'aktiv': [('aktivum', True)],
          'aktiv-': [('aktivum', True)],
          'aktiven': [('aktivum', True)],
          'aktivens': [('aktivum', True)],
          'aktiver': [('aktivum', True)],
          'aktiverna': [('aktivum', True)],
          'aktivernas': [('aktivum', True)],
          'aktivers': [('aktivum', True)],
          'aktivet': [('aktivum', True)],
          'aktivs': [('aktivum', True)],
          'aktor': [('aktor', False)],
          'aktorer': [('aktor', True)],
          'aktorers': [('aktor', True)],
          'aktori': [('aktori', False)],
          'aktori-': [('aktori', False)],
          'aktorier': [('aktori', False)],
          'aktoris': [('aktori', False)],
          'aktors': [('aktor', False)],
          'aktuarie-': [('aktuarie', True)],
          'aktuarier': [('aktuarie', True)],
          'aktuariernas': [('aktuarie', True)],
          'akturs-': [('aktur', False)],
          'akun': [('akun', False)],
          'akuns': [('akun', False)],
          'akurs': [('akurs', False)],
          'akurs-': [('akurs', False)],
          'akus': [('akus', False)],
          'akus-': [('akus', False)],
          'akusen': [('akus', False)],
          'akusens': [('akus', False)],
          'akut-': [('akut', True)],
          'akuts': [('akut', True)],
          'akuts-': [('akut', True)],
          'akvarier': [('akvarium', True)],
          'akvariernas': [('akvarium', True)],
          'akvarter': [('akvarter', False)],
          'akvarters': [('akvarter', False)],
          'akändarnas': [('akände', False)],
          'akår': [('akår', False)],
          'akåren': [('akår', False)],
          'akårens': [('akår', False)],
          'akårs': [('akår', False)],
          'akårs-': [('akår', False)],
          'akås': [('akås', False)],
          'akås-': [('akås', False)],
          'akök-': [('akök', False)],
          'aköks': [('akök', False)],
          'aköks-': [('akök', False)],
          'akön': [('akö', False)],
          'aköns': [('akö', False)],
          'akör': [('akör', False)],
          'aköre': [('aköre', False)],
          'akören': [('aköre', False)],
          'akörens': [('aköre', False)],
          'akörs': [('akör', False)],
          'al': [('al', False)],
          'al-': [('al', False)],
          'alack': [('alack', False)],
          'alag': [('alag', False)],
          'alagans': [('alaga', False)],
          'alagen': [('alag', False)],
          'alagens': [('alag', False)],
          'alaget': [('alag', False)],
          'alags': [('alag', False)],
          'alags-': [('alag', False)],
          'alahästarnas': [('alahäst', False)],
          'alahästars': [('alahäst', False)],
          'alamin': [('alami', False)],
          'alamins': [('alami', False)],
          'alamps': [('alampa', False)],
          'alamps-': [('alampa', False)],
          'alan': [('alan', True)],
          'alan-': [('alan', False)],
          'alanden': [('alande', False)],
          'alandena': [('alande', False)],
          'alandenas': [('alande', False)],
          'alandens': [('alande', False)],
          'alander': [('alander', False)],
          'alanders': [('alander', False)],
          'alandet': [('alande', False)],
          'alandets': [('aland', False)],
          'alaner': [('alan', False)],
          'alanerna': [('alan', False)],
          'alanernas': [('alan', False)],
          'alaners': [('alan', False)],
          'alans': [('alan', True)],
          'alans-': [('alan', False)],
          'alant-': [('alant', True)],
          'alanterna': [('alant', True)],
          'alanternas': [('alant', False)],
          'alants': [('alant', True)],
          'alar': [('al', True)],
          'alaren': [('alare', False)],
          'alarer': [('alar', False)],
          'alarerna': [('alar', False)],
          'alarernas': [('alar', False)],
          'alarers': [('alar', False)],
          'alarna': [('al', False)],
          'alarnas': [('al', False)],
          'alars': [('al', False)],
          'alars-': [('alar', False)],
          'alasen': [('alas', False)],
          'alasens': [('alas', False)],
          'alassar': [('alasse', False)],
          'alassarna': [('alasse', False)],
          'alassars': [('alasse', False)],
          'alassen': [('alasse', False)],
          'alassens': [('alasse', False)],
          'alat': [('alat', False)],
          'alat-': [('alat', False)],
          'alatans': [('alata', False)],
          'alaten': [('alat', False)],
          'alatens': [('alat', False)],
          'alater': [('alat', False)],
          'alaterna': [('alat', False)],
          'alaternas': [('alat', False)],
          'alaters': [('alat', False)],
          'alats': [('alater', False)],
          'alats-': [('alats', False)],
          'alav': [('alav', False)],
          'alav-': [('alav', False)],
          'alavar': [('alav', False)],
          'alavarna': [('alav', False)],
          'alavarnas': [('alav', False)],
          'alavars': [('alav', False)],
          'alaven': [('alav', False)],
          'alavens': [('alav', False)],
          'alavers': [('alaver', False)],
          'alavs': [('alav', False)],
          'alavs-': [('alav', False)],
          'alban': [('alban', True), ('alba', True)],
          'albans': [('alba', True), ('alban', True)],
          'albas': [('alba', True)],
          'alben': [('alben', False)],
          'albens': [('alb', False)],
          'albigenser': [('albigens', True), ('albigenser', True)],
          'albigenserna': [('albigens', True), ('albigenser', True)],
          'albigensernas': [('albigens', True), ('albigenser', True)],
          'albigensers': [('albigens', True), ('albigenser', True)],
          'albor': [('alba', True)],
          'alborna': [('alba', True)],
          'albornas': [('alba', True)],
          'alborr': [('alborr', False)],
          'alborr-': [('alborr', False)],
          'alborrar': [('alborr', False)],
          'alborrarna': [('alborr', False)],
          'alborrarnas': [('alborr', False)],
          'alborrars': [('alborr', False)],
          'alborren': [('alborr', False)],
          'alborrens': [('alborr', False)],
          'alborrs': [('alborr', False)],
          'alborrs-': [('alborr', False)],
          'albors': [('alba', True)],
          'aldans': [('aldans', False)],
          'aldans-': [('aldans', False)],
          'alder': [('alder', False)],
          'alders': [('alder', False)],
          'aldon': [('aldo', False)],
          'aldos': [('aldo', False)],
          'aldrarnas': [('alder', False)],
          'ale': [('ale', True)],
          'ale-': [('ale', True)],
          'aleas': [('alea', False)],
          'alek': [('alek', False)],
          'alekar': [('alek', False)],
          'alekarna': [('alek', False)],
          'alekarnas': [('alek', False)],
          'aleken': [('alek', False)],
          'aleks-': [('alek', False)],
          'alekternas': [('alekt', False)],
          'alementets': [('alement', False)],
          'alements': [('alement', False)],
          'alen': [('al', False)],
          'alen-': [('alen', False)],
          'alens': [('al', False)],
          'aler': [('al', False)],
          'aler-': [('aler', False)],
          'alerna': [('al', False)],
          'alernas': [('al', False)],
          'alers': [('al', False)],
          'alers-': [('aler', False)],
          'ales': [('ale', True)],
          'ales-': [('ale', True)],
          'alesarna': [('alesare', False)],
          'alesarnas': [('alesare', False)],
          'alesen': [('ales', False)],
          'alesens': [('ales', False)],
          'alet': [('ale', True)],
          'alets': [('ale', True)],
          'alettens': [('alett', False)],
          'alfat': [('alfa', True)],
          'alfats': [('alfa', True)],
          'alfen': [('alf', True)],
          'alfens': [('alf', True)],
          'alfiskar': [('alfisk', False)],
          'alfiskarna': [('alfisk', False)],
          'alg': [('alg', True)],
          'alg-': [('alg', True)],
          'algarnas': [('alge', False)],
          'algars': [('alge', False)],
          'algen': [('alg', True)],
          'algens': [('alg', True)],
          'algier': [('algi', False)],
          'algierna': [('algi', False)],
          'algiers': [('algi', False)],
          'algs': [('alg', True)],
          'algs-': [('alg', True)],
          'algångar': [('algång', False)],
          'algångarna': [('algång', False)],
          'algångarnas': [('algång', False)],
          'algångars': [('algång', False)],
          'algångs': [('algång', False)],
          'algångs-': [('algång', False)],
          'alharmonierna': [('alharmoni', False)],
          'alharmoniernas': [('alharmoni', False)],
          'alharmoniers': [('alharmoni', False)],
          'ali': [('ali', False)],
          'ali-': [('ali', False)],
          'alian': [('alia', False)],
          'alians': [('alia', False)],
          'alias': [('alia', False)],
          'alias-': [('alia', False)],
          'alid-': [('alid', False)],
          'alider': [('alid', False)],
          'aliderna': [('alid', False)],
          'alidernas': [('alid', False)],
          'aliders': [('alid', False)],
          'alids': [('alid', False)],
          'alie': [('alier', False)],
          'alie-': [('alie', False)],
          'alien': [('alie', False)],
          'aliens': [('ali', False)],
          'alier': [('alier', False)],
          'alierna': [('al', False)],
          'aliernas': [('alier', False)],
          'aliers': [('alier', False)],
          'aliet': [('alium', False)],
          'alifs': [('alif', False)],
          'aligans': [('aliga', False)],
          'alighets': [('alighet', False)],
          'alik': [('alik', False)],
          'alik-': [('alik', False)],
          'alike': [('alika', True)],
          'alike-': [('alika', True)],
          'aliken': [('alik', False)],
          'alikens': [('alik', False)],
          'aliker': [('alik', False)],
          'alikerna': [('alik', False)],
          'alikernas': [('alik', False)],
          'alikers': [('alik', False)],
          'aliks': [('alik', False)],
          'aliks-': [('alik', False)],
          'alin': [('ali', False)],
          'alin-': [('alin', False)],
          'alinen': [('alin', False)],
          'alinens': [('alin', False)],
          'aliner': [('alin', False)],
          'alinerna': [('alin', False)],
          'alinernas': [('alin', False)],
          'aliners': [('alin', False)],
          'alinet': [('alin', False)],
          'alins': [('alin', False)],
          'alins-': [('alin', False)],
          'alis': [('ali', False)],
          'alis-': [('alis', False)],
          'alisen': [('alis', False)],
          'alisens': [('alis', False)],
          'alisk': [('aliska', False)],
          'alisk-': [('aliska', False)],
          'aliss': [('alissa', False)],
          'alist': [('alist', False)],
          'alist-': [('alist', False)],
          'alit': [('alit', False)],
          'alit-': [('alit', False)],
          'aliten': [('alit', False)],
          'alitens': [('alit', False)],
          'aliter': [('alit', False)],
          'aliterna': [('alit', False)],
          'aliternas': [('alit', False)],
          'aliters': [('alit', False)],
          'alitet': [('alitet', False)],
          'alitets': [('alitet', False)],
          'alits': [('alit', False)],
          'alivs': [('aliv', False)],
          'alivs-': [('aliv', False)],
          'alj': [('alja', False)],
          'alj-': [('alja', False)],
          'aljans': [('alja', False)],
          'alje': [('alje', False)],
          'alje-': [('alje', False)],
          'aljen': [('alje', False)],
          'aljens': [('alje', False)],
          'aljer': [('alje', False)],
          'aljerna': [('alje', False)],
          'aljernas': [('alje', False)],
          'aljet': [('alj', False)],
          'aljets': [('alj', False)],
          'aljs': [('alja', False)],
          'aljs-': [('alja', False)],
          'alk': [('alka', True)],
          'alk-': [('alka', True)],
          'alkan': [('alkan', True), ('alka', True)],
          'alkans': [('alka', True), ('alkan', True)],
          'alkar': [('alkare', False)],
          'alkarna': [('alkare', False)],
          'alkarnas': [('alk', False)],
          'alker': [('alker', False)],
          'alkers': [('alker', False)],
          'alkor': [('alka', False)],
          'alkott-': [('alkotte', True)],
          'alkottar': [('alkotte', True)],
          'alkottarna': [('alkotte', True)],
          'alkottarnas': [('alkotte', True)],
          'alkottars': [('alkotte', True)],
          'alkottens': [('alkotte', True)],
          'alkotts': [('alkotte', True)],
          'alkover': [('alkov', True)],
          'alkovers': [('alkov', True)],
          'alks': [('alka', True)],
          'alks-': [('alka', True)],
          'alkurs-': [('alkurs', False)],
          'allagen': [('allage', False)],
          'allagens': [('allag', False)],
          'allan': [('alla', True)],
          'allanden': [('alland', False)],
          'allandens': [('alland', False)],
          'allandet': [('alland', False)],
          'allandets': [('allande', False)],
          'allans': [('alla', False)],
          'allar': [('alle', False)],
          'allar-': [('allare', False)],
          'allarna': [('all', False)],
          'allarnas': [('all', False)],
          'allars': [('alle', False)],
          'alle': [('alle', False)],
          'alle-': [('alle', False)],
          'allens': [('all', False)],
          'aller': [('aller', False)],
          'allers': [('aller', False)],
          'allierna': [('allier', False)],
          'alliernas': [('allier', False)],
          'allins': [('allins', False)],
          'allis': [('allis', False)],
          'allkor': [('allko', False)],
          'allkors': [('allko', False)],
          'allon': [('allo', False)],
          'allons': [('allo', False)],
          'allor': [('alla', True)],
          'allorna': [('alla', True)],
          'allornas': [('alla', True)],
          'allors': [('alla', True)],
          'allos': [('allo', False)],
          'allos-': [('allo', False)],
          'allrar': [('allrare', False)],
          'allstaket': [('allstak', False)],
          'allstakets': [('allstak', False)],
          'allstudie': [('allstudie', False)],
          'allstudier': [('allstudie', False)],
          'alltet': [('allt', False)],
          'allvärden': [('allvärde', False)],
          'allvärdens': [('allvärde', False)],
          'allåt': [('allå', False)],
          'allåts': [('allåt', False)],
          'allön': [('allö', False)],
          'allöns': [('allön', False)],
          'almanack': [('almanack', True), ('almanacka', True)],
          'almanacks': [('almanacka', True), ('almanack', True)],
          'almanacks-': [('almanack', True), ('almanacka', True)],
          'almar': [('alm', True)],
          'almar-': [('almar', False)],
          'almaren': [('almar', False)],
          'almarnas': [('alm', False)],
          'almars': [('alm', True)],
          'almas': [('almas', False)],
          'almas-': [('almas', False)],
          'almet': [('alme', True)],
          'almets': [('alme', True)],
          'alms': [('alm', False)],
          'alnar': [('aln', True)],
          'alnarnas': [('aln', True)],
          'alningar': [('alning', False)],
          'alningarna': [('alning', False)],
          'alningarnas': [('alning', False)],
          'alningars': [('alning', False)],
          'alnings': [('alning', False)],
          'alnings-': [('alning', False)],
          'alo-': [('alo', False)],
          'aloer': [('aloe', True)],
          'aloerna': [('aloe', True)],
          'aloernas': [('aloe', True)],
          'aloers': [('aloe', True)],
          'alog': [('alog', False)],
          'alog-': [('alog', False)],
          'alogen': [('alog', False)],
          'alogens': [('alog', False)],
          'aloger': [('alog', False)],
          'alogerna': [('alog', False)],
          'alogernas': [('alog', False)],
          'alogers': [('alog', False)],
          'alogiernas': [('alogi', False)],
          'alogs': [('alog', False)],
          'alogs-': [('alog', False)],
          'alom-': [('alom', False)],
          'aloms': [('alom', False)],
          'alon': [('alon', False)],
          'alonen': [('alon', False)],
          'alonens': [('alon', False)],
          'aloner': [('alon', False)],
          'alonerna': [('alon', False)],
          'alonernas': [('alon', False)],
          'aloners': [('alone', False)],
          'alons': [('alon', False)],
          'alopp': [('alopp', False)],
          'alopp-': [('alopp', False)],
          'alopps': [('alopp', False)],
          'alopps-': [('alopp', False)],
          'alor': [('ala', False)],
          'alorder': [('alorder', False)],
          'alorderna': [('alorder', False)],
          'alordernas': [('alorder', False)],
          'alorders': [('alorder', False)],
          'alorin': [('alori', False)],
          'alorna': [('ala', False)],
          'alornas': [('ala', False)],
          'alors': [('ala', False)],
          'alos': [('alos', False)],
          'alos-': [('alos', False)],
          'alosen': [('alos', False)],
          'alosens': [('alos', False)],
          'aloser': [('alos', False)],
          'alosers': [('alos', False)],
          'alott': [('alott', False)],
          'alott-': [('alott', False)],
          'alotts': [('alott', False)],
          'alotts-': [('alott', False)],
          'alp': [('alp', False)],
          'alparnas': [('alp', False)],
          'alpell': [('alpell', False)],
          'alpell-': [('alpell', False)],
          'alpells': [('alpell', False)],
          'alpells-': [('alpell', False)],
          'alpet': [('alp', False)],
          'alpeter': [('alpeter', False)],
          'alpeters': [('alpeter', False)],
          'alpets': [('alp', False)],
          'alps': [('alp', True)],
          'alriken': [('alrike', False)],
          'alrikens': [('alrike', False)],
          'alroller': [('alroll', False)],
          'alrollers': [('alroll', False)],
          'als': [('als', True), ('al', True)],
          'als-': [('als', True), ('al', True)],
          'alsarnas': [('als', False)],
          'alskor': [('alska', False)],
          'alskorna': [('alska', False)],
          'alskornas': [('alska', False)],
          'alskors': [('alska', False)],
          'alston': [('alston', False)],
          'alstrarnas': [('alstrare', True)],
          'alstudie': [('alstudium', False)],
          'alstudier': [('alstudium', False)],
          'alstyrkans': [('alstyrka', False)],
          'alsvar': [('alsvar', False)],
          'alt': [('alt', False)],
          'alt-': [('alt', True)],
          'altan': [('altan', True)],
          'altans': [('altan', True)],
          'altar': [('alt', True), ('altare', True)],
          'altarna': [('alt', True), ('altare', True)],
          'altarnas': [('altare', True), ('alt', True)],
          'altes-': [('altes', False)],
          'altets': [('alt', False)],
          'altor': [('altor', False)],
          'altorna': [('alta', False)],
          'altornas': [('altor', False)],
          'altors': [('altor', False)],
          'altos': [('altos', False)],
          'altos-': [('altos', False)],
          'altran': [('altran', False)],
          'alts': [('alt', True)],
          'alts-': [('alt', True)],
          'alumnen': [('alumn', True)],
          'alumnens': [('alumn', True)],
          'alunge': [('alunge', False)],
          'alunge-': [('alunge', False)],
          'aluns': [('alun', True)],
          'aluns-': [('aluns', False)],
          'alus': [('alu', False)],
          'alus-': [('alu', False)],
          'aluster': [('aluster', False)],
          'alusters': [('aluster', False)],
          'alut': [('alut', False)],
          'alut-': [('alut', False)],
          'aluten': [('alut', False)],
          'alutens': [('alut', False)],
          'aluts': [('alut', False)],
          'aluts-': [('alut', False)],
          'aluv': [('aluv', False)],
          'aluv-': [('aluv', False)],
          'aluvs': [('aluv', False)],
          'alv': [('alv', True)],
          'alv-': [('alv', True)],
          'alvals': [('alvals', False)],
          'alvals-': [('alvals', False)],
          'alvan': [('alva', False)],
          'alvans': [('alva', False)],
          'alvar': [('alvar', True)],
          'alvar-': [('alvar', True)],
          'alvaren': [('alvar', True)],
          'alvarens': [('alvar', True)],
          'alvarna': [('alvare', False)],
          'alvarnas': [('alvare', False)],
          'alvars': [('alvar', True)],
          'alvens': [('alv', False)],
          'alvills': [('alvill', False)],
          'alvind': [('alvind', False)],
          'alvis': [('alvia', False)],
          'alvis-': [('alvia', False)],
          'alvs': [('alv', True)],
          'alvs-': [('alv', True)],
          'alvtiden': [('alvtid', False)],
          'alväsendet': [('alväsen', False)],
          'alykt': [('alykt', False)],
          'alykts': [('alykt', False)],
          'alykts-': [('alykt', False)],
          'alys': [('alys', False)],
          'alys-': [('alys', False)],
          'alysen': [('alys', False)],
          'alysens': [('alys', False)],
          'alyte': [('alyta', False)],
          'alzheimers': [('alzheimer', True), ('alzheimers', True)],
          'alzonen': [('alzon', False)],
          'alzonens': [('alzon', False)],
          'aländ': [('alända', False)],
          'aländ-': [('alända', False)],
          'aländarnas': [('alände', False)],
          'aländen': [('alände', False)],
          'aländens': [('alände', False)],
          'aländs': [('alända', False)],
          'aländs-': [('alända', False)],
          'alär': [('alär', False)],
          'alär-': [('alär', False)],
          'alärs': [('alär', False)],
          'alärs-': [('alär', False)],
          'alät': [('alä', False)],
          'aläts': [('alä', False)],
          'alåt': [('alåt', False)],
          'alåts': [('alåt', False)],
          'am': [('amma', True)],
          'am-': [('amma', True)],
          'amager': [('amage', False)],
          'amagerna': [('amage', False)],
          'amagernas': [('amage', False)],
          'amagers': [('amage', False)],
          'amajor': [('amaja', False)],
          'amajors': [('amaja', False)],
          'amakar': [('amakare', False)],
          'amakarna': [('amakare', False)],
          'amakarnas': [('amakare', False)],
          'amalj': [('amalj', False)],
          'amalj-': [('amalj', False)],
          'amaljs': [('amalj', False)],
          'amaljs-': [('amalj', False)],
          'aman': [('aman', False)],
          'aman-': [('aman', False)],
          'amana': [('ama', False)],
          'amanas': [('ama', False)],
          'amanden': [('amande', False)],
          'amander': [('amander', False)],
          'amanders': [('amander', False)],
          'amaner': [('aman', False)],
          'amanerna': [('aman', False)],
          'amanernas': [('aman', False)],
          'amaners': [('aman', False)],
          'amannen': [('aman', False)],
          'amannens': [('aman', False)],
          'amans': [('aman', False)],
          'amar': [('am', False)],
          'amar-': [('amare', False)],
          'amaran': [('amaran', False)],
          'amarans': [('amaran', False)],
          'amare': [('amare', False)],
          'amaren': [('amare', False)],
          'amarna': [('am', False)],
          'amarnas': [('amare', False)],
          'amars': [('am', False)],
          'amas': [('ama', False)],
          'amas-': [('amas', False)],
          'amasen': [('amas', False)],
          'amasens': [('amas', False)],
          'amask': [('amask', False)],
          'amask-': [('amask', False)],
          'amaster': [('amast', False)],
          'amasters': [('amast', False)],
          'amat': [('amat', False)],
          'amaten': [('amat', False)],
          'amatens': [('amaten', False)],
          'amatet': [('amat', False)],
          'amatets': [('amat', False)],
          'amatik': [('amatik', False)],
          'amatik-': [('amatik', False)],
          'amatiks': [('amatik', False)],
          'amats': [('amat', False)],
          'amb': [('amba', False)],
          'amb-': [('amba', False)],
          'ambanden': [('amband', False)],
          'ambandens': [('amband', False)],
          'ambandet': [('amband', False)],
          'ambier': [('ambier', False)],
          'ambolaget': [('ambolage', False)],
          'ambole': [('ambole', False)],
          'ambole-': [('ambole', False)],
          'ambolen': [('ambole', False)],
          'ambolens': [('ambole', False)],
          'ambon': [('ambo', False)],
          'ambons': [('ambo', False)],
          'ambor': [('ambo', False)],
          'amborna': [('ambo', False)],
          'ambornas': [('ambo', False)],
          'ambors': [('amba', False)],
          'ambos': [('ambo', False)],
          'ambos-': [('ambo', False)],
          'ambosen': [('ambo', False)],
          'ambosens': [('ambo', False)],
          'ambräden': [('ambräde', False)],
          'ambrädens': [('ambräde', False)],
          'ambs': [('amba', False)],
          'ambs-': [('amba', False)],
          'amburs': [('ambur', False)],
          'ame': [('ama', False)],
          'ame-': [('ama', False)],
          'amel': [('amel', False)],
          'amel-': [('amel', False)],
          'amen': [('am', False)],
          'amena': [('amen', False)],
          'amenas': [('amen', False)],
          'amens': [('am', False)],
          'amens-': [('amen', False)],
          'amentets': [('ament', False)],
          'aments': [('ament', False)],
          'amer': [('am', False)],
          'amerna': [('am', False)],
          'amernas': [('am', False)],
          'amersen': [('amer', False)],
          'amersens': [('amer', False)],
          'ames': [('ame', False)],
          'ames-': [('ames', False)],
          'ameten': [('amet', False)],
          'ametens': [('amet', False)],
          'ameter': [('amet', False)],
          'ameterna': [('amet', False)],
          'ameternas': [('amet', False)],
          'ameters': [('amet', False)],
          'amfars': [('amfar', False)],
          'amfer': [('amfer', False)],
          'amfers': [('amfer', False)],
          'amiden': [('amid', False)],
          'amil': [('amil', False)],
          'amil-': [('amil', False)],
          'amilens': [('amil', False)],
          'amiler': [('amil', False)],
          'amilerna': [('amil', False)],
          'amilernas': [('amil', False)],
          'amilers': [('amil', False)],
          'amils': [('amil', False)],
          'amin': [('amin', True), ('ami', True)],
          'amin-': [('amin', False)],
          'amina': [('amen', False)],
          'aminas': [('amen', False)],
          'aminens': [('amin', False)],
          'aminet': [('amin', False)],
          'aminister': [('aminister', False)],
          'aministers': [('aminister', False)],
          'aminos': [('aminos', False)],
          'amins': [('ami', True), ('amin', True)],
          'amins-': [('amin', False)],
          'amisarnas': [('ami', False)],
          'amisk': [('amiska', False)],
          'amisk-': [('amiska', False)],
          'amister': [('amist', False)],
          'amisters': [('amist', False)],
          'amit': [('amit', False)],
          'amit-': [('amit', False)],
          'amjölk': [('amjölk', False)],
          'amjölk-': [('amjölk', False)],
          'amjölken': [('amjölk', False)],
          'amjölkens': [('amjölk', False)],
          'amjölks': [('amjölk', False)],
          'amjölks-': [('amjölk', False)],
          'aml': [('amla', False)],
          'aml-': [('amla', False)],
          'amlandets': [('amlande', False)],
          'amlar': [('amlare', False)],
          'amlarna': [('amlare', False)],
          'amlarnas': [('ammel', False)],
          'amman': [('amma', False)],
          'ammanet': [('ammanet', False)],
          'ammanets': [('ammanet', False)],
          'ammans': [('amma', True)],
          'ammar': [('amm', False)],
          'ammarens': [('ammare', False)],
          'ammarna': [('am', False)],
          'ammarnas': [('amm', False)],
          'ammars': [('am', False)],
          'ammen': [('am', False)],
          'ammens': [('am', False)],
          'ammer': [('ammer', False)],
          'ammerna': [('am', False)],
          'ammernas': [('ammer', False)],
          'ammers': [('am', False)],
          'ammet': [('am', False)],
          'ammets': [('am', False)],
          'ammo': [('ammo', False)],
          'ammo-': [('ammo', False)],
          'ammoden': [('ammode', False)],
          'ammodens': [('ammode', False)],
          'ammoder': [('ammoder', False)],
          'ammoders': [('ammoder', False)],
          'amnar': [('amne', False)],
          'amnarna': [('amne', False)],
          'amnarnas': [('amn', False)],
          'amnars': [('amne', False)],
          'amne': [('amne', False)],
          'amnets': [('amn', False)],
          'amo': [('amo', False)],
          'amodet': [('amod', False)],
          'amodets': [('amod', False)],
          'amods': [('amod', False)],
          'amods-': [('amod', False)],
          'amor': [('ama', False)],
          'amorna': [('ama', False)],
          'amornas': [('ama', False)],
          'amors': [('ama', False)],
          'amos': [('amo', False)],
          'amos-': [('amos', False)],
          'amots': [('amot', False)],
          'amotten': [('amotte', False)],
          'amottens': [('amott', False)],
          'ampan': [('ampa', False)],
          'ampans': [('ampa', False)],
          'ampar': [('ampare', False)],
          'ampar-': [('ampare', False)],
          'amparens': [('ampare', False)],
          'amparna': [('ampare', False)],
          'amparnas': [('amp', False)],
          'ampas': [('ampa', False)],
          'amplet': [('ampel', False)],
          'amrar': [('ammare', False)],
          'amrarna': [('ammer', False)],
          'amrarnas': [('ammer', False)],
          'amrars': [('ammer', False)],
          'amren': [('amren', False)],
          'amrens': [('amren', False)],
          'amrådens': [('amråd', False)],
          'amrådet': [('amråd', False)],
          'amrådets': [('amråd', False)],
          'ams': [('amma', True)],
          'ams-': [('amma', True)],
          'amsarnas': [('ams', False)],
          'amsets': [('ams', False)],
          'amtanden': [('amtand', False)],
          'amtandens': [('amtand', False)],
          'amtidens': [('amtid', False)],
          'amul': [('amul', False)],
          'amul-': [('amul', False)],
          'amulen': [('amul', False)],
          'amulens': [('amul', False)],
          'amuls': [('amul', False)],
          'amuls-': [('amul', False)],
          'amums': [('amum', False)],
          'amus': [('amus', False)],
          'amygg': [('amygga', False)],
          'amygg-': [('amygga', False)],
          'amyggs': [('amygga', False)],
          'amyggs-': [('amygga', False)],
          'amän': [('aman', False)],
          'amäns': [('aman', False)],
          'amären': [('amäre', False)],
          'amärens': [('amäre', False)],
          'amån': [('amån', False)],
          'amån-': [('amån', False)],
          'amåns': [('amån', False)],
          'amåns-': [('amån', False)],
          'amöbornas': [('amöba', True)],
          'amöss': [('amössa', False)],
          'an-': [('an', False)],
          'ana': [('ana', False)],
          'anack-': [('anacka', False)],
          'anacke': [('anacka', False)],
          'anacken': [('anack', False)],
          'anackens': [('anack', False)],
          'anader': [('anad', False)],
          'anaderna': [('anad', False)],
          'anadernas': [('anad', False)],
          'anaders': [('anad', False)],
          'anads': [('anad', False)],
          'anads-': [('anad', False)],
          'anagerna': [('anager', False)],
          'anagernas': [('anager', False)],
          'anagets': [('anage', False)],
          'anaker': [('anak', False)],
          'anakers': [('anak', False)],
          'anal': [('anal', False)],
          'anal-': [('anal', False)],
          'analen': [('anal', False)],
          'analens': [('anal', False)],
          'analer': [('anal', False)],
          'analerna': [('anal', False)],
          'analernas': [('anal', False)],
          'analers': [('anal', False)],
          'anals-': [('anal', False)],
          'anamn': [('anamn', False)],
          'anamn-': [('anamn', False)],
          'anamnen': [('anamn', False)],
          'anamnens': [('anamn', False)],
          'anamnes': [('anamnes', True)],
          'anamnes-': [('anamnes', True)],
          'anamns': [('anamn', False)],
          'anamns-': [('anamn', False)],
          'anan': [('anan', False)],
          'ananden': [('anande', False)],
          'anans': [('anan', False)],
          'anar': [('an', False)],
          'anar-': [('anare', False)],
          'anaren': [('anare', False)],
          'anarens': [('anare', False)],
          'anarna': [('ane', False)],
          'anarnas': [('anare', False)],
          'anars': [('an', False)],
          'anas': [('ana', False)],
          'anas-': [('ana', False)],
          'anasar': [('anas', False)],
          'anasarna': [('anas', False)],
          'anasarnas': [('anas', False)],
          'anask': [('anaska', False)],
          'anastas': [('anastas', True)],
          'anat': [('anat', False)],
          'anat-': [('anat', False)],
          'anaten': [('anat', False)],
          'anatens': [('anat', False)],
          'anater': [('anat', False)],
          'anaterna': [('anat', False)],
          'anaternas': [('anat', False)],
          'anaters': [('anat', False)],
          'anats': [('anat', False)],
          'anats-': [('anat', False)],
          'anbens': [('anben', False)],
          'anbroder': [('anbror', False)],
          'anbröderna': [('anbror', False)],
          'anbrödernas': [('anbror', False)],
          'anbröders': [('anbror', False)],
          'ance': [('ance', False)],
          'ancen': [('ance', False)],
          'ancens': [('ance', False)],
          'ances': [('ance', False)],
          'and': [('and', True)],
          'and-': [('and', True)],
          'anda': [('anda', False)],
          'andagen': [('andage', False)],
          'andagens': [('andage', False)],
          'andana': [('andum', False)],
          'andanas': [('andum', False)],
          'andans': [('anda', False)],
          'andans-': [('andans', False)],
          'andar': [('ande', False)],
          'andar-': [('andare', False)],
          'andaren': [('andar', False)],
          'andarens': [('andare', False)],
          'andarna': [('ande', True)],
          'andarnas': [('ande', False)],
          'andars': [('ande', False)],
          'andas': [('anda', False)],
          'andat': [('anda', False)],
          'andats': [('anda', False)],
          'ande': [('ande', False)],
          'ande-': [('ande', False)],
          'andelandet': [('andeland', False)],
          'andelar': [('andel', False)],
          'andelarna': [('andel', False)],
          'andelarnas': [('andel', False)],
          'anden': [('and', True), ('ande', True)],
          'andena': [('ande', False)],
          'andenas': [('ande', False)],
          'andens': [('and', True), ('ande', True)],
          'ander': [('ander', False)],
          'andernas': [('and', False)],
          'anders': [('ander', False)],
          'andes': [('ande', False)],
          'andes-': [('ande', False)],
          'andet': [('ande', False)],
          'andflat': [('andflata', False)],
          'andflat-': [('andflate', False)],
          'andflate': [('andflate', False)],
          'andflats': [('andflate', False)],
          'andflats-': [('andflate', False)],
          'andgångar': [('andgång', False)],
          'andgångarna': [('andgång', False)],
          'andgångarnas': [('andgång', False)],
          'andi': [('andi', False)],
          'andier': [('andier', False)],
          'andierna': [('andy', False)],
          'andiernas': [('andy', False)],
          'andiers': [('andy', False)],
          'andins': [('andi', False)],
          'andis': [('andi', False)],
          'andis-': [('andis', False)],
          'andit': [('andit', False)],
          'andits': [('andit', False)],
          'andlandet': [('andlande', False)],
          'andlandets': [('andlande', False)],
          'andlar': [('andlare', False)],
          'andlarna': [('andlare', False)],
          'andlarnas': [('andlare', False)],
          'andningsvägar': [('andningsvägar', True), ('andningsväg', True)],
          'andningsvägarna': [('andningsvägar', True), ('andningsväg', True)],
          'andningsvägarnas': [('andningsvägar', True), ('andningsväg', True)],
          'andningsvägars': [('andningsvägar', True), ('andningsväg', True)],
          'andningsvägs': [('andningsvägar', True), ('andningsväg', True)],
          'andningsvägs-': [('andningsvägar', True), ('andningsväg', True)],
          'andolen': [('andole', False)],
          'andoler': [('andole', False)],
          'andolerna': [('andole', False)],
          'andolernas': [('andole', False)],
          'andolers': [('andole', False)],
          'andon': [('ando', False)],
          'andons': [('ando', False)],
          'andosen': [('ando', False)],
          'andosens': [('ando', False)],
          'andrar': [('andur', True)],
          'andrarna': [('andur', True)],
          'andrarnas': [('andur', True)],
          'andrars': [('andur', True)],
          'andras': [('andras', False)],
          'andrems': [('andremsa', False)],
          'andrems-': [('andremsa', False)],
          'andrien': [('andri', False)],
          'andrin': [('andri', False)],
          'andringarna': [('andring', False)],
          'andrins': [('andrin', False)],
          'androten': [('androt', False)],
          'ands': [('and', True)],
          'ands-': [('and', True)],
          'andsen': [('ands', False)],
          'andsens': [('ands', False)],
          'andserfarenheter': [('andserfarenhet', False)],
          'andserfarenheterna': [('andserfarenhet', False)],
          'andserfarenheternas': [('andserfarenhet', False)],
          'andserfarenheters': [('andserfarenhet', False)],
          'andserfarenhets': [('andserfarenhet', False)],
          'andserfarenhets-': [('andserfarenhet', False)],
          'andske': [('andske', False)],
          'andske-': [('andske', False)],
          'andstoner': [('andstoner', False)],
          'andstonerna': [('andstoner', False)],
          'andstonernas': [('andstoner', False)],
          'andstoners': [('andstoner', False)],
          'andsträck': [('andsträck', True)],
          'andsträck-': [('andsträck', True)],
          'andsträcks': [('andsträck', True)],
          'andsträcks-': [('andsträck', True)],
          'ane': [('ana', False)],
          'ane-': [('ana', False)],
          'anedans': [('anedans', False)],
          'anedans-': [('anedans', False)],
          'aneger': [('anege', False)],
          'anegers': [('anege', False)],
          'anen': [('an', False)],
          'anens-': [('anens', False)],
          'anents': [('anent', False)],
          'aner': [('an', False)],
          'anerier': [('aneri', False)],
          'anerierna': [('aneri', False)],
          'aneriernas': [('aneri', False)],
          'aneriers': [('aneri', False)],
          'anerna': [('an', False)],
          'anernas': [('an', False)],
          'aners': [('an', False)],
          'anes': [('anes', False)],
          'anes-': [('anes', False)],
          'anesen': [('anes', False)],
          'anesens': [('anes', False)],
          'anesier': [('anesier', False)],
          'anesiernas': [('anesier', False)],
          'anesiers': [('anesier', False)],
          'anet': [('an', False)],
          'anfot': [('anfot', False)],
          'angar-': [('angare', False)],
          'angaren': [('angar', False)],
          'angarens': [('angare', False)],
          'angarn': [('angarn', False)],
          'angarns': [('angarn', False)],
          'angars': [('angar', False)],
          'ange': [('ange', False)],
          'ange-': [('ange', False)],
          'anges': [('ange', False)],
          'anges-': [('ange', False)],
          'angets': [('ang', False)],
          'angetter': [('angett', False)],
          'anglas': [('anglas', False)],
          'angon': [('ango', False)],
          'angons': [('ango', False)],
          'angor': [('ango', False)],
          'angorna': [('ango', False)],
          'angos': [('ango', False)],
          'angos-': [('ango', False)],
          'angosar': [('angos', False)],
          'angosarna': [('ango', False)],
          'angosarnas': [('angos', False)],
          'angosars': [('angos', False)],
          'angräns': [('angrän', False)],
          'angsens': [('angs', False)],
          'angster': [('angster', False)],
          'angsters': [('angster', False)],
          'anhållanden': [('anhållande', True), ('anhållan', True)],
          'anhållandena': [('anhållan', True), ('anhållande', True)],
          'anhållandenas': [('anhållande', True), ('anhållan', True)],
          'anhållandens': [('anhållan', True), ('anhållande', True)],
          'anie': [('ania', False)],
          'anie-': [('anium', False)],
          'anien': [('anium', False)],
          'aniens': [('anium', False)],
          'anierna': [('ani', False)],
          'aniernas': [('ani', False)],
          'aniers': [('anier', False)],
          'aniet': [('anium', False)],
          'aniets': [('ani', False)],
          'anik': [('anik', False)],
          'anik-': [('anik', False)],
          'aniker': [('anik', False)],
          'anikerna': [('anik', False)],
          'anikernas': [('anik', False)],
          'anikers': [('anik', False)],
          'aniks': [('anik', False)],
          'anin': [('anin', False)],
          'anin-': [('anin', False)],
          'aninen': [('anin', False)],
          'aninens': [('anin', False)],
          'aniner': [('anin', False)],
          'aninerna': [('anin', False)],
          'aninernas': [('anin', False)],
          'aniners': [('anin', False)],
          'aninet': [('anin', False)],
          'aninets': [('anin', False)],
          'anins': [('anin', False)],
          'anis': [('anis', False)],
          'anis-': [('anis', True)],
          'anisen': [('anis', True)],
          'anisens': [('anis', True)],
          'anist': [('anist', False)],
          'anister': [('anister', False)],
          'anisters': [('anister', False)],
          'anit': [('anit', False)],
          'anitet': [('anitet', False)],
          'anitets': [('anitet', False)],
          'anits': [('ani', False)],
          'anje': [('anje', False)],
          'anje-': [('anje', False)],
          'anjon': [('anjon', True)],
          'anjons': [('anjon', True)],
          'anjor': [('anjor', False)],
          'anjorna': [('anjo', False)],
          'anjornas': [('anjo', False)],
          'anjors': [('anjor', False)],
          'ank': [('anka', True)],
          'ank-': [('anka', False)],
          'ankar': [('ankar', True), ('ankare', True)],
          'ankar-': [('ankar', True), ('ankare', True)],
          'ankarna': [('ankare', True)],
          'ankarnas': [('ankare', False)],
          'ankars': [('ankar', True)],
          'anke': [('anka', True)],
          'anke-': [('anka', True)],
          'anken': [('anke', False)],
          'ankens': [('anke', False)],
          'anker': [('anker', False)],
          'ankers': [('anker', False)],
          'ankes': [('anke', False)],
          'ankes-': [('anke', False)],
          'ankets': [('ank', False)],
          'ankist-': [('ankist', False)],
          'anklagar': [('anklagare', True)],
          'anklagarna': [('anklagare', True)],
          'anklagarnas': [('anklagare', True)],
          'ankomst': [('ankomst', False)],
          'ankor': [('anka', True)],
          'ankorna': [('anka', True)],
          'ankornas': [('anka', True)],
          'ankors': [('anka', True)],
          'anks': [('anka', True)],
          'anks-': [('anka', True)],
          'anlopp': [('anlopp', True)],
          'anlopps': [('anlopp', True)],
          'anlopps-': [('anlopp', True)],
          'anländerna': [('anländerna', False)],
          'anländernas': [('anländerna', False)],
          'anmälningar': [('anmälning', True), ('anmälan', True)],
          'anmälningarna': [('anmälning', True), ('anmälan', True)],
          'anmälningarnas': [('anmälning', True), ('anmälan', True)],
          'anmälningars': [('anmälning', True), ('anmälan', True)],
          'ann': [('ann', False)],
          'ann-': [('anna', False)],
          'annal': [('annaler', True)],
          'annal-': [('annaler', True)],
          'annaler': [('annaler', True)],
          'annalerna': [('annaler', True)],
          'annalernas': [('annaler', True)],
          'annalers': [('annaler', True)],
          'annan': [('anna', False)],
          'annans': [('anna', False)],
          'annar': [('anne', False)],
          'annarna': [('anne', False)],
          'annarnas': [('anne', False)],
          'annars': [('an', False)],
          'anne': [('anne', False)],
          'anne-': [('anne', False)],
          'anner': [('anner', False)],
          'annerna': [('anner', False)],
          'annernas': [('anner', False)],
          'anners': [('anner', False)],
          'annes': [('anne', False)],
          'annes-': [('anne', False)],
          'annets': [('ann', False)],
          'anniet': [('anni', False)],
          'anning': [('anning', False)],
          'anning-': [('anning', False)],
          'anningar': [('anning', False)],
          'anningarna': [('anning', False)],
          'anningarnas': [('anning', False)],
          'anningars': [('anning', False)],
          'annings': [('anning', False)],
          'annings-': [('anning', False)],
          'annis': [('anni', False)],
          'annit': [('annit', False)],
          'annits': [('annit', False)],
          'annor': [('annor', False)],
          'annorna': [('annor', False)],
          'annornas': [('annor', False)],
          'annors': [('annor', False)],
          'anns': [('anna', False)],
          'anns-': [('anna', False)],
          'ano': [('ano', False)],
          'ano-': [('ano', False)],
          'anol': [('anol', False)],
          'anol-': [('anol', False)],
          'anols': [('anol', False)],
          'anomen': [('anom', False)],
          'anomens': [('anom', False)],
          'anon': [('anon', False)],
          'anon-': [('anon', False)],
          'anona': [('ano', False)],
          'anonas': [('ano', False)],
          'anons': [('anon', False)],
          'anons-': [('anon', False)],
          'anor': [('anor', True)],
          'anorden': [('anorden', False)],
          'anordens': [('anorden', False)],
          'anordnar': [('anordnare', True)],
          'anordnarna': [('anordnare', True)],
          'anordnarnas': [('anordnare', True)],
          'anorna': [('anor', True)],
          'anornas': [('anor', True)],
          'anors': [('anor', True)],
          'anos': [('anos', False)],
          'anos-': [('anos', False)],
          'anosen': [('anos', False)],
          'anot': [('anot', False)],
          'anot-': [('anot', False)],
          'anots': [('anot', False)],
          'anots-': [('anot', False)],
          'anotypen': [('anotyp', False)],
          'anotypens': [('anotyp', False)],
          'anotyper': [('anotyp', False)],
          'anotyperna': [('anotyp', False)],
          'anotypernas': [('anotyp', False)],
          'anotypers': [('anotyp', False)],
          'ans': [('ans', True)],
          'ans-': [('ans', True)],
          'ansa': [('ansa', False)],
          'ansar': [('ansare', False)],
          'ansar-': [('ansare', False)],
          'ansaren': [('ansar', False)],
          'ansarens': [('ansare', False)],
          'ansarna': [('an', False)],
          'ansarnas': [('ans', False)],
          'ansars': [('ansar', False)],
          'ansas': [('ansa', False)],
          'ansats': [('ansats', False)],
          'ansdags': [('ansdagar', False)],
          'ansdags-': [('ansdagar', False)],
          'ansen': [('ans', True)],
          'ansens': [('ans', True)],
          'ansikten': [('ansikte', False)],
          'ansis': [('ansis', False)],
          'ansis-': [('ansis', False)],
          'anskans': [('anska', False)],
          'anskaps': [('anskap', False)],
          'anskar': [('anskare', False)],
          'anskare': [('anskare', False)],
          'anskaren': [('anskare', False)],
          'anskarna': [('ansk', False)],
          'anskarnas': [('anskare', False)],
          'anskens': [('ansk', False)],
          'anskor': [('anska', False)],
          'anskorna': [('anska', False)],
          'anskornas': [('anska', False)],
          'anskors': [('anska', False)],
          'anskris': [('anskri', True)],
          'anskrit': [('anskri', True)],
          'anskrits': [('anskri', True)],
          'anskull': [('anskulla', False)],
          'anskulls': [('anskulla', False)],
          'anskär': [('anskär', False)],
          'anskär-': [('anskär', False)],
          'anskärs': [('anskär', False)],
          'anslandets': [('ansland', False)],
          'ansort': [('ansort', False)],
          'ansorter': [('ansort', False)],
          'ansorterna': [('ansort', False)],
          'ansorternas': [('ansort', False)],
          'ansorters': [('ansort', False)],
          'ansorts': [('ansort', False)],
          'ansorts-': [('ansort', False)],
          'anstalter': [('anstalter', True), ('anstalt', True)],
          'anstalterna': [('anstalter', True), ('anstalt', True)],
          'anstalternas': [('anstalter', True), ('anstalt', True)],
          'anstalters': [('anstalter', True), ('anstalt', True)],
          'anstalts': [('anstalter', True), ('anstalt', True)],
          'anstalts-': [('anstalter', True), ('anstalt', True)],
          'ant-': [('ant', False)],
          'anta': [('antum', False)],
          'antagen': [('antage', False)],
          'antagens': [('antage', False)],
          'antagets': [('antag', False)],
          'antar-': [('antare', False)],
          'antarens': [('antare', False)],
          'antarnas': [('ant', False)],
          'antas': [('anta', False)],
          'ante': [('ante', False)],
          'ante-': [('ante', False)],
          'antelen': [('antele', False)],
          'antelens': [('antele', False)],
          'antern': [('anterna', False)],
          'anterns': [('anterna', False)],
          'antes': [('ante', False)],
          'antes-': [('ante', False)],
          'antet': [('ante', False)],
          'antets': [('ante', False)],
          'antibiotika': [('antibiotikum', True), ('antibiotika', True)],
          'antibiotikas': [('antibiotikum', True), ('antibiotika', True)],
          'antien': [('anti', False)],
          'antiens': [('anti', False)],
          'antier': [('anti', False)],
          'antierna': [('antier', False)],
          'antiernas': [('anti', False)],
          'antiers': [('anti', False)],
          'anties': [('anty', False)],
          'antikvitetshandlar': [('antikvitetshandel', True), ('antikvitetshandlare', True)],
          'antikvitetshandlarna': [('antikvitetshandlare', True), ('antikvitetshandel', True)],
          'antikvitetshandlarnas': [('antikvitetshandlare', True), ('antikvitetshandel', True)],
          'antilen': [('antilena', False)],
          'antilens': [('antilena', False)],
          'antin': [('antin', False)],
          'antins': [('antin', False)],
          'antis': [('antis', False)],
          'antor': [('antor', False)],
          'antors': [('antor', False)],
          'antrana': [('antra', False)],
          'antranas': [('antra', False)],
          'antrans': [('antra', False)],
          'antrarnas': [('anter', False)],
          'antras': [('antra', False)],
          'antringarna': [('antring', False)],
          'antringarnas': [('antring', False)],
          'antros': [('antros', False)],
          'antros-': [('antro', False)],
          'anträden': [('anträde', True)],
          'anträdens': [('anträde', True)],
          'anträdet': [('anträde', True)],
          'anträdets': [('anträde', True)],
          'ants': [('ant', False)],
          'anumen': [('anum', False)],
          'anumens': [('anum', False)],
          'anurin': [('anuri', True)],
          'anus': [('anus', False)],
          'anus-': [('anus', False)],
          'anvärden': [('anvärd', False)],
          'anvärdens': [('anvärd', False)],
          'anåret': [('anår', False)],
          'anårets': [('anår', False)],
          'anör': [('anör', False)],
          'anör-': [('anör', False)],
          'anören': [('anör', False)],
          'anörens': [('anör', False)],
          'anörs': [('anör', False)],
          'anörs-': [('anör', False)],
          'anötter': [('anöt', False)],
          'anötterna': [('anöt', False)],
          'anötternas': [('anöt', False)],
          'aoke': [('aoke', False)],
          'aoke-': [('aoke', False)],
          'aoken': [('aoke', False)],
          'aokens': [('aoke', False)],
          'aolin': [('aolin', False)],
          'aområdet': [('aområdet', False)],
          'aon': [('ao', False)],
          'aoner': [('ao', False)],
          'aonerna': [('ao', False)],
          'aonernas': [('ao', False)],
          'aoners': [('ao', False)],
          'aons': [('ao', False)],
          'aord': [('aord', False)],
          'aorden': [('aorden', False)],
          'aordens': [('aord', False)],
          'aordnar': [('aorden', False)],
          'aordnarna': [('aorden', False)],
          'aordnarnas': [('aorden', False)],
          'aords': [('aord', False)],
          'aori': [('aori', False)],
          'aori-': [('aori', False)],
          'aorins': [('aori', False)],
          'aoris': [('aori', False)],
          'aormarnas': [('aorm', False)],
          'aoros': [('aoro', False)],
          'aos': [('ao', False)],
          'aos-': [('ao', False)],
          'aots': [('ao', False)],
          'ap': [('apa', True)],
          'ap-': [('apa', True)],
          'apack': [('apack', False)],
          'apack-': [('apack', False)],
          'apacken': [('apack', False)],
          'apackens': [('apack', False)],
          'apacks': [('apack', False)],
          'apacks-': [('apack', False)],
          'apad': [('apad', False)],
          'apad-': [('apad', False)],
          'apaden': [('apad', False)],
          'apadens': [('apad', False)],
          'apader': [('apad', False)],
          'apaderna': [('apad', False)],
          'apadernas': [('apad', False)],
          'apaders': [('apad', False)],
          'apads': [('apad', False)],
          'apads-': [('apad', False)],
          'apaket': [('apak', False)],
          'apakets': [('apak', False)],
          'apan': [('apa', True)],
          'apande': [('apande', False)],
          'apande-': [('apande', False)],
          'apans': [('apa', True)],
          'apar': [('ape', False)],
          'apar-': [('apare', False)],
          'aparen': [('apare', False)],
          'aparens': [('apar', False)],
          'apares': [('apare', False)],
          'aparna': [('ape', False)],
          'aparnas': [('ape', False)],
          'apars': [('ape', False)],
          'apars-': [('apar', False)],
          'apas': [('apa', True)],
          'apat': [('apat', False)],
          'apat-': [('apat', False)],
          'apaten': [('apat', False)],
          'apatens': [('apat', False)],
          'apater': [('apat', False)],
          'apaters': [('apat', False)],
          'apatiens': [('apati', True)],
          'apatiernas': [('apati', True)],
          'ape': [('apa', False)],
          'ape-': [('apa', False)],
          'apellen': [('apell', False)],
          'apellens': [('apell', False)],
          'apellet': [('apell', False)],
          'apellets': [('apell', False)],
          'apelsen': [('apelse', False)],
          'apelsens': [('apelse', False)],
          'apen': [('ap', False)],
          'apen-': [('apen', False)],
          'apengar': [('apeng', False)],
          'apengarna': [('apeng', False)],
          'apengarnas': [('apeng', False)],
          'apengars': [('apeng', False)],
          'apenning': [('apenning', False)],
          'apenningar': [('apenning', False)],
          'apenningarna': [('apenning', False)],
          'apenningarnas': [('apenning', False)],
          'apenningars': [('apenning', False)],
          'apennings': [('apenning', False)],
          'apennings-': [('apenning', False)],
          'apens': [('ap', False)],
          'apens-': [('apen', False)],
          'aper': [('ap', False)],
          'aperen': [('aper', False)],
          'aperens': [('aper', False)],
          'aperiernas': [('aperi', False)],
          'aperiers': [('aperi', True)],
          'aperiets': [('aperi', False)],
          'aperits': [('aperi', False)],
          'apermien': [('apermi', True)],
          'apermiens': [('apermi', True)],
          'apermis': [('apermi', True)],
          'aperna': [('ap', False)],
          'apernas': [('ap', False)],
          'apers': [('ap', False)],
          'apers-': [('aper', False)],
          'apet': [('ap', False)],
          'apet-': [('apet', False)],
          'apetens': [('apet', False)],
          'apeter': [('apet', False)],
          'apeters': [('apet', False)],
          'apets': [('apet', False)],
          'apets-': [('apet', False)],
          'aphone': [('aphona', True)],
          'aphone-': [('aphona', True)],
          'apiller': [('apill', False)],
          'apillerna': [('apill', False)],
          'apillernas': [('apill', False)],
          'apillers': [('apill', False)],
          'apin': [('api', False)],
          'apins': [('api', False)],
          'apir-': [('apir', False)],
          'apiren': [('apir', False)],
          'apis': [('apis', False)],
          'apis-': [('apis', False)],
          'aplandets': [('aplande', False)],
          'aplanet': [('aplan', False)],
          'aplanets': [('aplan', False)],
          'aplar': [('apel', False)],
          'aplarna': [('apel', False)],
          'aplarnas': [('apel', False)],
          'aplars': [('apel', False)],
          'aplotter': [('aplott', False)],
          'aplotters': [('aplott', False)],
          'apnen': [('apne', False)],
          'apnens': [('apne', True)],
          'apo-': [('apo', False)],
          'aponin': [('aponin', False)],
          'aponins': [('aponin', False)],
          'apor': [('apa', False)],
          'aporna': [('apa', False)],
          'apornas': [('apa', False)],
          'apors': [('apa', False)],
          'apot': [('apo', False)],
          'apott': [('apott', False)],
          'apott-': [('apott', False)],
          'apotts': [('apott', False)],
          'apotts-': [('apott', False)],
          'app': [('app', True)],
          'app-': [('app', True)],
          'appar': [('app', True)],
          'appar-': [('appare', False)],
          'apparna': [('app', True)],
          'apparnas': [('app', False)],
          'appars': [('app', True)],
          'appen': [('app', True)],
          'appens': [('app', True)],
          'apper': [('app', False)],
          'apperna': [('apper', False)],
          'appernas': [('apper', False)],
          'appers': [('apper', False)],
          'appets': [('app', False)],
          'applanden': [('applande', False)],
          'applandens': [('applande', False)],
          'applandet': [('applande', False)],
          'applåd': [('applåd', True)],
          'applåd-': [('applåd', True)],
          'applåds': [('applåd', True)],
          'applåds-': [('applåd', True)],
          'apporters': [('apport', False)],
          'approckarna': [('approck', False)],
          'approckarnas': [('approck', False)],
          'apps': [('app', True)],
          'apps-': [('app', True)],
          'apraxis': [('apraxi', True)],
          'aproblemet': [('aproblem', False)],
          'aps': [('apa', True)],
          'aps-': [('apa', True)],
          'apsarnas': [('aps', False)],
          'apsens': [('aps', False)],
          'apskorna': [('apska', False)],
          'apskornas': [('apska', False)],
          'apskors': [('apska', False)],
          'apslagar': [('apslag', False)],
          'apslagarna': [('apslag', False)],
          'apslagarnas': [('apslag', False)],
          'apson': [('apson', False)],
          'apstick': [('apstick', False)],
          'aptans': [('aptan', False)],
          'apten': [('apten', False)],
          'aptens': [('apten', False)],
          'apter': [('apter', False)],
          'apters': [('apter', False)],
          'aptot': [('apto', False)],
          'aptots': [('apto', False)],
          'apuns': [('apun', False)],
          'apuns-': [('apun', False)],
          'apyren': [('apyrus', False)],
          'apyrens': [('apyrus', False)],
          'apyrers': [('apyrus', False)],
          'apärs': [('apär', False)],
          'apärs-': [('apär', False)],
          'ar': [('ar', True)],
          'ar-': [('ar', False)],
          'aracen': [('aracen', False)],
          'arack': [('arack', False)],
          'arack-': [('arack', False)],
          'aracks': [('arack', False)],
          'aracks-': [('arack', False)],
          'araden': [('arad', False)],
          'aradens': [('arad', False)],
          'arads': [('arad', False)],
          'arage': [('arage', False)],
          'arage-': [('arage', False)],
          'aragets': [('arage', False)],
          'arams': [('aramsa', False)],
          'arams-': [('aramsa', False)],
          'aran': [('ara', True)],
          'aran-': [('aran', False)],
          'aranda': [('aranda', False)],
          'arandans': [('aranda', False)],
          'arandar': [('arande', False)],
          'arandarnas': [('arande', False)],
          'arandars': [('arande', False)],
          'arandas': [('aranda', False)],
          'arande': [('arande', False)],
          'arande-': [('arande', False)],
          'aranden': [('arande', False)],
          'arandens': [('arande', False)],
          'arandet': [('arande', False)],
          'aranger': [('arang', False)],
          'arangers': [('arang', False)],
          'arans': [('ara', True)],
          'arans-': [('arans', False)],
          'arapet': [('arapet', False)],
          'arapets': [('arapet', False)],
          'arar': [('are', False)],
          'ararna': [('are', False)],
          'ararnas': [('ar', False)],
          'arars': [('are', False)],
          'aras': [('ara', False)],
          'aras-': [('aras', False)],
          'arat': [('arat', False)],
          'araten': [('arat', False)],
          'aratens': [('arat', False)],
          'arater': [('arat', False)],
          'araterna': [('arat', False)],
          'araternas': [('arat', False)],
          'araters': [('arat', False)],
          'arationsdags': [('arationsdags', False)],
          'arationsdags-': [('arationsdags', False)],
          'arats': [('arat', False)],
          'arbariet': [('arbari', False)],
          'arbens': [('arben', False)],
          'arber': [('arber', False)],
          'arbers': [('arber', False)],
          'arbete': [('arbete', False)],
          'arbeten': [('arbete', False)],
          'arbetens': [('arbete', False)],
          'arbetsvane': [('arbetsvanor', True), ('arbetsvana', True)],
          'arbetsvane-': [('arbetsvanor', True), ('arbetsvana', True)],
          'arbon': [('arbo', False)],
          'arbons': [('arbo', False)],
          'arbroder': [('arbror', False)],
          'arbrors': [('arbror', False)],
          'arbröderna': [('arbror', False)],
          'arbröders': [('arbror', False)],
          'arda': [('arda', False)],
          'ardagen': [('ardagen', False)],
          'ardagens': [('ardagen', False)],
          'ardan': [('ardag', False)],
          'ardans-': [('ardans', False)],
          'ardar': [('ardag', False)],
          'ardarna': [('arde', False)],
          'ardarnas': [('ard', False)],
          'ardars': [('arde', False)],
          'ardas': [('arda', False)],
          'ardborr': [('ardborre', False)],
          'ardborr-': [('ardborre', False)],
          'ardborrar': [('ardborre', False)],
          'ardborrarna': [('ardborre', False)],
          'ardborrarnas': [('ardborre', False)],
          'ardborrars': [('ardborre', False)],
          'ardborren': [('ardborre', False)],
          'ardborrens': [('ardborre', False)],
          'ardborrs': [('ardborre', False)],
          'ardborrs-': [('ardborre', False)],
          'arde': [('arde', False)],
          'arde-': [('arde', False)],
          'ardet': [('arde', False)],
          'ardets': [('ard', False)],
          'ardian': [('ardian', False)],
          'ardien': [('ardi', False)],
          'ardiens': [('ardi', False)],
          'ardierna': [('ardi', False)],
          'ardiernas': [('ardi', False)],
          'ardiers': [('ardi', False)],
          'ardin': [('ardi', False)],
          'ardins': [('ardi', False)],
          'ardis': [('ardi', False)],
          'ardisk': [('ardisk', False)],
          'ardisk-': [('ardisk', False)],
          'ardus': [('ardus', False)],
          'are-': [('ara', False)],
          'arealen': [('areal', True)],
          'arealens': [('areal', False)],
          'arean': [('area', True)],
          'ared': [('ared', False)],
          'aredan': [('aredan', False)],
          'aredans': [('aredan', False)],
          'areden': [('ared', False)],
          'aredens': [('ared', False)],
          'areds': [('ared', False)],
          'areds-': [('ared', False)],
          'aremens': [('arem', False)],
          'aremis': [('aremi', False)],
          'arems': [('arem', False)],
          'arems-': [('arem', False)],
          'aren': [('ar', True)],
          'arena': [('arena', False)],
          'arenas': [('arena', False)],
          'arens': [('ar', False)],
          'arens-': [('arens', False)],
          'arer': [('ar', False)],
          'arerna': [('ar', False)],
          'arernas': [('ar', False)],
          'arers': [('ar', False)],
          'ares-': [('ares', False)],
          'arese': [('aresa', False)],
          'arese-': [('aresa', False)],
          'aresen': [('ares', False)],
          'aresens': [('ares', False)],
          'arestriktioner': [('arestriktioner', False)],
          'arestriktionerna': [('arestriktioner', False)],
          'arestriktionernas': [('arestriktioner', False)],
          'arestriktioners': [('arestriktioner', False)],
          'arestriktions': [('arestriktioner', False)],
          'arestriktions-': [('arestriktioner', False)],
          'aret': [('ar', False)],
          'areta': [('areta', False)],
          'areterna': [('aret', False)],
          'areternas': [('aret', False)],
          'areters': [('aret', False)],
          'aretor': [('areta', False)],
          'aretors': [('areta', False)],
          'arets': [('ar', False)],
          'arets-': [('aret', False)],
          'arfader-': [('arfar', False)],
          'arfadern': [('arfar', False)],
          'arfaderns': [('arfar', False)],
          'arfaders': [('arfar', False)],
          'arfar': [('arf', False)],
          'arfar-': [('arfar', False)],
          'arfarnas': [('arf', False)],
          'arfars': [('arf', False)],
          'arfars-': [('arfars', False)],
          'arfiskar': [('arfisk', False)],
          'arfäder': [('arfar', False)],
          'arfäders': [('arfar', False)],
          'arganden': [('argande', False)],
          'arge': [('arge', False)],
          'arge-': [('arge', False)],
          'argen': [('arge', False)],
          'argens': [('arge', False)],
          'arger': [('arge', False)],
          'argerna': [('arge', False)],
          'argernas': [('arge', False)],
          'argers': [('arge', False)],
          'argien': [('argi', False)],
          'argiens': [('argi', False)],
          'argis': [('argi', False)],
          'argon': [('argon', True)],
          'argons': [('argon', True)],
          'argot': [('argot', True)],
          'argots': [('argot', True)],
          'arhona': [('arhona', False)],
          'arhonas': [('arhona', False)],
          'ari': [('aria', False)],
          'ari-': [('aria', False)],
          'arian': [('arian', True), ('aria', True)],
          'arianas': [('aria', False)],
          'arians': [('arian', True), ('aria', True)],
          'arias': [('aria', False)],
          'arias-': [('aria', False)],
          'arid': [('arid', False)],
          'arid-': [('arid', False)],
          'arider': [('arid', False)],
          'ariderna': [('arid', False)],
          'aridernas': [('arid', False)],
          'ariders': [('arid', False)],
          'arie': [('aria', True)],
          'arie-': [('aria', True)],
          'arien': [('arie', False)],
          'ariens': [('arie', False)],
          'arier': [('arier', True)],
          'arierna': [('arier', True)],
          'ariernas': [('arier', True)],
          'ariers': [('arier', True)],
          'aries': [('arie', False)],
          'aries-': [('arie', False)],
          'ariet': [('arium', False)],
          'ariets': [('arium', False)],
          'ariffens': [('ariff', False)],
          'arighets': [('arighet', False)],
          'ariket': [('arike', False)],
          'arikets': [('arike', False)],
          'arill': [('arilla', False)],
          'arill-': [('arill', False)],
          'arills': [('arilla', False)],
          'arills-': [('arilla', False)],
          'arin-': [('arin', False)],
          'arina': [('arina', False)],
          'arinas': [('arina', False)],
          'ariner': [('arin', False)],
          'arinerna': [('arin', False)],
          'arinernas': [('arin', False)],
          'ariners': [('arin', False)],
          'aringar': [('aring', False)],
          'aringarna': [('aring', False)],
          'aringarnas': [('aring', False)],
          'arinor': [('arina', False)],
          'arinorna': [('arina', False)],
          'arinornas': [('arina', False)],
          'arinors': [('arina', False)],
          'arins': [('arin', False)],
          'arins-': [('arin', False)],
          'arion': [('ario', False)],
          'arior': [('aria', False)],
          'arios': [('ario', False)],
          'ariots': [('ario', False)],
          'aris': [('aris', False)],
          'aris-': [('aris', False)],
          'arisarna': [('aris', False)],
          'arisarnas': [('ari', False)],
          'arisen': [('ari', False)],
          'arisens': [('aris', False)],
          'arisk': [('ariska', False)],
          'arisk-': [('ariska', False)],
          'arismer': [('arisma', False)],
          'arismerna': [('arisma', False)],
          'arismernas': [('arisma', False)],
          'arismers': [('arisma', False)],
          'arit': [('arit', False)],
          'arit-': [('ariter', False)],
          'aritans': [('arita', False)],
          'ariter': [('arit', False)],
          'ariterna': [('arit', False)],
          'ariternas': [('ariter', False)],
          'ariters': [('ariter', False)],
          'aritet': [('aritet', False)],
          'aritets': [('aritet', False)],
          'arits': [('arit', False)],
          'arits-': [('ariter', False)],
          'arkan': [('arka', False)],
          'arkans': [('arka', False)],
          'arkar': [('arkare', False)],
          'arkarna': [('arkare', False)],
          'arkarnas': [('ark', False)],
          'arkas': [('arka', False)],
          'arkasse-': [('arkassa', False)],
          'arkassen': [('arkass', False)],
          'arkatt': [('arkatt', False)],
          'arkatt-': [('arkatt', False)],
          'arkatts': [('arkatt', False)],
          'arkatts-': [('arkatt', False)],
          'arket': [('ark', True)],
          'arkets': [('ark', True)],
          'arkis': [('arki', False)],
          'arkist-': [('arkist', False)],
          'arkling': [('arkling', False)],
          'arklings': [('arkling', False)],
          'arklädes': [('arkläde', False)],
          'arknäts': [('arknät', False)],
          'arkors': [('arkors', False)],
          'arksbygget': [('arksbygg', False)],
          'arkungar': [('arkung', False)],
          'arkungarna': [('arkung', False)],
          'arkungarnas': [('arkung', False)],
          'arkungars': [('arkung', False)],
          'arkungen': [('arkung', False)],
          'arkungens': [('arkung', False)],
          'arkurs': [('arkurs', False)],
          'arkurs-': [('arkurs', False)],
          'arlacks': [('arlack', False)],
          'arlacks-': [('arlack', False)],
          'arlanden': [('arland', False)],
          'arlandens': [('arland', False)],
          'arlandet': [('arland', False)],
          'arlek': [('arleka', False)],
          'arleks': [('arlek', False)],
          'arleks-': [('arleka', False)],
          'arlins-': [('arlins', False)],
          'arlogen': [('arloge', False)],
          'arlogens': [('arloge', False)],
          'armandens': [('armande', False)],
          'armar': [('arm', True)],
          'armarna': [('arm', True)],
          'armarnas': [('arm', True)],
          'armatte': [('armatte', False)],
          'armatte-': [('armatte', False)],
          'arme': [('arm', True)],
          'armen': [('arm', False)],
          'armets': [('arm', False)],
          'armin': [('armin', False)],
          'armoder': [('armor', False)],
          'armodet': [('armod', True)],
          'armodets': [('armod', True)],
          'armor': [('armor', False)],
          'armors': [('armor', False)],
          'armödrarna': [('armor', False)],
          'armödrarnas': [('armor', False)],
          'armödrars': [('armor', False)],
          'armörn': [('armör', False)],
          'armörns': [('armör', False)],
          'arn': [('ar', False)],
          'arna': [('', False)],
          'arner': [('arner', False)],
          'arners': [('arner', False)],
          'arnets': [('arn', False)],
          'arns': [('ar', False)],
          'aro': [('ara', False)],
          'aro-': [('aro', False)],
          'arock': [('arock', False)],
          'arockan': [('arockan', False)],
          'arockans': [('arockan', False)],
          'arockar': [('arock', False)],
          'arockarna': [('arock', False)],
          'arockarnas': [('arock', False)],
          'aroken': [('arok', False)],
          'arokens': [('arok', False)],
          'aroks': [('arok', False)],
          'aroller': [('aroll', False)],
          'arollerna': [('aroll', False)],
          'arollernas': [('aroll', False)],
          'arollers': [('aroll', False)],
          'arolls': [('aroll', False)],
          'arolls-': [('aroll', False)],
          'aroms-': [('arom', True)],
          'aron': [('aron', False)],
          'aron-': [('aroner', False)],
          'aronen': [('aron', False)],
          'aronens': [('aron', False)],
          'aroner': [('aron', False)],
          'aronerna': [('aron', False)],
          'aronernas': [('aron', False)],
          'aroners': [('aron', False)],
          'arons': [('aroner', False)],
          'arons-': [('aroner', False)],
          'aropen': [('arop', False)],
          'aropens': [('arop', False)],
          'arops': [('arop', False)],
          'aror': [('ara', True)],
          'arorden': [('arorden', False)],
          'arordens': [('arorden', False)],
          'arorna': [('ara', False)],
          'arornas': [('ara', False)],
          'arors': [('ara', False)],
          'aros': [('aros', False)],
          'aros-': [('aros', False)],
          'arov': [('arov', False)],
          'aroven': [('arov', False)],
          'arovs': [('arov', False)],
          'arovs-': [('arov', False)],
          'arp': [('arpa', False)],
          'arp-': [('arpa', False)],
          'arpar': [('arpar', False)],
          'arparen': [('arpar', False)],
          'arparna': [('arp', False)],
          'arparnas': [('arp', False)],
          'arpars': [('arpar', False)],
          'arpengar': [('arpengar', False)],
          'arpengarna': [('arpengar', False)],
          'arps': [('arpa', False)],
          'arps-': [('arp', False)],
          'arr': [('arr', True)],
          'arr-': [('arr', True)],
          'arrar': [('arre', False)],
          'arrarna': [('arre', False)],
          'arrarnas': [('arre', False)],
          'arrars': [('arre', False)],
          'arras': [('arras', False)],
          'arre': [('arre', False)],
          'arre-': [('arre', False)],
          'arren': [('arr', True)],
          'arrens': [('arr', True)],
          'arrevs': [('arreva', False)],
          'arrock': [('arrocka', False)],
          'arrock-': [('arrock', False)],
          'arrocks': [('arrock', False)],
          'arrocks-': [('arrock', False)],
          'arrs': [('arr', False)],
          'arrs-': [('arr', True)],
          'arråns': [('arrå', False)],
          'ars': [('ar', True)],
          'ars-': [('ar', False)],
          'arsan': [('arsa', False)],
          'arsans': [('arsa', False)],
          'arsarna': [('ar', False)],
          'arsen': [('ars', False)],
          'arsens': [('ar', False)],
          'arset': [('arset', False)],
          'arsets': [('arset', False)],
          'arsi': [('arsi', False)],
          'arsi-': [('arsi', False)],
          'arsian': [('arsian', False)],
          'arsians': [('arsian', False)],
          'arsis': [('arsi', False)],
          'arsis-': [('arsia', False)],
          'arsk': [('arsk', False)],
          'arsk-': [('arsk', False)],
          'arskallens': [('arskalle', False)],
          'arskar': [('arskara', False)],
          'arskar-': [('arskara', False)],
          'arskare': [('arskara', False)],
          'arskars': [('arskara', False)],
          'arsken': [('arsken', False)],
          'arskens': [('arsk', False)],
          'arskiftens': [('arskifte', False)],
          'arskiftet': [('arskifte', False)],
          'arsklandet': [('arskland', False)],
          'arsklandets': [('arsklande', False)],
          'arslen': [('arsle', False)],
          'arslens': [('arsle', False)],
          'arslet': [('arsle', True)],
          'arslets': [('arsle', False)],
          'arsläkts-': [('arsläkt', False)],
          'arsrasterna': [('arsraster', False)],
          'arsskiften': [('arsskift', False)],
          'arsskiftens': [('arsskift', False)],
          'arst-': [('arst', False)],
          'arstar': [('arstare', False)],
          'arstars': [('arstare', False)],
          'arsten': [('arsten', False)],
          'arstens': [('arst', False)],
          'arstråts': [('arstråt', False)],
          'arstövel': [('arstövel', False)],
          'arstövel-': [('arstövel', False)],
          'arstövels': [('arstövel', False)],
          'arstövels-': [('arstövel', False)],
          'arstövlar': [('arstövel', False)],
          'arstövlarna': [('arstövel', False)],
          'arstövlarnas': [('arstövel', False)],
          'art': [('art', True)],
          'art-': [('art', True)],
          'artan': [('arta', False)],
          'artans': [('artan', False)],
          'artar': [('artar', False)],
          'artaren': [('artar', False)],
          'artarnas': [('art', False)],
          'artars': [('artar', False)],
          'arten': [('art', True)],
          'artens': [('art', True)],
          'arter': [('art', True)],
          'arterna': [('art', True)],
          'arternas': [('art', True)],
          'arters': [('art', True)],
          'artier': [('arti', False)],
          'artierna': [('arti', False)],
          'artiernas': [('arti', False)],
          'artiers': [('arti', False)],
          'artiet': [('arti', False)],
          'artis-': [('arti', False)],
          'artit': [('arti', False)],
          'arton': [('arto', False)],
          'artons': [('arto', False)],
          'artranden': [('artrande', False)],
          'artrandens': [('artrande', False)],
          'artron': [('artron', False)],
          'artrons': [('artro', False)],
          'artros': [('artros', True)],
          'artros-': [('artros', True)],
          'arts': [('art', True)],
          'arts-': [('art', True)],
          'artsen': [('arts', False)],
          'artsens': [('arts', False)],
          'aru': [('ara', False)],
          'arull': [('arulle', False)],
          'arull-': [('arulle', False)],
          'arulle': [('arulle', False)],
          'arulle-': [('arulle', False)],
          'arulls': [('arulle', False)],
          'arulls-': [('arulle', False)],
          'arum': [('arum', False)],
          'arums': [('arum', False)],
          'arums-': [('arum', False)],
          'arund': [('arund', False)],
          'arunds': [('arund', False)],
          'arunds-': [('arund', False)],
          'arungen': [('arunge', False)],
          'arungens': [('arunge', False)],
          'arur': [('arur', False)],
          'arurs': [('arur', False)],
          'arus': [('arus', False)],
          'arus-': [('arus', False)],
          'arusar': [('arus', False)],
          'arusarna': [('arus', False)],
          'arv': [('arv', True), ('arve', True)],
          'arv-': [('arv', True), ('arve', True)],
          'arvals': [('arval', False)],
          'arvar': [('arve', True)],
          'arvar-': [('arvare', False)],
          'arvarens': [('arvare', False)],
          'arvarna': [('arve', True)],
          'arvarnas': [('arve', True)],
          'arvars': [('arve', False)],
          'arvas': [('arva', False)],
          'arve': [('arve', False)],
          'arven': [('arv', True), ('arve', True)],
          'arvens': [('arv', True), ('arve', True)],
          'arves': [('arve', True)],
          'arvs': [('arve', True), ('arv', True)],
          'arvs-': [('arv', True), ('arve', True)],
          'arvärden': [('arvärd', False)],
          'arvärdens': [('arvärd', False)],
          'aryller': [('aryllis', False)],
          'aryllernas': [('aryllis', False)],
          'aryot': [('aryot', False)],
          'aryots': [('aryot', False)],
          'aryt-': [('aryt', False)],
          'aryten': [('aryt', False)],
          'arytens': [('aryt', False)],
          'aräcke': [('aräcke', False)],
          'aräcken': [('aräcke', False)],
          'aräckens': [('aräcke', False)],
          'aräcket': [('aräcke', False)],
          'aräckets': [('aräcke', False)],
          'aråk': [('aråk', False)],
          'aråkar': [('aråk', False)],
          'aråkarna': [('aråk', False)],
          'aråks': [('aråk', False)],
          'aråks-': [('aråk', False)],
          'aröst': [('aröst', False)],
          'aröst-': [('aröst', False)],
          'arösten': [('aröst', False)],
          'aröstens': [('aröst', False)],
          'as': [('as', False)],
          'as-': [('as', True)],
          'asabin': [('asabi', False)],
          'asabins': [('asabi', False)],
          'asage': [('asaga', False)],
          'asage-': [('asaga', False)],
          'asago': [('asaga', False)],
          'asago-': [('asaga', False)],
          'asalen': [('asal', False)],
          'asalens': [('asal', False)],
          'asanden': [('asande', False)],
          'asandens': [('asande', False)],
          'asar': [('as', True)],
          'asar-': [('asar', False)],
          'asaren': [('asare', False)],
          'asarens': [('asar', False)],
          'asarna': [('as', True)],
          'asarnas': [('as', True)],
          'asars': [('as', False)],
          'asars-': [('asar', False)],
          'asbit': [('asbit', False)],
          'asch': [('asch', False)],
          'asch-': [('asch', False)],
          'aschan': [('ascha', False)],
          'aschans': [('aschan', False)],
          'aschen': [('asch', False)],
          'aschens': [('asch', False)],
          'ascher': [('asch', False)],
          'aschers': [('asch', False)],
          'ase': [('asa', False)],
          'ase-': [('asa', False)],
          'asegrar': [('aseger', False)],
          'asegrarna': [('aseger', False)],
          'asegrarnas': [('asegrare', False)],
          'asel': [('asel', False)],
          'asel-': [('asel', False)],
          'aselen': [('asel', False)],
          'aselens': [('asel', False)],
          'aseler': [('asel', False)],
          'asels': [('asel', False)],
          'asels-': [('asel', False)],
          'asen': [('as', False)],
          'asen-': [('asen', False)],
          'asena': [('a', False)],
          'asenas': [('a', False)],
          'asens': [('as', False)],
          'aser': [('as', False)],
          'aser-': [('aser', False)],
          'aseri': [('aserier', False)],
          'aseri-': [('aserier', False)],
          'aserier': [('aseri', False)],
          'aserierna': [('aserier', False)],
          'aseriernas': [('aseri', False)],
          'aseriers': [('aseri', False)],
          'asern': [('aser', False)],
          'aserna': [('as', False)],
          'asernas': [('as', False)],
          'aserns': [('aser', False)],
          'asers': [('as', False)],
          'asers-': [('aser', False)],
          'aservar': [('aserve', False)],
          'aserven': [('aserve', False)],
          'aset': [('as', False)],
          'asets': [('as', False)],
          'asetter': [('asett', False)],
          'asetters': [('asett', False)],
          'asframställningarnas': [('asframställning', False)],
          'asharnas': [('ash', False)],
          'ashets': [('ashets', False)],
          'ashets-': [('ashets', False)],
          'ashytt': [('ashytta', False)],
          'ashytt-': [('ashytta', False)],
          'ashytts': [('ashytta', False)],
          'asidan': [('asida', False)],
          'asidans': [('asida', False)],
          'aside-': [('asida', False)],
          'asides': [('asida', False)],
          'asier': [('asium', False)],
          'asierna': [('asier', False)],
          'asiernas': [('asium', False)],
          'asiers': [('asi', False)],
          'asilier': [('asilier', False)],
          'asiliers': [('asilier', False)],
          'asin': [('asi', False)],
          'asin-': [('asin', False)],
          'asinen': [('asin', False)],
          'asinens': [('asin', False)],
          'asiner': [('asin', False)],
          'asinerna': [('asin', False)],
          'asinernas': [('asin', False)],
          'asiners': [('asin', False)],
          'asingen': [('asingen', False)],
          'asingens': [('asingen', False)],
          'asins': [('asin', False)],
          'asins-': [('asin', False)],
          'asiren': [('asir', False)],
          'asirens': [('asir', False)],
          'asis': [('asis', False)],
          'asis-': [('asis', False)],
          'asisten': [('asist', False)],
          'asistens': [('asist', False)],
          'asiter': [('asit', False)],
          'asiterna': [('asit', False)],
          'asiters': [('asit', False)],
          'asits': [('asit', False)],
          'ask': [('ask', True), ('aska', True)],
          'ask-': [('ask', True), ('aska', True)],
          'askak': [('askaka', False)],
          'askak-': [('askaka', False)],
          'askaks': [('askaka', False)],
          'askaks-': [('askaka', False)],
          'askan': [('aska', False)],
          'askans': [('aska', False)],
          'askaps-': [('askap', False)],
          'askar': [('ask', False)],
          'askar-': [('askare', False)],
          'askare': [('askara', False)],
          'askare-': [('askara', False)],
          'askarens': [('askare', False)],
          'askarna': [('ask', True)],
          'askarnas': [('ask', False)],
          'askars': [('ask', False)],
          'aske': [('aske', True)],
          'aske-': [('aske', True)],
          'askeden': [('asked', False)],
          'askedens': [('asked', False)],
          'asken': [('ask', False)],
          'askenas': [('askenas', True)],
          'askens': [('ask', False)],
          'asker': [('asker', False)],
          'askers': [('asker', False)],
          'askes': [('aske', True), ('askes', True)],
          'askes-': [('aske', True), ('askes', True)],
          'asket': [('aske', True), ('asket', True)],
          'askets': [('asket', True), ('aske', True)],
          'askillen': [('askill', False)],
          'askills': [('askill', False)],
          'asklock': [('asklock', True)],
          'asklocks': [('asklock', True)],
          'asklocks-': [('asklock', True)],
          'asko': [('asko', False)],
          'askon': [('asko', False)],
          'askons': [('asko', False)],
          'askonst-': [('askonster', False)],
          'askonster': [('askonster', False)],
          'askonsterna': [('askonster', False)],
          'askonsternas': [('askonster', False)],
          'askonsters': [('askonster', False)],
          'askor': [('aska', False)],
          'askorna': [('asko', False)],
          'askornas': [('asko', False)],
          'askors': [('askors', False)],
          'askot': [('asko', False)],
          'askoter': [('askot', False)],
          'askoters': [('askot', False)],
          'askots': [('asko', False)],
          'askott': [('askott', False)],
          'askotten': [('askott', False)],
          'askottens': [('askott', False)],
          'askrans': [('askran', False)],
          'askrans-': [('askran', False)],
          'askrin': [('askri', False)],
          'askrins': [('askrin', False)],
          'askrällen': [('askräll', False)],
          'askrällens': [('askräll', False)],
          'askulder': [('askuld', False)],
          'askulor': [('askula', False)],
          'askulorna': [('askula', False)],
          'askulornas': [('askula', False)],
          'askulors': [('askula', False)],
          'askärmar': [('askärm', False)],
          'askärmarnas': [('askärm', False)],
          'askök': [('askök', False)],
          'asköks': [('askök', False)],
          'asköks-': [('askök', False)],
          'askör': [('askör', False)],
          'askör-': [('askör', False)],
          'askörs': [('askör', False)],
          'askörs-': [('askör', False)],
          'aslag': [('aslag', False)],
          'aslags': [('aslag', False)],
          'aslags-': [('aslag', False)],
          'aslanden': [('asland', False)],
          'aslandens': [('asland', False)],
          'aslandet': [('asland', False)],
          'aslarv': [('aslarv', False)],
          'aslarv-': [('aslarv', False)],
          'aslarvs': [('aslarv', False)],
          'asleken': [('aslek', False)],
          'aslekens': [('aslek', False)],
          'asleks': [('aslek', False)],
          'asleks-': [('aslek', False)],
          'asläkten': [('asläkt', False)],
          'asläktens': [('asläkt', False)],
          'asläkts': [('asläkt', False)],
          'asläkts-': [('asläkt', False)],
          'asman': [('asma', False)],
          'asmans': [('asma', False)],
          'asmatt': [('asmatta', False)],
          'asmatt-': [('asmatta', False)],
          'asmatts': [('asmatta', False)],
          'asmatts-': [('asmatta', False)],
          'asmer': [('asma', False)],
          'asmernas': [('asma', False)],
          'asms': [('asm', False)],
          'asnåret': [('asnåret', False)],
          'asnårets': [('asnåret', False)],
          'ason': [('ason', False)],
          'asoner': [('ason', False)],
          'asonerna': [('ason', False)],
          'asonernas': [('ason', False)],
          'asoners': [('ason', False)],
          'asons': [('ason', False)],
          'asor': [('asa', False)],
          'asorna': [('asa', False)],
          'asornas': [('asa', False)],
          'asors': [('asa', False)],
          'aspar': [('asp', True)],
          'asparnas': [('asp', False)],
          'aspars': [('asp', True)],
          'aspe-': [('aspe', True)],
          'aspen': [('asp', False)],
          'aspeng': [('aspeng', False)],
          'aspengar': [('aspeng', False)],
          'aspengarna': [('aspeng', False)],
          'aspengarnas': [('aspeng', False)],
          'aspengars': [('aspeng', False)],
          'aspengs': [('aspeng', False)],
          'aspengs-': [('aspeng', False)],
          'aspens': [('asp', False)],
          'aspet': [('aspe', True)],
          'aspets': [('aspe', True)],
          'aspets-': [('aspets', False)],
          'aspisar': [('aspis', False)],
          'aspisarna': [('aspis', False)],
          'aspisarnas': [('aspis', False)],
          'asprocessen': [('asprocessen', False)],
          'asprocessens': [('asprocessen', False)],
          'ass': [('ass', True)],
          'ass-': [('ass', False)],
          'assage': [('assage', False)],
          'assage-': [('assage', False)],
          'assaker': [('assaker', False)],
          'assakers': [('assaker', False)],
          'assans': [('assa', False)],
          'assar': [('assare', False)],
          'assar-': [('assare', False)],
          'assarens': [('assare', False)],
          'assarna': [('assare', False)],
          'assarnas': [('ass', False)],
          'assars': [('asse', False)],
          'assats': [('assat', False)],
          'assats-': [('assat', False)],
          'asse': [('asse', False)],
          'asse-': [('asse', False)],
          'assen': [('ass', True)],
          'assens': [('ass', True)],
          'assenter': [('assent', False)],
          'assenterna': [('assent', False)],
          'assenternas': [('assent', False)],
          'assenters': [('assent', False)],
          'asserierna': [('asseri', False)],
          'asset': [('ass', True)],
          'assets': [('ass', False)],
          'assier': [('assi', False)],
          'assis-': [('assi', False)],
          'assiv': [('assivum', False)],
          'assiv-': [('assivum', False)],
          'assiven': [('assivum', False)],
          'assivens': [('assivum', False)],
          'assiverna': [('assivum', False)],
          'assivernas': [('assivum', False)],
          'assivet': [('assivum', False)],
          'assivets': [('assiv', False)],
          'assivs': [('assivum', False)],
          'asslanden': [('asslande', False)],
          'asslandens': [('asslande', False)],
          'asslandet': [('asslande', False)],
          'asslar': [('asslare', False)],
          'asslarna': [('asslare', False)],
          'asslarnas': [('asslare', False)],
          'asslen': [('assle', False)],
          'asslens': [('assle', False)],
          'asso': [('asso', False)],
          'asson': [('asso', False)],
          'assons': [('asso', False)],
          'assopp': [('assopp', False)],
          'assopp-': [('assopp', False)],
          'assopps': [('assopp', False)],
          'assopps-': [('assopp', False)],
          'assor': [('asso', False)],
          'assorna': [('asso', False)],
          'assornas': [('asso', False)],
          'assors': [('asso', False)],
          'assvärmar': [('assvärmare', False)],
          'assvärmarna': [('assvärmare', False)],
          'assvärmarnas': [('assvärmare', False)],
          'ast': [('ast', False)],
          'ast-': [('asta', False)],
          'asta': [('asta', False)],
          'asta-': [('asta', False)],
          'astagen': [('astage', False)],
          'astagens': [('astage', False)],
          'astaget': [('astage', False)],
          'astagets': [('astage', False)],
          'astak': [('astak', False)],
          'astaken': [('astak', False)],
          'astakens': [('astak', False)],
          'astaket': [('astak', False)],
          'astakets': [('astak', False)],
          'astaks': [('astak', False)],
          'astaks-': [('astak', False)],
          'astan': [('asta', False)],
          'astankar': [('astankar', False)],
          'astankars': [('astankar', False)],
          'astanke': [('astankar', False)],
          'astanke-': [('astankar', False)],
          'astans': [('asta', False)],
          'astar': [('astare', False)],
          'astar-': [('astare', False)],
          'astarna': [('astare', False)],
          'astarnas': [('ast', False)],
          'astars': [('ast', False)],
          'astas': [('asta', False)],
          'aste': [('aste', False)],
          'aste-': [('aste', False)],
          'asteg': [('astege', False)],
          'asteg-': [('astege', False)],
          'astegen': [('astege', False)],
          'astegens': [('astege', False)],
          'astegs': [('astege', False)],
          'astegs-': [('astege', False)],
          'astens': [('ast', False)],
          'aster': [('aster', False)],
          'asteri': [('asteri', False)],
          'asteri-': [('asteri', False)],
          'asterier': [('asteri', False)],
          'asterierna': [('asteri', False)],
          'asteriers': [('asteri', False)],
          'asteriet': [('asteri', False)],
          'asteris': [('asteri', False)],
          'asteris-': [('asteri', False)],
          'asters': [('aster', False)],
          'astets': [('ast', False)],
          'astfiskar': [('astfisk', False)],
          'astfiskarnas': [('astfisk', False)],
          'asti': [('asti', False)],
          'asti-': [('asti', False)],
          'astika': [('astika', False)],
          'astikas': [('astika', False)],
          'astiker': [('astiker', False)],
          'astikerna': [('astiker', False)],
          'astikernas': [('astiker', False)],
          'astikers': [('astiker', False)],
          'astill': [('astill', False)],
          'astill-': [('astill', False)],
          'astills': [('astill', False)],
          'astills-': [('astill', False)],
          'astins': [('asti', False)],
          'astis': [('astis', False)],
          'astis-': [('astis', False)],
          'astmans': [('astma', False)],
          'astol': [('astol', False)],
          'astole': [('astole', False)],
          'astole-': [('astole', False)],
          'astolen': [('astole', False)],
          'astolens': [('astole', False)],
          'astols': [('astol', False)],
          'astols-': [('astol', False)],
          'astom': [('astom', False)],
          'astom-': [('astom', False)],
          'astoms': [('astom', False)],
          'aston': [('aston', False)],
          'astons': [('aston', False)],
          'astons-': [('aston', False)],
          'astor': [('asta', False)],
          'astoren': [('astor', False)],
          'astorens': [('astor', False)],
          'astorer': [('astor', False)],
          'astorerna': [('astor', False)],
          'astorernas': [('astor', False)],
          'astorers': [('astor', False)],
          'astormar': [('astormare', False)],
          'astormarna': [('astormare', False)],
          'astormarnas': [('astormare', False)],
          'astors': [('astor', False)],
          'astranden': [('astrande', False)],
          'astrandens': [('astrande', False)],
          'astrarnas': [('aster', False)],
          'astringens': [('astring', False)],
          'astron': [('astron', False)],
          'astronen': [('astron', False)],
          'astronens': [('astron', False)],
          'astrons': [('astron', False)],
          'astrum': [('astrumma', False)],
          'astrums': [('astrum', False)],
          'astrums-': [('astrumma', False)],
          'astuns': [('astu', False)],
          'astur': [('astu', False)],
          'asturs': [('astu', False)],
          'astvinds': [('astvind', False)],
          'astvinds-': [('astvind', False)],
          'astyren': [('astyre', False)],
          'astyrens': [('astyre', False)],
          'astötarnas': [('astöt', False)],
          'astövel': [('astövlar', False)],
          'astövel-': [('astövlar', False)],
          'astövels': [('astövlar', False)],
          'astövels-': [('astövlar', False)],
          'astövlar': [('astövlar', False)],
          'astövlarna': [('astövlar', False)],
          'astövlarnas': [('astövlar', False)],
          'astövlars': [('astövlar', False)],
          'asur': [('asur', False)],
          'asur-': [('asur', False)],
          'asurs': [('asur', False)],
          'asus': [('asus', False)],
          'asvar': [('asvara', False)],
          'asvar-': [('asvar', False)],
          'asverken': [('asverk', False)],
          'asverkens': [('asverk', False)],
          'asverket': [('asverk', False)],
          'asverks': [('asverk', False)],
          'asverks-': [('asverk', False)],
          'asvägens': [('asväg', False)],
          'asvävar': [('asväv', False)],
          'asvävarna': [('asväv', False)],
          'asvävarnas': [('asväv', False)],
          'asyn': [('asy', False)],
          'asyns': [('asy', False)],
          'asyren': [('asyr', False)],
          'asyrens': [('asyr', False)],
          'asyrs': [('asyr', False)],
          'asyrs-': [('asyr', False)],
          'at': [('at', False)],
          'at-': [('at', False)],
          'atack': [('atack', False)],
          'atack-': [('atack', False)],
          'atacks': [('atack', False)],
          'atagen': [('atag', False)],
          'atagens': [('atag', False)],
          'ataget': [('atag', False)],
          'ataken': [('atak', False)],
          'atalens': [('atal', False)],
          'ataler': [('atal', False)],
          'atalerna': [('atal', False)],
          'atalernas': [('atal', False)],
          'atalers': [('atal', False)],
          'atalet': [('atal', False)],
          'atalj': [('atalj', False)],
          'atalj-': [('atalj', False)],
          'ataljs': [('atalj', False)],
          'atan': [('atan', False)],
          'atan-': [('atan', False)],
          'atanden': [('atande', False)],
          'atandens': [('atande', False)],
          'atans': [('ata', False)],
          'atans-': [('atan', False)],
          'atar': [('ate', False)],
          'atar-': [('atar', False)],
          'ataren': [('atare', False)],
          'atarens': [('atar', False)],
          'atarie': [('atarie', False)],
          'atarie-': [('atarie', False)],
          'atarier': [('atarie', False)],
          'atarierna': [('atarier', False)],
          'atariernas': [('atarie', False)],
          'atariers': [('atarium', False)],
          'atarna': [('at', False)],
          'atarnas': [('ate', False)],
          'atars': [('atar', False)],
          'atars-': [('atar', False)],
          'atarven': [('atarv', False)],
          'atat': [('atat', False)],
          'atats': [('atat', False)],
          'atax': [('atax', False)],
          'atax-': [('atax', False)],
          'ataxis': [('ataxi', True)],
          'atbit': [('atbit', False)],
          'atbitar': [('atbit', False)],
          'atbitarna': [('atbit', False)],
          'atbitarnas': [('atbit', False)],
          'atdags': [('atdags', False)],
          'atdags-': [('atdags', False)],
          'ate': [('ata', False)],
          'ate-': [('ata', False)],
          'ateg': [('ateg', False)],
          'ateg-': [('ateg', False)],
          'ategen': [('ateg', False)],
          'ategens': [('ateg', False)],
          'ateger': [('ateg', False)],
          'ategernas': [('ateg', False)],
          'ategers': [('ateg', False)],
          'ateket': [('ateket', False)],
          'atekets': [('ateket', False)],
          'atekniker': [('ateknik', False)],
          'ateknikerna': [('ateknik', False)],
          'ateknikernas': [('ateknik', False)],
          'ateknikers': [('ateknik', False)],
          'atel': [('atel', False)],
          'atel-': [('atel', False)],
          'atelen': [('atel', False)],
          'atelens': [('atel', False)],
          'ateler': [('atel', False)],
          'atelerna': [('atel', False)],
          'atelernas': [('atel', False)],
          'atell': [('atella', False)],
          'atell-': [('atella', False)],
          'atellans': [('atella', False)],
          'atells': [('atella', False)],
          'atells-': [('atella', False)],
          'ateln': [('atel', False)],
          'atelns': [('atel', False)],
          'atels': [('atel', False)],
          'atels-': [('atel', False)],
          'aten': [('at', False)],
          'atens': [('at', False)],
          'atens-': [('aten', False)],
          'ater': [('at', False)],
          'ater-': [('ater', False)],
          'ateranden': [('aterande', False)],
          'aterandens': [('aterande', False)],
          'aterian': [('ateria', False)],
          'aterians': [('ateria', False)],
          'aterie': [('aterie', False)],
          'aterie-': [('aterie', False)],
          'atermin': [('atermi', False)],
          'atermins': [('atermi', False)],
          'atern': [('ater', False)],
          'aterna': [('at', False)],
          'aternas': [('at', False)],
          'aterns': [('ater', False)],
          'aters': [('at', False)],
          'aters-': [('ater', False)],
          'ates': [('ates', False)],
          'ates-': [('ates', False)],
          'atet': [('at', False)],
          'atets': [('at', False)],
          'atfiskarna': [('atfisk', False)],
          'athakens': [('athak', False)],
          'athet': [('athet', False)],
          'athets': [('athet', False)],
          'atias': [('atias', False)],
          'atics': [('atics', False)],
          'atiden': [('atid', False)],
          'atidens': [('atiden', False)],
          'atider': [('atid', False)],
          'atiderna': [('atider', False)],
          'atidernas': [('atider', False)],
          'atiders': [('atid', False)],
          'atie': [('atium', False)],
          'atie-': [('atium', False)],
          'aties': [('atie', False)],
          'atiet': [('atium', False)],
          'atiets': [('ation', False)],
          'atighets': [('atighet', False)],
          'atik': [('atik', False)],
          'atik-': [('atik', False)],
          'atiks': [('atik', False)],
          'atin': [('ati', False)],
          'atin-': [('atin', False)],
          'atina': [('atina', False)],
          'atinens': [('atin', False)],
          'atiner': [('atin', False)],
          'atinerna': [('atin', False)],
          'atinernas': [('atin', False)],
          'atiners': [('atin', False)],
          'atinorna': [('atina', False)],
          'atinors': [('atina', False)],
          'atins': [('atin', False)],
          'atins-': [('atin', False)],
          'atint-': [('atint', False)],
          'atints': [('atint', False)],
          'ations-': [('ation', False)],
          'atior': [('atio', False)],
          'atiorna': [('atio', False)],
          'atiornas': [('atio', False)],
          'atiors': [('atio', False)],
          'atir-': [('atir', False)],
          'atis': [('ati', False)],
          'atis-': [('atis', False)],
          'atit': [('atit', False)],
          'atit-': [('atit', False)],
          'atits': [('atit', False)],
          'atium': [('ation', False)],
          'atiums': [('ation', False)],
          'ativ': [('ativ', False)],
          'ativ-': [('ativ', False)],
          'ative': [('ativa', False)],
          'ative-': [('ativa', False)],
          'ativen': [('ativ', False)],
          'ativens': [('ativ', False)],
          'ativer': [('ativ', False)],
          'ativerna': [('ativ', False)],
          'ativernas': [('ativ', False)],
          'ativers': [('ativ', False)],
          'ativet': [('ativ', False)],
          'ativets': [('ativum', False)],
          'ativs': [('ativ', False)],
          'ativs-': [('ativ', False)],
          'atlandet': [('atland', False)],
          'atlar': [('atel', False)],
          'atlarna': [('atel', False)],
          'atlarnas': [('atel', False)],
          'atlet': [('atlet', True)],
          'atlets': [('atlet', True)],
          'atm': [('atma', False)],
          'atm-': [('atma', False)],
          'atman': [('atma', False)],
          'atmans': [('atman', False)],
          'atmask': [('atmask', False)],
          'atmask-': [('atmask', False)],
          'atmor': [('atmor', False)],
          'atmors': [('atma', False)],
          'atms': [('atma', False)],
          'atms-': [('atma', False)],
          'atnäv': [('atnäva', False)],
          'atnävs': [('atnäva', False)],
          'ato-': [('ato', False)],
          'atoden': [('atod', False)],
          'atodens': [('atod', False)],
          'atoll-': [('atoll', True)],
          'atollen': [('atoll', True)],
          'atollens': [('atoll', True)],
          'atolls': [('atoll', True)],
          'atom-': [('atom', False)],
          'atoms': [('atom', False)],
          'atomten': [('atomt', False)],
          'atomtens': [('atomt', False)],
          'aton': [('ato', False)],
          'atonik': [('atonik', False)],
          'atonik-': [('atonik', False)],
          'atoniks': [('atonik', False)],
          'atonin': [('atoni', True)],
          'atonins': [('atoni', True)],
          'atons': [('ato', False)],
          'ator': [('ata', False)],
          'atorer': [('ator', False)],
          'atorerna': [('ator', False)],
          'atorernas': [('ator', False)],
          'atorers': [('ator', False)],
          'atorier': [('atorium', False)],
          'atoriet': [('atorium', False)],
          'atorn': [('ator', False)],
          'atorna': [('ata', False)],
          'atornas': [('ata', False)],
          'atorns': [('ator', False)],
          'ators': [('ata', False)],
          'atos': [('atos', False)],
          'atos-': [('atos', False)],
          'atox-': [('atoxe', False)],
          'atrapp': [('atrappa', False)],
          'atrapp-': [('atrappa', False)],
          'atrapps': [('atrappa', False)],
          'atrapps-': [('atrappa', False)],
          'atrar': [('ater', False)],
          'atrarna': [('ater', False)],
          'atrars': [('ater', False)],
          'atrens': [('atur', False)],
          'atrer': [('ater', False)],
          'atrerna': [('ater', False)],
          'atrernas': [('ater', False)],
          'atret': [('atur', False)],
          'atrets': [('atur', False)],
          'atriernas': [('atrium', True)],
          'atrin': [('atrin', False)],
          'atringar': [('atring', False)],
          'atringars': [('atring', False)],
          'atringens': [('atring', False)],
          'atrins': [('atri', False)],
          'atris': [('atri', False)],
          'atron': [('atro', False)],
          'atron-': [('atron', False)],
          'atrons': [('atron', False)],
          'atrons-': [('atrona', False)],
          'atropin': [('atropin', True)],
          'atros': [('atro', False)],
          'atros-': [('atro', False)],
          'atrots': [('atrot', False)],
          'atrots-': [('atrot', False)],
          'atrulls': [('atrull', False)],
          'atrulls-': [('atrull', False)],
          'atrum': [('atrum', False)],
          'atrums': [('atrum', False)],
          'atrums-': [('atrum', False)],
          'aträd': [('aträd', False)],
          'aträd-': [('aträd', False)],
          'aträden': [('aträd', False)],
          'aträdens': [('aträd', False)],
          'aträdet': [('aträd', False)],
          'aträdets': [('aträd', False)],
          'aträds': [('aträd', False)],
          'aträn': [('aträd', False)],
          'aträna': [('aträd', False)],
          'atränas': [('aträd', False)],
          'aträns': [('aträd', False)],
          'aträt': [('aträ', False)],
          'aträts': [('aträ', False)],
          'ats': [('at', False)],
          'atsaks': [('atsak', False)],
          'atsaks-': [('atsak', False)],
          'atsar': [('ats', False)],
          'atsarna': [('at', False)],
          'atsarnas': [('ats', False)],
          'atsars': [('atse', False)],
          'atsen': [('at', False)],
          'atsens': [('atse', False)],
          'atskeden': [('atsked', False)],
          'atskedens': [('atsked', False)],
          'atslins': [('atslins', False)],
          'atställen': [('atställe', False)],
          'atstället': [('atställe', False)],
          'atsång': [('atsång', False)],
          'atsångs': [('atsång', False)],
          'atsångs-': [('atsång', False)],
          'attan': [('attan', True)],
          'attans': [('attan', True)],
          'attar': [('attare', False)],
          'attarna': [('att', False)],
          'attarnas': [('att', False)],
          'attars': [('atte', False)],
          'atte-': [('atta', False)],
          'atten': [('atten', False)],
          'attena': [('atte', False)],
          'attenas': [('atte', False)],
          'attens': [('att', False)],
          'atter': [('atter', False)],
          'atteranden': [('atterand', False)],
          'atterandens': [('atterand', False)],
          'atteriers': [('atteri', False)],
          'atters': [('atter', False)],
          'attet': [('atte', False)],
          'attets': [('att', False)],
          'attigheter': [('attighet', False)],
          'attigheterna': [('attighet', False)],
          'attigheternas': [('attighet', False)],
          'attigheters': [('attighet', False)],
          'attighets-': [('attighet', False)],
          'attkoppor': [('attkoppor', False)],
          'attkopporna': [('attkoppor', False)],
          'attkoppornas': [('attkoppor', False)],
          'attkoppors': [('attkoppor', False)],
          'attkopps': [('attkoppor', False)],
          'attkopps-': [('attkoppor', False)],
          'attlanden': [('attlande', False)],
          'attlandens': [('attlande', False)],
          'attlandet': [('attlande', False)],
          'attnar': [('attnare', False)],
          'attnens': [('atten', False)],
          'attnet': [('atten', False)],
          'attnets': [('atten', False)],
          'atto': [('atto', False)],
          'attras': [('attras', False)],
          'attros': [('attro', False)],
          'attros-': [('attro', False)],
          'attsidan': [('attsida', False)],
          'attsidans': [('attsida', False)],
          'atu': [('ata', False)],
          'atu-': [('ata', False)],
          'atum': [('atum', False)],
          'atum-': [('atum', False)],
          'atumen': [('atum', False)],
          'atumens': [('atum', False)],
          'atums': [('atum', False)],
          'atums-': [('atum', False)],
          'atunge': [('atunge', False)],
          'atunge-': [('atunge', False)],
          'atungen': [('atunge', False)],
          'atungens': [('atunge', False)],
          'atur': [('atur', False)],
          'atur-': [('atur', False)],
          'aturer': [('atur', False)],
          'aturerna': [('atur', False)],
          'aturernas': [('atur', False)],
          'aturers': [('atur', False)],
          'aturis': [('aturis', False)],
          'aturs': [('atur', False)],
          'aturs-': [('atur', False)],
          'atus': [('atus', False)],
          'atus-': [('atus', False)],
          'atut': [('atut', False)],
          'atut-': [('atut', False)],
          'atuts': [('atut', False)],
          'atuts-': [('atut', False)],
          'atyr': [('atyr', False)],
          'atyr-': [('atyr', False)],
          'atyren': [('atyr', False)],
          'atyrens': [('atyr', False)],
          'atyrer': [('atyr', False)],
          'atyrerna': [('atyr', False)],
          'atyrernas': [('atyr', False)],
          'atyrers': [('atyr', False)],
          'atyrs': [('atyr', False)],
          'atyrs-': [('atyr', False)],
          'atängens': [('atäng', False)],
          'atänger': [('atäng', False)],
          'atängerna': [('atäng', False)],
          'atängernas': [('atäng', False)],
          'atängers': [('atäng', False)],
          'atänk': [('atänka', False)],
          'atänk-': [('atänka', False)],
          'atänks': [('atänka', False)],
          'atänks-': [('atänka', False)],
          'atäten': [('atät', False)],
          'atätens': [('atät', False)],
          'atåg': [('atåg', False)],
          'atågs': [('atåg', False)],
          'atågs-': [('atåg', False)],
          'au': [('au', False)],
          'auan': [('auan', False)],
          'auans': [('auan', False)],
          'audiens': [('audiens', True)],
          'audier': [('audier', False)],
          'audierna': [('audier', False)],
          'audiernas': [('audier', False)],
          'audiers': [('audier', False)],
          'auen': [('au', False)],
          'auens': [('au', False)],
          'auernas': [('auer', False)],
          'auers': [('auer', False)],
          'auet': [('au', False)],
          'auge': [('auge', False)],
          'auge-': [('auge', False)],
          'augen': [('auge', False)],
          'augens': [('auge', False)],
          'aukarnas': [('auk', False)],
          'aula': [('aula', True)],
          'aulan': [('aula', True)],
          'aulans': [('aula', True)],
          'aulas': [('aula', True)],
          'aull': [('aull', False)],
          'aull-': [('aull', False)],
          'aulls': [('aull', False)],
          'aulls-': [('aull', False)],
          'aulun': [('aulun', False)],
          'auluns': [('aulun', False)],
          'auman': [('auma', False)],
          'aumer': [('auma', False)],
          'aumerna': [('auma', False)],
          'aumernas': [('auma', False)],
          'aumers': [('auma', False)],
          'aun': [('au', False)],
          'aun-': [('auna', False)],
          'auna': [('au', False)],
          'aunas': [('au', False)],
          'auniversitetet': [('auniversitetet', False)],
          'auns': [('auna', False)],
          'auns-': [('auna', False)],
          'auon': [('auon', False)],
          'auons': [('auon', False)],
          'aur': [('aura', False)],
          'aur-': [('aura', False)],
          'auran': [('aura', False)],
          'aurans': [('aura', False)],
          'auri': [('auri', False)],
          'auri-': [('auri', False)],
          'aurie-': [('aurie', False)],
          'aurien': [('aurie', False)],
          'aurier': [('auri', False)],
          'aurierna': [('auri', False)],
          'auriernas': [('aurie', False)],
          'auriers': [('aurie', False)],
          'aurin': [('auri', False)],
          'aurins': [('auri', False)],
          'auris': [('auri', False)],
          'aurs': [('aura', False)],
          'aurs-': [('aura', False)],
          'auruernas': [('auruer', False)],
          'aurusarnas': [('aurus', False)],
          'aus': [('au', False)],
          'aus-': [('au', False)],
          'auser': [('auser', False)],
          'auserna': [('auser', False)],
          'ausernas': [('auser', False)],
          'ausers': [('auser', False)],
          'auss': [('auss', False)],
          'aussen': [('auss', False)],
          'aussens': [('auss', False)],
          'aut': [('au', False)],
          'autarnas': [('aut', False)],
          'aute': [('aute', False)],
          'aute-': [('aute', False)],
          'auten': [('aute', False)],
          'autens': [('aute', False)],
          'auter': [('aute', False)],
          'auterna': [('aute', False)],
          'auternas': [('aute', False)],
          'auters': [('aute', False)],
          'auts': [('au', False)],
          'av': [('av', False)],
          'av-': [('av', False)],
          'avader': [('avad', False)],
          'avaders': [('avad', False)],
          'avaj': [('avaj', False)],
          'avaj-': [('avaj', False)],
          'avajer': [('avaj', False)],
          'avajers': [('avaj', False)],
          'avajs': [('avaj', False)],
          'avajs-': [('avaj', False)],
          'aval': [('aval', False)],
          'aval-': [('aval', False)],
          'avalen': [('aval', False)],
          'avalens': [('aval', False)],
          'avaljers': [('avaljer', False)],
          'avalls-': [('avaller', False)],
          'avals': [('aval', False)],
          'avals-': [('aval', False)],
          'avan': [('ava', True)],
          'avanden': [('avande', True)],
          'avandens': [('avande', True)],
          'avane': [('avane', False)],
          'avane-': [('avane', False)],
          'avanen': [('avan', False)],
          'avanens': [('avane', False)],
          'avaner': [('avan', False)],
          'avanerna': [('avane', False)],
          'avanernas': [('avan', False)],
          'avaners': [('avan', False)],
          'avanes': [('avanes', False)],
          'avanes-': [('avanes', False)],
          'avann': [('avann', False)],
          'avann-': [('avann', False)],
          'avannen': [('avann', False)],
          'avannens': [('avann', False)],
          'avanns': [('avann', False)],
          'avanns-': [('avann', False)],
          'avans': [('avans', True), ('ava', True)],
          'avans-': [('avans', True)],
          'avar-': [('avare', False)],
          'avaren': [('avare', False)],
          'avarna': [('avare', False)],
          'avars': [('av', False)],
          'avarts': [('avart', True)],
          'avas': [('ava', False)],
          'avatten': [('avatt', False)],
          'avattens': [('avatt', False)],
          'ave': [('ave', True)],
          'ave-': [('ave', True)],
          'avel': [('avel', False)],
          'avel-': [('avel', False)],
          'avels': [('avel', False)],
          'avels-': [('avel', False)],
          'aven': [('ave', True)],
          'avens': [('ave', True)],
          'aver': [('av', False)],
          'averande': [('averande', False)],
          'averande-': [('averande', False)],
          'averens': [('aver', False)],
          'avern': [('aver', False)],
          'avern-': [('averna', False)],
          'averna': [('av', False)],
          'averne-': [('averna', False)],
          'averns': [('averna', False)],
          'averns-': [('averna', False)],
          'avers': [('avers', True)],
          'avers-': [('avers', True)],
          'avet': [('ave', True)],
          'avets': [('ave', True)],
          'avett': [('avett', False)],
          'avett-': [('avett', False)],
          'avetten': [('avett', False)],
          'avettens': [('avett', False)],
          'avetts': [('avett', False)],
          'avetts-': [('avett', False)],
          'avgaserna': [('avgaser', True)],
          'avgasernas': [('avgaser', True)],
          'avgasers': [('avgaser', True)],
          'avid': [('avid', False)],
          'avid-': [('avid', False)],
          'aviden': [('avid', False)],
          'avidens': [('avid', False)],
          'avider': [('avid', False)],
          'aviders': [('avid', False)],
          'avids': [('avid', False)],
          'avier': [('avi', True)],
          'avierna': [('avi', True)],
          'aviernas': [('avi', True)],
          'aviers': [('avi', True)],
          'avin': [('avi', True)],
          'avin-': [('avin', False)],
          'aving': [('avinge', False)],
          'aving-': [('avinge', False)],
          'avingar': [('avinge', False)],
          'avingarna': [('avinge', False)],
          'avingarnas': [('avinge', False)],
          'avingars': [('avinge', False)],
          'avingen': [('avinge', False)],
          'avingens': [('avinge', False)],
          'avings': [('avinge', False)],
          'avings-': [('avinge', False)],
          'avins': [('avi', True)],
          'avins-': [('avin', False)],
          'avinsten': [('avinst', False)],
          'avinstens': [('avinst', False)],
          'avinter': [('avinter', False)],
          'avinters': [('avinter', False)],
          'aviolin': [('avioli', False)],
          'aviolins': [('avioli', False)],
          'avis': [('avi', True), ('avis', True), ('avisa', True)],
          'avis-': [('avisa', True), ('avis', True)],
          'avisa': [('avisa', True)],
          'avisas': [('avisa', True)],
          'avise': [('avisa', True)],
          'avisen': [('avis', True)],
          'avisens': [('avis', True)],
          'avisor': [('avisa', True)],
          'avist': [('avist', False)],
          'avist-': [('avist', False)],
          'avisten': [('avist', False)],
          'avistens': [('avist', False)],
          'avit': [('avit', False)],
          'avit-': [('avit', False)],
          'aviten': [('avit', False)],
          'avitens': [('avit', False)],
          'aviter': [('avit', False)],
          'aviterna': [('avit', False)],
          'aviters': [('avit', False)],
          'avitet': [('avitet', False)],
          'avitets': [('avitet', False)],
          'avits': [('avit', False)],
          'avkor': [('avkor', False)],
          'avkors': [('avkor', False)],
          'avlar': [('avel', False)],
          'avlarnas': [('avel', False)],
          'avlars': [('avel', False)],
          'avle': [('avle', False)],
          'avle-': [('avle', False)],
          'avlingen': [('avlinge', True), ('avling', True)],
          'avlingens': [('avling', True), ('avlinge', True)],
          'avo': [('avo', False)],
          'avo-': [('avo', False)],
          'avons': [('avo', False)],
          'avor': [('ava', False)],
          'avorna': [('ava', False)],
          'avornas': [('ava', False)],
          'avors': [('ava', False)],
          'avot': [('avo', False)],
          'avren': [('avre', False)],
          'avrens': [('avrens', True)],
          'avret': [('aver', False)],
          'avrets': [('aver', False)],
          'avs': [('av', False)],
          'avs-': [('av', False)],
          'avtidens': [('avtid', False)],
          'avträden': [('avträde', True)],
          'avträdens': [('avträde', True)],
          'avträdet': [('avträde', True)],
          'avträdets': [('avträde', True)],
          'avvårdar': [('avvård', False)],
          'avvårdarna': [('avvård', False)],
          'avägar': [('aväg', False)],
          'avägarna': [('aväg', False)],
          'avägarnas': [('aväg', False)],
          'avägars': [('aväg', False)],
          'avägs': [('aväg', False)],
          'avälden': [('avälde', False)],
          'aväldens': [('avälde', False)],
          'aväxlar': [('aväxel', False)],
          'aväxlarna': [('aväxel', False)],
          'aväxlarnas': [('aväxel', False)],
          'avågar': [('avågare', False)],
          'avågarna': [('avågare', False)],
          'avågarnas': [('avågare', False)],
          'awierna': [('awier', False)],
          'awiernas': [('awier', False)],
          'awiers': [('awier', False)],
          'awn': [('aw', False)],
          'ax': [('ax', False)],
          'ax-': [('ax', False)],
          'axar': [('ax', False)],
          'axarna': [('ax', False)],
          'axarnas': [('ax', False)],
          'axars': [('ax', False)],
          'axe': [('axa', False)],
          'axe-': [('axa', False)],
          'axen': [('ax', False)],
          'axens': [('ax', False)],
          'axer': [('ax', False)],
          'axerna': [('ax', False)],
          'axernas': [('ax', False)],
          'axers': [('ax', False)],
          'axet': [('ax', False)],
          'axin': [('axi', False)],
          'axis-': [('axis', False)],
          'axlar': [('axel', False)],
          'axlarna': [('axel', False)],
          'axlarnas': [('axel', False)],
          'axorna': [('axa', False)],
          'axornas': [('axa', False)],
          'ay': [('ay', False)],
          'ay-': [('ay', False)],
          'ayan': [('ayan', False)],
          'ayans': [('aya', False)],
          'ayaren': [('ayare', False)],
          'ayarnas': [('ayare', False)],
          'aye': [('aya', False)],
          'aye-': [('aya', False)],
          'ayen': [('ay', False)],
          'ayens': [('ay', False)],
          'ayer': [('ay', False)],
          'ayerna': [('ay', False)],
          'ayernas': [('ay', False)],
          'ayers': [('ay', False)],
          'ayn': [('ay', False)],
          'ayns': [('ay', False)],
          'ayon': [('ayon', False)],
          'ayons': [('ayon', False)],
          'ayor': [('aya', False)],
          'ayorna': [('aya', False)],
          'ayornas': [('aya', False)],
          'ays': [('aya', False)],
          'ays-': [('aya', False)],
          'ayte': [('ayte', False)],
          'ayte-': [('ayte', False)],
          'aytet': [('ayte', False)],
          'az': [('az', False)],
          'az-': [('az', False)],
          'azer': [('az', False)],
          'azers': [('az', False)],
          'azon': [('azon', False)],
          'azons': [('azo', False)],
          'azz': [('azza', False)],
          'azz-': [('azza', False)],
          'azzi': [('azzia', False)],
          'azzi-': [('azzia', False)],
          'aägar': [('aägare', False)],
          'aägarnas': [('aägare', False)],
          'aätt': [('aätt', False)],
          'aätter': [('aätt', False)],
          'aätterna': [('aätt', False)],
          'aätters': [('aätt', False)],
          'aätts': [('aätt', False)],
          'aätts-': [('aätt', False)],
          'aår': [('aår', False)],
          'aårs': [('aår', False)],
          'b': [('b', True)],
          'b-': [('b', True)],
          'ba': [('ba', False)],
          'ba-': [('ba', False)],
          'baber': [('bab', False)],
          'babers': [('bab', False)],
          'babies': [('baby', True)],
          'bachen': [('bach', False)],
          'bachens': [('bach', False)],
          'back': [('back', True), ('backa', True), ('backe', True)],
          'back-': [('backa', True), ('backe', True), ('back', True)],
          'backar': [('backe', True), ('back', True)],
          'backarna': [('back', True), ('backe', True)],
          'backarnas': [('back', True), ('backe', True)],
          'backars': [('backe', True), ('back', True)],
          'backe': [('backa', True), ('backe', True)],
          'backe-': [('backa', True)],
          'backen': [('backe', True), ('back', True)],
          'backens': [('backe', True), ('back', True)],
          'backer': [('back', False)],
          'backers': [('back', False)],
          'backor': [('backa', True)],
          'backorna': [('backa', True)],
          'backornas': [('backa', True)],
          'backors': [('backa', True)],
          'backs': [('backa', True), ('back', True), ('backe', True)],
          'backs-': [('backa', True), ('backe', True), ('back', True)],
          'badar': [('badare', False)],
          'badar-': [('badare', False)],
          'badarna': [('badare', True)],
          'badarnas': [('badare', True)],
          'baddarna': [('baddare', True)],
          'baddarnas': [('baddare', True)],
          'badets': [('bad', False)],
          'badier': [('badier', False)],
          'badiernas': [('badier', False)],
          'badiers': [('badier', False)],
          'badmintonracket': [('badmintonrack', True), ('badmintonracket', True)],
          'badmintonrackets': [('badmintonracket', True), ('badmintonrack', True)],
          'badskor': [('badsko', True)],
          'badskorna': [('badsko', True)],
          'badskornas': [('badsko', True)],
          'badskors': [('badsko', True)],
          'bagar': [('bag', True), ('bagare', True)],
          'bagar-': [('bagare', True)],
          'bagarna': [('bag', True), ('bagare', True)],
          'bagarnas': [('bag', True), ('bagare', True)],
          'bagars': [('bag', True)],
          'bagelsen': [('bagel', True)],
          'bagelsens': [('bagel', True)],
          'bagens': [('bag', False)],
          'bagg': [('bagg', True), ('bagge', True)],
          'bagg-': [('bagg', True), ('bagge', True)],
          'baggar': [('bagg', True), ('bagge', True)],
          'baggarna': [('bagg', True), ('bagge', True)],
          'baggarnas': [('bagg', True), ('bagge', True)],
          'baggars': [('bagg', True), ('bagge', True)],
          'baggen': [('bagg', True), ('bagge', True)],
          'baggens': [('bagg', True), ('bagge', True)],
          'baggs': [('bagg', True), ('bagge', True)],
          'baggs-': [('bagg', True), ('bagge', True)],
          'bago-': [('bago', False)],
          'bajrar': [('bajrare', True)],
          'bajrarna': [('bajrare', True)],
          'bajs': [('bajs', False)],
          'bak-': [('bak', True)],
          'bakarnas': [('bak', False)],
          'bakets': [('bak', False)],
          'bakist-': [('bakist', False)],
          'baklandets': [('bakland', True)],
          'baks': [('bak', False)],
          'baks-': [('bak', False)],
          'bakter': [('bakter', False)],
          'bakterierna': [('bakterie', False)],
          'bakteriernas': [('bakterie', False)],
          'bakteriers': [('bakterie', False)],
          'bakters': [('bakter', False)],
          'bakände': [('bakända', True), ('bakände', True)],
          'bakände-': [('bakände', True), ('bakända', True)],
          'bal': [('bale', True), ('bal', True)],
          'bal-': [('bale', True), ('bal', True)],
          'balan': [('bala', False)],
          'balandets': [('balande', True)],
          'balans': [('balans', False)],
          'balans-': [('balans', False)],
          'balar': [('bale', True), ('bal', True)],
          'balarna': [('bale', True), ('bal', True)],
          'balarnas': [('bale', True), ('bal', True)],
          'balars': [('bale', True), ('bal', True)],
          'balas': [('bala', False)],
          'bale': [('bale', True)],
          'balen': [('bale', True), ('bal', True)],
          'balens': [('bale', True), ('bal', True)],
          'bales': [('bale', True)],
          'bales-': [('bale', True)],
          'bali': [('balo', False)],
          'balis': [('balo', False)],
          'balje': [('balja', False)],
          'balje-': [('balja', False)],
          'balk': [('balk', False)],
          'balk-': [('balk', False)],
          'balkar': [('balk', False)],
          'balkarna': [('balk', False)],
          'balks': [('balk', False)],
          'balks-': [('balk', False)],
          'ball': [('balle', True)],
          'ball-': [('balle', True)],
          'ballagens': [('ballage', False)],
          'ballarna': [('balle', True)],
          'ballarnas': [('balle', True)],
          'ballen': [('balle', True)],
          'ballens': [('balle', True)],
          'balls': [('balle', True)],
          'balls-': [('balle', True)],
          'balon': [('balo', False)],
          'balonen': [('balone', False)],
          'balonens': [('balone', False)],
          'baloner': [('balone', False)],
          'balonerna': [('balone', False)],
          'balonernas': [('balone', False)],
          'balons': [('balo', False)],
          'balor': [('balo', False)],
          'balorna': [('balo', False)],
          'balornas': [('balo', False)],
          'balors': [('balo', False)],
          'balos': [('balo', False)],
          'bals': [('bale', True), ('bal', True)],
          'bals-': [('bale', True), ('bal', True)],
          'balt-': [('balt', True)],
          'balter': [('balt', True)],
          'balterna': [('balt', True)],
          'balternas': [('balt', True)],
          'balters': [('balt', True)],
          'balts-': [('balt', True)],
          'baluns': [('baluns', True)],
          'bambor': [('bamba', True)],
          'bamborna': [('bamba', True)],
          'bambornas': [('bamba', True)],
          'ban': [('ban', True), ('bana', True)],
          'ban-': [('bana', True), ('ban', True)],
          'banan': [('banan', True), ('bana', True)],
          'banans': [('banan', True), ('bana', True)],
          'banarna': [('ban', True)],
          'banarnas': [('ban', True)],
          'band': [('band', False)],
          'band-': [('band', False)],
          'banden': [('band', False)],
          'bandens': [('band', False)],
          'bander': [('band', False)],
          'banders': [('band', False)],
          'bandet': [('band', False)],
          'bandets': [('band', True)],
          'bandon': [('bandon', False)],
          'bandons': [('bandon', False)],
          'bands': [('band', False)],
          'bands-': [('band', False)],
          'bane': [('bane', True), ('bana', True)],
          'bane-': [('bane', True), ('bana', True)],
          'banens': [('ban', False)],
          'baner': [('baner', True), ('ban', True)],
          'baners': [('ban', True), ('baner', True)],
          'banes': [('bane', True)],
          'bang': [('bang', True)],
          'bang-': [('bang', False)],
          'bangar': [('bang', False)],
          'bangarna': [('bang', True)],
          'bangarnas': [('bang', True)],
          'bangars': [('bang', True)],
          'bangen': [('bang', True)],
          'bangens': [('bang', False)],
          'banger': [('bang', False)],
          'bangerna': [('bang', False)],
          'bangernas': [('bang', False)],
          'bangers': [('bang', False)],
          'bangs': [('bang', False)],
          'bangs-': [('bang', True)],
          'banjon': [('banjo', True)],
          'banjons': [('banjo', True)],
          'banjor': [('banjo', True)],
          'banjors': [('banjo', True)],
          'bank': [('bank', False)],
          'bank-': [('bank', False)],
          'bankar': [('bank', True)],
          'bankarna': [('bank', False)],
          'bankarnas': [('bank', False)],
          'bankars': [('bank', False)],
          'banken': [('bank', False)],
          'bankens': [('bank', False)],
          'banker': [('bank', False)],
          'bankerna': [('bank', False)],
          'bankernas': [('bank', False)],
          'bankers': [('bank', False)],
          'banklagar': [('banklag', True)],
          'banklagarna': [('banklag', True)],
          'banklagarnas': [('banklag', True)],
          'banks': [('bank', False)],
          'banks-': [('bank', False)],
          'bann': [('bannor', True), ('bann', True)],
          'bann-': [('bannor', True), ('bann', True)],
          'bannen': [('bann', True)],
          'bannens': [('bann', True)],
          'banns': [('bann', True), ('bannor', True)],
          'banns-': [('bann', True), ('bannor', True)],
          'banor': [('bana', False)],
          'banorna': [('bana', False)],
          'banornas': [('bana', False)],
          'banors': [('bana', False)],
          'bans': [('bana', True), ('ban', True)],
          'bans-': [('ban', True), ('bana', True)],
          'bansk': [('banska', False)],
          'bansk-': [('banska', False)],
          'bant': [('bant', False)],
          'banten': [('bant', False)],
          'bantens': [('bant', False)],
          'banter': [('bant', False)],
          'banterna': [('bant', False)],
          'banternas': [('bant', False)],
          'banters': [('bant', False)],
          'bar': [('bar', True)],
          'bar-': [('bar', True)],
          'barans': [('bara', False)],
          'bard': [('bard', False)],
          'bard-': [('bard', False)],
          'barden': [('bard', False)],
          'bardens': [('bard', False)],
          'barder': [('bard', True)],
          'barderna': [('bard', True)],
          'bardernas': [('bard', True)],
          'barders': [('bard', True)],
          'bardin': [('bardin', False)],
          'bardins': [('bardin', False)],
          'bards': [('bard', False)],
          'bards-': [('bard', True)],
          'bare': [('bare', False)],
          'baren': [('bar', False)],
          'barens': [('bar', True)],
          'bares': [('bare', False)],
          'baret': [('baret', False)],
          'barets': [('baret', False)],
          'bargon': [('bargo', False)],
          'bargons': [('bargo', False)],
          'bargot': [('bargo', False)],
          'bargots': [('bargo', False)],
          'bari': [('bari', False)],
          'bari-': [('bari', False)],
          'barie': [('barium', False)],
          'barie-': [('barium', False)],
          'barier': [('barium', False)],
          'barierna': [('barium', False)],
          'bariernas': [('barium', False)],
          'bariers': [('barium', False)],
          'bariet': [('barium', True)],
          'bariets': [('barium', True)],
          'baris': [('bari', False)],
          'barismer': [('barism', False)],
          'barismerna': [('barism', False)],
          'barismernas': [('barism', False)],
          'barismers': [('barism', False)],
          'barit': [('bari', False)],
          'barit-': [('barit', False)],
          'bariternas': [('barit', False)],
          'bariters': [('barit', False)],
          'barits': [('bari', False)],
          'barkar': [('bark', True)],
          'barkarna': [('bark', True)],
          'barkis': [('barkis', True)],
          'barmar': [('barm', True)],
          'barmarna': [('barm', True)],
          'barmarnas': [('barm', True)],
          'barn': [('barn', False)],
          'barns': [('barn', False)],
          'barnsmoder': [('barnsmoder', False)],
          'barnsmoder-': [('barnsmoder', False)],
          'barnsmodern': [('barnsmor', False)],
          'barnsmoderns': [('barnsmor', False)],
          'barnsmoders': [('barnsmor', False)],
          'barnsmoders-': [('barnsmor', False)],
          'barnsmödrar': [('barnsmoder', False)],
          'barnsmödrarna': [('barnsmoder', False)],
          'barnsmödrarnas': [('barnsmoder', False)],
          'barnsmödrars': [('barnsmoder', False)],
          'baron-': [('baron', False)],
          'barons': [('baron', True)],
          'barr': [('barr', True)],
          'barren': [('barre', True), ('barr', True)],
          'barrens': [('barr', True), ('barre', True)],
          'barrs-': [('barr', False)],
          'bars': [('bar', True)],
          'bas': [('bas', True)],
          'bas-': [('bas', False)],
          'basar': [('basar', True), ('bas', True)],
          'basar-': [('basar', True)],
          'basaren': [('basar', False)],
          'basarens': [('basar', True)],
          'basarna': [('bas', True)],
          'basarnas': [('bas', False)],
          'basars': [('bas', True), ('basar', True)],
          'bask': [('bask', True)],
          'bask-': [('bask', True)],
          'basker': [('bask', True), ('basker', True)],
          'baskers': [('bask', True), ('basker', True)],
          'basket': [('basket', True)],
          'baskets': [('basket', True)],
          'basm': [('basm', False)],
          'basm-': [('basm', False)],
          'basmer': [('basm', False)],
          'basmerna': [('basm', False)],
          'basmernas': [('basm', False)],
          'basmers': [('basm', False)],
          'basnåret': [('basnår', False)],
          'basnårets': [('basnår', False)],
          'baspar': [('baspar', True)],
          'baspars': [('baspar', True)],
          'bass': [('basse', True)],
          'bass-': [('basse', True)],
          'bassar': [('basse', True)],
          'bassarna': [('basse', True)],
          'bassarnas': [('basse', True)],
          'bassen': [('basse', True)],
          'bassens': [('basse', True)],
          'basset': [('basset', True)],
          'bassets': [('basset', True)],
          'bast-': [('bast', True)],
          'basten': [('bast', False)],
          'bastrums': [('bastrumma', True)],
          'basvar-': [('basvara', True)],
          'batier': [('batier', False)],
          'batierna': [('batier', False)],
          'batiernas': [('batier', False)],
          'batiers': [('batier', False)],
          'bation': [('bation', False)],
          'bationen': [('bation', False)],
          'bations': [('bation', False)],
          'bator': [('bator', False)],
          'bators': [('bator', False)],
          'bats-': [('bat', False)],
          'batt': [('batt', False)],
          'batt-': [('batt', False)],
          'batten': [('batt', False)],
          'battens': [('battens', True)],
          'batter': [('batt', False)],
          'batteranden': [('batterande', False)],
          'batterandens': [('batterande', False)],
          'batters': [('batt', False)],
          'batts': [('batt', False)],
          'batts-': [('batt', False)],
          'bb': [('bb', False)],
          'bbal': [('bbal', False)],
          'bbalans': [('bbala', False)],
          'bbalar': [('bbal', False)],
          'bbalarna': [('bbal', False)],
          'bbalarnas': [('bbal', False)],
          'bbalars': [('bbal', False)],
          'bbalen': [('bbal', False)],
          'bbalens': [('bbal', False)],
          'bbals': [('bbal', False)],
          'bbals-': [('bbal', False)],
          'bban': [('bba', False)],
          'bbanden': [('bbande', False)],
          'bbandens': [('bbande', False)],
          'bbandet': [('bbande', False)],
          'bbandets': [('bbande', False)],
          'bbans': [('bba', False)],
          'bbar-': [('bbare', False)],
          'bbaren': [('bbare', False)],
          'bbarens': [('bbare', False)],
          'bbarnas': [('bb', False)],
          'bbars': [('bb', False)],
          'bbas': [('bba', False)],
          'bbas-': [('bba', False)],
          'bbe': [('bba', False)],
          'bbe-': [('bba', False)],
          'bbel': [('bbel', False)],
          'bbel-': [('bbel', False)],
          'bbels': [('bbel', False)],
          'bbels-': [('bbel', False)],
          'bbens': [('bb', False)],
          'bberiernas': [('bberi', False)],
          'bberiers': [('bberi', False)],
          'bbet': [('bb', False)],
          'bbets': [('bb', False)],
          'bbevis': [('bbevisa', False)],
          'bbevis-': [('bbevisa', False)],
          'bbier': [('bbi', False)],
          'bbierna': [('bby', False)],
          'bbiernas': [('bby', False)],
          'bbiers': [('bby', False)],
          'bbiner': [('bbin', False)],
          'bbinerna': [('bbin', False)],
          'bbinernas': [('bbin', False)],
          'bbiners': [('bbin', False)],
          'bbing': [('bbing', False)],
          'bbing-': [('bbing', False)],
          'bbingen': [('bbing', False)],
          'bbingens': [('bbing', False)],
          'bbings': [('bbing', False)],
          'bbis-': [('bbis', False)],
          'bbitar': [('bbitare', False)],
          'bbitarna': [('bbitare', False)],
          'bbitarnas': [('bbitare', False)],
          'bble': [('bble', False)],
          'bbleke': [('bbleka', False)],
          'bbleke-': [('bbleka', False)],
          'bblen': [('bbel', False)],
          'bblens': [('bbel', False)],
          'bbler': [('bbler', False)],
          'bblerna': [('bbler', False)],
          'bblers': [('bbler', False)],
          'bblet': [('bble', False)],
          'bblets': [('bble', False)],
          'bblänkar': [('bblänk', False)],
          'bblänkarna': [('bblänk', False)],
          'bblänkarnas': [('bblänk', False)],
          'bblänken': [('bblänk', False)],
          'bblänkens': [('bblänk', False)],
          'bblänks': [('bblänk', False)],
          'bblänks-': [('bblänk', False)],
          'bbläsar': [('bbläsare', False)],
          'bbläsarna': [('bbläsare', False)],
          'bbläsarnas': [('bbläsare', False)],
          'bblån': [('bblån', False)],
          'bbolet': [('bbolet', False)],
          'bbolets': [('bbolet', False)],
          'bbon': [('bbon', False)],
          'bbons': [('bbon', False)],
          'bbor': [('bba', False)],
          'bborna': [('bba', False)],
          'bbornas': [('bba', False)],
          'bborr': [('bborre', False)],
          'bborr-': [('bborre', False)],
          'bborrar': [('bborre', False)],
          'bborrarna': [('bborre', False)],
          'bborrarnas': [('bborre', False)],
          'bborrars': [('bborre', False)],
          'bborren': [('bborre', False)],
          'bborrens': [('bborre', False)],
          'bborrs': [('bborre', False)],
          'bborrs-': [('bborre', False)],
          'bbors': [('bba', False)],
          'bbot': [('bbot', False)],
          'bbots': [('bbot', False)],
          'bbranden': [('bbrande', False)],
          'bbrandens': [('bbrande', False)],
          'bbras': [('bbras', False)],
          'bbras-': [('bbras', False)],
          'bbrons': [('bbro', False)],
          'bbränne': [('bbränna', False)],
          'bbränne-': [('bbränna', False)],
          'bbs': [('bb', False)],
          'bbs-': [('bb', False)],
          'bbyerna': [('bby', False)],
          'bc': [('bc', False)],
          'bc-': [('bc', False)],
          'bdagar': [('bdag', False)],
          'bdagars': [('bdag', False)],
          'bdagen': [('bdag', False)],
          'bdagens': [('bdag', False)],
          'bdags': [('bdag', False)],
          'bdags-': [('bdag', False)],
          'bdan': [('bda', False)],
          'bdana': [('bda', False)],
          'bdanas': [('bda', False)],
          'bdans': [('bda', False)],
          'bdat': [('bda', False)],
          'bdats': [('bda', False)],
          'bden': [('bden', False)],
          'bdens': [('bden', False)],
          'bdocks': [('bdocka', False)],
          'bdocks-': [('bdocka', False)],
          'bdomen': [('bdomen', False)],
          'bdomens': [('bdomen', False)],
          'bdomina': [('bdomen', False)],
          'bdominas': [('bdomen', False)],
          'be': [('be', False)],
          'be-': [('be', False)],
          'beans': [('bea', True)],
          'beck': [('beck', False)],
          'beck-': [('beck', True)],
          'becks': [('beck', True)],
          'becks-': [('beck', True)],
          'bedjan': [('bedjan', False)],
          'bedjans': [('bedjan', False)],
          'beens': [('bee', False)],
          'befordran': [('befordran', False)],
          'befordringar': [('befordring', True), ('befordran', True)],
          'befordringarna': [('befordran', True), ('befordring', True)],
          'befordringarnas': [('befordring', True), ('befordran', True)],
          'befordringars': [('befordring', True), ('befordran', True)],
          'begärans': [('begäran', False)],
          'behandlar': [('behandlare', False)],
          'behandlarnas': [('behandlare', False)],
          'beivrarnas': [('beivrare', True)],
          'bek': [('bek', False)],
          'bek-': [('bek', False)],
          'beker': [('bek', False)],
          'bekers': [('bek', False)],
          'beks': [('bek', False)],
          'belgångar': [('belgångare', False)],
          'belgångarna': [('belgångare', False)],
          'belhake': [('belhaka', False)],
          'belie-': [('belia', False)],
          'belis-': [('belia', False)],
          'belisk': [('belisk', False)],
          'belisk-': [('belisk', False)],
          'belkammar': [('belkammare', False)],
          'bell': [('bell', False)],
          'bell-': [('bell', False)],
          'bellan': [('bella', False)],
          'belle': [('bella', False)],
          'belle-': [('bella', False)],
          'bellen': [('bell', False)],
          'beller': [('bell', False)],
          'bellerna': [('bell', False)],
          'bellernas': [('bell', False)],
          'bellers': [('bell', False)],
          'bellis': [('bellis', True)],
          'bellor': [('bella', False)],
          'bellorna': [('bella', False)],
          'bellornas': [('bella', False)],
          'bellors': [('bella', False)],
          'bells': [('bell', False)],
          'bells-': [('bell', False)],
          'bels': [('brer', False)],
          'bels-': [('brer', False)],
          'belskor': [('belsko', False)],
          'belskorna': [('belsko', False)],
          'belskornas': [('belsko', False)],
          'belskors': [('belsko', False)],
          'belvind': [('belvinda', False)],
          'beläts': [('beläte', True)],
          'bemang': [('bemang', False)],
          'bemang-': [('bemang', False)],
          'bemangs': [('bemang', False)],
          'bemangs-': [('bemang', False)],
          'ben': [('bena', True), ('ben', True)],
          'ben-': [('ben', True), ('bena', True)],
          'bena': [('bena', True)],
          'benans': [('bena', True)],
          'benas': [('bena', False)],
          'bendets': [('bende', False)],
          'bene': [('bena', False)],
          'bene-': [('bena', False)],
          'benet': [('ben', False)],
          'benets': [('ben', False)],
          'benklädes-': [('benkläder', True)],
          'benknäckarna': [('benknäckare', True)],
          'benknäckarnas': [('benknäckare', True)],
          'bens': [('bena', True), ('ben', True)],
          'bens-': [('ben', True), ('bena', True)],
          'bensens': [('bensen', True)],
          'benskens': [('benskena', True)],
          'bent': [('bent', False)],
          'benten': [('bent', False)],
          'bentens': [('bent', False)],
          'benter': [('bent', False)],
          'benterna': [('bent', False)],
          'benternas': [('bent', False)],
          'benters': [('bent', False)],
          'bents-': [('bent', False)],
          'beor': [('bea', True)],
          'beorna': [('bea', True)],
          'beornas': [('bea', True)],
          'beors': [('bea', True)],
          'ber': [('ber', False)],
          'ber-': [('ber', False)],
          'berans': [('berans', False)],
          'berare': [('berare', False)],
          'berares': [('berare', False)],
          'berarna': [('berare', False)],
          'berarnas': [('berare', False)],
          'bergen': [('berg', True)],
          'bergens': [('berg', False)],
          'bergis': [('bergis', True)],
          'bergslager': [('bergslag', True), ('bergslager', True)],
          'bergslagerna': [('bergslager', True), ('bergslag', True)],
          'bergslagernas': [('bergslag', True), ('bergslager', True)],
          'bergslagers': [('bergslag', True), ('bergslager', True)],
          'beri': [('beri', False)],
          'beri-': [('beri', False)],
          'berian': [('berian', False)],
          'berians': [('berian', False)],
          'berier': [('beri', False)],
          'berierna': [('beri', False)],
          'beriernas': [('berier', False)],
          'beriers': [('berier', False)],
          'beriet': [('beri', False)],
          'berins': [('beri', False)],
          'beris': [('beri', False)],
          'beris-': [('beri', False)],
          'berisen': [('beris', False)],
          'berisens': [('beris', False)],
          'berit': [('beri', False)],
          'beron': [('bero', False)],
          'berons': [('bero', False)],
          'beror': [('bero', False)],
          'berorna': [('bero', False)],
          'berornas': [('bero', False)],
          'berors': [('bero', False)],
          'beros': [('bero', False)],
          'beros-': [('bero', False)],
          'bers': [('ber', False)],
          'bers-': [('ber', False)],
          'berstens': [('bersten', False)],
          'bertens': [('bert', False)],
          'bertets': [('bertet', False)],
          'bertin-': [('bertin', False)],
          'bertinens': [('bertin', False)],
          'bertins': [('bertin', False)],
          'berts': [('bert', False)],
          'berts-': [('bert', False)],
          'bes': [('be', False)],
          'bes-': [('be', False)],
          'beskeden': [('besked', False)],
          'beskedet': [('besked', False)],
          'beskärmarna': [('beskärmare', True)],
          'beskärmarnas': [('beskärmare', True)],
          'best-': [('best', False)],
          'bestar': [('best', True)],
          'bestarna': [('best', True)],
          'bet': [('beta', True), ('bete', True), ('bet', True)],
          'bet-': [('bete', True), ('beta', True), ('bet', True)],
          'beta': [('beta', True)],
          'betan': [('beta', False)],
          'betanas': [('beta', True)],
          'betans': [('beta', False)],
          'betar': [('bet', True), ('bete', True)],
          'betarna': [('bet', True), ('bete', True)],
          'betarnas': [('bet', True), ('bete', True)],
          'betars': [('bet', True), ('bete', True)],
          'betas': [('beta', False)],
          'betat': [('beta', True)],
          'bete': [('beta', True), ('bete', True)],
          'bete-': [('beta', True)],
          'beten': [('bet', True), ('bete', True)],
          'betens': [('bet', True), ('bete', True)],
          'beter': [('bet', False)],
          'beters': [('bet', False)],
          'betes': [('bete', False)],
          'betes-': [('bete', False)],
          'betet': [('bete', False)],
          'betets': [('bete', True)],
          'betikernas': [('betiker', False)],
          'betikers': [('betiker', False)],
          'bets': [('bet', True), ('bets', True), ('beta', True), ('bete', True)],
          'bets-': [('bet', True), ('bete', True), ('beta', True), ('bets', True)],
          'betsbasar': [('betsbas', False)],
          'betsbasars': [('betsbas', False)],
          'betsen': [('bets', True)],
          'betsens': [('bets', True)],
          'bett': [('bett', False)],
          'bett-': [('bett', True)],
          'betten': [('bett', False)],
          'bettlandets': [('bettlande', True)],
          'bettlar': [('bettel', True), ('bettlare', True)],
          'bettlarna': [('bettel', True), ('bettlare', True)],
          'bettlarnas': [('bettel', True), ('bettlare', True)],
          'betts': [('bett', False)],
          'betts-': [('bett', False)],
          'bevis': [('bevis', True)],
          'bevis-': [('bevis', True)],
          'bevisas': [('bevisa', False)],
          'bevisors': [('bevisa', False)],
          'bfasonernas': [('bfason', False)],
          'bfasoners': [('bfason', False)],
          'bfläck': [('bfläck', False)],
          'bfoton': [('bfoto', False)],
          'bfotons': [('bfoto', False)],
          'bh-': [('bh', True)],
          'bhar': [('bh', True)],
          'bharna': [('bh', True)],
          'bhars': [('bh', True)],
          'bhen': [('bh', True)],
          'bhens': [('bh', True)],
          'bheter': [('bhet', False)],
          'bheterna': [('bhet', False)],
          'bheternas': [('bhet', False)],
          'bheters': [('bhet', False)],
          'bhets': [('bhet', False)],
          'bhets-': [('bhet', False)],
          'bhns': [('bh', True)],
          'bhus': [('bhus', False)],
          'bi': [('bi', False)],
          'bi-': [('bi', False)],
          'bialen': [('bial', False)],
          'bialens': [('bial', False)],
          'bialet': [('bial', False)],
          'bialets': [('bial', False)],
          'bian': [('bian', False)],
          'bian-': [('bian', False)],
          'bians': [('bian', False)],
          'bias': [('bias', True)],
          'bias-': [('bias', True)],
          'bidan': [('bidan', True)],
          'bidans': [('bidan', True)],
          'biden': [('bid', False)],
          'bidens': [('bid', False)],
          'bidon': [('bido', False)],
          'bidons': [('bido', False)],
          'bidos': [('bido', False)],
          'bidots': [('bido', False)],
          'bids': [('bid', False)],
          'bie': [('bier', False)],
          'bie-': [('bier', False)],
          'bien': [('bi', True)],
          'biens': [('bi', False)],
          'bier': [('bier', False)],
          'bierna': [('bi', False)],
          'biernas': [('bi', False)],
          'biers': [('bi', False)],
          'bies': [('by', False)],
          'bies-': [('bies', False)],
          'biesen': [('bies', False)],
          'biesens': [('bies', False)],
          'biet': [('bi', True)],
          'biets': [('bi', True)],
          'biffar': [('biff', False)],
          'biffarna': [('biff', True)],
          'biffen': [('biff', False)],
          'bigat': [('bigata', True)],
          'bigat-': [('bigata', True)],
          'bigator': [('bigata', True)],
          'bigators': [('bigata', True)],
          'bigens': [('bigens', False)],
          'bigens-': [('bigens', False)],
          'bigge': [('bigga', False)],
          'bigheter': [('bighet', False)],
          'bigheterna': [('bighet', False)],
          'bigheternas': [('bighet', False)],
          'bigheters': [('bighet', False)],
          'bighets-': [('bighet', False)],
          'bikarnas': [('bik', False)],
          'bikten': [('bikt', True)],
          'biktens': [('bikt', True)],
          'bikts': [('bikt', True)],
          'bikts-': [('bikt', True)],
          'bil': [('bil', True), ('bila', True)],
          'bil-': [('bila', True), ('bil', True)],
          'bilandet': [('biland', True), ('bilande', True)],
          'bilandets': [('bilande', True), ('biland', True)],
          'bilar': [('bil', True)],
          'bilaren': [('bilar', False)],
          'bilars': [('bil', True)],
          'bild': [('bild', False)],
          'bild-': [('bild', True)],
          'bildanden': [('bildande', True)],
          'bildandens': [('bildande', False)],
          'bildar': [('bildare', False)],
          'bildarna': [('bildare', False)],
          'bilden': [('bild', False)],
          'bildens': [('bild', False)],
          'bilds': [('bild', False)],
          'bilds-': [('bild', False)],
          'bileers': [('bileum', False)],
          'bili': [('bilier', False)],
          'bili-': [('bilier', False)],
          'bilie-': [('bilier', False)],
          'bilierna': [('bilier', False)],
          'biliernas': [('bilier', False)],
          'bilister': [('bilist', True)],
          'bilisters': [('bilist', True)],
          'bill': [('billa', True), ('bill', True)],
          'bill-': [('billa', True), ('bill', True)],
          'billan': [('billa', True)],
          'billar': [('bill', False)],
          'billars': [('bill', False)],
          'bille': [('billa', True)],
          'bille-': [('billa', True)],
          'billen': [('bill', False)],
          'biller': [('bill', True)],
          'billerna': [('bill', True)],
          'billernas': [('bill', True)],
          'billers': [('bill', True)],
          'billor': [('billa', False)],
          'billorna': [('billa', False)],
          'billornas': [('billa', False)],
          'billors': [('billa', True)],
          'bills': [('billa', True), ('bill', True)],
          'bills-': [('billa', True), ('bill', True)],
          'bils': [('bil', True), ('bila', True)],
          'bils-': [('bil', True), ('bila', True)],
          'bimbors': [('bimbo', True)],
          'bimån': [('bimåne', True)],
          'bin': [('bi', True)],
          'bina': [('bi', False)],
          'binas': [('bi', False)],
          'binats-': [('binat', False)],
          'bind': [('bind', True), ('binda', True)],
          'bind-': [('bind', True), ('binda', True)],
          'bindarnas': [('bindare', False)],
          'bindlar': [('bindel', True)],
          'bindlarna': [('bindel', False)],
          'bindlarnas': [('bindel', False)],
          'binds': [('bind', True), ('binda', True)],
          'binds-': [('bind', True), ('binda', True)],
          'bindslen': [('bindsel', True), ('bindsle', True)],
          'bindslens': [('bindsel', True), ('bindsle', True)],
          'bindslet': [('bindsle', True), ('bindsel', True)],
          'bindslets': [('bindsle', True), ('bindsel', True)],
          'biner': [('bino', False)],
          'binerna': [('bino', False)],
          'binernas': [('bino', False)],
          'biners': [('bino', False)],
          'binets': [('bin', False)],
          'bing': [('binga', True), ('binge', True)],
          'bing-': [('binge', True), ('binga', True)],
          'bingar': [('binge', True)],
          'bingarnas': [('binge', True)],
          'binge': [('binga', True), ('binge', True)],
          'binge-': [('binga', True)],
          'bingel': [('bingel', True)],
          'bingel-': [('bingel', True)],
          'bingen': [('binge', True)],
          'bingens': [('binge', True)],
          'binglar': [('bingel', True)],
          'binglarna': [('bingel', True)],
          'binglarnas': [('bingel', True)],
          'bingor': [('binga', True)],
          'bingorna': [('binga', True)],
          'bings': [('binga', True), ('binge', True)],
          'bings-': [('binge', True), ('binga', True)],
          'bink': [('binka', True)],
          'bink-': [('binka', True)],
          'binks': [('binka', True)],
          'binks-': [('binka', True)],
          'binons': [('bino', False)],
          'binos': [('bino', False)],
          'bins': [('bi', False)],
          'bint': [('bint', False)],
          'binter': [('bint', False)],
          'binterna': [('bint', False)],
          'binternas': [('bint', False)],
          'binters': [('bint', False)],
          'bints-': [('bint', False)],
          'bions': [('bio', True)],
          'bior': [('bia', False)],
          'biorna': [('bia', False)],
          'biornas': [('bia', False)],
          'biors': [('bia', False)],
          'bios': [('bio', True)],
          'bios-': [('bios', False)],
          'biosen': [('bios', False)],
          'biosens': [('bios', False)],
          'biplanet': [('biplan', True), ('biplanet', True)],
          'biplanets': [('biplanet', True), ('biplan', True)],
          'bir': [('bira', True), ('bir', True)],
          'bir-': [('bira', True), ('bir', True)],
          'biroller': [('biroll', True)],
          'birollers': [('biroll', True)],
          'birot': [('birot', True)],
          'birots': [('birot', True)],
          'birr': [('birr', False)],
          'birr-': [('birr', False)],
          'birren': [('birr', False)],
          'birrens': [('birr', False)],
          'birrs-': [('birr', False)],
          'birs': [('bira', True), ('bir', True)],
          'birs-': [('bira', True), ('bir', True)],
          'bis': [('bi', False)],
          'bis-': [('bia', False)],
          'biskan': [('biska', False)],
          'biskans': [('biska', False)],
          'biske': [('biska', False)],
          'biske-': [('biska', False)],
          'biskvin': [('biskvi', True)],
          'biskvins': [('biskvi', True)],
          'bismerna': [('bism', False)],
          'bismernas': [('bism', False)],
          'bisp': [('bisp', True)],
          'bisp-': [('bisp', True)],
          'bispar': [('bisp', True)],
          'bisparna': [('bisp', True)],
          'bispars': [('bisp', True)],
          'bispens': [('bisp', True)],
          'bissarna': [('bisse', False)],
          'bissarnas': [('bisse', False)],
          'bist-': [('bist', False)],
          'bisten': [('bist', False)],
          'bistens': [('bist', False)],
          'bister': [('bister', True)],
          'bisterna': [('bist', False)],
          'bisternas': [('bist', False)],
          'bisters': [('bister', True)],
          'bistron': [('bistro', True)],
          'bistrons': [('bistro', True)],
          'bit': [('bi', True), ('bit', True)],
          'bitaler': [('bital', False)],
          'bitalerna': [('bital', False)],
          'bitalernas': [('bital', False)],
          'bitalers': [('bital', False)],
          'bitar': [('bit', True)],
          'bitar-': [('bitare', False)],
          'bitarens': [('bitare', False)],
          'bitarna': [('bit', True)],
          'bitarnas': [('bit', False)],
          'bitars': [('bit', True)],
          'biterierna': [('biteri', False)],
          'biteriers': [('biteri', False)],
          'biteriet': [('biteri', False)],
          'biternas': [('bit', False)],
          'bitet': [('bit', False)],
          'bitets': [('bit', False)],
          'bitor': [('bitor', False)],
          'bitors': [('bitor', False)],
          'bits': [('bits', True), ('bit', True), ('bi', True)],
          'bits-': [('bit', True), ('bits', True)],
          'bitsar': [('bits', False)],
          'bitsarna': [('bits', False)],
          'bitsen': [('bits', False)],
          'bitsens': [('bits', False)],
          'bium': [('bium', False)],
          'biums': [('bium', False)],
          'bivalens': [('bivalens', False)],
          'bjack': [('bjacka', False)],
          'bjack-': [('bjacka', False)],
          'bjacks': [('bjacka', False)],
          'bjacks-': [('bjacka', False)],
          'bjudar': [('bjudare', False)],
          'bjudarna': [('bjudare', False)],
          'bjudarnas': [('bjudare', False)],
          'bjälk': [('bjälke', False)],
          'bjälk-': [('bjälke', False)],
          'bjälkar': [('bjälke', True)],
          'bjälkarna': [('bjälke', False)],
          'bjälkars': [('bjälke', True)],
          'bjälken': [('bjälke', False)],
          'bjälkens': [('bjälke', False)],
          'bjälks': [('bjälke', False)],
          'bjälks-': [('bjälke', False)],
          'bjälle': [('bjälle', False)],
          'bjälle-': [('bjälle', False)],
          'bjället': [('bjälle', False)],
          'bjällets': [('bjälle', False)],
          'bjäss': [('bjässe', False)],
          'bjäss-': [('bjässe', False)],
          'bjässe': [('bjässe', False)],
          'bjässe-': [('bjässe', True)],
          'bjävlarna': [('bjävel', False)],
          'bjävlarnas': [('bjävel', False)],
          'bjävlars': [('bjävel', False)],
          'björnbindslen': [('björnbindsel', True), ('björnbindsle', True)],
          'björnbindslens': [('björnbindsel', True), ('björnbindsle', True)],
          'björnbindslet': [('björnbindsle', True), ('björnbindsel', True)],
          'björnbindslets': [('björnbindsel', True), ('björnbindsle', True)],
          'bkasse': [('bkassa', False)],
          'bkikarnas': [('bkikare', False)],
          'bkist-': [('bkista', False)],
          'bkistan': [('bkista', False)],
          'bkistans': [('bkista', False)],
          'bkurs': [('bkurs', False)],
          'bkurs-': [('bkurs', False)],
          'bköks': [('bkök', False)],
          'bköks-': [('bkök', False)],
          'black': [('black', True)],
          'black-': [('black', True)],
          'blackarnas': [('black', True)],
          'blacks': [('black', True)],
          'blacks-': [('black', True)],
          'blad': [('blad', False)],
          'blad-': [('blad', True)],
          'blads': [('blad', False)],
          'blads-': [('blad', False)],
          'blaff': [('blaffa', True)],
          'blaff-': [('blaffa', True)],
          'blaffs': [('blaffa', True)],
          'blaffs-': [('blaffa', True)],
          'blam': [('blam', True)],
          'blam-': [('blam', True)],
          'blamen': [('blam', True)],
          'blamens': [('blam', True)],
          'blamer': [('blam', True)],
          'blamerna': [('blam', True)],
          'blamernas': [('blam', True)],
          'blamers': [('blam', True)],
          'blams': [('blam', True)],
          'blams-': [('blam', True)],
          'blan': [('bla', False)],
          'blanden': [('blande', False)],
          'blandena': [('blande', False)],
          'blandenas': [('blande', False)],
          'blandens': [('blande', False)],
          'blandet': [('blande', False)],
          'blandets': [('blande', False)],
          'blans': [('bla', False)],
          'blaren': [('blare', False)],
          'blask': [('blaska', True), ('blask', True)],
          'blask-': [('blaska', True), ('blask', True)],
          'blat': [('blat', False)],
          'blat-': [('blat', False)],
          'blaten': [('blat', False)],
          'blatens': [('blat', False)],
          'blater': [('blat', False)],
          'blaterna': [('blat', False)],
          'blaternas': [('blat', False)],
          'blaters': [('blat', False)],
          'blats': [('blat', False)],
          'blats-': [('blat', False)],
          'blatte': [('blatte', True)],
          'blatte-': [('blatte', True)],
          'ble-': [('bla', False)],
          'bleke': [('bleke', True)],
          'bleke-': [('bleke', True)],
          'bleken': [('bleke', True)],
          'blekens': [('bleke', True)],
          'blem': [('blemma', False)],
          'blem-': [('blemma', True)],
          'blemet': [('blem', False)],
          'blemets': [('blem', False)],
          'blems': [('blemma', False)],
          'blems-': [('blemma', False)],
          'blen': [('ble', False)],
          'blens': [('ble', False)],
          'bler': [('bel', False)],
          'bler-': [('bler', False)],
          'blerna': [('bel', False)],
          'blernas': [('bler', False)],
          'blers': [('bel', False)],
          'blers-': [('bler', False)],
          'blessen': [('blesse', False)],
          'blessens': [('bless', False)],
          'blesser': [('blesse', False)],
          'blesserna': [('blesse', False)],
          'blessernas': [('blesse', False)],
          'blessers': [('blesse', False)],
          'blet': [('bel', False)],
          'blets': [('bel', False)],
          'blettens': [('blett', False)],
          'blick': [('blick', False)],
          'blickarnas': [('blick', False)],
          'blid': [('blida', True)],
          'blid-': [('blida', True)],
          'blids': [('blida', True)],
          'blids-': [('blida', True)],
          'blighets': [('blighet', False)],
          'blik': [('blik', False)],
          'blik-': [('blik', False)],
          'blikan': [('blikan', False)],
          'blikans': [('blikan', False)],
          'bliken': [('blik', False)],
          'blikens': [('blik', False)],
          'bliker': [('blik', False)],
          'blikerna': [('blik', False)],
          'blikernas': [('blik', False)],
          'blikers': [('blik', False)],
          'bliks': [('blik', False)],
          'bliks-': [('blik', False)],
          'blindans': [('blinda', True)],
          'blingets': [('bling', True)],
          'blink-': [('blink', True)],
          'blinks': [('blink', True)],
          'blinks-': [('blink', True)],
          'blip': [('blip', True)],
          'blip-': [('blip', True)],
          'blipar': [('blip', True)],
          'bliparna': [('blip', True)],
          'blipparnas': [('blipp', True)],
          'blips': [('blip', True)],
          'blips-': [('blip', True)],
          'blivs': [('bliv', False)],
          'blivs-': [('bliv', False)],
          'block': [('block', False)],
          'blockalmanack': [('blockalmanacka', True), ('blockalmanack', True)],
          'blockalmanacks': [('blockalmanacka', True), ('blockalmanack', True)],
          'blockalmanacks-': [('blockalmanacka', True), ('blockalmanack', True)],
          'bloden': [('blod', False)],
          'blodens': [('blod', False)],
          'blog': [('blog', True)],
          'blog-': [('blog', True)],
          'blogar': [('blog', True), ('blogare', True)],
          'blogarna': [('blog', True), ('blogare', True)],
          'blogarnas': [('blogare', True), ('blog', True)],
          'blogars': [('blog', True)],
          'blogen': [('blog', True)],
          'blogens': [('blog', True)],
          'bloggar': [('bloggare', True), ('blogg', True)],
          'bloggarna': [('blogg', True), ('bloggare', True)],
          'bloggarnas': [('blogg', True), ('bloggare', True)],
          'blogs': [('blog', True)],
          'blogs-': [('blog', True)],
          'blom': [('blomma', True), ('blom', True)],
          'blom-': [('blomma', True), ('blom', True)],
          'blomme': [('blomma', False)],
          'blomme-': [('blomma', False)],
          'blommen': [('blom', True)],
          'blommens': [('blom', False)],
          'bloms': [('blomma', True), ('blom', True)],
          'bloms-': [('blomma', True), ('blom', True)],
          'blomsterhandlar': [('blomsterhandel', True), ('blomsterhandlare', True)],
          'blomsterhandlarna': [('blomsterhandel', True), ('blomsterhandlare', True)],
          'blomsterhandlarnas': [('blomsterhandel', True), ('blomsterhandlare', True)],
          'blon': [('blon', False)],
          'blonen': [('blon', False)],
          'blonens': [('blon', False)],
          'bloner': [('blon', False)],
          'blonerna': [('blon', False)],
          'blonernas': [('blon', False)],
          'bloners': [('blon', False)],
          'blons': [('blon', False)],
          'blor': [('bla', False)],
          'blorna': [('bla', False)],
          'blornas': [('bla', False)],
          'blors': [('bla', False)],
          'blots': [('blot', True)],
          'blots-': [('blot', False)],
          'blott': [('blotta', True)],
          'blott-': [('blotta', True)],
          'blottar': [('blottare', True)],
          'blottarna': [('blottare', True)],
          'blotts': [('blotta', True)],
          'blotts-': [('blotta', True)],
          'bls': [('ble', False)],
          'bls-': [('ble', False)],
          'bluffar': [('bluff', False)],
          'bluffarna': [('bluff', False)],
          'bluffarnas': [('bluff', False)],
          'blunder': [('blunder', True)],
          'blunders': [('blunder', True)],
          'blundrarnas': [('blunder', False)],
          'blys': [('bly', True)],
          'bläck': [('bläcka', True), ('bläck', True)],
          'bläck-': [('bläcka', True), ('bläck', True)],
          'bläcks': [('bläcka', True), ('bläck', True)],
          'bläcks-': [('bläcka', True), ('bläck', True)],
          'bländar': [('bländare', True)],
          'bländarna': [('bländare', False)],
          'blände': [('blände', False)],
          'bländen': [('blände', True)],
          'bländens': [('blände', True)],
          'bländer': [('bland', False)],
          'bländerna': [('bland', False)],
          'bländernas': [('bland', False)],
          'bländers': [('bland', False)],
          'bläng': [('bläng', True)],
          'bläng-': [('bläng', True)],
          'blängar': [('bläng', True)],
          'blängarna': [('bläng', True)],
          'blängarnas': [('bläng', True)],
          'blängs': [('bläng', True)],
          'blängs-': [('bläng', True)],
          'blänkar': [('blänkare', True), ('blänk', True)],
          'blänkarna': [('blänkare', True), ('blänk', True)],
          'blänkarnas': [('blänkare', True), ('blänk', True)],
          'blänken': [('blänke', True), ('blänk', True)],
          'blänkens': [('blänke', True), ('blänk', True)],
          'blänket': [('blänke', True), ('blänk', True)],
          'blänkets': [('blänk', True), ('blänke', True)],
          'blänks': [('blänke', True), ('blänk', True)],
          'blänks-': [('blänke', True), ('blänk', True)],
          'bläs': [('bläs', True)],
          'bläs-': [('bläs', True)],
          'bläsanden': [('bläsand', True)],
          'bläsandens': [('bläsand', True)],
          'bläsar': [('bläs', True)],
          'bläsarna': [('bläs', True)],
          'bläsarnas': [('bläs', True)],
          'bläster': [('bläster', False)],
          'blästers': [('bläster', True)],
          'blån': [('blå', False)],
          'blåns': [('blån', False)],
          'blåns-': [('blån', False)],
          'blås': [('blåsa', False)],
          'blås-': [('blåsa', False)],
          'blåsar': [('blåsare', False)],
          'blåsarna': [('blåsare', True)],
          'blåsarnas': [('blåsare', False)],
          'blöje': [('blöja', True)],
          'blöje-': [('blöja', True)],
          'blöt': [('blöta', False)],
          'blöt-': [('blöta', False)],
          'blöte': [('blöta', False)],
          'blöts': [('blöta', False)],
          'blöts-': [('blöta', False)],
          'bman': [('bman', False)],
          'bmannens': [('bman', False)],
          'bmat': [('bmat', False)],
          'bmatt': [('bmatta', False)],
          'bmatt-': [('bmatta', False)],
          'bmatte': [('bmatta', False)],
          'bmatte-': [('bmatta', False)],
          'bmatts': [('bmatta', False)],
          'bmatts-': [('bmatta', False)],
          'bmus': [('bmus', False)],
          'bmäns': [('bman', False)],
          'bmöss': [('bmus', False)],
          'bnosen': [('bnos', False)],
          'bnudel': [('bnudlar', False)],
          'bnudel-': [('bnudlar', False)],
          'bnudels': [('bnudlar', False)],
          'bnudels-': [('bnudlar', False)],
          'bnudlar': [('bnudlar', False)],
          'bnudlarna': [('bnudlar', False)],
          'bnudlarnas': [('bnudlar', False)],
          'bnudlars': [('bnudlar', False)],
          'bnäs': [('bnäsa', False)],
          'bnäs-': [('bnäsa', False)],
          'bnäv': [('bnäve', False)],
          'bnäv-': [('bnäve', False)],
          'bnäve': [('bnäve', False)],
          'bnävs': [('bnäve', False)],
          'bnävs-': [('bnäve', False)],
          'bo': [('bo', False)],
          'boas': [('boa', True)],
          'bobar': [('bob', True)],
          'bobb': [('bobba', True), ('bobb', True)],
          'bobb-': [('bobba', True), ('bobb', True)],
          'bobbar': [('bobb', True)],
          'bobbarna': [('bobb', True)],
          'bobbarnas': [('bobb', True)],
          'bobbars': [('bobb', True)],
          'bobbe': [('bobba', True)],
          'bobbens': [('bobb', True)],
          'bobbs': [('bobb', True), ('bobba', True)],
          'bobbs-': [('bobb', True), ('bobba', True)],
          'bobin': [('bobin', True)],
          'bock-': [('bock', False)],
          'bockar': [('bock', True)],
          'bockarna': [('bock', False)],
          'bocken': [('bock', False)],
          'bockens': [('bock', False)],
          'bockers': [('bockers', False)],
          'bocks': [('bock', False)],
          'bocks-': [('bock', False)],
          'boden': [('bod', False)],
          'bodens': [('bod', False)],
          'bods': [('bod', False)],
          'bods-': [('bod', False)],
          'boen': [('bo', False)],
          'boens': [('bo', False)],
          'boer': [('boer', True)],
          'boerna': [('boer', True)],
          'boernas': [('boer', True)],
          'boers': [('boer', True)],
          'boet': [('bo', False)],
          'boj': [('boja', True), ('boj', True)],
          'boj-': [('boj', True), ('boja', True)],
          'bojan': [('boja', False)],
          'bojans': [('boja', False)],
          'bojar': [('bojar', True), ('boj', True)],
          'bojaren': [('bojar', True)],
          'bojars': [('bojar', True), ('boj', True)],
          'bojet': [('bojet', False)],
          'bojs': [('boj', True), ('boja', True)],
          'bojs-': [('boja', True), ('boj', True)],
          'bokarnas': [('bok', False)],
          'boke': [('boke', True)],
          'boke-': [('boke', True)],
          'boket': [('boke', True)],
          'bokets': [('boke', True)],
          'bokhandlar': [('bokhandlare', True), ('bokhandel', True)],
          'bokhandlarna': [('bokhandlare', True), ('bokhandel', True)],
          'bokhandlarnas': [('bokhandlare', True), ('bokhandel', True)],
          'bol': [('bol', True)],
          'bol-': [('bol', True)],
          'bolaget': [('bolag', True)],
          'bolagets': [('bolag', False)],
          'bolar': [('bolare', True)],
          'bolar-': [('bolare', True)],
          'bolarens': [('bolare', True)],
          'bolarna': [('bolare', True)],
          'bolarnas': [('bolare', True)],
          'bolen': [('bol', True)],
          'bolens': [('bol', True)],
          'boles': [('bole', False)],
          'bolet': [('bol', True)],
          'bolets': [('bol', True)],
          'boli': [('boli', False)],
          'bolien': [('boli', False)],
          'boliens': [('boli', False)],
          'bolier': [('boli', False)],
          'bolierna': [('boli', False)],
          'boliernas': [('boli', False)],
          'boliers': [('boli', False)],
          'bolin': [('bolin', True)],
          'bolins': [('bolin', True)],
          'bolis': [('boli', False)],
          'boll': [('boll', False)],
          'boll-': [('boll', True)],
          'bollar': [('boll', False)],
          'bollarna': [('boll', False)],
          'bollarnas': [('boll', False)],
          'bollars': [('boll', False)],
          'bollen': [('boll', False)],
          'bollens': [('boll', False)],
          'bolls': [('boll', False)],
          'bolls-': [('boll', False)],
          'bols': [('bol', True)],
          'bols-': [('bol', True)],
          'bolt-': [('bolt', False)],
          'bolts': [('bolt', False)],
          'bomb': [('bomber', True), ('bomb', True)],
          'bomb-': [('bomb', True), ('bomber', True)],
          'bomben': [('bomb', False)],
          'bombens': [('bomb', False)],
          'bomber': [('bomber', True), ('bomb', True)],
          'bomberna': [('bomber', True), ('bomb', True)],
          'bombernas': [('bomber', True), ('bomb', True)],
          'bombers': [('bomber', True), ('bomb', True)],
          'bombs': [('bomber', True), ('bomb', True)],
          'bombs-': [('bomber', True), ('bomb', True)],
          'bomen': [('bom', False)],
          'bomens': [('bom', False)],
          'bommarna': [('bom', True)],
          'boms': [('bom', False)],
          'boms-': [('bom', False)],
          'bon': [('bo', False)],
          'bon-': [('bon', False)],
          'bona': [('bo', False)],
          'bonas': [('bo', False)],
          'bond': [('bonde', True)],
          'bond-': [('bonde', True)],
          'bonden': [('bonde', True)],
          'bondens': [('bonde', True)],
          'bonder': [('bond', False)],
          'bonders': [('bond', False)],
          'bonds': [('bonde', True)],
          'bonds-': [('bonde', True)],
          'bong': [('bong', True)],
          'bong-': [('bong', True)],
          'bongar': [('bong', True)],
          'bongarna': [('bong', True)],
          'bongarnas': [('bong', True)],
          'bongs': [('bong', True)],
          'bongs-': [('bong', True)],
          'bons': [('bo', False)],
          'boorna': [('boa', True)],
          'boornas': [('boa', True)],
          'boots': [('boots', True)],
          'bor': [('bor', True)],
          'bord': [('bord', False)],
          'bord-': [('bord', False)],
          'bordan': [('bordan', False)],
          'bordans-': [('bordan', False)],
          'bordarnas': [('bordare', False)],
          'borden': [('bord', False)],
          'bordens': [('bord', False)],
          'bords': [('bord', False)],
          'bords-': [('bord', False)],
          'bordtennisracket': [('bordtennisracket', True), ('bordtennisrack', True)],
          'bordtennisrackets': [('bordtennisracket', True), ('bordtennisrack', True)],
          'borgar': [('borgare', True), ('borg', True)],
          'borgarna': [('borgare', True), ('borg', True)],
          'borgarnas': [('borgare', True), ('borg', True)],
          'borgen': [('borgen', True), ('borg', True)],
          'borgens': [('borg', True), ('borgen', True)],
          'borgers': [('borg', False)],
          'borgskors': [('borgska', False)],
          'borna': [('bo', False)],
          'bornas': [('bo', False)],
          'borr': [('borr', False)],
          'borr-': [('borr', False)],
          'borrar': [('borr', False)],
          'borrarna': [('borr', False)],
          'borrarnas': [('borr', False)],
          'borrars': [('borr', False)],
          'borren': [('borr', False)],
          'borrens': [('borr', False)],
          'borrs': [('borr', False)],
          'borrs-': [('borr', False)],
          'bors': [('bor', False)],
          'borst': [('borste', True), ('borst', True)],
          'borst-': [('borst', True), ('borste', True)],
          'borstar': [('borste', False)],
          'borstarna': [('borste', False)],
          'borstarnas': [('borste', False)],
          'borstars': [('borste', False)],
          'borsten': [('borst', True), ('borste', True)],
          'borstens': [('borste', True), ('borst', True)],
          'bort-': [('bort', False)],
          'borten': [('bort', False)],
          'bortens': [('bort', False)],
          'borternas': [('bort', False)],
          'bortände': [('bortände', True), ('bortända', True)],
          'bortände-': [('bortända', True), ('bortände', True)],
          'bos': [('bo', False)],
          'bos-': [('bo', False)],
          'bosarna': [('bo', False)],
          'boss': [('boss', True)],
          'boss-': [('boss', True)],
          'bossar': [('boss', True)],
          'bossarnas': [('boss', False)],
          'bossars': [('boss', False)],
          'bossen': [('boss', False)],
          'bossens': [('boss', False)],
          'bostan': [('bostad', False)],
          'bostans': [('bostad', False)],
          'bot': [('bo', True), ('bot', True)],
          'botarnas': [('bot', False)],
          'bots': [('bot', True), ('bo', True)],
          'botten': [('botten', False)],
          'bottens': [('botten', False)],
          'bottenskrap': [('bottenskrap', True), ('bottenskrapa', True)],
          'bottenskraps': [('bottenskrapa', True), ('bottenskrap', True)],
          'bottenskraps-': [('bottenskrap', True), ('bottenskrapa', True)],
          'bours': [('bour', False)],
          'bovar': [('bov', False)],
          'box': [('box', False)],
          'box-': [('box', False)],
          'boxar': [('boxare', True), ('box', True)],
          'boxarna': [('boxare', True), ('box', True)],
          'boxarnas': [('boxare', True), ('box', True)],
          'boxars': [('box', False)],
          'boxen': [('box', False)],
          'boxens': [('box', False)],
          'boxer': [('boxer', True)],
          'boxers': [('boxer', True)],
          'boyens': [('boy', False)],
          'bplanet': [('bplan', False)],
          'bplanets': [('bplan', False)],
          'br': [('bra', False)],
          'br-': [('bra', False)],
          'brack': [('bracka', True)],
          'brack-': [('bracka', True)],
          'bracks': [('bracka', True)],
          'bracks-': [('bracka', True)],
          'brador': [('brador', False)],
          'brak': [('brak', False)],
          'brak-': [('brak', False)],
          'braken': [('brak', False)],
          'brakens': [('brak', False)],
          'braket': [('brak', True)],
          'brakets': [('brak', False)],
          'braks': [('brak', False)],
          'braks-': [('brak', False)],
          'brall': [('bralla', True)],
          'brall-': [('bralla', True)],
          'bralls': [('bralla', True)],
          'bralls-': [('bralla', True)],
          'braman': [('braman', True)],
          'braman-': [('braman', True)],
          'bramaner': [('braman', True)],
          'bramanerna': [('braman', True)],
          'bramanernas': [('braman', True)],
          'bramaners': [('braman', True)],
          'bramans': [('braman', True)],
          'bramin': [('bramin', True)],
          'bran-': [('bran', False)],
          'brana': [('brum', False)],
          'branas': [('brum', False)],
          'brandarna': [('brand', False)],
          'brande': [('brande', False)],
          'brande-': [('brande', False)],
          'branden': [('brand', True)],
          'brandens': [('brand', True)],
          'brandet': [('brande', False)],
          'brann': [('brand', False)],
          'branns': [('brand', False)],
          'brans-': [('bran', False)],
          'brarnas': [('ber', False)],
          'bras': [('brasa', True)],
          'bras-': [('brasa', True)],
          'brasen': [('bras', False)],
          'brasens': [('bras', False)],
          'brassens': [('brasse', True)],
          'brat': [('brat', False)],
          'bratar': [('brat', True)],
          'bratarna': [('brat', True)],
          'bratarnas': [('brat', True)],
          'braten': [('brat', False)],
          'bratens': [('brat', True)],
          'brater': [('brat', False)],
          'braterna': [('brat', False)],
          'braternas': [('brat', False)],
          'braters': [('brat', False)],
          'braton': [('brato', False)],
          'bratons': [('brato', False)],
          'brats': [('brats', True), ('brat', True)],
          'brats-': [('brats', True), ('brat', True)],
          'bratt': [('brattar', True)],
          'bratt-': [('brattar', True)],
          'brattar': [('brattar', True)],
          'brattarna': [('brattar', True)],
          'brattarnas': [('brattar', True)],
          'brattars': [('brattar', True)],
          'bre': [('bra', False)],
          'bre-': [('bra', False)],
          'bremiss': [('bremiss', False)],
          'bremiss-': [('bremiss', False)],
          'brems': [('brems', True)],
          'brems-': [('brems', True)],
          'bren': [('bre', False)],
          'brena': [('brum', False)],
          'brenas': [('brum', False)],
          'brens': [('ber', False)],
          'brerna': [('brer', False)],
          'brernas': [('brer', False)],
          'brers': [('ber', False)],
          'bret': [('bre', False)],
          'brets': [('bre', False)],
          'brev': [('brev', False)],
          'brev-': [('brev', False)],
          'breven': [('brev', False)],
          'brevens': [('brev', False)],
          'brevs': [('brev', False)],
          'brevs-': [('brev', False)],
          'bri': [('bri', False)],
          'bri-': [('bri', False)],
          'brianden': [('briand', False)],
          'briandens': [('briand', False)],
          'briander': [('briand', False)],
          'brianders': [('briand', False)],
          'brick-': [('bricka', False)],
          'bricks': [('bricka', False)],
          'bricks-': [('bricka', False)],
          'brid': [('brid', False)],
          'brid-': [('brid', False)],
          'brider': [('brid', False)],
          'briderna': [('brid', False)],
          'bridernas': [('brid', False)],
          'briders': [('brid', False)],
          'brie': [('brium', False)],
          'brie-': [('brium', False)],
          'briet': [('brium', False)],
          'briets': [('brium', False)],
          'brighets': [('brighet', False)],
          'brik': [('brik', False)],
          'brik-': [('brik', False)],
          'briken': [('brik', False)],
          'brikens': [('brik', False)],
          'briker': [('brik', False)],
          'brikerna': [('brik', False)],
          'brikernas': [('brik', False)],
          'brikers': [('brik', False)],
          'briks': [('brik', False)],
          'briks-': [('brik', False)],
          'brill': [('brillor', False)],
          'brill-': [('brillor', True)],
          'brillor': [('brillor', True)],
          'brillorna': [('brillor', True)],
          'brillornas': [('brillor', True)],
          'brillors': [('brillor', False)],
          'brills': [('brillor', True)],
          'brills-': [('brillor', True)],
          'brin-': [('brin', False)],
          'briner': [('brin', False)],
          'brinerna': [('brin', False)],
          'brinernas': [('brin', False)],
          'briners': [('brin', False)],
          'bring': [('bringa', True)],
          'bring-': [('bringa', True)],
          'bringar': [('bringare', False)],
          'bringarna': [('bringare', False)],
          'bringarnas': [('bringare', False)],
          'bringornas': [('bringa', True)],
          'bringors': [('bringa', True)],
          'brings': [('bringa', True)],
          'brings-': [('bringa', True)],
          'brinkar': [('brink', True)],
          'brins': [('brin', False)],
          'brins-': [('brin', False)],
          'briolet': [('briolet', False)],
          'brion': [('brio', True)],
          'brions': [('brio', True)],
          'brios': [('brio', True)],
          'bris': [('bris', False)],
          'bris-': [('bris', False)],
          'brisarna': [('bris', False)],
          'brisens': [('bris', False)],
          'briser': [('bris', False)],
          'briserna': [('bris', False)],
          'brisernas': [('bris', True)],
          'brisers': [('bris', False)],
          'britet': [('britet', False)],
          'britets': [('britet', False)],
          'brits': [('brits', False)],
          'brits-': [('brits', False)],
          'bro-': [('bro', False)],
          'brock': [('brock', False)],
          'brockar': [('brock', True)],
          'brockarna': [('brock', True)],
          'brockarnas': [('brock', True)],
          'brockets': [('brock', False)],
          'broddar': [('brodd', True)],
          'broddarna': [('brodd', False)],
          'broddarnas': [('brodd', True)],
          'broder': [('broder', True), ('bror', True)],
          'brodern': [('bror', True), ('broder', True)],
          'broderns': [('bror', True), ('broder', True)],
          'broders': [('broder', True), ('bror', True)],
          'brokar': [('brok', True), ('brokar', True)],
          'brokarna': [('brok', True)],
          'brokars': [('brok', True), ('brokar', True)],
          'broken': [('brok', True)],
          'brokens': [('brok', True)],
          'broks': [('brok', True)],
          'broks-': [('brok', True)],
          'broms': [('brom', True), ('broms', True)],
          'broms-': [('broms', False)],
          'bromsar': [('bromsare', True), ('broms', True)],
          'bromsarna': [('bromsare', True), ('broms', True)],
          'bromsarnas': [('bromsare', True), ('broms', True)],
          'brons': [('brons', True), ('bro', True)],
          'brons-': [('brons', False)],
          'bror': [('bror', True)],
          'brorna': [('bra', False)],
          'brornas': [('bra', False)],
          'brors': [('bror', True), ('brorsa', True)],
          'brors-': [('brorsa', True), ('bror', True)],
          'bros': [('bro', False)],
          'bros-': [('bro', True)],
          'broschen': [('brosch', True)],
          'broschens': [('brosch', True)],
          'brottar': [('brottare', True)],
          'brottarnas': [('brottare', False)],
          'brs': [('bre', False)],
          'brs-': [('bra', False)],
          'brud': [('brud', False)],
          'brud-': [('brud', False)],
          'brudens': [('brud', False)],
          'bruds': [('brud', False)],
          'bruds-': [('brud', False)],
          'bruk': [('bruk', False)],
          'bruk-': [('bruk', True)],
          'bruks': [('bruk', False)],
          'bruks-': [('bruk', False)],
          'brum': [('brum', False)],
          'brum-': [('brum', False)],
          'brumbas': [('brumbas', True)],
          'brums-': [('brum', True)],
          'brun': [('brun', False)],
          'brun-': [('brun', True)],
          'brunnar': [('brunn', False)],
          'brunnarna': [('brunn', False)],
          'brunnarnas': [('brunn', False)],
          'bruns': [('brun', False)],
          'bruns-': [('brun', False)],
          'brunsten': [('brunst', True), ('brunsten', True)],
          'brunstens': [('brunst', True), ('brunsten', True)],
          'brunten': [('brunte', True)],
          'bruntens': [('brunte', True)],
          'brus': [('brus', False)],
          'brus-': [('brus', True)],
          'brutt': [('brutta', True)],
          'brutt-': [('brutta', True)],
          'brutts': [('brutta', True)],
          'brutts-': [('brutta', True)],
          'bry': [('bry', False)],
          'bry-': [('bry', True)],
          'brygg': [('brygga', False)],
          'brygg-': [('brygga', False)],
          'bryggar': [('bryggare', False)],
          'bryggarna': [('bryggare', False)],
          'bryggarnas': [('bryggare', False)],
          'bryggs': [('brygga', False)],
          'bryggs-': [('brygga', False)],
          'bryn': [('bryn', False)],
          'bryn-': [('bryn', True)],
          'brynen': [('bryn', True), ('bryne', True)],
          'brynens': [('bryn', True), ('bryne', True)],
          'brynet': [('bryne', True), ('bryn', True)],
          'brynets': [('bryne', True), ('bryn', True)],
          'bryns': [('bryne', True), ('bryn', True)],
          'bryns-': [('bryne', True), ('bryn', True)],
          'brys': [('bry', False)],
          'bryt': [('bryte', True)],
          'bryt-': [('bryte', True)],
          'brytar': [('bryte', True), ('brytare', True)],
          'brytarna': [('bryte', True), ('brytare', True)],
          'brytarnas': [('bryte', True), ('brytare', True)],
          'bryten': [('bryte', True)],
          'brytens': [('bryte', True)],
          'bryts': [('bryte', True)],
          'bryts-': [('bryte', True)],
          'bräck': [('bräck', True)],
          'bräck-': [('bräck', True)],
          'bräcke': [('bräcka', False)],
          'bräcken': [('bräck', False)],
          'bräckens': [('bräck', False)],
          'bräcket': [('bräck', False)],
          'bräckets': [('bräck', True)],
          'bräcks': [('bräck', True)],
          'bräcks-': [('bräck', True)],
          'bräd': [('bräda', False)],
          'bräd-': [('bräda', False)],
          'brädd-': [('brädd', True)],
          'bräddar': [('brädd', True)],
          'bräddarna': [('brädd', True)],
          'bräddarnas': [('brädd', False)],
          'bräde': [('bräde', True)],
          'bräde-': [('bräda', False)],
          'bräden': [('bräde', False)],
          'brädens': [('bräde', False)],
          'bräder': [('bräda', False)],
          'bräderna': [('bräda', True)],
          'brädernas': [('bräda', True)],
          'bräders': [('bräda', True)],
          'brädets': [('bräde', False)],
          'bräds': [('bräde', True)],
          'bräds-': [('bräde', True)],
          'bräken': [('bräken', True)],
          'bräkens': [('bräken', True)],
          'bräknar': [('bräken', True)],
          'bräknarna': [('bräken', True)],
          'bräknarnas': [('bräken', False)],
          'bräknen': [('bräken', True)],
          'bräknens': [('bräken', True)],
          'bräm-': [('bräm', True)],
          'bräms': [('bräm', True)],
          'bräms-': [('bräm', True)],
          'bränderna': [('brand', False)],
          'brändernas': [('brand', False)],
          'bränders': [('brand', False)],
          'bränn': [('bränna', False)],
          'bränn-': [('bränna', False)],
          'bränne': [('bränne', True)],
          'bränne-': [('bränne', True)],
          'brännet': [('bränne', True)],
          'brännets': [('bränne', True)],
          'bränns': [('bränna', False)],
          'bränns-': [('bränna', False)],
          'brätten': [('brätte', True)],
          'brättens': [('brätte', True)],
          'brättet': [('brätte', True)],
          'brättighets-': [('brättighet', False)],
          'brätts': [('brätte', True)],
          'brätts-': [('brätte', True)],
          'bråden': [('bråd', False)],
          'bråk': [('bråka', True), ('bråk', True)],
          'bråk-': [('bråka', True), ('bråk', True)],
          'bråken': [('bråk', False)],
          'bråkens': [('bråk', False)],
          'bråks': [('bråka', True), ('bråk', True)],
          'bråks-': [('bråka', True), ('bråk', True)],
          'brån': [('brå', False)],
          'bråns': [('brå', False)],
          'bröd': [('bröd', False)],
          'bröder': [('broder', True), ('bror', True)],
          'bröderna': [('bror', True), ('broder', True)],
          'brödernas': [('broder', True), ('bror', True)],
          'bröders': [('bror', True), ('broder', True)],
          'brödkavlar': [('brödkavle', True), ('brödkavel', True)],
          'brödkavlarna': [('brödkavel', True), ('brödkavle', True)],
          'brödkavlarnas': [('brödkavle', True), ('brödkavel', True)],
          'brödkavlars': [('brödkavel', True), ('brödkavle', True)],
          'bröds': [('bröd', False)],
          'bröds-': [('bröd', False)],
          'bröst': [('brösta', True), ('bröst', True)],
          'bröst-': [('brösta', True), ('bröst', True)],
          'bröstan': [('brösta', True)],
          'bröste': [('brösta', True)],
          'brösten': [('bröst', False)],
          'bröstens': [('bröst', False)],
          'bröstet': [('bröst', False)],
          'bröstets': [('bröst', False)],
          'bröt': [('bröt', False)],
          'bröt-': [('bröt', True)],
          'bröts': [('bröt', True)],
          'bsen': [('bs', False)],
          'bsens': [('bs', False)],
          'bsens-': [('bsens', False)],
          'bsid': [('bsid', False)],
          'bsid-': [('bsid', False)],
          'bsidan': [('bsida', False)],
          'bsidans': [('bsida', False)],
          'bside-': [('bsida', False)],
          'bsiden': [('bsid', False)],
          'bsidens': [('bsid', False)],
          'bsider': [('bsid', False)],
          'bsiderna': [('bsid', False)],
          'bsidernas': [('bsid', False)],
          'bsiders': [('bsid', False)],
          'bsides': [('bsida', False)],
          'bsidie': [('bsidier', False)],
          'bsidie-': [('bsidier', False)],
          'bsidierna': [('bsidier', False)],
          'bsikten': [('bsikte', False)],
          'bsiktens': [('bsikte', False)],
          'bsinter': [('bsint', False)],
          'bsinters': [('bsint', False)],
          'bsistens': [('bsistens', False)],
          'bsistens-': [('bsistens', False)],
          'bsjukan': [('bsjuka', False)],
          'bskartans': [('bskarta', False)],
          'bsko': [('bsko', False)],
          'bskor': [('bsko', False)],
          'bskorna': [('bsko', False)],
          'bskornas': [('bsko', False)],
          'bskors': [('bsko', False)],
          'bslag': [('bslag', False)],
          'bslags': [('bslag', False)],
          'bslags-': [('bslag', False)],
          'bsolverande': [('bsolverande', False)],
          'bsolverande-': [('bsolverande', False)],
          'bsorber': [('bsorber', False)],
          'bsorbers': [('bsorber', False)],
          'bspännen': [('bspänne', False)],
          'bspännens': [('bspänne', False)],
          'bsstegen': [('bsstege', False)],
          'bsstegs': [('bsstege', False)],
          'bssylt-': [('bssylt', False)],
          'bssylts': [('bssylt', False)],
          'bssylts-': [('bssylt', False)],
          'bstackar': [('bstackare', False)],
          'bstackarna': [('bstackare', False)],
          'bstackarnas': [('bstackare', False)],
          'bstammar': [('bstam', False)],
          'bstammarna': [('bstam', False)],
          'bstammarnas': [('bstam', False)],
          'bstans': [('bstans', False)],
          'bstans-': [('bstans', False)],
          'bstekar': [('bstek', False)],
          'bstekarna': [('bstek', False)],
          'bstekarnas': [('bstek', False)],
          'bsten': [('bsten', False)],
          'bstick': [('bsticka', False)],
          'bstick-': [('bsticka', False)],
          'bsticks': [('bsticka', False)],
          'bsticks-': [('bsticka', False)],
          'bstol': [('bstol', False)],
          'bstol-': [('bstol', False)],
          'bstols': [('bstol', False)],
          'bstols-': [('bstol', False)],
          'bsvans': [('bsvans', False)],
          'bsvans-': [('bsvans', False)],
          'btagen': [('btag', False)],
          'btaget': [('btag', False)],
          'btask': [('btaska', False)],
          'btask-': [('btaska', False)],
          'btestens': [('btest', False)],
          'btåg': [('btåg', False)],
          'btågs': [('btåg', False)],
          'btågs-': [('btåg', False)],
          'bu': [('bu', False)],
          'bu-': [('bu', False)],
          'bubbel': [('bubbel', True), ('bubbla', True)],
          'bubbel-': [('bubbel', True), ('bubbla', True)],
          'budkavlar': [('budkavel', True), ('budkavle', True)],
          'budkavlarna': [('budkavle', True), ('budkavel', True)],
          'budkavlarnas': [('budkavel', True), ('budkavle', True)],
          'budkavlars': [('budkavle', True), ('budkavel', True)],
          'buer': [('bu', False)],
          'buerna': [('bu', False)],
          'buernas': [('bu', False)],
          'buers': [('bu', False)],
          'buff': [('buff', True), ('buffa', True)],
          'buff-': [('buff', True), ('buffa', True)],
          'buffar': [('buff', True)],
          'buffarna': [('buff', True)],
          'bufflar': [('buffel', True)],
          'bufflarna': [('buffel', True)],
          'bufflarnas': [('buffel', True)],
          'buffs': [('buff', True), ('buffa', True)],
          'buffs-': [('buff', True), ('buffa', True)],
          'bug-': [('bug', False)],
          'bugg': [('bugg', True)],
          'bugg-': [('bugg', True)],
          'buggar': [('bugg', True)],
          'buggarna': [('bugg', True)],
          'buggarnas': [('bugg', True)],
          'buggars': [('bugg', True)],
          'buggen': [('bugg', True)],
          'buggens': [('bugg', True)],
          'buggs': [('bugg', True)],
          'buggs-': [('bugg', True)],
          'bugs-': [('bug', False)],
          'bukarnas': [('buk', True)],
          'bukt': [('bukt', True)],
          'bukt-': [('bukt', False)],
          'bukter': [('bukt', False)],
          'bukterna': [('bukt', False)],
          'bukternas': [('bukt', False)],
          'bukters': [('bukt', False)],
          'bukts': [('bukt', False)],
          'bukts-': [('bukt', True)],
          'bul': [('bula', True)],
          'bul-': [('bula', False)],
          'bula': [('bula', True)],
          'bulan': [('bula', True)],
          'bulans': [('bula', True)],
          'bulas': [('bula', False)],
          'bulens': [('bulens', False)],
          'bulinets': [('bulin', False)],
          'bulk': [('bulk', True)],
          'bull': [('bulla', True), ('bulle', True)],
          'bull-': [('bulle', True), ('bulla', True)],
          'bullarnas': [('bulle', False)],
          'bulle': [('bulle', True), ('bulla', True)],
          'bulle-': [('bulla', False)],
          'bullen': [('bulle', False)],
          'bullens': [('bulle', False)],
          'bulls': [('bulle', True), ('bulla', True)],
          'bulls-': [('bulla', True), ('bulle', True)],
          'bulos': [('bulosa', False)],
          'bulos-': [('bulosa', False)],
          'buls': [('bula', True)],
          'buls-': [('bula', False)],
          'bult-': [('bult', False)],
          'bultar': [('bult', False)],
          'bultarna': [('bult', False)],
          'bultars': [('bult', False)],
          'bulten': [('bult', False)],
          'bultens': [('bult', False)],
          'bults': [('bult', False)],
          'bults-': [('bult', False)],
          'bulvan': [('bulvan', True)],
          'bulvans': [('bulvan', True)],
          'buminets': [('bumin', False)],
          'bun': [('bu', False)],
          'buna': [('bu', False)],
          'bunas': [('bu', False)],
          'bund': [('bund', False)],
          'bund-': [('bund', False)],
          'bundans': [('bundans', False)],
          'bunds': [('bund', False)],
          'bunds-': [('bund', False)],
          'bunkar': [('bunke', True)],
          'bunkarna': [('bunke', True)],
          'bunkarnas': [('bunke', False)],
          'bunks': [('bunke', False)],
          'buns': [('bu', False)],
          'buns-': [('bun', False)],
          'bunt': [('bunt', False)],
          'buntarna': [('bunt', False)],
          'buntars': [('bunt', True)],
          'bunten': [('bunt', False)],
          'buntens': [('bunt', False)],
          'bunts-': [('bunt', False)],
          'burgunder': [('burgunder', True), ('burgund', True)],
          'burgunderna': [('burgunder', True), ('burgund', True)],
          'burgundernas': [('burgund', True), ('burgunder', True)],
          'burgunders': [('burgunder', True), ('burgund', True)],
          'burin': [('burin', False)],
          'burk': [('burk', False)],
          'burk-': [('burk', True)],
          'burks': [('burk', False)],
          'burks-': [('burk', False)],
          'burr': [('burr', False)],
          'burr-': [('burr', True)],
          'burren': [('burr', True)],
          'burrens': [('burr', True)],
          'burrs': [('burr', False)],
          'burrs-': [('burr', True)],
          'burs': [('bur', True)],
          'burs-': [('bur', True)],
          'burser': [('burs', False)],
          'burserna': [('burs', False)],
          'bursernas': [('burs', False)],
          'bursers': [('burs', False)],
          'bus': [('bus', True), ('buse', True)],
          'bus-': [('buse', True), ('bus', True)],
          'busar': [('buse', False)],
          'busarna': [('buse', False)],
          'busarnas': [('buse', True)],
          'busars': [('buse', False)],
          'buse': [('buse', False)],
          'buse-': [('buse', False)],
          'busen': [('buse', False)],
          'busens': [('buse', False)],
          'buskar': [('buske', False)],
          'busringar': [('busringare', True)],
          'buss': [('buss', True)],
          'bussar': [('buss', False)],
          'bussars': [('buss', False)],
          'bussen': [('buss', False)],
          'bussens': [('buss', False)],
          'but': [('bu', False)],
          'butans': [('butan', True)],
          'butets': [('but', False)],
          'buts': [('bu', False)],
          'bval': [('bval', False)],
          'bval-': [('bval', False)],
          'bvalarna': [('bval', False)],
          'bvalarnas': [('bval', False)],
          'bvalen': [('bval', False)],
          'bvalens': [('bval', False)],
          'bvals': [('bval', False)],
          'bvals-': [('bval', False)],
          'bvälden': [('bvälde', False)],
          'bväldens': [('bvälde', False)],
          'bwierna': [('bwier', False)],
          'bwiernas': [('bwier', False)],
          'bwiers': [('bwier', False)],
          'by': [('by', False)],
          'by-': [('by', False)],
          'byar': [('by', True)],
          'byarna': [('by', False)],
          'byer': [('by', False)],
          'byerna': [('byer', False)],
          'byernas': [('by', False)],
          'byers': [('by', False)],
          'byggar': [('byggare', False)],
          'bygget': [('bygge', True)],
          'byggets': [('bygge', False)],
          'byk': [('byk', True)],
          'bykandens': [('bykande', True)],
          'bykarnas': [('byk', True)],
          'byke': [('byke', True)],
          'byke-': [('byke', True)],
          'byket': [('byke', True)],
          'byks-': [('byk', True)],
          'byllan': [('bylla', False)],
          'bylle': [('bylla', False)],
          'bylle-': [('bylla', False)],
          'bylts': [('bylte', True)],
          'bylts-': [('bylte', True)],
          'byn': [('by', False)],
          'byna': [('by', False)],
          'bynas': [('by', False)],
          'byns': [('by', False)],
          'bys': [('by', False)],
          'bys-': [('by', False)],
          'bysarna': [('by', False)],
          'byst': [('byst', False)],
          'byst-': [('byst', False)],
          'bysten': [('byst', False)],
          'bystens': [('byst', False)],
          'byster': [('byst', True)],
          'bysters': [('byst', False)],
          'byt': [('by', False)],
          'bytar': [('bytare', False)],
          'bytarna': [('bytare', False)],
          'byte': [('byte', False)],
          'byte-': [('byte', False)],
          'byten': [('byte', False)],
          'bytens': [('byte', False)],
          'byter': [('byter', False)],
          'byters': [('byter', False)],
          'bytet': [('byte', False)],
          'byts': [('by', False)],
          'bytte': [('bytta', False)],
          'byx': [('byx', True), ('byxa', True)],
          'byx-': [('byx', True), ('byxa', True)],
          'byxorna': [('byxa', True)],
          'byxornas': [('byxa', True)],
          'bäck': [('bäck', False)],
          'bäck-': [('bäck', False)],
          'bäckar': [('bäck', False)],
          'bäckarna': [('bäck', False)],
          'bäcken': [('bäck', True), ('bäcken', True)],
          'bäckens': [('bäck', True), ('bäcken', True)],
          'bäcks': [('bäck', True)],
          'bäcks-': [('bäck', False)],
          'bädd': [('bädd', False)],
          'bädden': [('bädd', False)],
          'bäddens': [('bädd', False)],
          'bädds': [('bädd', False)],
          'bädds-': [('bädd', False)],
          'bägar': [('bägare', False)],
          'bägarna': [('bägare', False)],
          'bägarnas': [('bägare', False)],
          'bäke': [('bäke', False)],
          'bäken': [('bäke', False)],
          'bäkens': [('bäke', False)],
          'bäket': [('bäke', False)],
          'bält': [('bälta', True)],
          'bälte': [('bälta', True), ('bälte', True)],
          'bälte-': [('bälta', True)],
          'bältets': [('bälte', False)],
          'bänk': [('bänk', False)],
          'bänk-': [('bänk', False)],
          'bänken': [('bänk', False)],
          'bänkens': [('bänk', False)],
          'bänks': [('bänk', False)],
          'bänks-': [('bänk', False)],
          'bärarnas': [('bärare', False)],
          'bärgen': [('bärge', False)],
          'bärgens': [('bärge', False)],
          'bärgs': [('bärge', False)],
          'bärgs-': [('bärge', False)],
          'bärs': [('bärs', True), ('bär', True)],
          'bärs-': [('bärs', True), ('bär', True)],
          'bättrarna': [('bättrare', False)],
          'bättrarnas': [('bättrare', False)],
          'bäver': [('bäver', False)],
          'bävers': [('bäver', True)],
          'båd': [('båda', True), ('både', True)],
          'båd-': [('både', True), ('båda', True)],
          'bådan': [('båda', True)],
          'bådar': [('både', True)],
          'bådarna': [('både', True)],
          'bådarnas': [('både', True)],
          'bådars': [('både', True)],
          'både': [('både', True), ('båda', True)],
          'båden': [('både', True)],
          'bådens': [('både', True)],
          'bådets': [('båd', False)],
          'båds': [('båda', True), ('både', True)],
          'båds-': [('både', True), ('båda', True)],
          'båg': [('båg', True), ('båge', True)],
          'båg-': [('båg', True), ('båge', True)],
          'bågar': [('båge', False)],
          'bågarna': [('båge', False)],
          'bågars': [('båge', False)],
          'båge': [('båge', False)],
          'båge-': [('båge', False)],
          'bågen': [('båge', False)],
          'bågens': [('båge', False)],
          'bågs': [('båg', True), ('båge', True)],
          'bågs-': [('båg', True), ('båge', True)],
          'båkar': [('båk', True)],
          'båkarna': [('båk', True)],
          'båkarnas': [('båk', True)],
          'båker': [('båker', False)],
          'båkers': [('båker', False)],
          'bålarnas': [('bål', True)],
          'bålars': [('bål', False)],
          'bålen': [('bål', False)],
          'bår': [('bår', True)],
          'bår-': [('bår', True)],
          'bårarna': [('bår', True)],
          'bårarnas': [('bår', True)],
          'bård': [('bård', False)],
          'bård-': [('bård', True)],
          'bårder': [('bård', False)],
          'bårderna': [('bård', False)],
          'bårdernas': [('bård', False)],
          'bårders': [('bård', True)],
          'bårds': [('bård', True)],
          'bårds-': [('bård', True)],
          'bårs': [('bår', True)],
          'bårs-': [('bår', True)],
          'bås': [('bås', False)],
          'bås-': [('bås', False)],
          'båtarnas': [('båt', False)],
          'béerna': [('bé', False)],
          'béernas': [('bé', False)],
          'böjar': [('böjare', True), ('böj', True)],
          'böjarna': [('böjare', True), ('böj', True)],
          'böjarnas': [('böjare', True), ('böj', True)],
          'böjs': [('böj', True)],
          'bökets': [('bök', True)],
          'bölar': [('bölare', False)],
          'bölarna': [('bölare', False)],
          'bölarnas': [('bölare', False)],
          'bölje': [('bölja', True)],
          'bön': [('bön', True), ('böna', True)],
          'bön-': [('bön', True), ('böna', True)],
          'böne': [('bön', True), ('böna', True)],
          'böne-': [('bön', True), ('böna', True)],
          'bönernas': [('bön', False)],
          'böns': [('böna', True), ('bön', True)],
          'böns-': [('böna', True), ('bön', True)],
          'börjans': [('början', True)],
          'börjarnas': [('börjare', False)],
          'börs': [('börs', False)],
          'börs-': [('börs', False)],
          'börsar': [('börs', True)],
          'börsarnas': [('börs', True)],
          'bösse': [('bössa', True)],
          'böt': [('böter', True)],
          'böt-': [('böter', False)],
          'böter': [('böter', True)],
          'böterna': [('böter', True)],
          'böternas': [('böter', False)],
          'böters': [('böter', False)],
          'böts': [('böter', False)],
          'böts-': [('böter', False)],
          'bövlars': [('bövel', True)],
          'c': [('c', True)],
          'c-': [('c', True)],
          'ca': [('ca', False)],
          'ca-': [('ca', False)],
          'cabb': [('cabb', True)],
          'cabb-': [('cabb', True)],
          'cabbarna': [('cabb', True)],
          'cabbarnas': [('cabb', True)],
          'cabbars': [('cabb', True)],
          'cabbens': [('cabb', True)],
          'cabbs': [('cabb', True)],
          'cabbs-': [('cabb', True)],
          'cadon': [('cado', False)],
          'cador': [('cado', False)],
          'cadorna': [('cado', False)],
          'cadornas': [('cado', False)],
          'cadors': [('cador', False)],
          'cados-': [('cado', False)],
          'cals': [('cal', False)],
          'cals-': [('cal', False)],
          'calzonen': [('calzone', True)],
          'calzonens': [('calzone', True)],
          'camparnas': [('campare', True)],
          'can': [('ca', False)],
          'canastas': [('canasta', True)],
          'candets': [('cande', False)],
          'cane': [('cane', False)],
          'cane-': [('cane', False)],
          'canens': [('can', False)],
          'canes': [('cane', False)],
          'canon': [('cano', False)],
          'canons': [('cano', False)],
          'canos': [('cano', False)],
          'canot': [('cano', False)],
          'canots': [('cano', False)],
          'cans': [('ca', False)],
          'cape': [('cape', True)],
          'cape-': [('cape', True)],
          'capen': [('cape', True)],
          'capens': [('cape', True)],
          'caper': [('cape', True)],
          'caperna': [('cape', True)],
          'capernas': [('cape', True)],
          'capers': [('cape', True)],
          'car': [('car', False)],
          'caran': [('cara', False)],
          'carans': [('cara', False)],
          'card': [('card', False)],
          'card-': [('card', False)],
          'carden': [('card', False)],
          'cardens': [('card', False)],
          'cardet': [('card', False)],
          'cards': [('card', False)],
          'cards-': [('card', False)],
          'carian': [('caria', False)],
          'carians': [('caria', False)],
          'carna': [('ce', False)],
          'carnas': [('c', False)],
          'cars': [('ce', False)],
          'cart': [('cart', False)],
          'cart-': [('cart', False)],
          'carten': [('cart', False)],
          'cartens': [('cart', False)],
          'carterna': [('cart', False)],
          'carters': [('cart', False)],
          'carts': [('cart', False)],
          'carts-': [('cart', False)],
          'cartsen': [('cart', False)],
          'cartsens': [('cart', False)],
          'carves': [('carf', False)],
          'cas': [('ca', False)],
          'cas-': [('cas', False)],
          'cashets': [('cash', True)],
          'cat': [('cata', False)],
          'cat-': [('cata', False)],
          'cata': [('cata', False)],
          'catan': [('cata', False)],
          'catas': [('cata', False)],
          'catos': [('cato', False)],
          'cats': [('cata', False)],
          'cats-': [('cata', False)],
          'catsarnas': [('cat', False)],
          'catsens': [('cat', False)],
          'ccent-': [('ccent', False)],
          'ccenter': [('ccent', False)],
          'ccenters': [('ccent', False)],
          'ccents': [('ccent', False)],
          'cci': [('ccia', False)],
          'cci-': [('ccia', False)],
          'ccian': [('ccia', False)],
          'ccians': [('ccia', False)],
          'ccidens': [('ccidens', False)],
          'ccie-': [('ccia', False)],
          'ccins': [('ccin', False)],
          'ccis': [('ccis', False)],
          'ccis-': [('ccis', False)],
          'ccors': [('cco', False)],
          'cd': [('cd', False)],
          'cd-': [('cd', False)],
          'cdar': [('cd', True)],
          'cdarna': [('cd', False)],
          'cdarnas': [('cd', True)],
          'cdars': [('cd', True)],
          'cder': [('cd', False)],
          'cderna': [('cd', True)],
          'cdernas': [('cd', True)],
          'cders': [('cd', False)],
          'cds': [('cd', True)],
          'ce': [('ce', False)],
          'ce-': [('ce', False)],
          'cean': [('cean', False)],
          'ceans': [('cean', False)],
          'cedens': [('cedens', False)],
          'ceder': [('ceder', True)],
          'ceders': [('ceder', True)],
          'ceers': [('ceum', False)],
          'ceets': [('ceum', False)],
          'ceivrar': [('ceiver', False)],
          'ceivrarna': [('ceiver', False)],
          'celie': [('celium', False)],
          'cell': [('cell', True)],
          'cell-': [('cell', False)],
          'cellan': [('cella', True)],
          'cellen': [('cell', False)],
          'cellens': [('cell', True)],
          'celler': [('cell', False)],
          'cellerna': [('cell', False)],
          'cellernas': [('cell', False)],
          'cellers': [('cell', False)],
          'cellor': [('cella', True), ('cello', True)],
          'cellorna': [('cella', True), ('cello', True)],
          'cellornas': [('cella', True), ('cello', True)],
          'cellors': [('cella', True), ('cello', True)],
          'cells': [('cell', False)],
          'cells-': [('cell', False)],
          'celuck-': [('celucka', False)],
          'celucks': [('celucka', False)],
          'celucks-': [('celucka', False)],
          'cemang': [('cemang', False)],
          'cemang-': [('cemang', False)],
          'cemangs': [('cemang', False)],
          'cemangs-': [('cemang', False)],
          'cementen': [('cement', False)],
          'cementens': [('cement', True)],
          'cementet': [('cement', True)],
          'cements-': [('cement', False)],
          'cen': [('ce', False)],
          'cenat-': [('cenat', False)],
          'cenats-': [('cenat', False)],
          'cendens': [('cendens', False)],
          'cendos': [('cendo', False)],
          'cenie': [('cenium', False)],
          'cenier': [('cenium', False)],
          'cenierna': [('cenium', False)],
          'ceniernas': [('cenium', False)],
          'ceniers': [('cenium', False)],
          'ceniets': [('cenium', False)],
          'cens': [('ce', False)],
          'cens-': [('cens', False)],
          'censen': [('cens', False)],
          'censens': [('cens', False)],
          'censer': [('cens', False)],
          'censerna': [('cens', False)],
          'censernas': [('cens', False)],
          'censers': [('cens', False)],
          'cent': [('cent', False)],
          'cent-': [('cent', True)],
          'centanden': [('centande', False)],
          'centandens': [('centande', False)],
          'centaren': [('centare', False)],
          'cente': [('centa', False)],
          'cente-': [('centa', False)],
          'centen': [('cent', False)],
          'centens': [('cent', False)],
          'center': [('center', True)],
          'centerna': [('cent', False)],
          'centernas': [('cent', False)],
          'centers': [('center', False)],
          'centor': [('centa', False)],
          'centors': [('centa', False)],
          'centrer': [('center', True), ('centrum', True)],
          'centrerna': [('centrum', True), ('center', True)],
          'centrernas': [('centrum', True), ('center', True)],
          'centrers': [('center', True), ('centrum', True)],
          'centret': [('center', True), ('centrum', True)],
          'centrets': [('centrum', True), ('center', True)],
          'cents': [('cent', True)],
          'cents-': [('cent', False)],
          'ceps': [('ceps', False)],
          'ceps-': [('ceps', False)],
          'cepter': [('cept', False)],
          'cepters': [('cept', False)],
          'cer': [('cer', False)],
          'cer-': [('cer', False)],
          'cerare': [('cerare', False)],
          'cerares': [('cerare', False)],
          'cerarna': [('cerare', False)],
          'cerarnas': [('cerare', False)],
          'cerbil': [('cerbil', False)],
          'cerbils': [('cerbil', False)],
          'cerbils-': [('cerbil', False)],
          'ceri-': [('cerier', False)],
          'cerids': [('cerid', False)],
          'cerierna': [('cerier', False)],
          'ceriernas': [('cerier', False)],
          'ceriers': [('cerier', False)],
          'ceriets': [('cerium', True)],
          'cerin': [('cerin', False)],
          'cern-': [('cern', False)],
          'cerna': [('ce', False)],
          'cernas': [('ce', False)],
          'cerner': [('cern', False)],
          'cerners': [('cern', False)],
          'cerns-': [('cern', False)],
          'ceros': [('cero', False)],
          'cers': [('ce', False)],
          'cers-': [('cer', False)],
          'certens': [('cert', True)],
          'certer': [('cert', True)],
          'certers': [('cert', True)],
          'certs': [('cert', True)],
          'certs-': [('cert', True)],
          'ces': [('ce', False)],
          'ces-': [('ce', False)],
          'cesiet': [('cesium', True)],
          'cesiets': [('cesium', True)],
          'cess': [('cess', False)],
          'cessen': [('cess', False)],
          'cessens': [('cess', False)],
          'cesser': [('cess', False)],
          'cesserna': [('cess', False)],
          'cessernas': [('cess', False)],
          'cessers': [('cess', False)],
          'cest-': [('cest', False)],
          'cestor': [('cestor', False)],
          'cesurs': [('cesur', True)],
          'cet': [('ce', False)],
          'cetat': [('cetat', False)],
          'cetats': [('cetat', False)],
          'cetins': [('ceti', False)],
          'cets': [('ce', False)],
          'cett': [('cett', False)],
          'cett-': [('cett', False)],
          'cetten': [('cett', False)],
          'cetter': [('cett', False)],
          'cetterna': [('cett', False)],
          'cetternas': [('cett', False)],
          'cetters': [('cett', False)],
          'cetts': [('cett', False)],
          'cetts-': [('cett', False)],
          'cetylen': [('cetylen', False)],
          'cetylens': [('cetylen', False)],
          'cevärden': [('cevärd', False)],
          'cevärdens': [('cevärd', False)],
          'ch': [('ch', False)],
          'ch-': [('ch', False)],
          'chack': [('chack', False)],
          'chack-': [('chack', False)],
          'chacks': [('chack', False)],
          'chacks-': [('chack', False)],
          'chagg': [('chagg', False)],
          'chagg-': [('chagg', False)],
          'chaggs': [('chagg', False)],
          'chaggs-': [('chagg', False)],
          'chalarna': [('chal', False)],
          'chalarnas': [('chal', False)],
          'chals': [('chal', False)],
          'chals-': [('chal', False)],
          'chan': [('cha', False)],
          'chan-': [('chan', False)],
          'chanden': [('chande', False)],
          'chandens': [('chande', False)],
          'chanen': [('chan', False)],
          'chanens': [('chan', False)],
          'chans': [('chans', False)],
          'chans-': [('chans', False)],
          'char': [('char', True)],
          'char-': [('char', True)],
          'charen': [('char', True)],
          'charens': [('char', True)],
          'charna': [('ch', False)],
          'chars': [('char', True)],
          'chars-': [('char', True)],
          'chasen': [('chas', False)],
          'chasens': [('chase', False)],
          'chatar': [('chat', True)],
          'chatarna': [('chat', True)],
          'chatarnas': [('chat', True)],
          'che': [('cha', False)],
          'che-': [('cha', False)],
          'chel': [('chel', False)],
          'chel-': [('chel', False)],
          'chels': [('chel', False)],
          'chen': [('ch', False)],
          'chens': [('ch', False)],
          'cher': [('ch', False)],
          'cherna': [('ch', False)],
          'chernas': [('ch', False)],
          'chers': [('ch', False)],
          'chet': [('ch', False)],
          'cheten': [('chete', False)],
          'chetens': [('chete', False)],
          'cheter': [('chete', False)],
          'cheterna': [('chete', False)],
          'cheternas': [('chete', False)],
          'chets': [('ch', False)],
          'chets-': [('chet', False)],
          'chette': [('chette', False)],
          'chetten': [('chette', False)],
          'chettens': [('chett', False)],
          'chetter': [('chette', False)],
          'chetterna': [('chette', False)],
          'chetternas': [('chette', False)],
          'chetters': [('chett', False)],
          'chin': [('chi', True)],
          'chins': [('chi', True)],
          'chipp': [('chipp', False)],
          'chipps': [('chipp', False)],
          'chipps-': [('chipp', False)],
          'chips': [('chips', True), ('chip', True)],
          'chips-': [('chips', True)],
          'chis': [('chi', True)],
          'chis-': [('chi', True)],
          'chit': [('chi', True)],
          'chits': [('chi', True)],
          'chman': [('chma', False)],
          'chmans': [('chman', False)],
          'chmers': [('chma', False)],
          'chon': [('chon', False)],
          'chon-': [('chon', False)],
          'chonen': [('chon', False)],
          'chonens': [('chon', False)],
          'choner': [('chon', False)],
          'chonerna': [('chon', False)],
          'chonernas': [('chon', False)],
          'choners': [('chon', False)],
          'chons': [('chon', False)],
          'chons-': [('chon', False)],
          'chor': [('cha', False)],
          'chorder': [('chorder', False)],
          'chorderna': [('chorder', False)],
          'chordernas': [('chorder', False)],
          'chorders': [('chorder', False)],
          'chorna': [('cha', False)],
          'chornas': [('cha', False)],
          'chors': [('cho', False)],
          'chos': [('chos', False)],
          'chos-': [('chos', False)],
          'chosen': [('chos', False)],
          'chosens': [('chos', False)],
          'choser': [('choser', True)],
          'choserna': [('choser', True)],
          'chosernas': [('choser', True)],
          'chosers': [('choser', True)],
          'chus': [('chu', False)],
          'chyr': [('chyr', False)],
          'chyr-': [('chyr', False)],
          'chyrs': [('chyr', False)],
          'chäft': [('chäft', False)],
          'chäft-': [('chäft', False)],
          'chäften': [('chäft', False)],
          'chäftens': [('chäft', False)],
          'chäftet': [('chäft', False)],
          'chäftets': [('chäft', False)],
          'chäfts': [('chäft', False)],
          'chäfts-': [('chäft', False)],
          'chäs': [('chäs', False)],
          'chäs-': [('chäs', False)],
          'chörn': [('chör', False)],
          'chörns': [('chör', False)],
          'ci': [('ci', False)],
          'ci-': [('ci', False)],
          'cialen': [('cial', False)],
          'cialens': [('cial', False)],
          'cian': [('cian', False)],
          'cian-': [('cian', False)],
          'cians': [('cian', False)],
          'ciceron': [('cicero', True), ('ciceron', True)],
          'cicerons': [('cicero', True), ('ciceron', True)],
          'ciden': [('cid', False)],
          'cidens': [('cid', False)],
          'cidens-': [('cidens', False)],
          'cider': [('cider', True)],
          'ciders': [('cider', True)],
          'cidos': [('cidos', False)],
          'cids': [('cid', False)],
          'cie': [('cia', False)],
          'cien': [('ci', False)],
          'ciens': [('ciens', False)],
          'cier': [('cier', False)],
          'cies': [('cy', False)],
          'ciesen': [('cies', False)],
          'ciesens': [('cies', False)],
          'ciet': [('cium', False)],
          'ciets': [('cium', False)],
          'cigarrsnoppar': [('cigarrsnopp', True), ('cigarrsnoppare', True)],
          'cigarrsnopparna': [('cigarrsnoppare', True), ('cigarrsnopp', True)],
          'cigarrsnopparnas': [('cigarrsnopp', True), ('cigarrsnoppare', True)],
          'cigg': [('cigg', True)],
          'cigg-': [('cigg', True)],
          'ciggarna': [('cigg', True)],
          'ciggarnas': [('cigg', True)],
          'ciggars': [('cigg', True)],
          'ciggen': [('cigg', True)],
          'ciggens': [('cigg', True)],
          'ciggs': [('cigg', True)],
          'cikad': [('cikada', True)],
          'cikad-': [('cikada', True)],
          'cikads': [('cikada', True)],
          'cikads-': [('cikada', True)],
          'cilian': [('cilian', False)],
          'cilians': [('cilian', False)],
          'cilie': [('cilie', True)],
          'cilie-': [('cilie', True)],
          'cilien': [('cilie', True)],
          'ciliens': [('cilie', True)],
          'cilier': [('cilie', True)],
          'ciliernas': [('cilie', True)],
          'ciliers': [('cilie', True)],
          'cill': [('cill', False)],
          'cill-': [('cill', False)],
          'cillan': [('cilla', False)],
          'cillen': [('cill', False)],
          'ciller': [('cill', False)],
          'cillerna': [('cill', False)],
          'cillernas': [('cill', False)],
          'cillers': [('cill', False)],
          'cillor': [('cilla', False)],
          'cillorna': [('cilla', False)],
          'cillornas': [('cilla', False)],
          'cillors': [('cilla', False)],
          'cills': [('cill', False)],
          'cills-': [('cill', False)],
          'cimen': [('cimen', False)],
          'cimens': [('cimen', False)],
          'cin': [('cin', False)],
          'cinar': [('cinare', False)],
          'cinar-': [('cinare', False)],
          'cinarens': [('cinare', False)],
          'cinarna': [('cinare', False)],
          'cinets': [('cin', False)],
          'cing': [('cing', False)],
          'cing-': [('cing', False)],
          'cingar': [('cing', False)],
          'cingarna': [('cing', False)],
          'cingarnas': [('cing', False)],
          'cingars': [('cing', False)],
          'cingen': [('cing', False)],
          'cingens': [('cing', False)],
          'cings': [('cing', False)],
          'cings-': [('cing', False)],
          'cinons': [('cino', False)],
          'cinos': [('cino', False)],
          'cint': [('cint', False)],
          'cinter': [('cint', False)],
          'cinterna': [('cint', False)],
          'cinternas': [('cint', False)],
          'cinters': [('cint', False)],
          'cints-': [('cint', False)],
          'cior': [('cia', False)],
          'ciorna': [('cia', False)],
          'ciornas': [('cia', False)],
          'ciors': [('cia', False)],
          'ciosats': [('ciosa', False)],
          'ciskan': [('ciskan', False)],
          'ciskan-': [('ciskan', False)],
          'ciskans': [('ciskan', False)],
          'cismer': [('cism', False)],
          'cismerna': [('cism', False)],
          'cismernas': [('cism', False)],
          'cismers': [('cism', False)],
          'ciss': [('ciss', False)],
          'cissen': [('ciss', False)],
          'cissens': [('ciss', False)],
          'cisser': [('ciss', False)],
          'cisserna': [('ciss', False)],
          'cissernas': [('ciss', False)],
          'cissers': [('ciss', False)],
          'cist-': [('cist', False)],
          'cisten': [('cist', False)],
          'cistens': [('cist', False)],
          'cister': [('cist', False)],
          'cisteriernas': [('cisteri', False)],
          'cisteriets': [('cisteri', False)],
          'cisterna': [('cist', False)],
          'cisternas': [('cist', False)],
          'cisters': [('cist', False)],
          'cistik': [('cistik', False)],
          'cistik-': [('cistik', False)],
          'cistiks': [('cistik', False)],
          'cit': [('cit', False)],
          'citans': [('citans', False)],
          'citernas': [('cit', False)],
          'cites': [('cites', False)],
          'citet': [('cit', False)],
          'citets': [('cit', False)],
          'cits': [('cit', False)],
          'citter': [('cittra', True)],
          'cium': [('cium', False)],
          'ciums': [('cium', False)],
          'ck-': [('ck', False)],
          'ckad': [('ckad', False)],
          'ckad-': [('ckad', False)],
          'ckadens': [('ckad', False)],
          'ckader': [('ckad', False)],
          'ckaders': [('ckad', False)],
          'ckads': [('ckad', False)],
          'ckads-': [('ckad', False)],
          'ckan-': [('ckan', False)],
          'ckana': [('cka', False)],
          'ckanas': [('cka', False)],
          'ckanden': [('ckande', False)],
          'ckankarna': [('ckankare', False)],
          'ckankarnas': [('ckankare', False)],
          'ckans-': [('ckan', False)],
          'ckar-': [('ckare', False)],
          'ckare': [('ckare', False)],
          'ckaren': [('ckare', False)],
          'ckarens': [('ckare', False)],
          'ckars': [('ck', False)],
          'ckart': [('ckart', False)],
          'ckarts': [('ckart', False)],
          'ckarts-': [('ckart', False)],
          'ckas': [('cka', False)],
          'ckas-': [('cka', False)],
          'ckat': [('ckat', False)],
          'ckaten': [('ckat', False)],
          'ckatens': [('ckat', False)],
          'ckatet': [('ckat', False)],
          'ckatets': [('ckat', False)],
          'ckativ': [('ckativ', False)],
          'ckativ-': [('ckativ', False)],
          'ckativs': [('ckativ', False)],
          'ckats': [('cka', False)],
          'ckats-': [('ckat', False)],
          'ckdelar': [('ckdel', False)],
          'ckdelarna': [('ckdel', False)],
          'ckdelarnas': [('ckdel', False)],
          'cke': [('cka', False)],
          'cke-': [('cka', False)],
          'ckel': [('ckel', False)],
          'ckel-': [('ckel', False)],
          'ckelknippe-': [('ckelknippa', False)],
          'ckelroller': [('ckelroll', False)],
          'ckelrollers': [('ckelroll', False)],
          'ckels': [('ckel', False)],
          'ckels-': [('ckel', False)],
          'ckelsen': [('ckelse', False)],
          'cken': [('ck', False)],
          'cken-': [('cken', False)],
          'ckens': [('ck', False)],
          'ckens-': [('cken', False)],
          'ckenskaps': [('ckenskap', False)],
          'cker': [('ck', False)],
          'ckerits': [('ckeri', False)],
          'ckerna': [('ck', False)],
          'ckernas': [('ck', False)],
          'ckers': [('ck', False)],
          'ckersen': [('ckers', False)],
          'ckerärterna': [('ckerärter', False)],
          'ckerärternas': [('ckerärter', False)],
          'ckerärters': [('ckerärter', False)],
          'cket': [('ck', False)],
          'ckfiskar': [('ckfiskare', False)],
          'ckfiskarna': [('ckfisk', False)],
          'ckfiskarnas': [('ckfiskare', False)],
          'ckfots-': [('ckfot', False)],
          'ckfötter': [('ckfot', False)],
          'ckfötterna': [('ckfot', False)],
          'ckfötternas': [('ckfot', False)],
          'ckfötters': [('ckfot', False)],
          'ckhamrar': [('ckhammer', False)],
          'ckhamrarna': [('ckhammare', False)],
          'ckhamrarnas': [('ckhammare', False)],
          'ckhamrars': [('ckhammare', False)],
          'ckis-': [('ckis', False)],
          'ckisarnas': [('ckis', False)],
          'ckisen': [('ckis', False)],
          'ckisens': [('ckis', False)],
          'ckl': [('ckla', False)],
          'ckl-': [('ckla', False)],
          'cklaget': [('cklage', False)],
          'cklamp': [('cklampa', False)],
          'cklamp-': [('cklampa', False)],
          'cklamps': [('cklampa', False)],
          'cklamps-': [('cklampa', False)],
          'cklandets': [('cklande', False)],
          'cklar': [('ckel', False)],
          'cklarna': [('cklare', False)],
          'cklarnas': [('ckel', False)],
          'cklars': [('ckel', False)],
          'cklas': [('ckla', False)],
          'cklen': [('ckel', False)],
          'cklens': [('ckel', False)],
          'ckles': [('ckle', False)],
          'cklet': [('ckel', False)],
          'cklets': [('ckel', False)],
          'ckling': [('ckling', False)],
          'ckling-': [('ckling', False)],
          'cklings': [('ckling', False)],
          'cklings-': [('ckling', False)],
          'cklock': [('cklock', False)],
          'cklocks': [('cklock', False)],
          'cklocks-': [('cklock', False)],
          'cklon': [('cklo', False)],
          'cklons': [('cklo', False)],
          'cklopp': [('cklopp', False)],
          'cklopps': [('cklopp', False)],
          'cklor': [('ckla', False)],
          'cklorna': [('ckla', False)],
          'cklornas': [('ckla', False)],
          'cklors': [('ckla', False)],
          'cklot': [('cklo', False)],
          'cklots': [('cklo', False)],
          'ckls': [('ckle', False)],
          'ckls-': [('ckla', False)],
          'ckna': [('ck', False)],
          'cknar': [('cken', False)],
          'cknarna': [('cknare', False)],
          'cknarnas': [('cknare', False)],
          'cknas': [('ck', False)],
          'cknatt': [('cknatt', False)],
          'cknatten': [('cknatt', False)],
          'cknattens': [('cknatt', False)],
          'cknatts': [('cknatt', False)],
          'cknatts-': [('cknatt', False)],
          'cknen': [('cken', False)],
          'ckningar': [('ckning', False)],
          'ckningarna': [('ckning', False)],
          'ckningarnas': [('ckning', False)],
          'ckningars': [('ckning', False)],
          'cknings': [('ckning', False)],
          'cknings-': [('ckning', False)],
          'cko': [('cka', False)],
          'cko-': [('cko', False)],
          'ckon': [('cko', False)],
          'ckona': [('cko', False)],
          'ckonas': [('cko', False)],
          'ckons': [('cko', False)],
          'ckor': [('cka', False)],
          'ckord': [('ckord', False)],
          'ckord-': [('ckord', False)],
          'ckords': [('ckord', False)],
          'ckords-': [('ckord', False)],
          'ckorna': [('cka', False)],
          'ckornas': [('cka', False)],
          'ckors': [('cka', False)],
          'ckos': [('cko', False)],
          'ckos-': [('cko', False)],
          'ckot': [('cko', False)],
          'ckots': [('cko', False)],
          'ckr': [('ckra', False)],
          'ckr-': [('ckra', False)],
          'ckrams': [('ckram', False)],
          'ckrams-': [('ckram', False)],
          'ckran': [('ckra', False)],
          'ckrans': [('ckra', False)],
          'ckrarnas': [('ckrare', False)],
          'ckras': [('ckra', False)],
          'ckrets': [('cker', False)],
          'ckringar': [('ckring', False)],
          'ckringars': [('ckring', False)],
          'ckrull': [('ckrulle', False)],
          'ckrull-': [('ckrulle', False)],
          'ckrulle': [('ckrulle', False)],
          'ckrulls': [('ckrulle', False)],
          'ckrulls-': [('ckrulle', False)],
          'ckröst-': [('ckröst', False)],
          'ckrösten': [('ckröst', False)],
          'cks': [('ck', False)],
          'cks-': [('ck', False)],
          'cksaks': [('cksak', False)],
          'cksaks-': [('cksak', False)],
          'cksens': [('cks', False)],
          'cksnärt-': [('cksnärta', False)],
          'cksnärts-': [('cksnärta', False)],
          'cksvärden': [('cksvärd', False)],
          'cksvärdens': [('cksvärd', False)],
          'cksvärdets': [('cksvärd', False)],
          'ckteater': [('ckteater', False)],
          'ckteaters': [('ckteater', False)],
          'cktons': [('ckton', False)],
          'cktorn': [('cktorn', False)],
          'cktorns': [('cktorn', False)],
          'ckungar': [('ckunge', False)],
          'ckungarna': [('ckunge', False)],
          'ckungarnas': [('ckunge', False)],
          'ckungars': [('ckunge', False)],
          'ckungen': [('ckunge', False)],
          'ckungens': [('ckunge', False)],
          'ckup': [('ckup', False)],
          'ckup-': [('ckup', False)],
          'ckups': [('ckup', False)],
          'ckups-': [('ckup', False)],
          'ckuret': [('ckur', False)],
          'ckurets': [('ckur', False)],
          'ckurs': [('ckur', False)],
          'ckurs-': [('ckur', False)],
          'ckus': [('cku', False)],
          'ckus-': [('cku', False)],
          'ckut': [('cku', False)],
          'ckuts': [('cku', False)],
          'ckändarnas': [('ckände', False)],
          'ckår': [('ckår', False)],
          'ckåren': [('ckår', False)],
          'ckårens': [('ckår', False)],
          'ckårs': [('ckår', False)],
          'ckårs-': [('ckår', False)],
          'ckås': [('ckås', False)],
          'ckås-': [('ckås', False)],
          'cl': [('cl', True)],
          'clen': [('cle', False)],
          'clens': [('cle', False)],
          'clet': [('cle', False)],
          'clets': [('cle', False)],
          'clips-': [('clips', True)],
          'cm-': [('cm', True)],
          'cn': [('c', False)],
          'cne-': [('cne', False)],
          'cnen': [('cne', False)],
          'cnens': [('cne', False)],
          'cns': [('c', False)],
          'codan': [('coda', True)],
          'coer': [('co', False)],
          'coerna': [('co', False)],
          'coernas': [('co', False)],
          'coers': [('co', False)],
          'col': [('cola', False)],
          'col-': [('cola', False)],
          'coli': [('coli', False)],
          'colins': [('coli', False)],
          'colis': [('coli', False)],
          'collagens': [('collage', True)],
          'collier': [('collier', True), ('collie', True)],
          'colliers': [('collier', True), ('collie', True)],
          'colon': [('colo', False)],
          'colons': [('colo', False)],
          'color': [('cola', True)],
          'colorna': [('cola', True)],
          'colornas': [('cola', True)],
          'colors': [('cola', True)],
          'colos': [('colo', False)],
          'colos-': [('colo', False)],
          'cols': [('cola', False)],
          'cols-': [('cola', False)],
          'coltan': [('coltan', True)],
          'coltans': [('coltan', True)],
          'combin': [('combi', True)],
          'comen': [('com', False)],
          'comens': [('com', False)],
          'commarna': [('com', False)],
          'coms': [('com', False)],
          'comsen': [('com', False)],
          'comsens': [('com', False)],
          'con': [('co', False)],
          'cone': [('cone', False)],
          'cone-': [('cone', False)],
          'conen': [('cone', False)],
          'conens': [('cone', False)],
          'coner': [('cone', False)],
          'conerna': [('cone', False)],
          'conernas': [('cone', False)],
          'coners': [('cone', False)],
          'cones': [('cone', False)],
          'cones-': [('cone', False)],
          'conesen': [('cone', False)],
          'conesens': [('cone', False)],
          'cons': [('co', False)],
          'cor': [('co', False)],
          'core': [('core', False)],
          'core-': [('core', False)],
          'coren': [('core', False)],
          'corens': [('core', False)],
          'cores': [('core', False)],
          'corn': [('corn', False)],
          'corn-': [('corn', False)],
          'corna': [('co', False)],
          'cornas': [('co', False)],
          'cornen': [('corn', False)],
          'cornens': [('corn', False)],
          'corns': [('corn', False)],
          'corns-': [('corn', False)],
          'cors': [('ca', False)],
          'cos': [('co', False)],
          'cos-': [('co', False)],
          'cosarna': [('co', False)],
          'cosen': [('co', False)],
          'cosens': [('co', False)],
          'cot': [('cot', False)],
          'cote': [('cote', False)],
          'cote-': [('cote', False)],
          'coten': [('cote', False)],
          'cotens': [('cote', False)],
          'coter': [('cote', False)],
          'coterna': [('cote', False)],
          'coternas': [('cote', False)],
          'coters': [('cote', False)],
          'cotes': [('cote', False)],
          'cotes-': [('cote', False)],
          'cots': [('co', False)],
          'cous': [('cous', False)],
          'cousen': [('cous', False)],
          'cousens': [('cous', False)],
          'couten': [('cout', False)],
          'coutens': [('cout', False)],
          'couter': [('cout', False)],
          'couterna': [('cout', False)],
          'couternas': [('cout', False)],
          'couters': [('cout', False)],
          'cover': [('cover', True)],
          'covers': [('cover', True)],
          'coyoten': [('coyote', True)],
          'coyotens': [('coyote', True)],
          'coyoter': [('coyote', True)],
          'coyoterna': [('coyote', True)],
          'coyoternas': [('coyote', True)],
          'coyoters': [('coyote', True)],
          'crackers': [('crackers', True)],
          'crande': [('crande', False)],
          'crande-': [('crande', False)],
          'cranden': [('crande', False)],
          'crandens': [('crande', False)],
          'crandet': [('crande', False)],
          'crarnas': [('cer', False)],
          'cred': [('cred', True)],
          'cred-': [('cred', True)],
          'creden': [('cred', True)],
          'credens': [('cred', True)],
          'creds': [('cred', True)],
          'creds-': [('cred', True)],
          'cremen': [('creme', True)],
          'cremens': [('creme', True)],
          'crepe': [('crepe', True)],
          'crepe-': [('crepe', True)],
          'crepen': [('crepe', True)],
          'crepens': [('crepe', True)],
          'cricket': [('cricket', True)],
          'cripta': [('cripta', False)],
          'criptas': [('cripta', False)],
          'cror': [('cro', False)],
          'cros': [('cro', False)],
          'cros-': [('cro', False)],
          'cry': [('cry', False)],
          'cry-': [('cry', False)],
          'crys': [('cry', False)],
          'cs': [('c', True)],
          'cs-': [('ca', False)],
          'csarnas': [('c', False)],
          'csen': [('c', False)],
          'csens': [('c', False)],
          'cset': [('cies', False)],
          'csets': [('cies', False)],
          'ct': [('c', False)],
          'cter-': [('cter', False)],
          'cters': [('cter', False)],
          'cts': [('c', False)],
          'cturnen': [('cturne', False)],
          'cturnens': [('cturne', False)],
          'cturner': [('cturne', False)],
          'cturnerna': [('cturne', False)],
          'cturnernas': [('cturne', False)],
          'cturners': [('cturne', False)],
          'culotte-': [('culotte', False)],
          'culottens': [('culotte', False)],
          'cune': [('cune', False)],
          'cune-': [('cune', False)],
          'cunen': [('cune', False)],
          'cunens': [('cune', False)],
          'cuner': [('cune', False)],
          'cunerna': [('cune', False)],
          'cunernas': [('cune', False)],
          'cuners': [('cune', False)],
          'curie': [('curia', True), ('curie', True)],
          'curie-': [('curie', True), ('curia', True)],
          'curien': [('curie', True)],
          'curis': [('curia', True)],
          'curlandet': [('curlande', True)],
          'cusarnas': [('cus', False)],
          'cutsarna': [('cut', False)],
          'cutsarnas': [('cut', False)],
          'cy': [('cy', False)],
          'cyan': [('cyan', True)],
          'cyans': [('cyan', True)],
          'cyer': [('cy', False)],
          'cyerna': [('cy', False)],
          'cyernas': [('cy', False)],
          'cyers': [('cy', False)],
          'cyklings': [('cykling', True)],
          'cyn': [('cy', False)],
          'cyns': [('cy', False)],
          'cys': [('cy', False)],
          'cysarna': [('cy', False)],
          'cyst': [('cysta', True)],
          'cyst-': [('cysta', True)],
          'cystan': [('cysta', True)],
          'cystans': [('cysta', True)],
          'cyste': [('cysta', True)],
          'cyt': [('cyt', False)],
          'cyt-': [('cyt', False)],
          'cyts': [('cyt', False)],
          'cyts-': [('cyt', False)],
          'céerna': [('cé', False)],
          'céernas': [('cé', False)],
          'd': [('d', True)],
          'd-': [('d', True)],
          'd-ins': [('d-in', False)],
          'da': [('da', False)],
          'da-': [('da', False)],
          'dadd-': [('dadda', True)],
          'dadier': [('dadier', False)],
          'dadiernas': [('dadier', False)],
          'dadiers': [('dadier', False)],
          'daers': [('dae', False)],
          'dagar': [('dag', True)],
          'dagarna': [('dag', True)],
          'dagarnas': [('dag', True)],
          'dagars': [('dag', True)],
          'dagdrömmar': [('dagdrömmare', True), ('dagdröm', True)],
          'dagdrömmarna': [('dagdrömmare', True), ('dagdröm', True)],
          'dagdrömmarnas': [('dagdrömmare', True), ('dagdröm', True)],
          'dage': [('dage', False)],
          'dage-': [('dage', False)],
          'dagen': [('dag', True)],
          'dagens': [('dagens', True), ('dag', True)],
          'dager': [('dager', False)],
          'dagers': [('dager', True)],
          'daget': [('dage', False)],
          'dagg': [('dagg', False)],
          'dagg-': [('dagg', True)],
          'daggarna': [('dagg', True)],
          'daggarnas': [('dagg', False)],
          'daggars': [('dagg', True)],
          'daggen': [('dagg', False)],
          'daggens': [('dagg', False)],
          'daggs-': [('dagg', False)],
          'dago-': [('dago', True)],
          'dagods': [('dagods', False)],
          'dagods-': [('dagods', False)],
          'dagrar': [('dager', True)],
          'dagrars': [('dager', True)],
          'dags': [('dags', True), ('dag', True)],
          'dags-': [('dags', True)],
          'dagsnyheter': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsnyheterna': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsnyheternas': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsnyheters': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsnyhets': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsnyhets-': [('dagsnyhet', True), ('dagsnyheter', True)],
          'dagsverkets': [('dagsverke', False)],
          'dagsvärden': [('dagsvärde', True)],
          'dagsvärdets': [('dagsvärde', True)],
          'dakin': [('dakin', False)],
          'dakter': [('dakt', False)],
          'dakters': [('dakt', False)],
          'daktik': [('daktik', False)],
          'daktik-': [('daktik', False)],
          'daktiks': [('daktik', False)],
          'dalandets': [('dalande', True)],
          'dalar': [('dal', False)],
          'dalben': [('dalb', False)],
          'dalbor': [('dalbo', True)],
          'dalborna': [('dalbo', True)],
          'dalbornas': [('dalbo', True)],
          'dalbors': [('dalbo', True)],
          'daler': [('daler', True)],
          'dalerna': [('daler', False)],
          'dalernas': [('daler', False)],
          'dalers': [('daler', False)],
          'dalet': [('dal', False)],
          'dalets': [('dal', False)],
          'dalier': [('dal', False)],
          'daliernas': [('dal', False)],
          'daliers': [('dal', False)],
          'dalisk': [('dalisk', False)],
          'dalisk-': [('dalisk', False)],
          'dalj': [('dalj', True)],
          'dalj-': [('dalj', False)],
          'daljen': [('dalj', False)],
          'daljens': [('dalj', False)],
          'daljer': [('dalj', False)],
          'daljerna': [('dalj', False)],
          'daljernas': [('dalj', False)],
          'daljers': [('dalj', False)],
          'daljs': [('dalj', False)],
          'daljs-': [('dalj', False)],
          'daller-': [('daller', True)],
          'dals': [('dal', False)],
          'dals-': [('dal', False)],
          'dalts': [('dalt', True)],
          'dam': [('dam', False)],
          'dam-': [('dam', True)],
          'dame': [('dame', False)],
          'dame-': [('dame', False)],
          'damen': [('dam', True)],
          'damens': [('dam', True)],
          'damenten': [('dament', False)],
          'damentens': [('dament', False)],
          'damentet': [('dament', False)],
          'daments-': [('dament', False)],
          'damer': [('dam', True)],
          'damerna': [('dam', True)],
          'damernas': [('dam', True)],
          'damers': [('dam', False)],
          'dames-': [('dame', False)],
          'dammarna': [('damm', False)],
          'dammars': [('damm', False)],
          'dammen': [('damm', False)],
          'dammens': [('damm', False)],
          'dammer': [('dam', False)],
          'dammernas': [('dam', False)],
          'dammet': [('damm', False)],
          'dammets': [('damm', False)],
          'damp': [('damp', True)],
          'damp-': [('damp', True)],
          'dampen': [('damp', True)],
          'dampens': [('damp', True)],
          'damps': [('damp', True)],
          'dams': [('dam', False)],
          'dams-': [('dam', True)],
          'dan': [('dag', True)],
          'dana': [('dum', False)],
          'danar': [('danare', False)],
          'danarna': [('danare', True)],
          'danas': [('dum', False)],
          'dand': [('dand', False)],
          'dand-': [('dand', False)],
          'dandarna': [('dande', False)],
          'dandets': [('dande', False)],
          'dandier': [('dandy', True)],
          'dands': [('dand', False)],
          'danens': [('dan', False)],
          'danets': [('dan', False)],
          'dang': [('dang', False)],
          'dang-': [('dang', False)],
          'dangen': [('dang', False)],
          'dangens': [('dang', False)],
          'danger': [('dang', False)],
          'dangerna': [('dang', False)],
          'dangernas': [('dang', False)],
          'dangers': [('dang', False)],
          'dangs': [('dang', False)],
          'danhållanden': [('danhållande', False)],
          'danhållandena': [('danhållande', False)],
          'danhållandenas': [('danhållande', False)],
          'danhållandens': [('danhållande', False)],
          'danier': [('danier', False)],
          'danierna': [('danier', False)],
          'daniernas': [('danier', False)],
          'dank': [('dank', False)],
          'dank-': [('dank', False)],
          'dankar': [('dank', False)],
          'dankar-': [('dankare', False)],
          'dankarna': [('dank', True)],
          'dankarnas': [('dank', True)],
          'dankars': [('dank', True)],
          'danke': [('danka', False)],
          'danken': [('dank', False)],
          'dankens': [('dank', False)],
          'dankor': [('danka', False)],
          'danks': [('dank', False)],
          'danks-': [('dank', True)],
          'dans': [('dans', True), ('dag', True)],
          'dans-': [('dans', False)],
          'dansaren': [('dansare', False)],
          'dansarna': [('dansare', False)],
          'dansarnas': [('dansare', True)],
          'dansen': [('dans', False)],
          'dansens': [('dans', False)],
          'danser': [('dans', False)],
          'danserna': [('dans', False)],
          'dansernas': [('dans', False)],
          'dansers': [('dans', False)],
          'dansk': [('danska', True), ('dansk', True)],
          'dansk-': [('danska', True), ('dansk', True)],
          'danskar': [('dansk', True)],
          'danskarnas': [('dansk', True)],
          'danstalter': [('danstalt', False)],
          'danstalterna': [('danstalt', False)],
          'danstalternas': [('danstalt', False)],
          'danstalters': [('danstalt', False)],
          'danstalts': [('danstalt', False)],
          'danstalts-': [('danstalt', False)],
          'dant': [('dant', False)],
          'dantagen': [('dantag', False)],
          'dantagens': [('dantag', False)],
          'dantar': [('dantare', False)],
          'dantarna': [('dantare', False)],
          'dantarnas': [('dantare', False)],
          'danten': [('dant', False)],
          'dantens': [('dant', False)],
          'danter': [('dant', False)],
          'danterna': [('dant', False)],
          'danternas': [('dant', False)],
          'danters': [('dant', False)],
          'dap-': [('dapa', False)],
          'dapan': [('dapa', False)],
          'dapans': [('dapa', False)],
          'dapas': [('dapa', False)],
          'daps': [('dapa', False)],
          'dar': [('dag', True)],
          'dar-': [('dare', False)],
          'dard': [('dard', False)],
          'dard-': [('dard', False)],
          'darden': [('dard', False)],
          'dardens': [('dard', False)],
          'darder': [('dard', False)],
          'darderna': [('dard', False)],
          'dardernas': [('dard', False)],
          'darders': [('dard', False)],
          'dards': [('dard', False)],
          'dards-': [('dard', False)],
          'dare': [('dare', False)],
          'darena': [('dare', False)],
          'darenas': [('dare', False)],
          'darens': [('dare', False)],
          'dares': [('dare', False)],
          'dares-': [('dare', False)],
          'darie': [('darium', False)],
          'darie-': [('darium', False)],
          'darier': [('darium', False)],
          'darierna': [('darium', False)],
          'dariernas': [('darium', False)],
          'dariers': [('darium', False)],
          'darin': [('darin', False)],
          'darmar': [('darm', False)],
          'darmarnas': [('darm', False)],
          'darna': [('dag', True)],
          'darnas': [('dag', True)],
          'darrock-': [('darrocka', True)],
          'darrocks': [('darrocka', True)],
          'darrocks-': [('darrocka', True)],
          'darrs-': [('darr', True)],
          'dars': [('dag', True)],
          'dart': [('dart', False)],
          'darten': [('dart', True)],
          'dartens': [('dart', True)],
          'darterna': [('dart', False)],
          'darts-': [('dart', False)],
          'das': [('da', False)],
          'das-': [('da', False)],
          'dask': [('dask', True)],
          'dask-': [('dask', True)],
          'dasket': [('dask', True)],
          'daskets': [('dask', True)],
          'dass': [('dass', False)],
          'dassar': [('dass', False)],
          'dassarna': [('dass', False)],
          'dassars': [('dass', False)],
          'dassens': [('dass', False)],
          'dasset': [('dass', True)],
          'dastolen': [('dastol', False)],
          'dastolens': [('dastol', False)],
          'dat': [('dat', True)],
          'data': [('data', False)],
          'datan': [('data', False)],
          'datana': [('data', False)],
          'datanas': [('data', False)],
          'datar': [('dat', False)],
          'datarnas': [('dat', False)],
          'datars': [('dat', False)],
          'datas': [('data', True)],
          'datat': [('data', False)],
          'datats': [('data', False)],
          'date': [('date', True)],
          'date-': [('date', True)],
          'daten': [('date', True), ('dat', True)],
          'datens': [('date', True), ('dat', True)],
          'dater': [('date', True), ('dat', True)],
          'daterna': [('date', True), ('dat', True)],
          'daternas': [('date', True), ('dat', True)],
          'daters': [('date', True), ('dat', True)],
          'dates': [('date', True)],
          'dates-': [('date', True)],
          'datidens': [('datid', False)],
          'datids': [('datid', False)],
          'datids-': [('datid', False)],
          'dation': [('dation', False)],
          'dationen': [('dation', False)],
          'dations': [('dation', False)],
          'dativ': [('dativ', True)],
          'dativ-': [('dativ', True)],
          'dativen': [('dativ', True)],
          'dativens': [('dativ', True)],
          'dativer': [('dativ', True)],
          'dativerna': [('dativ', True)],
          'dativernas': [('dativ', True)],
          'dativers': [('dativ', True)],
          'dativet': [('dativum', False)],
          'dativs': [('dativ', True)],
          'dator': [('data', True), ('dator', True)],
          'dators': [('data', True), ('dator', True)],
          'datos': [('dato', True)],
          'datos-': [('dato', True)],
          'dats': [('dat', True)],
          'dats-': [('dat', False)],
          'dattens': [('datten', True)],
          'davatten': [('davatten', False)],
          'davattens': [('davatten', False)],
          'daver': [('daver', False)],
          'daverna': [('daver', False)],
          'davernas': [('daver', False)],
          'davers': [('daver', False)],
          'davier': [('davier', False)],
          'davierna': [('davier', False)],
          'daviernas': [('davier', False)],
          'daviers': [('davier', False)],
          'davitet': [('davit', False)],
          'davitets': [('davit', False)],
          'davren': [('daver', False)],
          'davrens': [('daver', False)],
          'dback-': [('dbacke', False)],
          'dbackar': [('dbacke', False)],
          'dbackarna': [('dbacke', False)],
          'dbackarnas': [('dbacke', False)],
          'dbackars': [('dbacke', False)],
          'dbacke': [('dbacke', False)],
          'dbacke-': [('dbacke', False)],
          'dbacken': [('dbacke', False)],
          'dbacks': [('dbacke', False)],
          'dbacks-': [('dbacke', False)],
          'dbagg': [('dbagge', False)],
          'dbagg-': [('dbagge', False)],
          'dbaggar': [('dbagge', False)],
          'dbaggarna': [('dbagge', False)],
          'dbaggarnas': [('dbagge', False)],
          'dbaggars': [('dbagge', False)],
          'dbaggen': [('dbagge', False)],
          'dbaggens': [('dbagge', False)],
          'dbaggs': [('dbagge', False)],
          'dbaggs-': [('dbagge', False)],
          'dbal': [('dbal', False)],
          'dbalen': [('dbal', False)],
          'dbalens': [('dbal', False)],
          'dbals': [('dbal', False)],
          'dbals-': [('dbal', False)],
          'dbanan': [('dbana', False)],
          'dbanans': [('dbana', False)],
          'dbandets': [('dband', False)],
          'dbane': [('dbana', False)],
          'dbane-': [('dbana', False)],
          'dbarren': [('dbarr', False)],
          'dbarrens': [('dbarr', False)],
          'dbasar': [('dbasare', False)],
          'dbasar-': [('dbasare', False)],
          'dbasaren': [('dbasare', False)],
          'dbasarens': [('dbasare', False)],
          'dbasarna': [('dbasare', False)],
          'dbasarnas': [('dbasare', False)],
          'dben': [('dben', False)],
          'dben-': [('dbena', False)],
          'dbens': [('dbena', False)],
          'dbens-': [('dben', False)],
          'dbet': [('dbeta', False)],
          'dbet-': [('dbeta', False)],
          'dbete': [('dbeta', False)],
          'dbets': [('dbeta', False)],
          'dbets-': [('dbeta', False)],
          'dbevis': [('dbevis', False)],
          'dbevis-': [('dbevis', False)],
          'dbiets': [('dbi', False)],
          'dbil': [('dbil', False)],
          'dbilar': [('dbil', False)],
          'dbilars': [('dbil', False)],
          'dbils': [('dbil', False)],
          'dbils-': [('dbil', False)],
          'dbin': [('dbi', False)],
          'dbit': [('dbi', False)],
          'dbitars': [('dbit', False)],
          'dbits': [('dbit', False)],
          'dbits-': [('dbit', False)],
          'dboj': [('dboj', False)],
          'dboj-': [('dboja', False)],
          'dbojar': [('dboj', False)],
          'dbojars': [('dboj', False)],
          'dbojs': [('dboja', False)],
          'dbojs-': [('dboj', False)],
          'dbolaget': [('dbolag', False)],
          'dbomb': [('dbomb', False)],
          'dbomber': [('dbomb', False)],
          'dbomberna': [('dbomb', False)],
          'dbombernas': [('dbomb', False)],
          'dbombers': [('dbomb', False)],
          'dbombs': [('dbomb', False)],
          'dbombs-': [('dbomb', False)],
          'dborgar': [('dborg', False)],
          'dborgarna': [('dborgare', False)],
          'dborgarnas': [('dborgare', False)],
          'dborgen': [('dborg', False)],
          'dborgens': [('dborg', False)],
          'dborr': [('dborre', False)],
          'dborr-': [('dborre', False)],
          'dborrar': [('dborre', False)],
          'dborrarna': [('dborre', False)],
          'dborrarnas': [('dborre', False)],
          'dborrars': [('dborre', False)],
          'dborren': [('dborre', False)],
          'dborrens': [('dborre', False)],
          'dborrs': [('dborre', False)],
          'dborrs-': [('dborre', False)],
          'dbors': [('dbo', False)],
          'dborst': [('dborste', False)],
          'dborst-': [('dborste', False)],
          'dborsten': [('dborste', False)],
          'dborstens': [('dborste', False)],
          'dbrandens': [('dbrand', False)],
          'dbroder': [('dbroder', False)],
          'dbrodern': [('dbroder', False)],
          'dbroderns': [('dbroder', False)],
          'dbroders': [('dbroder', False)],
          'dbroms': [('dbroms', False)],
          'dbromsar': [('dbroms', False)],
          'dbromsarna': [('dbroms', False)],
          'dbromsarnas': [('dbroms', False)],
          'dbrons': [('dbro', False)],
          'dbryt': [('dbry', False)],
          'dbrytar': [('dbrytare', False)],
          'dbrytarna': [('dbrytare', False)],
          'dbrytarnas': [('dbrytare', False)],
          'dbryts': [('dbry', False)],
          'dbråk': [('dbråk', False)],
          'dbråks': [('dbråk', False)],
          'dbråks-': [('dbråk', False)],
          'dbröder': [('dbroder', False)],
          'dbröderna': [('dbroder', False)],
          'dbrödernas': [('dbroder', False)],
          'dbröders': [('dbroder', False)],
          'dbyx': [('dbyxa', False)],
          'dbyx-': [('dbyxa', False)],
          'dbälte': [('dbälte', False)],
          'dbärs': [('dbär', False)],
          'dbärs-': [('dbär', False)],
          'dbåg': [('dbåge', False)],
          'dbåg-': [('dbåge', False)],
          'dbågs': [('dbåge', False)],
          'dbågs-': [('dbåge', False)],
          'dbön': [('dböna', False)],
          'dbön-': [('dböna', False)],
          'dböne': [('dböna', False)],
          'dböne-': [('dböna', False)],
          'dböns': [('dböna', False)],
          'dböns-': [('dböna', False)],
          'dcell': [('dcell', False)],
          'dchen': [('dchen', False)],
          'dchens': [('dchen', False)],
          'dd': [('dd', False)],
          'ddagar': [('ddag', False)],
          'ddagarna': [('ddag', False)],
          'ddagarnas': [('ddag', False)],
          'ddagars': [('ddag', False)],
          'ddagen': [('ddag', False)],
          'ddagens': [('ddag', False)],
          'ddags': [('ddag', False)],
          'ddags-': [('ddag', False)],
          'ddan': [('dda', False)],
          'ddanden': [('ddande', False)],
          'ddandens': [('ddande', False)],
          'ddans': [('ddag', False)],
          'ddaren': [('ddare', False)],
          'ddarnas': [('ddare', False)],
          'ddars': [('dd', False)],
          'ddator': [('ddator', False)],
          'ddators': [('ddator', False)],
          'dde': [('dda', False)],
          'dde-': [('dda', False)],
          'ddel': [('ddel', False)],
          'ddelandet': [('ddelande', False)],
          'ddelar': [('ddelare', False)],
          'ddelarna': [('ddelare', False)],
          'ddelarnas': [('ddelare', False)],
          'ddels': [('ddel', False)],
          'ddels-': [('ddel', False)],
          'dden': [('dd', False)],
          'ddenderna': [('ddend', False)],
          'ddendernas': [('ddend', False)],
          'ddens': [('dd', False)],
          'dder': [('dd', False)],
          'dder-': [('dder', False)],
          'dderits': [('dderi', False)],
          'dderivat': [('dderivat', False)],
          'dderivat-': [('dderivat', False)],
          'dderivats': [('dderivat', False)],
          'ddern': [('dder', False)],
          'dderna': [('dd', False)],
          'ddernas': [('dd', False)],
          'dderns': [('dder', False)],
          'dders': [('dd', False)],
          'dders-': [('dder', False)],
          'ddet': [('dd', False)],
          'ddie': [('ddie', False)],
          'ddie-': [('ddie', False)],
          'ddien': [('ddie', False)],
          'ddiens': [('ddie', False)],
          'ddierna': [('ddie', False)],
          'ddiers': [('ddie', False)],
          'ddies': [('ddie', False)],
          'dding': [('dding', False)],
          'dding-': [('dding', False)],
          'ddingar': [('dding', False)],
          'ddingarna': [('dding', False)],
          'ddingarnas': [('dding', False)],
          'ddingars': [('dding', False)],
          'ddingen': [('dding', False)],
          'ddingens': [('dding', False)],
          'ddings': [('dding', False)],
          'ddings-': [('dding', False)],
          'ddiskar': [('ddisk', False)],
          'ddiskarna': [('ddisk', False)],
          'ddiskarnas': [('ddisk', False)],
          'ddjävlar': [('ddjävel', False)],
          'ddjävlarna': [('ddjävel', False)],
          'ddjävlarnas': [('ddjävel', False)],
          'ddjävlars': [('ddjävel', False)],
          'ddlar': [('ddel', False)],
          'ddlarna': [('ddel', False)],
          'ddlarnas': [('ddel', False)],
          'ddlars': [('ddel', False)],
          'ddo-': [('ddo', False)],
          'ddock': [('ddock', False)],
          'ddock-': [('ddocka', False)],
          'ddocks': [('ddocka', False)],
          'ddocks-': [('ddock', False)],
          'ddomar': [('ddom', False)],
          'ddomarna': [('ddom', False)],
          'ddomarnas': [('ddom', False)],
          'ddon': [('ddon', False)],
          'ddona': [('ddo', False)],
          'ddonas': [('ddo', False)],
          'ddons': [('ddon', False)],
          'ddons-': [('ddon', False)],
          'ddor': [('dda', False)],
          'ddorna': [('dda', False)],
          'ddornas': [('dda', False)],
          'ddors': [('dda', False)],
          'ddos': [('ddo', False)],
          'ddot': [('ddo', False)],
          'ddplants': [('ddplanta', False)],
          'ddr': [('ddra', False)],
          'ddr-': [('ddra', False)],
          'ddra': [('ddra', False)],
          'ddran': [('ddra', False)],
          'ddrans': [('ddra', False)],
          'ddrars': [('dder', False)],
          'ddras': [('ddra', False)],
          'ddringar': [('ddring', False)],
          'ddringarnas': [('ddring', False)],
          'ddringars': [('ddring', False)],
          'ddrorna': [('ddra', False)],
          'ddrottar': [('ddrott', False)],
          'ddrottarnas': [('ddrott', False)],
          'dds': [('dd', False)],
          'dds-': [('dd', False)],
          'ddsar': [('ddsare', False)],
          'ddyn': [('ddy', False)],
          'ddyns': [('ddy', False)],
          'ddyns-': [('ddyn', False)],
          'ddyrkar': [('ddyrkare', False)],
          'ddyrkarna': [('ddyrkare', False)],
          'ddyrkarnas': [('ddyrkare', False)],
          'ddys': [('ddy', False)],
          'dealen': [('deal', False)],
          'dealens': [('deal', False)],
          'dealet': [('deal', False)],
          'dealets': [('deal', False)],
          'deanden': [('deand', False)],
          'deandens': [('deand', False)],
          'debanans': [('debana', False)],
          'deborgen': [('deborg', False)],
          'deen': [('de', False)],
          'deens': [('de', False)],
          'deer': [('dé', False)],
          'deerna': [('de', False)],
          'deg': [('deg', True)],
          'deg-': [('deg', True)],
          'degar': [('deg', False)],
          'degarna': [('deg', True)],
          'degs': [('deg', False)],
          'degs-': [('deg', True)],
          'dej': [('deja', True)],
          'dej-': [('deja', True)],
          'dejs': [('deja', True)],
          'dejs-': [('deja', True)],
          'dejt': [('dejt', False)],
          'dejt-': [('dejt', False)],
          'dejtar': [('dejt', False)],
          'dejtarna': [('dejt', True)],
          'dejtars': [('dejt', False)],
          'dejten': [('dejt', False)],
          'dejtens': [('dejt', False)],
          'dejts': [('dejt', False)],
          'dejts-': [('dejt', True)],
          'dekadens': [('dekadens', True), ('dekad', True)],
          'dekan': [('dekan', True)],
          'dekans': [('dekan', True)],
          'dekor': [('dekor', True)],
          'dekors': [('dekor', True)],
          'dekrets-': [('dekret', True)],
          'del': [('del', True)],
          'del-': [('del', True)],
          'delanden': [('delande', False)],
          'delandens': [('delande', False)],
          'delandet': [('delande', True)],
          'delandets': [('delande', False)],
          'delar': [('del', False)],
          'delar-': [('delare', False)],
          'delare': [('delare', False)],
          'delarens': [('delare', False)],
          'delares': [('delare', False)],
          'delarna': [('del', False)],
          'delarnas': [('del', False)],
          'delars': [('del', True)],
          'delblom': [('delblomma', False)],
          'delblom-': [('delblomma', False)],
          'delbloms': [('delblomma', False)],
          'delbloms-': [('delblomma', False)],
          'deldar': [('deld', False)],
          'deldarna': [('deld', False)],
          'deldarnas': [('deld', False)],
          'delers': [('del', False)],
          'dell': [('dell', False)],
          'dell-': [('dell', False)],
          'dellen': [('dell', False)],
          'deller': [('dell', False)],
          'dellerna': [('dell', False)],
          'dellernas': [('dell', False)],
          'dellers': [('dell', False)],
          'dellet': [('dell', False)],
          'dellets': [('dell', False)],
          'dells': [('dell', False)],
          'dells-': [('dell', False)],
          'dels': [('del', True)],
          'dels-': [('del', True)],
          'delsträck': [('delsträcka', True)],
          'delsträck-': [('delsträcka', True)],
          'delsträcks-': [('delsträcka', True)],
          'delsvar': [('delsvara', False)],
          'dem': [('dem', False)],
          'dem-': [('dem', False)],
          'demang': [('demang', False)],
          'demang-': [('demang', False)],
          'demangs': [('demang', False)],
          'demangs-': [('demang', False)],
          'demens': [('demens', True)],
          'dementin': [('dementi', True)],
          'dementins': [('dementi', True)],
          'demien': [('demi', False)],
          'demiens': [('demi', False)],
          'demier': [('demi', False)],
          'demierna': [('demi', False)],
          'demiernas': [('demi', False)],
          'demiers': [('demi', False)],
          'demiker': [('demiker', False)],
          'demikerna': [('demiker', False)],
          'demikernas': [('demiker', False)],
          'demikers': [('demiker', False)],
          'demis': [('demi', False)],
          'demon': [('demon', True), ('demo', True)],
          'demons': [('demon', True), ('demo', True)],
          'demosens': [('demo', True)],
          'dems': [('dem', False)],
          'dena': [('de', False)],
          'denaps-': [('denapa', False)],
          'denar': [('denar', True)],
          'denaren': [('denar', True)],
          'denars': [('denar', True)],
          'denas': [('de', False)],
          'dendana': [('denda', False)],
          'dendanas': [('denda', False)],
          'dendans': [('denda', False)],
          'denden': [('dend', False)],
          'dendens': [('dend', False)],
          'dender': [('dend', False)],
          'denders': [('dend', False)],
          'denet': [('den', False)],
          'denets': [('den', False)],
          'denheter': [('denhet', False)],
          'denheterna': [('denhet', False)],
          'denheternas': [('denhet', False)],
          'denheters': [('denhet', False)],
          'denhets': [('denhet', False)],
          'denhets-': [('denhet', False)],
          'denie': [('denia', False)],
          'denie-': [('denia', False)],
          'denier': [('denier', True)],
          'deniers': [('denier', True)],
          'denior': [('denia', False)],
          'deniors': [('denia', False)],
          'denis': [('denia', False)],
          'denis-': [('denia', False)],
          'denits': [('denit', False)],
          'denner': [('denner', False)],
          'dennerna': [('denner', False)],
          'dennernas': [('denner', False)],
          'denners': [('denner', False)],
          'denomens': [('denom', False)],
          'dens-': [('dens', False)],
          'densarnas': [('densare', False)],
          'densats': [('densat', False)],
          'densen': [('dens', False)],
          'densens': [('dens', False)],
          'denser': [('dens', False)],
          'denserna': [('dens', False)],
          'densernas': [('dens', False)],
          'densers': [('dens', False)],
          'dent': [('dent', False)],
          'dentaler': [('dental', False)],
          'dentalers': [('dental', False)],
          'denten': [('dent', False)],
          'dentens': [('dent', False)],
          'denter': [('dent', False)],
          'denterna': [('dent', False)],
          'denternas': [('dent', False)],
          'denters': [('dent', False)],
          'dentian': [('dentia', False)],
          'dentiana': [('dentia', False)],
          'dentianas': [('dentia', False)],
          'dentians': [('dentia', False)],
          'dentiat': [('dentia', False)],
          'dentiats': [('dentia', False)],
          'dentier': [('dentier', False)],
          'dentiernas': [('dentier', False)],
          'dentiers': [('dentier', False)],
          'dentit': [('dentit', False)],
          'dentit-': [('dentit', False)],
          'dentits': [('dentit', False)],
          'dents-': [('dent', False)],
          'deon': [('deo', False)],
          'deons': [('deo', False)],
          'depens': [('depens', True)],
          'depter': [('dept', False)],
          'depters': [('dept', False)],
          'deran': [('dera', False)],
          'derans': [('dera', False)],
          'derare': [('derare', False)],
          'derares': [('derare', False)],
          'derarna': [('derare', False)],
          'derarnas': [('derare', False)],
          'derben': [('derben', False)],
          'derbens-': [('derben', False)],
          'derbets': [('derbeta', False)],
          'derbitarnas': [('derbitare', False)],
          'derbloggar': [('derblogg', False)],
          'derbloggarna': [('derblogg', False)],
          'derbloggarnas': [('derblogg', False)],
          'derdomar': [('derdom', False)],
          'derdomarnas': [('derdom', False)],
          'derdos': [('derdosa', False)],
          'dergarten': [('dergarten', False)],
          'dergartens': [('dergarten', False)],
          'derhandlar': [('derhandlare', False)],
          'derhandlarna': [('derhandlare', False)],
          'derhandlarnas': [('derhandlare', False)],
          'deri': [('deri', False)],
          'deri-': [('deri', False)],
          'derier': [('deri', False)],
          'derierna': [('deri', False)],
          'deriers': [('deri', False)],
          'deriet': [('deri', False)],
          'derike': [('derike', False)],
          'deris': [('deri', False)],
          'deris-': [('deri', False)],
          'derit': [('deri', False)],
          'derivat': [('derivata', True), ('derivat', True)],
          'derivat-': [('derivata', True), ('derivat', True)],
          'derivats': [('derivata', True), ('derivat', True)],
          'derivats-': [('derivata', True), ('derivat', True)],
          'derjorden': [('derjorden', False)],
          'derjordens': [('derjorden', False)],
          'derlikar': [('derlike', False)],
          'derlikarnas': [('derlike', False)],
          'derliken': [('derlike', False)],
          'derman': [('derman', False)],
          'dermans': [('derman', False)],
          'dermis': [('dermis', False)],
          'derne-': [('derne', False)],
          'dernet': [('derne', False)],
          'dernets': [('derne', False)],
          'dernitet': [('dernitet', False)],
          'dernitets': [('dernitet', False)],
          'derornas': [('dera', False)],
          'derrån': [('derrå', False)],
          'dersarnas': [('der', False)],
          'dersen': [('der', False)],
          'derskris': [('derskris', False)],
          'dersläkts-': [('dersläkte', False)],
          'derstens': [('dersten', False)],
          'dertens': [('dert', False)],
          'derts': [('dert', False)],
          'derts-': [('dert', False)],
          'dervals-': [('derval', False)],
          'derån': [('derån', False)],
          'des': [('de', False)],
          'des-': [('de', False)],
          'desarnas': [('des', False)],
          'desierna': [('desier', False)],
          'desis': [('desi', False)],
          'dester': [('dest', False)],
          'desterna': [('dest', False)],
          'desternas': [('dest', False)],
          'desters': [('dest', False)],
          'det-': [('deter', False)],
          'detagen': [('detag', False)],
          'detagens': [('detag', False)],
          'detaget': [('detag', False)],
          'detagets': [('detag', False)],
          'deten': [('det', False)],
          'detens': [('det', False)],
          'deter': [('deter', False)],
          'deterna': [('deter', False)],
          'deternas': [('deter', False)],
          'deters': [('deter', False)],
          'detidens': [('detid', False)],
          'dets': [('d', False)],
          'dets-': [('deter', False)],
          'dett': [('dett', False)],
          'dett-': [('dett', False)],
          'detten': [('dett', False)],
          'detter': [('dett', False)],
          'detterna': [('dett', False)],
          'detternas': [('dett', False)],
          'detters': [('dett', False)],
          'dettor': [('detta', False)],
          'dettors': [('detta', False)],
          'detts': [('dett', False)],
          'detts-': [('dett', False)],
          'devar': [('devara', False)],
          'devillen': [('devill', False)],
          'devillens': [('deville', False)],
          'deviller': [('devill', False)],
          'devillerna': [('devill', False)],
          'devillernas': [('devill', False)],
          'devillers': [('devill', False)],
          'devills': [('devill', False)],
          'devisas': [('devisa', False)],
          'devisors': [('devisa', False)],
          'dextrin': [('dextrin', True)],
          'dextrins': [('dextrin', True)],
          'dfader': [('dfar', False)],
          'dfader-': [('dfar', False)],
          'dfadern': [('dfar', False)],
          'dfaderns': [('dfar', False)],
          'dfaders': [('dfar', False)],
          'dfaders-': [('dfar', False)],
          'dfar': [('dfar', False)],
          'dfar-': [('dfar', False)],
          'dfare': [('dfara', False)],
          'dfars': [('dfar', False)],
          'dfars-': [('dfar', False)],
          'dfasan': [('dfasan', False)],
          'dfasans': [('dfasan', False)],
          'dfats': [('dfat', False)],
          'dfel': [('dfel', False)],
          'dfels': [('dfel', False)],
          'dfels-': [('dfel', False)],
          'dfilar': [('dfil', False)],
          'dfilarna': [('dfil', False)],
          'dfilarnas': [('dfil', False)],
          'dfilen': [('dfil', False)],
          'dfilens': [('dfil', False)],
          'dfiskar': [('dfisk', False)],
          'dfiskarna': [('dfisk', False)],
          'dfiskarnas': [('dfisk', False)],
          'dflagg-': [('dflagga', False)],
          'dflor': [('dflora', False)],
          'dflor-': [('dflora', False)],
          'dflors': [('dflora', False)],
          'dflors-': [('dflora', False)],
          'dflyt': [('dfly', False)],
          'dflyts': [('dfly', False)],
          'dfläck': [('dfläck', False)],
          'dfläcks': [('dfläck', False)],
          'dflödet': [('dflöde', False)],
          'dformar': [('dform', False)],
          'dformarna': [('dform', False)],
          'dformarnas': [('dform', False)],
          'dfoton': [('dfoto', False)],
          'dfotons': [('dfoto', False)],
          'dfots-': [('dfot', False)],
          'dfräsarna': [('dfräs', False)],
          'dfyrar': [('dfyr', False)],
          'dfäder': [('dfar', False)],
          'dfäderna': [('dfar', False)],
          'dfädernas': [('dfar', False)],
          'dfäders': [('dfar', False)],
          'dfälle': [('dfälle', False)],
          'dfällen': [('dfälle', False)],
          'dfällens': [('dfälle', False)],
          'dfälls': [('dfälle', False)],
          'dfälls-': [('dfälle', False)],
          'dfång': [('dfång', False)],
          'dfång-': [('dfång', False)],
          'dfångar': [('dfångare', False)],
          'dfångarna': [('dfångare', False)],
          'dfångarnas': [('dfångare', False)],
          'dfången': [('dfång', False)],
          'dfångs': [('dfång', False)],
          'dfångs-': [('dfång', False)],
          'dföljens': [('dfölje', False)],
          'dförar': [('dförare', False)],
          'dförarna': [('dförare', False)],
          'dförarnas': [('dförare', False)],
          'dfören': [('dföre', False)],
          'dförens': [('dföre', False)],
          'dförlust-': [('dförlust', False)],
          'dförluster': [('dförlust', False)],
          'dförlusterna': [('dförlust', False)],
          'dförlusternas': [('dförlust', False)],
          'dförs': [('dföre', False)],
          'dförs-': [('dföre', False)],
          'dförsäkringar': [('dförsäkring', False)],
          'dförsäkringarna': [('dförsäkring', False)],
          'dförsäkringarnas': [('dförsäkring', False)],
          'dförsäkringars': [('dförsäkring', False)],
          'dgan': [('dga', False)],
          'dgandens': [('dgande', False)],
          'dgans': [('dga', False)],
          'dgar': [('dgar', False)],
          'dgarna': [('dgar', False)],
          'dgarnas': [('dgar', False)],
          'dgars': [('dgar', False)],
          'dgas': [('dga', False)],
          'dgate': [('dgata', False)],
          'dgate-': [('dgata', False)],
          'dgator': [('dgata', False)],
          'dgators': [('dgata', False)],
          'dgats': [('dgata', False)],
          'dgen': [('dge', False)],
          'dgenier': [('dgeni', False)],
          'dgenierna': [('dgeni', False)],
          'dgeniernas': [('dgeni', False)],
          'dgeniers': [('dgeni', False)],
          'dgeniets': [('dgeni', False)],
          'dgens': [('dge', False)],
          'dget': [('dget', False)],
          'dgets': [('dget', False)],
          'dgetter': [('dget', False)],
          'dgetterna': [('dget', False)],
          'dgin': [('dgin', False)],
          'dgin-': [('dgin', False)],
          'dginen': [('dgin', False)],
          'dgins': [('dgin', False)],
          'dgins-': [('dgin', False)],
          'dgivar': [('dgivare', False)],
          'dgivarna': [('dgivare', False)],
          'dgivarnas': [('dgivare', False)],
          'dgnist': [('dgnista', False)],
          'dgnist-': [('dgnista', False)],
          'dgods': [('dgods', False)],
          'dgods-': [('dgods', False)],
          'dgor': [('dga', False)],
          'dgorna': [('dga', False)],
          'dgornas': [('dga', False)],
          'dgors': [('dga', False)],
          'dgräns': [('dgräns', False)],
          'dgräns-': [('dgräns', False)],
          'dgrönsaker': [('dgrönsak', False)],
          'dgrönsakerna': [('dgrönsak', False)],
          'dgrönsakernas': [('dgrönsak', False)],
          'dgrönsakers': [('dgrönsak', False)],
          'dgrönsaks': [('dgrönsak', False)],
          'dgrönsaks-': [('dgrönsak', False)],
          'dgulden': [('dguld', False)],
          'dguldens': [('dguld', False)],
          'dgum': [('dgum', False)],
          'dgum-': [('dgum', False)],
          'dgums': [('dgum', False)],
          'dgums-': [('dgum', False)],
          'dgärden': [('dgärd', False)],
          'dgärdens': [('dgärd', False)],
          'dgångar': [('dgång', False)],
          'dgångarna': [('dgång', False)],
          'dgångarnas': [('dgång', False)],
          'dgås': [('dgås', False)],
          'dgås-': [('dgås', False)],
          'dgåsen': [('dgås', False)],
          'dgåsens': [('dgås', False)],
          'dgåt': [('dgåta', False)],
          'dgåt-': [('dgåta', False)],
          'dgåts': [('dgåta', False)],
          'dgåts-': [('dgåta', False)],
          'dgåvors': [('dgåva', False)],
          'dh': [('dha', False)],
          'dh-': [('dha', False)],
          'dhack': [('dhacka', False)],
          'dhack-': [('dhacka', False)],
          'dhackor': [('dhacka', False)],
          'dhacks': [('dhacka', False)],
          'dhacks-': [('dhacka', False)],
          'dhake': [('dhake', False)],
          'dhake-': [('dhake', False)],
          'dhaken': [('dhake', False)],
          'dhakens': [('dhake', False)],
          'dhalar': [('dhalare', False)],
          'dhan': [('dha', False)],
          'dhans': [('dha', False)],
          'dhas': [('dha', False)],
          'dhe': [('dha', False)],
          'dhe-': [('dha', False)],
          'dheter': [('dhet', False)],
          'dheterna': [('dhet', False)],
          'dheternas': [('dhet', False)],
          'dheters': [('dhet', False)],
          'dhets': [('dhet', False)],
          'dhets-': [('dhet', False)],
          'dhette-': [('dhetta', False)],
          'dhin': [('dhi', False)],
          'dhins': [('dhi', False)],
          'dhjälpar': [('dhjälp', False)],
          'dhjälparna': [('dhjälp', False)],
          'dhjälparnas': [('dhjälpare', False)],
          'dhopp': [('dhoppa', False)],
          'dhopp-': [('dhoppa', False)],
          'dhopps': [('dhoppa', False)],
          'dhopps-': [('dhoppa', False)],
          'dhor': [('dha', False)],
          'dhorna': [('dha', False)],
          'dhornas': [('dha', False)],
          'dhors': [('dha', False)],
          'dhost': [('dhosta', False)],
          'dhost-': [('dhosta', False)],
          'dhs': [('dha', False)],
          'dhundars': [('dhund', False)],
          'dhus': [('dhus', False)],
          'dhylle': [('dhylla', False)],
          'dhylle-': [('dhylla', False)],
          'dhytt': [('dhytt', False)],
          'dhytts': [('dhytt', False)],
          'dhytts-': [('dhytt', False)],
          'dhyvlar': [('dhyvel', False)],
          'dhyvlarna': [('dhyvel', False)],
          'dhyvlarnas': [('dhyvel', False)],
          'dhäll': [('dhäll', False)],
          'dhäll-': [('dhäll', False)],
          'dhälls': [('dhäll', False)],
          'dhälls-': [('dhäll', False)],
          'dhängen': [('dhäng', False)],
          'dhängens': [('dhäng', False)],
          'dhänget': [('dhäng', False)],
          'dhängets': [('dhäng', False)],
          'dhängs': [('dhäng', False)],
          'dhängs-': [('dhäng', False)],
          'dhästarnas': [('dhäst', False)],
          'dhästars': [('dhäst', False)],
          'dhål': [('dhål', False)],
          'dhåls': [('dhål', False)],
          'dhåls-': [('dhål', False)],
          'di': [('di', False)],
          'di-': [('di', False)],
          'dia': [('dia', True)],
          'dian': [('dia', True)],
          'dian-': [('dian', False)],
          'dianas': [('dium', False)],
          'dianden': [('diande', True)],
          'dians': [('dia', True)],
          'dias': [('dia', True)],
          'diat': [('diat', False)],
          'diater': [('diat', False)],
          'diaters': [('diat', False)],
          'diats': [('diat', False)],
          'dicie': [('dicium', False)],
          'dicie-': [('dicium', False)],
          'dicierna': [('dicium', False)],
          'diciernas': [('dicium', False)],
          'dicina': [('dikus', False)],
          'dicinas': [('dikus', False)],
          'dicis': [('dikus', False)],
          'dick-': [('dick', False)],
          'dicker': [('dick', False)],
          'dickers': [('dick', False)],
          'dicks': [('dick', False)],
          'die': [('dium', False)],
          'die-': [('dium', False)],
          'dien': [('di', False)],
          'diena': [('dium', False)],
          'diens': [('di', False)],
          'dier': [('die', False)],
          'diernas': [('die', False)],
          'dies': [('dy', False)],
          'diesarna': [('die', False)],
          'diesarnas': [('die', False)],
          'diet': [('diet', True)],
          'dietiden': [('dietid', False)],
          'diets': [('diet', True)],
          'digans': [('digan', False)],
          'digar': [('digare', False)],
          'digarna': [('digare', False)],
          'digarnas': [('digare', False)],
          'diger': [('diger', False)],
          'digerna': [('diger', False)],
          'digers': [('diger', False)],
          'digheter': [('dighet', False)],
          'digheterna': [('dighet', False)],
          'digheternas': [('dighet', False)],
          'digheters': [('dighet', False)],
          'dighets-': [('dighet', False)],
          'digmat': [('digmat', False)],
          'dikandens': [('dikande', False)],
          'dikar': [('dikare', True)],
          'dikarna': [('dikare', True)],
          'dikator': [('dikator', False)],
          'dikators': [('dikator', False)],
          'dike': [('dike', False)],
          'diken': [('dike', False)],
          'dikens': [('dike', False)],
          'diker': [('diker', False)],
          'dikerna': [('diker', False)],
          'dikernas': [('diker', False)],
          'dikers': [('diker', False)],
          'diket': [('dike', True)],
          'diktarnas': [('diktare', False)],
          'dikten': [('dikt', False)],
          'diktens': [('dikt', False)],
          'diktet': [('dikt', False)],
          'diktions-': [('diktion', False)],
          'dikts': [('dikt', False)],
          'dikts-': [('dikt', False)],
          'dikurs': [('dikur', False)],
          'dilj': [('dilj', False)],
          'dilj-': [('dilj', False)],
          'diljen': [('dilj', False)],
          'diljens': [('dilj', False)],
          'diljs': [('dilj', False)],
          'dill': [('dill', False)],
          'dill-': [('dill', False)],
          'dillen': [('dill', True), ('dille', True)],
          'dillens': [('dille', True), ('dill', True)],
          'diller': [('dill', False)],
          'diller-': [('diller', False)],
          'dillerna': [('dill', False)],
          'dillernas': [('dill', False)],
          'dillers': [('dill', False)],
          'dillrar': [('diller', False)],
          'dills': [('dill', True)],
          'dills-': [('dill', True)],
          'dim': [('dimma', True)],
          'dim-': [('dimma', False)],
          'dimme': [('dimma', False)],
          'dimme-': [('dimma', False)],
          'dims': [('dimma', False)],
          'dims-': [('dimma', False)],
          'din': [('di', True)],
          'dina': [('d', False)],
          'dinanden': [('dinand', False)],
          'dinar': [('dinar', True)],
          'dinar-': [('dinar', True)],
          'dinaren': [('dinar', True)],
          'dinarens': [('dinar', True)],
          'dinarie': [('dinarie', False)],
          'dinarier': [('dinarie', False)],
          'dinarierna': [('dinarie', False)],
          'dinariernas': [('dinarie', False)],
          'dinarna': [('dinare', False)],
          'dinars': [('dinar', True)],
          'dinas': [('d', False)],
          'dinets': [('din', False)],
          'ding': [('dinge', True)],
          'ding-': [('dinge', True)],
          'dingar': [('dinge', True)],
          'dingarna': [('dinge', True)],
          'dingarnas': [('dinge', True)],
          'dingars': [('dinge', True)],
          'dingen': [('dinge', True)],
          'dingens': [('dinge', True)],
          'dingornas': [('dingo', True)],
          'dingors': [('dingo', True)],
          'dings': [('dinge', True)],
          'dings-': [('dinge', True)],
          'dingsvägs': [('dingsväg', False)],
          'dinkomst-': [('dinkomst', False)],
          'dinkomster': [('dinkomst', False)],
          'dinkomsternas': [('dinkomst', False)],
          'dinne': [('dinna', False)],
          'dinne-': [('dinna', False)],
          'dinringarna': [('dinring', False)],
          'dinringarnas': [('dinring', False)],
          'dins': [('di', False)],
          'dinventarie': [('dinventarium', False)],
          'dinventarie-': [('dinventarium', False)],
          'dinventarier': [('dinventarium', False)],
          'dinventarierna': [('dinventarium', False)],
          'dinventariernas': [('dinventarium', False)],
          'dinventariers': [('dinventarium', False)],
          'dion': [('dion', False)],
          'dionen': [('dion', False)],
          'dionens': [('dion', False)],
          'dions': [('dio', False)],
          'dior': [('dia', False)],
          'diorna': [('dia', True)],
          'diornas': [('dia', True)],
          'diors': [('dia', True)],
          'diots': [('diot', False)],
          'diparnas': [('dip', True)],
          'dipp': [('dipp', True)],
          'dipp-': [('dipp', True)],
          'dippar': [('dipp', True)],
          'dipparna': [('dipp', False)],
          'dippen': [('dipp', False)],
          'dippens': [('dipp', True)],
          'dipps': [('dipp', False)],
          'dipps-': [('dipp', True)],
          'dirk': [('dirk', True)],
          'dirk-': [('dirk', True)],
          'dirks': [('dirk', True)],
          'dirks-': [('dirk', True)],
          'dis': [('dis', True), ('di', True)],
          'dis-': [('dis', True)],
          'disa': [('disa', False)],
          'disan': [('disa', False)],
          'disans': [('disa', False)],
          'disarnas': [('dis', False)],
          'disas': [('disa', False)],
          'disk': [('disk', False)],
          'disk-': [('disk', False)],
          'diskan': [('diska', False)],
          'diskans': [('diska', False)],
          'diskar': [('diskare', True), ('disk', True)],
          'diskarna': [('diskare', True), ('disk', True)],
          'diskarnas': [('diskare', True), ('disk', True)],
          'diske': [('diska', False)],
          'diske-': [('diska', False)],
          'disko-': [('disko', True)],
          'diskon': [('disko', True)],
          'diskons': [('disko', True)],
          'diskos': [('disko', True)],
          'dismerna': [('dism', False)],
          'dismernas': [('dism', False)],
          'diss': [('diss', True)],
          'disse': [('dissa', False)],
          'disse-': [('dissa', False)],
          'dist-': [('dist', False)],
          'distans': [('distans', False)],
          'disten': [('dist', False)],
          'distens': [('dist', False)],
          'dister': [('dist', False)],
          'disterna': [('dist', False)],
          'disternas': [('dist', False)],
          'disters': [('dist', False)],
          'distik': [('distik', False)],
          'distik-': [('distik', False)],
          'distika': [('distikon', True)],
          'distikas': [('distikon', True)],
          'distiks': [('distik', False)],
          'dit': [('dit', False)],
          'ditarnas': [('dit', False)],
          'diternas': [('dit', False)],
          'ditor': [('ditor', False)],
          'ditorier': [('ditori', False)],
          'ditorierna': [('ditorium', False)],
          'ditoriernas': [('ditorium', False)],
          'ditoriers': [('ditorium', False)],
          'ditoriet': [('ditori', False)],
          'ditoriets': [('ditorium', False)],
          'ditoris': [('ditori', False)],
          'ditors': [('ditor', False)],
          'dits': [('dit', False)],
          'dium': [('dium', False)],
          'diums': [('dium', False)],
          'div': [('diva', True)],
          'div-': [('diva', True)],
          'divan': [('divan', True), ('diva', True)],
          'divans': [('divan', True), ('diva', True)],
          'divarier': [('divarius', False)],
          'divariernas': [('divarius', False)],
          'divariers': [('divarius', False)],
          'diver': [('diver', False)],
          'diverna': [('diver', False)],
          'divernas': [('diver', False)],
          'divers': [('diver', False)],
          'divets': [('div', False)],
          'divs': [('diva', True)],
          'divs-': [('diva', True)],
          'dj': [('dja', False)],
          'dj-': [('dja', False)],
          'djack': [('djacka', False)],
          'djack-': [('djacka', False)],
          'djacks': [('djacka', False)],
          'djacks-': [('djacka', False)],
          'djan': [('djan', False)],
          'djan-': [('djan', False)],
          'djans': [('djan', False)],
          'djaren': [('djare', False)],
          'djarnas': [('djare', False)],
          'dje': [('dja', False)],
          'dje-': [('dja', False)],
          'djoggar': [('djogg', False)],
          'djoggarna': [('djogg', False)],
          'djoggarnas': [('djogg', False)],
          'djoner': [('djon', False)],
          'djonerna': [('djon', False)],
          'djonernas': [('djon', False)],
          'djoners': [('djon', False)],
          'djons': [('djon', False)],
          'djor': [('dja', False)],
          'djorna': [('dja', False)],
          'djornas': [('dja', False)],
          'djors': [('dja', False)],
          'djur': [('djur', False)],
          'djur-': [('djur', False)],
          'djuren': [('djur', False)],
          'djurens': [('djur', False)],
          'djurs': [('djur', False)],
          'djurs-': [('djur', False)],
          'djär': [('djär', False)],
          'djär-': [('djär', False)],
          'djärs': [('djär', False)],
          'djärs-': [('djär', False)],
          'djävlar': [('djävel', True), ('djävul', True)],
          'djävlarna': [('djävel', True), ('djävul', True)],
          'djävlarnas': [('djävul', True), ('djävel', True)],
          'djävlars': [('djävel', True), ('djävul', True)],
          'djöns': [('djö', False)],
          'dkall': [('dkalle', False)],
          'dkall-': [('dkalle', False)],
          'dkallar': [('dkalle', False)],
          'dkalle': [('dkalle', False)],
          'dkallen': [('dkalle', False)],
          'dkallens': [('dkalle', False)],
          'dkalls': [('dkalle', False)],
          'dkalls-': [('dkalle', False)],
          'dkammar': [('dkammare', False)],
          'dkan': [('dka', False)],
          'dkanden': [('dkande', False)],
          'dkans': [('dka', False)],
          'dkapar': [('dkap', False)],
          'dkaparna': [('dkap', False)],
          'dkaparnas': [('dkap', False)],
          'dkapp': [('dkappa', False)],
          'dkapp-': [('dkappa', False)],
          'dkappe': [('dkappa', False)],
          'dkapps': [('dkappa', False)],
          'dkapps-': [('dkappa', False)],
          'dkaps': [('dkap', False)],
          'dkar': [('dkar', False)],
          'dkar-': [('dkare', False)],
          'dkare': [('dkare', False)],
          'dkaren': [('dkare', False)],
          'dkarens': [('dkar', False)],
          'dkaret': [('dkar', False)],
          'dkarets': [('dkar', False)],
          'dkarnas': [('dkare', False)],
          'dkars': [('dkar', False)],
          'dkars-': [('dkar', False)],
          'dkart': [('dkarta', False)],
          'dkart-': [('dkarta', False)],
          'dkartan': [('dkarta', False)],
          'dkarts': [('dkarta', False)],
          'dkarts-': [('dkarta', False)],
          'dkas': [('dkase', False)],
          'dkas-': [('dkase', False)],
          'dkasarna': [('dkase', False)],
          'dkasse': [('dkassa', False)],
          'dkatt-': [('dkatt', False)],
          'dkatten': [('dkatt', False)],
          'dkattens': [('dkatt', False)],
          'dkatts': [('dkatt', False)],
          'dkliniker': [('dklinik', False)],
          'dklinikerna': [('dklinik', False)],
          'dklinikernas': [('dklinik', False)],
          'dklinikers': [('dklinik', False)],
          'dklock': [('dklocka', False)],
          'dklot': [('dklot', False)],
          'dklots': [('dklot', False)],
          'dklots-': [('dklot', False)],
          'dklovs': [('dklove', False)],
          'dklyvar': [('dklyv', False)],
          'dklyvarna': [('dklyv', False)],
          'dklyvarnas': [('dklyv', False)],
          'dklädes': [('dkläde', False)],
          'dklädes-': [('dkläder', False)],
          'dkläds': [('dkläde', False)],
          'dkläds-': [('dkläde', False)],
          'dknot': [('dknota', False)],
          'dknot-': [('dknota', False)],
          'dknots': [('dknota', False)],
          'dknots-': [('dknota', False)],
          'dknäppar': [('dknäpp', False)],
          'dknäpparna': [('dknäpp', False)],
          'dknäpparnas': [('dknäpp', False)],
          'dknäppen': [('dknäpp', False)],
          'dknäppens': [('dknäpp', False)],
          'dkols': [('dkol', False)],
          'dkols-': [('dkol', False)],
          'dkomst-': [('dkomst', False)],
          'dkonst-': [('dkonst', False)],
          'dkonster': [('dkonst', False)],
          'dkonsterna': [('dkonst', False)],
          'dkonsternas': [('dkonst', False)],
          'dkonsters': [('dkonst', False)],
          'dkors': [('dkors', False)],
          'dkors-': [('dkors', False)],
          'dkots': [('dkota', False)],
          'dkrafters': [('dkraft', False)],
          'dkrafts': [('dkraft', False)],
          'dkrafts-': [('dkraft', False)],
          'dkramar': [('dkramare', False)],
          'dkramarna': [('dkramare', False)],
          'dkramarnas': [('dkramare', False)],
          'dkramp': [('dkramp', False)],
          'dkramps': [('dkramp', False)],
          'dkramps-': [('dkramp', False)],
          'dkrans': [('dkrans', False)],
          'dkrans-': [('dkrans', False)],
          'dkrets-': [('dkrets', False)],
          'dkris': [('dkris', False)],
          'dkris-': [('dkris', False)],
          'dkrokarnas': [('dkrok', False)],
          'dkronan': [('dkrona', False)],
          'dkronans': [('dkrona', False)],
          'dkrons-': [('dkrona', False)],
          'dkräm': [('dkräm', False)],
          'dkröken': [('dkrök', False)],
          'dkulor': [('dkula', False)],
          'dkulorna': [('dkula', False)],
          'dkulornas': [('dkula', False)],
          'dkulors': [('dkula', False)],
          'dkunskaper': [('dkunskap', False)],
          'dkunskapernas': [('dkunskap', False)],
          'dkunskaps': [('dkunskap', False)],
          'dkurs': [('dkurs', False)],
          'dkurs-': [('dkurs', False)],
          'dkurv': [('dkurva', False)],
          'dkurv-': [('dkurva', False)],
          'dkurvor': [('dkurva', False)],
          'dkurvorna': [('dkurva', False)],
          'dkurvornas': [('dkurva', False)],
          'dkurvors': [('dkurva', False)],
          'dkurvs': [('dkurva', False)],
          'dkurvs-': [('dkurva', False)],
          'dkvarter': [('dkvarter', False)],
          'dkvarters': [('dkvarter', False)],
          'dkäll': [('dkälla', False)],
          'dkämparnas': [('dkämpe', False)],
          'dkår': [('dkår', False)],
          'dkårs': [('dkår', False)],
          'dkårs-': [('dkår', False)],
          'dkön': [('dkö', False)],
          'dköns': [('dkö', False)],
          'dl': [('dl', True)],
          'dl-': [('dl', True)],
          'dlack': [('dlack', False)],
          'dlag': [('dlag', False)],
          'dlagarna': [('dlag', False)],
          'dlagen': [('dlag', False)],
          'dlaget': [('dlag', False)],
          'dlags': [('dlag', False)],
          'dlags-': [('dlag', False)],
          'dlamp': [('dlampa', False)],
          'dlamp-': [('dlampa', False)],
          'dlamps': [('dlampa', False)],
          'dlamps-': [('dlampa', False)],
          'dlan': [('dla', False)],
          'dlanden': [('dlande', False)],
          'dlandena': [('dlande', False)],
          'dlandenas': [('dlande', False)],
          'dlandens': [('dlande', False)],
          'dlandet': [('dlande', False)],
          'dlandets': [('dlande', False)],
          'dlans': [('dla', False)],
          'dlans-': [('dlan', False)],
          'dlar': [('dlare', False)],
          'dlaren': [('dlare', False)],
          'dlarna': [('dlare', False)],
          'dlarnas': [('dlare', False)],
          'dlarv': [('dlarv', False)],
          'dlarver': [('dlarv', False)],
          'dlarvers': [('dlarv', False)],
          'dlarvs': [('dlarv', False)],
          'dlarvs-': [('dlarv', False)],
          'dle': [('dla', False)],
          'dle-': [('dla', False)],
          'dleg': [('dlega', False)],
          'dleg-': [('dlega', False)],
          'dlegans': [('dlega', False)],
          'dlegs': [('dlega', False)],
          'dlegs-': [('dlega', False)],
          'dlek': [('dlek', False)],
          'dlekar': [('dlek', False)],
          'dlekarna': [('dlek', False)],
          'dlekarnas': [('dlek', False)],
          'dleken': [('dlek', False)],
          'dleks-': [('dlek', False)],
          'dlem-': [('dlem', False)],
          'dlems-': [('dlem', False)],
          'dlen': [('del', False)],
          'dlens': [('del', False)],
          'dler': [('del', False)],
          'dlerna': [('del', False)],
          'dlers': [('del', False)],
          'dlet': [('del', False)],
          'dlets': [('del', False)],
          'dliftar': [('dlift', False)],
          'dliftarna': [('dlift', False)],
          'dliftarnas': [('dlift', False)],
          'dligans': [('dliga', False)],
          'dlighets': [('dlighet', False)],
          'dlik': [('dlik', False)],
          'dliken': [('dlik', False)],
          'dlikens': [('dlik', False)],
          'dliks': [('dlik', False)],
          'dliks-': [('dlik', False)],
          'dlimp': [('dlimpa', False)],
          'dlimps-': [('dlimpa', False)],
          'dlin': [('dlina', False)],
          'dlin-': [('dlina', False)],
          'dlina': [('dlina', False)],
          'dline': [('dlina', False)],
          'dline-': [('dline', False)],
          'dlins': [('dlina', False)],
          'dlins-': [('dlins', False)],
          'dlist': [('dlist', False)],
          'dlist-': [('dlist', False)],
          'dlivs': [('dliv', False)],
          'dlivs-': [('dliv', False)],
          'dlok': [('dloka', False)],
          'dlok-': [('dloka', False)],
          'dloks': [('dloka', False)],
          'dloks-': [('dloka', False)],
          'dlopp': [('dloppa', False)],
          'dlopp-': [('dloppa', False)],
          'dlopps': [('dloppa', False)],
          'dlopps-': [('dloppa', False)],
          'dlor': [('dla', False)],
          'dlorna': [('dla', False)],
          'dlornas': [('dla', False)],
          'dlors': [('dla', False)],
          'dlott': [('dlott', False)],
          'dlott-': [('dlott', False)],
          'dlottens': [('dlott', False)],
          'dlotts': [('dlott', False)],
          'dlotts-': [('dlott', False)],
          'dlov': [('dlove', False)],
          'dlov-': [('dlove', False)],
          'dlovar': [('dlove', False)],
          'dlovarna': [('dlove', False)],
          'dlovarnas': [('dlove', False)],
          'dlovars': [('dlove', False)],
          'dloven': [('dlove', False)],
          'dlovens': [('dlove', False)],
          'dlovs': [('dlove', False)],
          'dlovs-': [('dlove', False)],
          'dlut': [('dlut', False)],
          'dlut-': [('dlut', False)],
          'dluts': [('dlut', False)],
          'dluts-': [('dlut', False)],
          'dlyftar': [('dlyftare', False)],
          'dlyftarna': [('dlyftare', False)],
          'dlykt': [('dlykta', False)],
          'dlykt-': [('dlykta', False)],
          'dlykts': [('dlykta', False)],
          'dläggar': [('dläggare', False)],
          'dläggarna': [('dläggare', False)],
          'dläggarnas': [('dläggare', False)],
          'dländar': [('dländare', False)],
          'dländarna': [('dländare', False)],
          'dläng-': [('dlänga', False)],
          'dlängs': [('dlänga', False)],
          'dlärk': [('dlärka', False)],
          'dlärk-': [('dlärka', False)],
          'dlärks': [('dlärka', False)],
          'dlärks-': [('dlärka', False)],
          'dläsarnas': [('dläsare', False)],
          'dlåns': [('dlån', False)],
          'dlåns-': [('dlån', False)],
          'dlös': [('dlösa', False)],
          'dlöss': [('dlus', False)],
          'dlössen': [('dlus', False)],
          'dlössens': [('dlus', False)],
          'dmajs': [('dmajs', False)],
          'dmakar': [('dmakare', False)],
          'dmakarna': [('dmakare', False)],
          'dmakarnas': [('dmakare', False)],
          'dman': [('dman', False)],
          'dmanar': [('dman', False)],
          'dmanarna': [('dman', False)],
          'dmannen': [('dman', False)],
          'dmannens': [('dman', False)],
          'dmans': [('dman', False)],
          'dmask': [('dmask', False)],
          'dmask-': [('dmask', False)],
          'dmat': [('dmat', False)],
          'dmaten': [('dmat', False)],
          'dmatens': [('dmat', False)],
          'dmaterier': [('dmateria', False)],
          'dmaterierna': [('dmateria', False)],
          'dmateriernas': [('dmateria', False)],
          'dmateriers': [('dmateria', False)],
          'dmed': [('dmed', False)],
          'dmedar': [('dmed', False)],
          'dmedarna': [('dmed', False)],
          'dmedarnas': [('dmed', False)],
          'dmedars': [('dmed', False)],
          'dmeden': [('dmed', False)],
          'dmedens': [('dmed', False)],
          'dmeds': [('dmed', False)],
          'dmeds-': [('dmed', False)],
          'dmerit': [('dmeri', False)],
          'dmerits': [('dmeri', False)],
          'dmil': [('dmil', False)],
          'dmil-': [('dmil', False)],
          'dmils': [('dmil', False)],
          'dmin': [('dmina', False)],
          'dmin-': [('dmina', False)],
          'dminas': [('dmina', False)],
          'dminors': [('dmina', False)],
          'dmins': [('dmina', False)],
          'dmins-': [('dmina', False)],
          'dmoder': [('dmor', False)],
          'dmoder-': [('dmor', False)],
          'dmodern': [('dmor', False)],
          'dmoderns': [('dmor', False)],
          'dmoders': [('dmor', False)],
          'dmoders-': [('dmor', False)],
          'dmor': [('dmora', False)],
          'dmor-': [('dmor', False)],
          'dmoras': [('dmora', False)],
          'dmors': [('dmor', False)],
          'dmors-': [('dmor', False)],
          'dmoss': [('dmossa', False)],
          'dmoss-': [('dmossa', False)],
          'dmosse': [('dmossa', False)],
          'dmul': [('dmule', False)],
          'dmul-': [('dmule', False)],
          'dmule': [('dmule', False)],
          'dmuls': [('dmule', False)],
          'dmuls-': [('dmule', False)],
          'dmurar': [('dmur', False)],
          'dmurarna': [('dmur', False)],
          'dmurarnas': [('dmur', False)],
          'dmussel': [('dmussla', False)],
          'dmussel-': [('dmussla', False)],
          'dmynt': [('dmynt', False)],
          'dmynts': [('dmynt', False)],
          'dmynts-': [('dmynt', False)],
          'dmyr': [('dmyra', False)],
          'dmyr-': [('dmyra', False)],
          'dmyrs': [('dmyra', False)],
          'dmyrs-': [('dmyra', False)],
          'dmän': [('dman', False)],
          'dmäns': [('dman', False)],
          'dmån': [('dmån', False)],
          'dmån-': [('dmåne', False)],
          'dmånen': [('dmån', False)],
          'dmånens': [('dmån', False)],
          'dmåns': [('dmåne', False)],
          'dmåns-': [('dmån', False)],
          'dmödrar': [('dmor', False)],
          'dmödrarna': [('dmor', False)],
          'dmödrarnas': [('dmor', False)],
          'dmödrars': [('dmor', False)],
          'dmöss': [('dmössa', False)],
          'dn': [('d', False)],
          'dna': [('dna', True)],
          'dnader': [('dnad', False)],
          'dnaderna': [('dnad', False)],
          'dnadernas': [('dnad', False)],
          'dnaders': [('dnad', False)],
          'dnads': [('dnad', False)],
          'dnads-': [('dnad', False)],
          'dnaggarna': [('dnagg', False)],
          'dnaggs': [('dnagg', False)],
          'dnanas': [('dna', True)],
          'dnanden': [('dnande', False)],
          'dnappar': [('dnappare', False)],
          'dnapparna': [('dnappare', False)],
          'dnapparnas': [('dnappare', False)],
          'dnar-': [('dnare', False)],
          'dnaren': [('dnare', False)],
          'dnarens': [('dnare', False)],
          'dnars': [('den', False)],
          'dnas': [('dna', True)],
          'dnat': [('dna', True)],
          'dnats': [('dna', True)],
          'dnattens': [('dnatt', False)],
          'dnebulosan': [('dnebulosan', False)],
          'dnebulosans': [('dnebulosan', False)],
          'dnen': [('den', False)],
          'dnens': [('den', False)],
          'dnet': [('dion', False)],
          'dnets': [('dion', False)],
          'dningsbot': [('dningsbot', False)],
          'dningsbots': [('dningsbot', False)],
          'dningskrans': [('dningskran', False)],
          'dningskrans-': [('dningskran', False)],
          'dningskurs': [('dningskurs', False)],
          'dningskurs-': [('dningskurs', False)],
          'dningslins': [('dningslins', False)],
          'dningslins-': [('dningslins', False)],
          'dningsställens': [('dningsställ', False)],
          'dnot': [('dnot', False)],
          'dnot-': [('dnot', False)],
          'dnots': [('dnot', False)],
          'dnots-': [('dnot', False)],
          'dns': [('d', False)],
          'dnubb-': [('dnubb', False)],
          'dnubbar': [('dnubb', False)],
          'dnubbarna': [('dnubb', False)],
          'dnubbarnas': [('dnubb', False)],
          'dnubbars': [('dnubb', False)],
          'dnubben': [('dnubb', False)],
          'dnubbens': [('dnubb', False)],
          'dnyp': [('dnypa', False)],
          'dnyp-': [('dnypa', False)],
          'dnyps': [('dnypa', False)],
          'dnyps-': [('dnypa', False)],
          'dnäbb': [('dnäbb', False)],
          'dnäbb-': [('dnäbb', False)],
          'dnäbbs': [('dnäbb', False)],
          'dnäbbs-': [('dnäbb', False)],
          'dnär': [('dnär', False)],
          'dnär-': [('dnär', False)],
          'dnärer': [('dnär', False)],
          'dnärerna': [('dnär', False)],
          'dnärernas': [('dnär', False)],
          'dnärers': [('dnär', False)],
          'dnärs': [('dnär', False)],
          'dnärs-': [('dnär', False)],
          'dnäts': [('dnät', False)],
          'dnäv': [('dnäva', False)],
          'dnäv-': [('dnäva', False)],
          'dnäve': [('dnäva', False)],
          'dnävs': [('dnäva', False)],
          'dnävs-': [('dnäva', False)],
          'dnötter': [('dnöt', False)],
          'dnötterna': [('dnöt', False)],
          'dnötters': [('dnöt', False)],
          'do': [('do', False)],
          'do-': [('da', False)],
          'doar': [('do', False)],
          'doars': [('do', False)],
          'doben': [('dobe', False)],
          'dobens': [('dobe', False)],
          'dock': [('docka', False)],
          'dock-': [('docka', True)],
          'dockar': [('dock', False)],
          'dockarna': [('dock', False)],
          'docken': [('dock', False)],
          'dockens': [('dock', False)],
          'docker': [('dock', False)],
          'dockers': [('dock', False)],
          'docks': [('docka', True)],
          'docks-': [('docka', True)],
          'doft': [('doft', False)],
          'doft-': [('doft', False)],
          'dofts': [('doft', False)],
          'dofts-': [('doft', False)],
          'dogat': [('dogata', False)],
          'dogat-': [('dogata', False)],
          'dogats-': [('dogata', False)],
          'doge': [('doge', True)],
          'doge-': [('doge', True)],
          'dogen': [('doge', True)],
          'dogens': [('doge', True)],
          'doger': [('doge', True)],
          'dogerna': [('doge', True)],
          'dogernas': [('doge', True)],
          'dogers': [('doge', True)],
          'doggarna': [('dogg', False)],
          'doggarnas': [('dogg', False)],
          'dogren': [('dogren', False)],
          'doj': [('doja', True)],
          'doj-': [('doja', True)],
          'dojan': [('doja', True)],
          'dojans': [('doja', True)],
          'dojs': [('doja', True)],
          'dojs-': [('doja', True)],
          'doke': [('doke', False)],
          'doke-': [('doke', False)],
          'doken': [('dok', True)],
          'dokens': [('dok', True)],
          'dokets': [('dok', False)],
          'doktorn': [('doktor', True)],
          'doktorns': [('doktor', False)],
          'dokus': [('doku', False)],
          'dokusar': [('doku', False)],
          'dokusarna': [('doku', False)],
          'dokusarnas': [('doku', False)],
          'dokusars': [('doku', False)],
          'dokusen': [('doku', False)],
          'dokusens': [('doku', False)],
          'dole': [('dole', False)],
          'dole-': [('dole', False)],
          'doles': [('dole', False)],
          'doles-': [('dole', False)],
          'doli': [('doli', False)],
          'dolin': [('dolin', False)],
          'dolis': [('doli', False)],
          'dolk': [('dolk', True)],
          'dolk-': [('dolk', True)],
          'dolkar': [('dolk', True)],
          'dolkarna': [('dolk', True)],
          'dolks': [('dolk', True)],
          'dolks-': [('dolk', True)],
          'doll': [('doll', False)],
          'doll-': [('doll', False)],
          'dollar': [('dollar', False)],
          'dollar-': [('dollar', True)],
          'dollarna': [('dollar', False)],
          'dollarnas': [('dollar', False)],
          'dollars': [('dollar', False)],
          'dollen': [('doll', False)],
          'dollens': [('doll', False)],
          'doller': [('doll', False)],
          'dollerna': [('doll', False)],
          'dollernas': [('doll', False)],
          'dollers': [('doll', False)],
          'dolls': [('doll', False)],
          'dolm': [('dolme', False)],
          'dolm-': [('dolme', False)],
          'dolmar': [('dolma', True)],
          'dolmarna': [('dolma', True)],
          'dolmarnas': [('dolma', True)],
          'dolmars': [('dolma', False)],
          'dolmen': [('dolme', False)],
          'dolmens': [('dolme', False)],
          'dolms': [('dolme', False)],
          'dolms-': [('dolme', False)],
          'dologen': [('dologe', False)],
          'dologens': [('dologe', False)],
          'dologer': [('dologe', False)],
          'dologerna': [('dologe', False)],
          'dologernas': [('dologe', False)],
          'dologers': [('dologe', False)],
          'dologier': [('dologi', False)],
          'dologierna': [('dologi', False)],
          'dologiers': [('dologi', False)],
          'domar': [('dom', True), ('domare', True)],
          'domarna': [('dom', True), ('domare', True)],
          'domarnas': [('dom', True), ('domare', True)],
          'domen': [('dom', True)],
          'domens': [('dom', False)],
          'domina': [('domina', True)],
          'dominans': [('domina', True), ('dominans', True)],
          'dominas': [('domina', True)],
          'dominor': [('domina', True), ('domino', True)],
          'dominorna': [('domina', True), ('domino', True)],
          'dominornas': [('domina', True), ('domino', True)],
          'dominors': [('domina', True), ('domino', True)],
          'doms': [('dom', False)],
          'doms-': [('dom', False)],
          'domän': [('domän', False)],
          'domäns': [('domän', True)],
          'don': [('don', True), ('dona', True)],
          'don-': [('dona', True), ('don', True)],
          'dona': [('dona', True)],
          'donan': [('dona', True)],
          'donans': [('dona', True)],
          'donas': [('dona', True)],
          'dong': [('dong', False)],
          'dong-': [('dong', False)],
          'donger': [('dong', False)],
          'dongerna': [('dong', False)],
          'dongernas': [('dong', False)],
          'dongers': [('dong', False)],
          'dongs': [('dong', False)],
          'dongs-': [('dong', False)],
          'donier': [('donier', False)],
          'donierna': [('donier', False)],
          'doniernas': [('donier', False)],
          'donk': [('donk', True)],
          'donk-': [('donk', True)],
          'donks': [('donk', True)],
          'donks-': [('donk', True)],
          'donn': [('donna', False)],
          'donn-': [('donna', False)],
          'donnans': [('donna', True)],
          'donne': [('donna', False)],
          'donne-': [('donna', False)],
          'dons': [('dona', True), ('don', True)],
          'dons-': [('dona', True), ('don', True)],
          'donter': [('dont', False)],
          'donters': [('dont', False)],
          'dopp': [('dopp', True)],
          'dopp-': [('dopp', True)],
          'doppen': [('dopp', True)],
          'doppens': [('dopp', True)],
          'dopps': [('dopp', True)],
          'dopps-': [('dopp', False)],
          'dorans': [('doran', False)],
          'dord': [('dord', False)],
          'dord-': [('dord', False)],
          'dorden': [('dord', False)],
          'dordens': [('dord', False)],
          'dordrarna': [('dorder', False)],
          'dords': [('dord', False)],
          'dords-': [('dord', False)],
          'dorer': [('dorer', True)],
          'dorerna': [('dorer', True)],
          'dorernas': [('dorer', True)],
          'dorers': [('dorer', True)],
          'dorfin': [('dorfin', False)],
          'dorfins': [('dorfin', False)],
          'dorian': [('dorian', False)],
          'dorians': [('dorian', False)],
          'dormar': [('dorm', False)],
          'dormarna': [('dorm', False)],
          'dormarnas': [('dorm', False)],
          'dorn': [('dorn', True)],
          'dorn-': [('dorn', True)],
          'dornar': [('dorn', True)],
          'dornarna': [('dorn', True)],
          'dornarnas': [('dorn', True)],
          'dornars': [('dorn', True)],
          'dornen': [('dorn', True)],
          'dornens': [('dorn', True)],
          'dorns': [('dorn', True)],
          'dorns-': [('dorn', True)],
          'dorran': [('dorran', False)],
          'dorten': [('dort', False)],
          'dortens': [('dort', False)],
          'dorterna': [('dort', False)],
          'dorternas': [('dort', False)],
          'dorters': [('dort', False)],
          'dorts': [('dort', False)],
          'dorts-': [('dort', False)],
          'dos': [('dosa', True), ('dos', True)],
          'dos-': [('dosa', True), ('dos', True)],
          'dosa': [('dosa', False)],
          'dosan': [('dosa', False)],
          'dosans': [('dosa', False)],
          'dosarna': [('do', False)],
          'dosas': [('dosa', False)],
          'dosen': [('dos', True)],
          'dosens': [('dos', True)],
          'dost-': [('dost', False)],
          'dot': [('dot', False)],
          'dots': [('do', False)],
          'dotter-': [('dotter', False)],
          'douten': [('dout', False)],
          'doutens': [('dout', False)],
          'dox': [('dox', False)],
          'dox-': [('dox', False)],
          'doxen': [('dox', False)],
          'doxens': [('dox', False)],
          'doxins': [('doxi', False)],
          'doyen': [('doyen', True)],
          'doyer': [('doyer', False)],
          'doyers': [('doyer', False)],
          'dpakets': [('dpaket', False)],
          'dpalt': [('dpalt', False)],
          'dpalt-': [('dpalt', False)],
          'dpalts': [('dpalt', False)],
          'dpalts-': [('dpalt', False)],
          'dpar': [('dpar', False)],
          'dpar-': [('dpar', False)],
          'dpars-': [('dpar', False)],
          'dpastor': [('dpasta', False)],
          'dpastors': [('dpasta', False)],
          'dpelar': [('dpelare', False)],
          'dpelar-': [('dpelare', False)],
          'dpengar': [('dpengar', False)],
          'dpengarna': [('dpeng', False)],
          'dpengarnas': [('dpeng', False)],
          'dpengars': [('dpeng', False)],
          'dpenn': [('dpenna', False)],
          'dpenning': [('dpenning', False)],
          'dpenning-': [('dpenning', False)],
          'dpenningar': [('dpenning', False)],
          'dpenningarna': [('dpenning', False)],
          'dpenningarnas': [('dpenning', False)],
          'dpenningars': [('dpenning', False)],
          'dpennings': [('dpenning', False)],
          'dpennings-': [('dpenning', False)],
          'dpetarnas': [('dpetare', False)],
          'dpinnarnas': [('dpinne', False)],
          'dpipar': [('dpipare', False)],
          'dpiparna': [('dpipare', False)],
          'dpiparnas': [('dpipare', False)],
          'dpisk': [('dpiska', False)],
          'dpisk-': [('dpiska', False)],
          'dplanet': [('dplan', False)],
          'dplanets': [('dplan', False)],
          'dplank': [('dplank', False)],
          'dplank-': [('dplank', False)],
          'dplanks': [('dplank', False)],
          'dplanks-': [('dplank', False)],
          'dplants': [('dplants', False)],
          'dplants-': [('dplanta', False)],
          'dpokers': [('dpoker', False)],
          'dpol': [('dpol', False)],
          'dpol-': [('dpol', False)],
          'dpolens': [('dpol', False)],
          'dpolskor': [('dpolska', False)],
          'dpolskorna': [('dpolska', False)],
          'dpolskornas': [('dpolska', False)],
          'dpolskors': [('dpolska', False)],
          'dposter': [('dpost', False)],
          'dposters': [('dpost', False)],
          'dproblemets': [('dproblem', False)],
          'dprogrammet': [('dprogram', False)],
          'dpump': [('dpump', False)],
          'dpumps': [('dpump', False)],
          'dpumps-': [('dpump', False)],
          'dpöls': [('dpöl', False)],
          'dpöls-': [('dpöl', False)],
          'dr': [('dr', True)],
          'dr-': [('dr', True)],
          'drack': [('dracka', False)],
          'drack-': [('dracka', False)],
          'dracks': [('dracka', False)],
          'dracks-': [('dracka', False)],
          'drade': [('drade', False)],
          'dradets': [('drade', False)],
          'drag': [('drag', False)],
          'drag-': [('drag', False)],
          'dragarna': [('dragare', False)],
          'dragarnas': [('dragare', False)],
          'dragen': [('drag', False)],
          'dragens': [('drag', False)],
          'draget': [('drag', False)],
          'draggar': [('dragg', True)],
          'draggarna': [('dragg', True)],
          'draggarnas': [('dragg', True)],
          'dragor': [('dragora', False)],
          'dragors': [('dragora', False)],
          'drags': [('drag', False)],
          'drags-': [('drag', False)],
          'drak': [('drake', False)],
          'drak-': [('drake', False)],
          'drakarnas': [('drake', True)],
          'drake': [('drake', False)],
          'draks': [('drake', True)],
          'draks-': [('drake', False)],
          'dramarna': [('dram', False)],
          'dramer': [('drama', True)],
          'dramerna': [('drama', True)],
          'dramernas': [('drama', True)],
          'dramers': [('drama', False)],
          'drams': [('dram', False)],
          'drams-': [('dram', False)],
          'drande': [('drande', False)],
          'drande-': [('drande', False)],
          'dranden': [('drande', False)],
          'drandens': [('drande', False)],
          'drandet': [('drande', False)],
          'drank': [('drank', True)],
          'drank-': [('drank', True)],
          'dranks': [('drank', True)],
          'dranks-': [('drank', True)],
          'drans': [('dran', False)],
          'drans-': [('dran', False)],
          'drap': [('drapa', True)],
          'drap-': [('drapa', True)],
          'draparens': [('drapar', False)],
          'drape': [('drapa', True)],
          'drape-': [('drapa', True)],
          'draps': [('drapa', True)],
          'draps-': [('drapa', True)],
          'drarnas': [('der', False)],
          'dras-': [('dras', False)],
          'drasens': [('dras', False)],
          'drassen': [('drass', False)],
          'drassens': [('drass', False)],
          'drat': [('drat', False)],
          'draten': [('drat', False)],
          'dratens': [('drat', False)],
          'drater': [('drat', False)],
          'draterna': [('drat', False)],
          'draternas': [('drat', False)],
          'draters': [('drat', False)],
          'drats': [('drat', False)],
          'drav': [('drav', True)],
          'drav-': [('drav', True)],
          'draven': [('drav', True)],
          'dravens': [('drav', True)],
          'dravs': [('drav', True)],
          'dravs-': [('drav', True)],
          'dre': [('dra', False)],
          'dre-': [('dra', False)],
          'dremmar': [('drem', False)],
          'dremmarna': [('drem', False)],
          'dremmarnas': [('drem', False)],
          'drems': [('dremsa', False)],
          'drems-': [('dremsa', False)],
          'dren': [('der', False)],
          'drenar': [('dren', False)],
          'drenarna': [('dren', False)],
          'drens': [('der', False)],
          'drese': [('dresa', False)],
          'drese-': [('dresa', False)],
          'dressarna': [('dress', True)],
          'dressarnas': [('dress', False)],
          'dret': [('der', False)],
          'drets': [('der', False)],
          'drev': [('drev', False)],
          'drev-': [('drev', False)],
          'drevens': [('drev', False)],
          'drevers': [('drever', True)],
          'drevers-': [('drever', True)],
          'drevs': [('drev', True)],
          'drevs-': [('drev', False)],
          'dri': [('dri', False)],
          'dri-': [('dri', False)],
          'drick-': [('dricka', False)],
          'dricks': [('dricks', True)],
          'dricks-': [('dricks', True)],
          'drie': [('drie', False)],
          'drie-': [('drie', False)],
          'drien': [('dri', False)],
          'dries': [('drie', False)],
          'dries-': [('drie', False)],
          'drighets': [('drighet', False)],
          'driket': [('drike', False)],
          'drill-': [('drill', False)],
          'drillarna': [('drill', False)],
          'drillarnas': [('drill', False)],
          'drim': [('drim', False)],
          'drims': [('drim', False)],
          'drims-': [('drim', False)],
          'drin': [('dri', False)],
          'drin-': [('drin', False)],
          'driner': [('drin', False)],
          'drinerna': [('drin', False)],
          'drinernas': [('drin', False)],
          'driners': [('drin', False)],
          'dringarna': [('dring', False)],
          'drinkar': [('drinkare', True), ('drink', True)],
          'drinkarna': [('drinkare', True), ('drink', True)],
          'drinkarnas': [('drinkare', True), ('drink', True)],
          'drins': [('drin', False)],
          'drins-': [('drin', False)],
          'dris': [('dri', False)],
          'dris-': [('dris', False)],
          'driser': [('dris', False)],
          'driserna': [('dris', False)],
          'drisernas': [('dris', False)],
          'drisers': [('dris', False)],
          'drisk': [('driska', False)],
          'drisk-': [('driska', False)],
          'driter': [('drit', False)],
          'drits': [('drit', False)],
          'driv': [('driv', True), ('driva', True)],
          'driv-': [('driv', True), ('driva', True)],
          'drivar': [('driv', True), ('drive', True)],
          'drivar-': [('drivare', False)],
          'drivarna': [('drive', True), ('driv', True)],
          'drivarnas': [('drive', True), ('driv', True)],
          'drivars': [('driv', True), ('drive', True)],
          'drive': [('driva', True), ('drive', True)],
          'drive-': [('drive', True), ('driva', True)],
          'driven': [('drive', True), ('driv', True)],
          'drivens': [('drive', True), ('driv', True)],
          'drivs': [('driva', True), ('driv', True)],
          'drivs-': [('driv', True), ('driva', True)],
          'dro-': [('dro', False)],
          'drock': [('drock', False)],
          'drockar': [('drockare', False)],
          'drockarna': [('drockare', False)],
          'drockarnas': [('drockare', False)],
          'drogen': [('drog', True)],
          'drogenerna': [('drogener', False)],
          'drogens': [('drog', True)],
          'droghandlar': [('droghandel', True), ('droghandlare', True)],
          'droghandlarna': [('droghandlare', True), ('droghandel', True)],
          'droghandlarnas': [('droghandlare', True), ('droghandel', True)],
          'droller': [('droll', False)],
          'drollerna': [('droll', False)],
          'drollernas': [('droll', False)],
          'drollers': [('droll', False)],
          'drolls': [('droll', False)],
          'drolls-': [('droll', False)],
          'droms': [('drom', False)],
          'droms-': [('drom', False)],
          'dron': [('dron', False)],
          'dronen': [('dron', False)],
          'dronens': [('dron', False)],
          'droner': [('dron', False)],
          'dronerna': [('dron', False)],
          'dronernas': [('dron', False)],
          'droners': [('dron', False)],
          'drons': [('dron', False)],
          'dropen': [('drop', False)],
          'dropens': [('drop', False)],
          'dropins': [('dropin', True)],
          'dropp': [('dropp', True), ('droppe', True)],
          'dropp-': [('dropp', True), ('droppe', True)],
          'droppar': [('droppe', False)],
          'dropparna': [('droppe', False)],
          'dropparnas': [('droppe', False)],
          'droppars': [('droppe', True)],
          'droppen': [('droppe', False)],
          'droppens': [('droppe', False)],
          'dropps': [('droppe', True), ('dropp', True)],
          'dropps-': [('droppe', True), ('dropp', True)],
          'drops': [('drop', False)],
          'dror': [('dra', False)],
          'drornas': [('dra', False)],
          'drors': [('dra', False)],
          'dros': [('dros', False)],
          'dros-': [('dros', False)],
          'drosk': [('droska', True)],
          'drosk-': [('droska', True)],
          'drot': [('drot', False)],
          'drotarnas': [('drote', False)],
          'droten': [('drot', False)],
          'drots': [('drots', True)],
          'drots-': [('drots', True)],
          'drottar': [('drott', True)],
          'drottarna': [('drott', False)],
          'drottarnas': [('drott', True)],
          'drov': [('drov', False)],
          'drov-': [('drov', False)],
          'drove-': [('drova', False)],
          'drovs': [('drov', False)],
          'drovs-': [('drov', False)],
          'drs': [('dra', False)],
          'drs-': [('dra', False)],
          'drulens': [('drul', True)],
          'drull': [('drulle', False)],
          'drull-': [('drulle', False)],
          'drulle': [('drulle', False)],
          'drulle-': [('drulle', False)],
          'drulls': [('drulle', False)],
          'drulls-': [('drulle', False)],
          'druls': [('drul', True)],
          'druls-': [('drul', True)],
          'drum': [('drum', False)],
          'drum-': [('drum', False)],
          'drumlar': [('drummel', True)],
          'drumlarna': [('drummel', True)],
          'drumlarnas': [('drummel', True)],
          'drums': [('drum', False)],
          'drums-': [('drum', False)],
          'drus': [('drus', True)],
          'dryck': [('dryck', False)],
          'dryggar': [('drygg', False)],
          'dräden': [('dräd', False)],
          'dräder': [('dräd', False)],
          'dräds-': [('dräd', False)],
          'dräks-': [('dräka', False)],
          'drällens': [('dräll', True)],
          'drän': [('drän', True)],
          'dränderna': [('drand', False)],
          'drändernas': [('drand', False)],
          'dränders': [('drand', False)],
          'dräns': [('drän', True)],
          'dräns-': [('drän', True)],
          'drättar': [('drätt', True)],
          'drättarna': [('drätt', True)],
          'drättarnas': [('drätt', True)],
          'drättens': [('drätt', False)],
          'drävarnas': [('dräv', False)],
          'dråden': [('dråd', False)],
          'drådens': [('dråd', False)],
          'drågen': [('dråg', False)],
          'drågens': [('dråg', False)],
          'drån': [('drå', False)],
          'dråns': [('drå', False)],
          'drås': [('dråse', True)],
          'drås-': [('dråse', True)],
          'drögar': [('drög', True)],
          'drögarna': [('drög', True)],
          'drögarnas': [('drög', True)],
          'dröken': [('drök', False)],
          'drökens': [('drök', False)],
          'drömmar': [('drömmare', True), ('dröm', True)],
          'drömmarna': [('drömmare', True), ('dröm', True)],
          'drömmarnas': [('drömmare', True), ('dröm', True)],
          'drös': [('dröse', True)],
          'drös-': [('dröse', True)],
          'drösen': [('dröse', True)],
          'drösens': [('dröse', True)],
          'drötter': [('drot', False)],
          'drötterna': [('drot', False)],
          'drötternas': [('drot', False)],
          'drötters': [('drot', False)],
          'dsaker': [('dsak', False)],
          'dsakernas': [('dsak', False)],
          'dsakers': [('dsak', False)],
          'dsalen': [('dsal', False)],
          'dsalens': [('dsal', False)],
          'dsandar': [('dsande', False)],
          'dsandarna': [('dsande', False)],
          'dsandarnas': [('dsande', False)],
          'dsandars': [('dsande', False)],
          'dsanden': [('dsande', False)],
          'dsandens': [('dsande', False)],
          'dsaren': [('dsare', False)],
          'dsarna': [('dsare', False)],
          'dsarnas': [('dsare', False)],
          'dsars': [('ds', False)],
          'dsats': [('dsats', False)],
          'dsats-': [('dsats', False)],
          'dsaxar': [('dsax', False)],
          'dsaxarna': [('dsax', False)],
          'dsaxarnas': [('dsax', False)],
          'dsback': [('dsbacke', False)],
          'dsbackarna': [('dsbacke', False)],
          'dsbackarnas': [('dsbacke', False)],
          'dsbacks': [('dsbacke', False)],
          'dschans': [('dschans', False)],
          'dsdags-': [('dsdagar', False)],
          'dsdammen': [('dsdamm', False)],
          'dsdelar': [('dsdel', False)],
          'dsdelarna': [('dsdel', False)],
          'dsdelarnas': [('dsdel', False)],
          'dsdomar': [('dsdomare', False)],
          'dsdomarna': [('dsdomare', False)],
          'dsdomarnas': [('dsdomare', False)],
          'dseffekt': [('dseffekt', False)],
          'dseffekter': [('dseffekt', False)],
          'dseffekternas': [('dseffekt', False)],
          'dseffekters': [('dseffekt', False)],
          'dseffekts': [('dseffekt', False)],
          'dseffekts-': [('dseffekt', False)],
          'dsegrar': [('dseger', False)],
          'dsegrarna': [('dseger', False)],
          'dsegrarnas': [('dseger', False)],
          'dsel': [('dsel', False)],
          'dsel-': [('dsel', False)],
          'dsels': [('dsel', False)],
          'dsels-': [('dsel', False)],
          'dsemestrar': [('dsemester', False)],
          'dsemestrarna': [('dsemester', False)],
          'dsemestrarnas': [('dsemester', False)],
          'dsen': [('ds', False)],
          'dsens': [('ds', False)],
          'dserfarenhets': [('dserfarenhet', False)],
          'dserfarenhets-': [('dserfarenhet', False)],
          'dset': [('ds', False)],
          'dsets': [('ds', False)],
          'dsett': [('dsetta', False)],
          'dsett-': [('dsetta', False)],
          'dsetts': [('dsetta', False)],
          'dsetts-': [('dsetta', False)],
          'dsfader': [('dsfader', False)],
          'dsfader-': [('dsfader', False)],
          'dsfaderns': [('dsfader', False)],
          'dsfaders-': [('dsfader', False)],
          'dsfaktorer': [('dsfaktor', False)],
          'dsfaktorers': [('dsfaktor', False)],
          'dsfar': [('dsfara', False)],
          'dsfar-': [('dsfara', False)],
          'dsflagg': [('dsflagga', False)],
          'dsflaggs': [('dsflagga', False)],
          'dsfädernas': [('dsfader', False)],
          'dsfången': [('dsfånge', False)],
          'dsförsäkringars': [('dsförsäkring', False)],
          'dsgatan': [('dsgata', False)],
          'dsgåve': [('dsgåvor', False)],
          'dsgåve-': [('dsgåvor', False)],
          'dsgåvor': [('dsgåvor', False)],
          'dsgåvorna': [('dsgåvor', False)],
          'dsgåvors': [('dsgåvor', False)],
          'dshets': [('dshets', False)],
          'dshets-': [('dshets', False)],
          'dshots': [('dshot', False)],
          'dshots-': [('dshot', False)],
          'dsidan': [('dsida', False)],
          'dsidans': [('dsida', False)],
          'dside': [('dsida', False)],
          'dside-': [('dsida', False)],
          'dsides': [('dsida', False)],
          'dsims': [('dsim', False)],
          'dsims-': [('dsim', False)],
          'dsis': [('dsis', False)],
          'dsis-': [('dsis', False)],
          'dsjukan': [('dsjuka', False)],
          'dsk': [('dska', False)],
          'dsk-': [('dska', False)],
          'dskalas': [('dskalas', False)],
          'dskall': [('dskall', False)],
          'dskallen': [('dskall', False)],
          'dskallens': [('dskalle', False)],
          'dskalls': [('dskall', False)],
          'dskalls-': [('dskall', False)],
          'dskammar': [('dskam', False)],
          'dskan': [('dska', False)],
          'dskans': [('dska', False)],
          'dskaps-': [('dskap', False)],
          'dskar': [('dske', False)],
          'dskarna': [('dske', False)],
          'dskarnas': [('dske', False)],
          'dskars': [('dske', False)],
          'dskartan': [('dskartan', False)],
          'dskartans': [('dskarta', False)],
          'dskasse-': [('dskassa', False)],
          'dskat': [('dskata', False)],
          'dskat-': [('dskata', False)],
          'dskate': [('dskata', False)],
          'dskats': [('dskata', False)],
          'dskats-': [('dskata', False)],
          'dskatts-': [('dskatt', False)],
          'dsken': [('dske', False)],
          'dsken-': [('dsken', False)],
          'dskens': [('dske', False)],
          'dskens-': [('dsken', False)],
          'dskes': [('dske', False)],
          'dskes-': [('dske', False)],
          'dskiften': [('dskifte', False)],
          'dskiftens': [('dskifte', False)],
          'dskiftet': [('dskifte', False)],
          'dskiftets': [('dskifte', False)],
          'dskill': [('dskille', False)],
          'dskill-': [('dskille', False)],
          'dskillens': [('dskille', False)],
          'dskills-': [('dskille', False)],
          'dskling': [('dsklinga', False)],
          'dsklings-': [('dsklinga', False)],
          'dsklubb': [('dsklubba', False)],
          'dsklubb-': [('dsklubba', False)],
          'dsklubbs': [('dsklubba', False)],
          'dsklubbs-': [('dsklubba', False)],
          'dsko': [('dsko', False)],
          'dskon': [('dsko', False)],
          'dskons': [('dsko', False)],
          'dskonst': [('dskonst', False)],
          'dskor': [('dsko', False)],
          'dskorna': [('dsko', False)],
          'dskornas': [('dsko', False)],
          'dskors': [('dsko', False)],
          'dskott': [('dskott', False)],
          'dskott-': [('dskotte', False)],
          'dskottar': [('dskotte', False)],
          'dskottarna': [('dskotte', False)],
          'dskotten': [('dskott', False)],
          'dskottens': [('dskott', False)],
          'dskotts': [('dskotte', False)],
          'dskotts-': [('dskott', False)],
          'dskrafter': [('dskrafter', False)],
          'dskrafterna': [('dskrafter', False)],
          'dskrafternas': [('dskrafter', False)],
          'dskrafters': [('dskrafter', False)],
          'dskrafts': [('dskrafter', False)],
          'dskrafts-': [('dskrafter', False)],
          'dskratt': [('dskratta', False)],
          'dskratt-': [('dskratta', False)],
          'dskratts': [('dskratta', False)],
          'dskratts-': [('dskratta', False)],
          'dskris': [('dskris', False)],
          'dskrällen': [('dskrälle', False)],
          'dskrällens': [('dskrälle', False)],
          'dskullarnas': [('dskulle', False)],
          'dskurs': [('dskur', False)],
          'dskurs-': [('dskurs', False)],
          'dskäll': [('dskälla', False)],
          'dskäll-': [('dskälla', False)],
          'dskälls': [('dskälla', False)],
          'dskälls-': [('dskälla', False)],
          'dskär': [('dskär', False)],
          'dskär-': [('dskär', False)],
          'dskärmar': [('dskärm', False)],
          'dskärmarna': [('dskärm', False)],
          'dskärmarnas': [('dskärm', False)],
          'dskärs': [('dskär', False)],
          'dskärs-': [('dskär', False)],
          'dskår': [('dskår', False)],
          'dskåren': [('dskår', False)],
          'dskårens': [('dskår', False)],
          'dskårs': [('dskår', False)],
          'dskårs-': [('dskår', False)],
          'dskön': [('dskö', False)],
          'dsköns': [('dskö', False)],
          'dslag': [('dslag', False)],
          'dslag-': [('dslag', False)],
          'dslagar': [('dslagare', False)],
          'dslagarna': [('dslagare', False)],
          'dslagarnas': [('dslagare', False)],
          'dslags': [('dslag', False)],
          'dslags-': [('dslag', False)],
          'dslan': [('dsla', False)],
          'dslanden': [('dsland', False)],
          'dslandens': [('dsland', False)],
          'dslandet': [('dsland', False)],
          'dslandets': [('dslande', False)],
          'dslans': [('dsla', False)],
          'dslants-': [('dslant', False)],
          'dslar': [('dsel', False)],
          'dslarna': [('dsel', False)],
          'dslarnas': [('dsel', False)],
          'dslas': [('dsla', False)],
          'dsle': [('dsle', False)],
          'dsle-': [('dsle', False)],
          'dslen': [('dsel', False)],
          'dslens': [('dsel', False)],
          'dslets': [('dsel', False)],
          'dsling': [('dsling', False)],
          'dsling-': [('dsling', False)],
          'dslings': [('dsling', False)],
          'dslings-': [('dsling', False)],
          'dslopp': [('dslopp', False)],
          'dslopps': [('dslopp', False)],
          'dslopps-': [('dslopp', False)],
          'dslotts': [('dslott', False)],
          'dsloven': [('dslov', False)],
          'dslovens': [('dslov', False)],
          'dsläng': [('dslänga', False)],
          'dsläng-': [('dslänga', False)],
          'dslängs': [('dslänga', False)],
          'dslängs-': [('dslänga', False)],
          'dslån': [('dslå', False)],
          'dslåns': [('dslå', False)],
          'dslås': [('dslå', False)],
          'dslås-': [('dslås', False)],
          'dsmatt': [('dsmatta', False)],
          'dsmatt-': [('dsmatta', False)],
          'dsmatts': [('dsmatta', False)],
          'dsmatts-': [('dsmatta', False)],
          'dsnacks': [('dsnack', False)],
          'dsnacks-': [('dsnack', False)],
          'dsnip': [('dsnipa', False)],
          'dsnip-': [('dsnipa', False)],
          'dsnips': [('dsnipa', False)],
          'dsnips-': [('dsnipa', False)],
          'dsområdet': [('dsområde', False)],
          'dson': [('dson', False)],
          'dsons': [('dson', False)],
          'dsorden': [('dsorden', False)],
          'dsordens': [('dsorden', False)],
          'dspad': [('dspade', False)],
          'dspad-': [('dspade', False)],
          'dspads': [('dspade', False)],
          'dspads-': [('dspade', False)],
          'dspeng': [('dspeng', False)],
          'dspengar': [('dspeng', False)],
          'dspengarna': [('dspeng', False)],
          'dspengarnas': [('dspeng', False)],
          'dspengars': [('dspeng', False)],
          'dspengs': [('dspeng', False)],
          'dspengs-': [('dspeng', False)],
          'dspisar': [('dspis', False)],
          'dspisarna': [('dspis', False)],
          'dspisarnas': [('dspis', False)],
          'dspol-': [('dspole', False)],
          'dspolar': [('dspole', False)],
          'dspolitikerna': [('dspolitiker', False)],
          'dsporr': [('dsporr', False)],
          'dsporr-': [('dsporr', False)],
          'dsporren': [('dsporr', False)],
          'dsporrens': [('dsporr', False)],
          'dsporrs': [('dsporr', False)],
          'dsportar': [('dsport', False)],
          'dsportarna': [('dsport', False)],
          'dspott': [('dspotta', False)],
          'dspott-': [('dspotta', False)],
          'dspotts': [('dspott', False)],
          'dspotts-': [('dspotta', False)],
          'dspring': [('dspringa', False)],
          'dspring-': [('dspringa', False)],
          'dsprings': [('dspringa', False)],
          'dsprings-': [('dspringa', False)],
          'dspris': [('dspris', False)],
          'dsprit': [('dsprit', False)],
          'dsprits': [('dsprit', False)],
          'dsprits-': [('dsprit', False)],
          'dsprivilegie': [('dsprivilegium', False)],
          'dsprivilegie-': [('dsprivilegium', False)],
          'dsprivilegier': [('dsprivilegium', False)],
          'dsprivilegierna': [('dsprivilegium', False)],
          'dsprivilegiernas': [('dsprivilegier', False)],
          'dsprivilegiers': [('dsprivilegium', False)],
          'dsprut': [('dspruta', False)],
          'dsprut-': [('dspruta', False)],
          'dspruts': [('dspruta', False)],
          'dspruts-': [('dspruta', False)],
          'dspännen': [('dspänne', False)],
          'dspännens': [('dspänne', False)],
          'dsranden': [('dsrand', False)],
          'dsrandens': [('dsrand', False)],
          'dsregionen': [('dsregion', False)],
          'dsregionens': [('dsregion', False)],
          'dsrättigheterna': [('dsrättigheter', False)],
          'dsrättigheternas': [('dsrättigheter', False)],
          'dsrättigheters': [('dsrättigheter', False)],
          'dsrättighets-': [('dsrättigheter', False)],
          'dssel': [('dssele', False)],
          'dssel-': [('dssele', False)],
          'dssels': [('dssele', False)],
          'dssels-': [('dssele', False)],
          'dsskalas': [('dsskala', False)],
          'dsskiften': [('dsskifte', False)],
          'dsskiftens': [('dsskifte', False)],
          'dsstudie': [('dsstudier', False)],
          'dsstudie-': [('dsstudier', False)],
          'dsstudier': [('dsstudier', False)],
          'dsstudierna': [('dsstudier', False)],
          'dsstudiernas': [('dsstudier', False)],
          'dsställens': [('dsställ', False)],
          'dssyrs': [('dssyrsa', False)],
          'dssyrs-': [('dssyrsa', False)],
          'dstak': [('dstak', False)],
          'dstaken': [('dstak', False)],
          'dstakens': [('dstak', False)],
          'dstaket': [('dstak', False)],
          'dstakets': [('dstak', False)],
          'dstaks': [('dstak', False)],
          'dstaks-': [('dstak', False)],
          'dstalet': [('dstalet', False)],
          'dstalets': [('dstal', False)],
          'dstammar': [('dstam', False)],
          'dstammarna': [('dstam', False)],
          'dstammarnas': [('dstam', False)],
          'dstankarna': [('dstanke', False)],
          'dstankarnas': [('dstanke', False)],
          'dstanken': [('dstanke', False)],
          'dstankens': [('dstanke', False)],
          'dstans': [('dstad', False)],
          'dstar': [('dste', False)],
          'dstarna': [('dste', False)],
          'dstarnas': [('dste', False)],
          'dstars': [('dste', False)],
          'dstavarna': [('dstav', False)],
          'dste': [('dste', False)],
          'dste-': [('dste', False)],
          'dsteg': [('dsteg', False)],
          'dsteg-': [('dsteg', False)],
          'dstegen': [('dsteg', False)],
          'dstegens': [('dsteg', False)],
          'dstegs': [('dsteg', False)],
          'dstegs-': [('dsteg', False)],
          'dstekniker': [('dsteknik', False)],
          'dsteknikerna': [('dsteknik', False)],
          'dsteknikernas': [('dsteknik', False)],
          'dsteknikers': [('dsteknik', False)],
          'dsten': [('dsten', False)],
          'dstens': [('dsten', False)],
          'dstick': [('dsticka', False)],
          'dstick-': [('dsticka', False)],
          'dsticks': [('dsticka', False)],
          'dsticks-': [('dsticka', False)],
          'dstimmen': [('dstimme', False)],
          'dstimmens': [('dstimme', False)],
          'dstjärn': [('dstjärna', False)],
          'dstjärn-': [('dstjärna', False)],
          'dstjärns': [('dstjärna', False)],
          'dstjärns-': [('dstjärna', False)],
          'dstol': [('dstol', False)],
          'dstol-': [('dstol', False)],
          'dstols': [('dstol', False)],
          'dstols-': [('dstol', False)],
          'dstomten': [('dstomt', False)],
          'dston': [('dston', False)],
          'dstormarna': [('dstorm', False)],
          'dstormarnas': [('dstorm', False)],
          'dsträna': [('dsträd', False)],
          'dstränas': [('dsträd', False)],
          'dstråk': [('dstråk', False)],
          'dstråk-': [('dstråk', False)],
          'dstråken': [('dstråk', False)],
          'dstråkens': [('dstråk', False)],
          'dstråks': [('dstråk', False)],
          'dstråks-': [('dstråk', False)],
          'dstudsar': [('dstudsare', False)],
          'dstudsarna': [('dstudsare', False)],
          'dstudsarnas': [('dstudsare', False)],
          'dstump': [('dstump', False)],
          'dstump-': [('dstump', False)],
          'dstumps': [('dstump', False)],
          'dstumps-': [('dstump', False)],
          'dstuns': [('dstu', False)],
          'dstycken': [('dstycke', False)],
          'dstyckena': [('dstycke', False)],
          'dstyckenas': [('dstycke', False)],
          'dstyckens': [('dstycke', False)],
          'dstycket': [('dstycke', False)],
          'dstyckets': [('dstycke', False)],
          'dstycks': [('dstycke', False)],
          'dstyren': [('dstyre', False)],
          'dstyrens': [('dstyre', False)],
          'dstyret': [('dstyre', False)],
          'dstyrkan': [('dstyrka', False)],
          'dstyrke': [('dstyrka', False)],
          'dställandena': [('dställande', False)],
          'dställandens': [('dställande', False)],
          'dställen': [('dställe', False)],
          'dställens': [('dställe', False)],
          'dstället': [('dställe', False)],
          'dställets': [('dställe', False)],
          'dställningar': [('dställning', False)],
          'dställningarna': [('dställning', False)],
          'dställningarnas': [('dställning', False)],
          'dställningars': [('dställning', False)],
          'dställnings': [('dställning', False)],
          'dställnings-': [('dställning', False)],
          'dstäpp': [('dstäppa', False)],
          'dstäpp-': [('dstäppa', False)],
          'dstäpps': [('dstäppa', False)],
          'dstäpps-': [('dstäppa', False)],
          'dstäv': [('dstäv', False)],
          'dstäv-': [('dstäv', False)],
          'dstävs': [('dstäv', False)],
          'dstävs-': [('dstäv', False)],
          'dstörar': [('dstörare', False)],
          'dstörarna': [('dstörare', False)],
          'dstörarnas': [('dstörare', False)],
          'dstötarnas': [('dstöt', False)],
          'dstövlars': [('dstövel', False)],
          'dsugar': [('dsugare', False)],
          'dsugarna': [('dsugare', False)],
          'dsugarnas': [('dsugare', False)],
          'dsupar': [('dsup', False)],
          'dsuparna': [('dsupare', False)],
          'dsuparnas': [('dsupare', False)],
          'dsur': [('dsur', False)],
          'dsur-': [('dsur', False)],
          'dsurs': [('dsur', False)],
          'dsurs-': [('dsur', False)],
          'dsval': [('dsval', False)],
          'dsvalar': [('dsval', False)],
          'dsvalarna': [('dsval', False)],
          'dsvalarnas': [('dsval', False)],
          'dsvalars': [('dsval', False)],
          'dsvalen': [('dsval', False)],
          'dsvalens': [('dsval', False)],
          'dsvals': [('dsval', False)],
          'dsvals-': [('dsval', False)],
          'dsvanor': [('dsvana', False)],
          'dsvanorna': [('dsvana', False)],
          'dsvanornas': [('dsvana', False)],
          'dsvanors': [('dsvana', False)],
          'dsvar': [('dsvara', False)],
          'dsvensk': [('dsvensk', False)],
          'dsvensk-': [('dsvensk', False)],
          'dsverken': [('dsverk', False)],
          'dsverkens': [('dsverk', False)],
          'dsverks': [('dsverk', False)],
          'dsverks-': [('dsverk', False)],
          'dsviter': [('dsvit', False)],
          'dsviterna': [('dsvit', False)],
          'dsviternas': [('dsvit', False)],
          'dsviters': [('dsvit', False)],
          'dsvägens': [('dsväg', False)],
          'dsvärden': [('dsvärde', False)],
          'dsvärdens': [('dsvärde', False)],
          'dsvärdet': [('dsvärde', False)],
          'dsvärdets': [('dsvärde', False)],
          'dsvävar': [('dsväv', False)],
          'dsvävarna': [('dsväv', False)],
          'dsvävarnas': [('dsväv', False)],
          'dsyn': [('dsyn', False)],
          'dsyns': [('dsyn', False)],
          'dsäden': [('dsäd', False)],
          'dsädens': [('dsäd', False)],
          'dsädes': [('dsäd', False)],
          'dsäds': [('dsäd', False)],
          'dsäds-': [('dsäd', False)],
          'dsändar': [('dsände', False)],
          'dsändarna': [('dsände', False)],
          'dsändarnas': [('dsände', False)],
          'dsärter': [('dsärt', False)],
          'dsärts': [('dsärt', False)],
          'dsås': [('dsås', False)],
          'dsås-': [('dsås', False)],
          'dsön': [('dsö', False)],
          'dsös': [('dsö', False)],
          'dt': [('dt', False)],
          'dt-': [('dt', False)],
          'dtack': [('dtacka', False)],
          'dtack-': [('dtacka', False)],
          'dtacks': [('dtacka', False)],
          'dtacks-': [('dtacka', False)],
          'dtagen': [('dtag', False)],
          'dtagens': [('dtag', False)],
          'dtaget': [('dtag', False)],
          'dtaken': [('dtak', False)],
          'dtaket': [('dtak', False)],
          'dtalandena': [('dtalande', False)],
          'dtalandenas': [('dtalande', False)],
          'dtalandens': [('dtalande', False)],
          'dtalen': [('dtal', False)],
          'dtalens': [('dtal', False)],
          'dtalet': [('dtal', False)],
          'dtank': [('dtanke', False)],
          'dtank-': [('dtanke', False)],
          'dtankar': [('dtanke', False)],
          'dtankarna': [('dtanke', False)],
          'dtankarnas': [('dtanke', False)],
          'dtankars': [('dtanke', False)],
          'dtanke': [('dtanke', False)],
          'dtanke-': [('dtanke', False)],
          'dtanken': [('dtanke', False)],
          'dtankens': [('dtanke', False)],
          'dtanks': [('dtanke', False)],
          'dtanks-': [('dtanke', False)],
          'dtekniker': [('dtekniker', False)],
          'dteknikerna': [('dtekniker', False)],
          'dteknikernas': [('dtekniker', False)],
          'dteknikers': [('dtekniker', False)],
          'dten': [('dt', False)],
          'dtens': [('dt', False)],
          'dter': [('dt', False)],
          'dterna': [('dt', False)],
          'dternas': [('dt', False)],
          'dters': [('dt', False)],
          'dtes': [('dtes', False)],
          'dtes-': [('dtes', False)],
          'dtiden': [('dtid', False)],
          'dtider': [('dtid', False)],
          'dtiderna': [('dtid', False)],
          'dtiders': [('dtid', False)],
          'dtittar': [('dtittare', False)],
          'dtittarna': [('dtittare', False)],
          'dtittarnas': [('dtittare', False)],
          'dtomten': [('dtomt', False)],
          'dtomtens': [('dtomt', False)],
          'dton': [('dton', False)],
          'dtoner': [('dton', False)],
          'dtonerna': [('dton', False)],
          'dtopparnas': [('dtopp', False)],
          'dtrall': [('dtralla', False)],
          'dtrall-': [('dtralla', False)],
          'dtralls': [('dtralla', False)],
          'dtralls-': [('dtralla', False)],
          'dtras': [('dtrasa', False)],
          'dtrav': [('dtrave', False)],
          'dtrav-': [('dtrave', False)],
          'dtravar': [('dtrave', False)],
          'dtravarna': [('dtrave', False)],
          'dtravarnas': [('dtrave', False)],
          'dtraven': [('dtrave', False)],
          'dtravens': [('dtrave', False)],
          'dtravs': [('dtrave', False)],
          'dtravs-': [('dtrave', False)],
          'dtrycken': [('dtryck', False)],
          'dtryckens': [('dtryck', False)],
          'dtrycket': [('dtryck', False)],
          'dtryckets': [('dtryck', False)],
          'dtrycks': [('dtryck', False)],
          'dtrycks-': [('dtryck', False)],
          'dträd': [('dträd', False)],
          'dträd-': [('dträd', False)],
          'dträden': [('dträd', False)],
          'dträdens': [('dträd', False)],
          'dträdet': [('dträd', False)],
          'dträdets': [('dträd', False)],
          'dträds': [('dträd', False)],
          'dträn': [('dträ', False)],
          'dträna': [('dträd', False)],
          'dtränas': [('dträd', False)],
          'dträns': [('dträ', False)],
          'dträt': [('dträ', False)],
          'dträts': [('dträ', False)],
          'dts': [('d', False)],
          'dtub': [('dtub', False)],
          'dtubs': [('dtub', False)],
          'dtubs-': [('dtub', False)],
          'dtur': [('dtur', False)],
          'dturerna': [('dtur', False)],
          'dturernas': [('dtur', False)],
          'dturers': [('dtur', False)],
          'dturs': [('dtur', False)],
          'dturs-': [('dtur', False)],
          'dtycket': [('dtycke', False)],
          'dtypen': [('dtyp', False)],
          'dtyperna': [('dtyp', False)],
          'dtypernas': [('dtyp', False)],
          'dtypers': [('dtyp', False)],
          'dtändar': [('dtändare', False)],
          'dtänderna': [('dtand', False)],
          'dtänger': [('dtång', False)],
          'dtängernas': [('dtång', False)],
          'dtängers': [('dtång', False)],
          'dtång': [('dtång', False)],
          'dtång-': [('dtång', False)],
          'dtången': [('dtång', False)],
          'dtångens': [('dtång', False)],
          'dtångs': [('dtång', False)],
          'dtörn': [('dtörn', False)],
          'dtörnen': [('dtörn', False)],
          'dtörnens': [('dtörn', False)],
          'dtörns': [('dtörn', False)],
          'dtörns-': [('dtörn', False)],
          'du': [('dua', False)],
          'du-': [('dua', False)],
          'dua': [('duum', False)],
          'duan': [('duan', False)],
          'duans': [('duan', False)],
          'duas': [('dua', False)],
          'dubb': [('dubb', True)],
          'dubbarna': [('dubb', True)],
          'dubbarnas': [('dubb', True)],
          'dubbars': [('dubb', False)],
          'dubbel': [('dubbel', True)],
          'dubbel-': [('dubbel', True)],
          'dubbens': [('dubb', True)],
          'dubblar': [('dubbel', True), ('dubblare', True)],
          'dubblarna': [('dubbel', True), ('dubblare', True)],
          'dubblarnas': [('dubblare', True), ('dubbel', True)],
          'dubbs': [('dubb', False)],
          'dubbs-': [('dubb', False)],
          'due': [('dua', False)],
          'due-': [('duum', False)],
          'duer': [('duum', False)],
          'duernas': [('duum', False)],
          'duers': [('duum', False)],
          'duet': [('duum', False)],
          'duets': [('duum', False)],
          'duettens': [('duett', True)],
          'duetters': [('duett', True)],
          'dufflar': [('duffel', True)],
          'dufflarna': [('duffel', True)],
          'dufflarnas': [('duffel', True)],
          'duins': [('duin', False)],
          'dukarnas': [('duk', False)],
          'dukt': [('dukt', True)],
          'dukt-': [('dukt', False)],
          'dukter': [('dukt', False)],
          'dukterna': [('dukt', False)],
          'dukternas': [('dukt', False)],
          'dukters': [('dukt', False)],
          'dukts': [('dukt', False)],
          'dukts-': [('dukt', False)],
          'dulls-': [('dull', False)],
          'duman': [('duma', True)],
          'dummar': [('dummer', True)],
          'dummarna': [('dummer', True)],
          'dummarnas': [('dummer', True)],
          'dummars': [('dummer', True)],
          'dumors': [('duma', True)],
          'dump': [('dump', False)],
          'dump-': [('dump', False)],
          'dumps': [('dump', False)],
          'dumps-': [('dump', False)],
          'dun': [('dun', False)],
          'dunandens': [('dunande', True)],
          'dundans': [('dundans', False)],
          'dunderkurs': [('dunderkur', True)],
          'dunderkurs-': [('dunderkur', True)],
          'dundernas': [('dunder', False)],
          'dung': [('dunge', True)],
          'dungen': [('dunge', True)],
          'dungens': [('dunge', True)],
          'dungs': [('dunge', True)],
          'dungs-': [('dunge', True)],
          'dunk': [('dunk', False)],
          'dunk-': [('dunk', True)],
          'dunkar': [('dunk', True)],
          'dunkarna': [('dunk', True)],
          'dunkarnas': [('dunk', False)],
          'dunkars': [('dunk', False)],
          'dunken': [('dunk', False)],
          'dunkens': [('dunk', False)],
          'dunks': [('dunk', False)],
          'dunks-': [('dunk', False)],
          'duns': [('dun', True), ('duns', True)],
          'duns-': [('duns', True), ('dun', True)],
          'duor': [('duo', True)],
          'duorna': [('duo', True)],
          'duornas': [('duo', True)],
          'duors': [('duo', True)],
          'duri': [('duri', False)],
          'duri-': [('duri', False)],
          'duriens': [('duri', False)],
          'durin': [('duri', False)],
          'durins': [('duri', False)],
          'duris': [('duri', False)],
          'durk': [('durk', False)],
          'durk-': [('durk', True)],
          'durks': [('durk', False)],
          'durks-': [('durk', False)],
          'durn': [('dur', False)],
          'durns': [('dur', False)],
          'dus': [('dus', True)],
          'dus-': [('dus', True)],
          'dusan': [('dusa', False)],
          'dusans': [('dusa', False)],
          'dusarnas': [('dus', False)],
          'dusk': [('dusk', True)],
          'dusk-': [('dusk', True)],
          'duske': [('duska', False)],
          'duske-': [('duska', False)],
          'duskor': [('duska', False)],
          'duskorna': [('duska', False)],
          'duskornas': [('duska', False)],
          'duskors': [('duska', False)],
          'dussins': [('dussin', False)],
          'dust-': [('dust', True)],
          'duster': [('dust', True)],
          'dusterna': [('dust', True)],
          'dusternas': [('dust', True)],
          'dusters': [('dust', True)],
          'dutt': [('dutt', False)],
          'dutt-': [('dutt', False)],
          'dutten': [('dutt', False)],
          'dutter': [('dutt', False)],
          'dutters': [('dutt', False)],
          'dutts': [('dutt', False)],
          'dutts-': [('dutt', False)],
          'duv': [('duva', False)],
          'duv-': [('duva', False)],
          'duvs': [('duva', False)],
          'duvs-': [('duva', False)],
          'dvadar': [('dvad', False)],
          'dvadarna': [('dvad', False)],
          'dvadarnas': [('dvad', False)],
          'dval': [('dval', False)],
          'dval-': [('dval', False)],
          'dvalarna': [('dval', False)],
          'dvalarnas': [('dval', False)],
          'dvalen': [('dval', False)],
          'dvalens': [('dval', False)],
          'dvallar': [('dvall', False)],
          'dvallarna': [('dvall', False)],
          'dvallarnas': [('dvall', False)],
          'dvalls-': [('dvall', False)],
          'dvals': [('dval', False)],
          'dvals-': [('dval', False)],
          'dvana': [('dvana', False)],
          'dvane': [('dvana', False)],
          'dvane-': [('dvana', False)],
          'dvanors': [('dvana', False)],
          'dvar': [('dvar', False)],
          'dvar-': [('dvar', False)],
          'dvaran': [('dvara', False)],
          'dvarans': [('dvara', False)],
          'dvarar': [('dvar', False)],
          'dvararna': [('dvar', False)],
          'dvararnas': [('dvar', False)],
          'dvarens': [('dvar', False)],
          'dvarnar': [('dvarnare', False)],
          'dvarnarna': [('dvarnare', False)],
          'dvars': [('dvar', False)],
          'dvatten': [('dvatten', False)],
          'dveck': [('dveck', False)],
          'dveck-': [('dveck', False)],
          'dvecks': [('dveck', False)],
          'dvecks-': [('dveck', False)],
          'dverben': [('dverb', False)],
          'dverbens': [('dverb', False)],
          'dvers': [('dvers', False)],
          'dvertens': [('dvertens', False)],
          'dvikar': [('dvikare', False)],
          'dvikarna': [('dvikare', False)],
          'dvikarnas': [('dvikare', False)],
          'dvin': [('dvin', False)],
          'dvin-': [('dvin', False)],
          'dvind': [('dvind', False)],
          'dvindarnas': [('dvind', False)],
          'dvinds': [('dvind', False)],
          'dvinds-': [('dvind', False)],
          'dvins': [('dvin', False)],
          'dvins-': [('dvin', False)],
          'dvinsten': [('dvinst', False)],
          'dvinter': [('dvinter', False)],
          'dvinters': [('dvinter', False)],
          'dvis': [('dvisa', False)],
          'dvis-': [('dvisa', False)],
          'dvisa': [('dvisa', False)],
          'dvisar': [('dvisare', False)],
          'dvisarna': [('dvisare', False)],
          'dvisarnas': [('dvisare', False)],
          'dvisas': [('dvisa', False)],
          'dvise': [('dvisa', False)],
          'dvisor': [('dvisa', False)],
          'dvispar': [('dvisp', False)],
          'dvisparna': [('dvisp', False)],
          'dvisparnas': [('dvisp', False)],
          'dvispars': [('dvisp', False)],
          'dvitas': [('dvita', False)],
          'dvite': [('dvita', False)],
          'dvits': [('dvits', False)],
          'dvits-': [('dvits', False)],
          'dvitsar': [('dvits', False)],
          'dvitsarna': [('dvits', False)],
          'dvitsarnas': [('dvits', False)],
          'dvägar': [('dväg', False)],
          'dvägarna': [('dväg', False)],
          'dvägarnas': [('dväg', False)],
          'dvägars': [('dväg', False)],
          'dvägen': [('dväg', False)],
          'dvägens': [('dvägen', False)],
          'dvägs': [('dväg', False)],
          'dvägs-': [('dväg', False)],
          'dvärden': [('dvärde', False)],
          'dvärdens': [('dvärde', False)],
          'dvärmar': [('dvärmare', False)],
          'dvärmarna': [('dvärmare', False)],
          'dvärmarnas': [('dvärmare', False)],
          'dväsendet': [('dväsen', False)],
          'dväsendets': [('dväsen', False)],
          'dvävar': [('dväv', False)],
          'dvävarna': [('dväv', False)],
          'dvävarnas': [('dväv', False)],
          'dy': [('dy', False)],
          'dy-': [('dy', False)],
          'dyar': [('dy', False)],
          'dyarna': [('dy', False)],
          'dyer': [('dy', False)],
          'dyerna': [('dy', False)],
          'dyernas': [('dy', False)],
          'dyers': [('dy', False)],
          'dykanden': [('dykand', True), ('dykande', True)],
          'dykandens': [('dykande', True), ('dykand', True)],
          'dykar': [('dykare', False)],
          'dykarna': [('dykare', False)],
          'dyll': [('dyll', False)],
          'dyll-': [('dyll', False)],
          'dyllen': [('dyll', False)],
          'dyller': [('dyll', False)],
          'dyllerna': [('dyll', False)],
          'dyllernas': [('dyll', False)],
          'dyllers': [('dyll', False)],
          'dylls': [('dyll', False)],
          'dylls-': [('dyll', False)],
          'dyn': [('dyna', True), ('dy', True), ('dyn', True)],
          'dyn-': [('dyn', True), ('dyna', True)],
          'dynets': [('dyn', True)],
          'dyni': [('dyni', False)],
          'dyni-': [('dyni', False)],
          'dynis': [('dyni', False)],
          'dyns': [('dy', True), ('dyna', True), ('dyn', True)],
          'dyns-': [('dyn', True), ('dyna', True)],
          'dynt': [('dynt', True)],
          'dyntet': [('dynt', True)],
          'dynts-': [('dynt', True)],
          'dyrers': [('dyr', False)],
          'dyrk': [('dyrk', True)],
          'dyrk-': [('dyrk', True)],
          'dyrkan': [('dyrkan', False)],
          'dyrkans': [('dyrkan', False)],
          'dyrkar': [('dyrk', True), ('dyrkare', True)],
          'dyrkarna': [('dyrk', True), ('dyrkare', True)],
          'dyrkarnas': [('dyrk', True), ('dyrkare', True)],
          'dyrken': [('dyrk', True)],
          'dyrkens': [('dyrk', True)],
          'dyrks': [('dyrk', True)],
          'dyrks-': [('dyrk', True)],
          'dys': [('dysa', True), ('dys', True), ('dy', True)],
          'dys-': [('dysa', True), ('dys', True)],
          'dysarna': [('dy', False)],
          'dysch': [('dyscha', True)],
          'dysch-': [('dyscha', True)],
          'dyt': [('dyt', False)],
          'dyt-': [('dyt', False)],
          'dyts': [('dyt', False)],
          'dyts-': [('dyt', False)],
          'dyvik': [('dyvika', True), ('dyvik', True)],
          'dyvik-': [('dyvika', True), ('dyvik', True)],
          'dyvikar': [('dyvikare', True), ('dyvik', True)],
          'dyvikarna': [('dyvikare', True), ('dyvik', True)],
          'dyvikarnas': [('dyvikare', True), ('dyvik', True)],
          'dyviks': [('dyvik', True), ('dyvika', True)],
          'dyviks-': [('dyvika', True), ('dyvik', True)],
          'dyx': [('dyxa', False)],
          'dyx-': [('dyxa', False)],
          'däck': [('däck', False)],
          'däck-': [('däck', True)],
          'däckarnas': [('däckare', False)],
          'däcken': [('däck', False)],
          'däckens': [('däck', False)],
          'däcket': [('däck', False)],
          'däcklar': [('däckel', True)],
          'däcklarnas': [('däckel', True)],
          'däcks': [('däck', False)],
          'däcks-': [('däck', False)],
          'dägar': [('dägare', False)],
          'dägarnas': [('dägare', False)],
          'dägg-': [('dägg', False)],
          'däggs': [('dägg', False)],
          'däggs-': [('dägg', False)],
          'dälden': [('däld', True)],
          'däldens': [('däld', True)],
          'dälder': [('däld', True)],
          'dälderna': [('däld', True)],
          'däldernas': [('däld', True)],
          'dälders': [('däld', True)],
          'dälds': [('däld', True)],
          'dälds-': [('däld', True)],
          'dämmar': [('dämmare', True)],
          'dämmarna': [('dämmare', True)],
          'dämmarnas': [('dämmare', True)],
          'dämmen': [('dämme', True)],
          'dämmens': [('dämme', True)],
          'dämne-': [('dämne', False)],
          'dämparnas': [('dämpare', False)],
          'däng': [('däng', True)],
          'däng-': [('däng', False)],
          'dängar': [('däng', False)],
          'dängarna': [('däng', False)],
          'dängarnas': [('dängare', False)],
          'dänge': [('dänga', False)],
          'dängen': [('däng', False)],
          'dängens': [('däng', False)],
          'dänger': [('däng', False)],
          'dängerna': [('däng', False)],
          'dängernas': [('däng', False)],
          'dängers': [('däng', False)],
          'dänget': [('däng', True)],
          'dängs': [('däng', False)],
          'därv': [('därv', False)],
          'därv-': [('därv', False)],
          'därvar': [('därvare', False)],
          'därvarna': [('därvare', False)],
          'därvarnas': [('därvare', False)],
          'därvs': [('därv', False)],
          'därvs-': [('därv', False)],
          'då': [('då', False)],
          'då-': [('då', False)],
          'dåd': [('dåd', True)],
          'dåd-': [('dåd', False)],
          'dådar': [('dådare', False)],
          'dådarna': [('dådare', False)],
          'dåder': [('dåder', False)],
          'dåder-': [('dåder', False)],
          'dåders': [('dåder', False)],
          'dådets': [('dåd', False)],
          'dådra': [('dådra', False)],
          'dådran': [('dådra', False)],
          'dådrans': [('dådra', False)],
          'dådras': [('dådra', False)],
          'dådre': [('dådra', False)],
          'dådre-': [('dådra', True)],
          'dådror': [('dådra', True)],
          'dådrorna': [('dådra', False)],
          'dådrornas': [('dådra', False)],
          'dådrors': [('dådra', True)],
          'dåds': [('dåd', False)],
          'dåds-': [('dåd', False)],
          'dåg': [('dåga', False)],
          'dåg-': [('dåga', False)],
          'dågs': [('dåga', False)],
          'dågs-': [('dåga', False)],
          'dåkar': [('dåkare', False)],
          'dåkarna': [('dåkare', False)],
          'dåligheter': [('dålighet', True), ('dåligheter', True)],
          'dåligheterna': [('dålighet', True), ('dåligheter', True)],
          'dåligheternas': [('dåligheter', True), ('dålighet', True)],
          'dåligheters': [('dålighet', True), ('dåligheter', True)],
          'dålighets': [('dåligheter', True), ('dålighet', True)],
          'dålighets-': [('dåligheter', True), ('dålighet', True)],
          'dån': [('dån', False)],
          'dångarna': [('dångare', False)],
          'dåns': [('dån', True)],
          'dår': [('dåre', True)],
          'dår-': [('dåre', False)],
          'dårar': [('dåre', False)],
          'dårars': [('dåre', True)],
          'dåre': [('dåre', True)],
          'dåre-': [('dåre', False)],
          'dåren': [('dåre', False)],
          'dårens': [('dåre', False)],
          'dårs': [('dåre', False)],
          'dårs-': [('dåre', False)],
          'dås': [('dås', True)],
          'dås-': [('dås', True)],
          'dåtidens': [('dåtid', True)],
          'déerna': [('dé', False)],
          'déernas': [('dé', False)],
          'dödar': [('död', False)],
          'dödarna': [('död', True)],
          'dödarnas': [('död', True)],
          'döden': [('död', False)],
          'dödens': [('död', False)],
          'dödsdans': [('dödsdans', True), ('dödsdag', True)],
          'dödsryckningar': [('dödsryckning', True), ('dödsryckningar', True)],
          'dödsryckningarna': [('dödsryckning', True), ('dödsryckningar', True)],
          'dödsryckningarnas': [('dödsryckning', True), ('dödsryckningar', True)],
          'dödsryckningars': [('dödsryckning', True), ('dödsryckningar', True)],
          'dödsrycknings': [('dödsryckning', True), ('dödsryckningar', True)],
          'dödsrycknings-': [('dödsryckning', True), ('dödsryckningar', True)],
          'dögats': [('döga', False)],
          'dögonens': [('döga', False)],
          'dögons': [('döga', False)],
          'döken': [('döken', False)],
          'dökens': [('döken', False)],
          'dön': [('dön', False)],
          'döns': [('dön', True)],
          'döns-': [('dön', True)],
          'dören': [('dör', False)],
          'dörens': [('dör', False)],
          'dörj': [('dörj', True)],
          'dörj-': [('dörj', True)],
          'dörjar': [('dörj', True)],
          'dörjarna': [('dörj', True)],
          'dörn': [('dör', False)],
          'dörns': [('dör', False)],
          'dörtens': [('dört', False)],
          'dös': [('dös', False)],
          'dös-': [('dös', False)],
          'dösarna': [('dös', False)],
          'dösarnas': [('dös', True)],
          'dösten': [('döst', False)],
          'e': [('e', True)],
          'e-': [('e-', True), ('e', True)],
          'e-postar': [('e-postare', True), ('e-post', True)],
          'e-postarna': [('e-postare', True), ('e-post', True)],
          'e-postarnas': [('e-postare', True), ('e-post', True)],
          'ea': [('ea', False)],
          'ea-': [('ea', False)],
          'eadets': [('ead', False)],
          'eador': [('eador', False)],
          'eadors': [('eador', False)],
          'eagens': [('eagens', False)],
          'eaglar': [('eagle', False)],
          'eaglarna': [('eagle', False)],
          'eaglarnas': [('eagle', False)],
          'eaglars': [('eagle', False)],
          'eaglen': [('eagle', False)],
          'eaglens': [('eagle', False)],
          'eak-': [('eak', False)],
          'eakarnas': [('eak', False)],
          'eaker': [('eaker', False)],
          'eakerna': [('eaker', False)],
          'eakernas': [('eaker', False)],
          'eakers': [('eaker', False)],
          'eakets': [('eak', False)],
          'eaks': [('eak', False)],
          'eaks-': [('eak', False)],
          'eakter': [('eakt', False)],
          'eakters': [('eakt', False)],
          'eaktorer': [('eaktor', False)],
          'eaktorers': [('eaktor', False)],
          'eale': [('eale', False)],
          'eale-': [('eale', False)],
          'eales': [('eale', False)],
          'ealet': [('eale', False)],
          'ealets': [('eale', False)],
          'ealie-': [('ealier', False)],
          'ealierna': [('ealier', False)],
          'eallön': [('eallön', False)],
          'eals': [('eal', False)],
          'eals-': [('eal', False)],
          'eam': [('eam', False)],
          'eam-': [('eam', False)],
          'eamet': [('eam', False)],
          'eamets': [('eam', False)],
          'eams': [('eam', False)],
          'eams-': [('eam', False)],
          'ean': [('ea', False)],
          'eand': [('eand', False)],
          'eandarna': [('eande', False)],
          'eanden': [('eande', False)],
          'eandens': [('eande', False)],
          'eandets': [('eande', False)],
          'eandrar': [('eander', False)],
          'eandrarna': [('eander', False)],
          'eandrarnas': [('eander', False)],
          'eandrars': [('eander', False)],
          'eands': [('eand', False)],
          'eands-': [('eand', False)],
          'eanens': [('ean', False)],
          'eang': [('eang', False)],
          'eang-': [('eang', False)],
          'eangen': [('eang', False)],
          'eangens': [('eang', False)],
          'eanger': [('eang', False)],
          'eangerna': [('eang', False)],
          'eangernas': [('eang', False)],
          'eangers': [('eang', False)],
          'eangs': [('eang', False)],
          'eangs-': [('eang', False)],
          'eannen': [('eanne', False)],
          'eannens': [('eanne', False)],
          'eanner': [('eanne', False)],
          'eannerna': [('eanne', False)],
          'eannernas': [('eanne', False)],
          'eanners': [('eanne', False)],
          'eans': [('eans', False)],
          'eansen': [('eans', False)],
          'eansens': [('eans', False)],
          'eanser': [('eans', False)],
          'eanserna': [('eans', False)],
          'eansernas': [('eans', False)],
          'eansers': [('eans', False)],
          'eansk': [('eanska', False)],
          'eansk-': [('eanska', False)],
          'eanstalter': [('eanstalt', False)],
          'eanstalterna': [('eanstalt', False)],
          'eanstalternas': [('eanstalt', False)],
          'eanstalters': [('eanstalt', False)],
          'eanstalts': [('eanstalt', False)],
          'eanstalts-': [('eanstalt', False)],
          'eant': [('eant', False)],
          'eanten': [('eant', False)],
          'eantens': [('eant', False)],
          'eanter': [('eant', False)],
          'eanterna': [('eant', False)],
          'eanternas': [('eant', False)],
          'eanters': [('eant', False)],
          'eants-': [('eant', False)],
          'eap-': [('eapa', False)],
          'eapan': [('eapa', False)],
          'eapas': [('eapa', False)],
          'eaps': [('eapa', False)],
          'earin': [('earin', False)],
          'earmar': [('earm', False)],
          'earmarna': [('earm', False)],
          'earmarnas': [('earm', False)],
          'earnas': [('e', False)],
          'ears': [('e', False)],
          'eart': [('eart', False)],
          'earten': [('eart', False)],
          'eartens': [('eart', False)],
          'earterna': [('eart', False)],
          'earternas': [('eart', False)],
          'earters': [('eart', False)],
          'earts': [('eart', False)],
          'earv': [('earv', False)],
          'earven': [('earv', False)],
          'earvens': [('earv', False)],
          'earvs': [('earv', False)],
          'earvs-': [('earv', False)],
          'eas': [('ea', False)],
          'easarna': [('ea', False)],
          'easarnas': [('ea', False)],
          'ease': [('ease', False)],
          'ease-': [('ease', False)],
          'easen': [('ease', False)],
          'easens': [('ease', False)],
          'easingen': [('easing', False)],
          'easingens': [('easing', False)],
          'east-': [('east', False)],
          'easten': [('east', False)],
          'easter': [('east', False)],
          'easterna': [('east', False)],
          'easternas': [('east', False)],
          'easters': [('east', False)],
          'eater': [('eater', False)],
          'eaters': [('eater', False)],
          'eation': [('eation', False)],
          'eationen': [('eation', False)],
          'eations': [('eation', False)],
          'eats-': [('eat', False)],
          'eauns': [('eau', False)],
          'eback': [('eback', False)],
          'eback-': [('eback', False)],
          'ebacken': [('eback', False)],
          'ebackens': [('eback', False)],
          'ebacks': [('eback', False)],
          'ebal': [('ebal', False)],
          'ebalar': [('ebal', False)],
          'ebalarna': [('ebal', False)],
          'ebalarnas': [('ebal', False)],
          'ebalars': [('ebal', False)],
          'ebalen': [('ebal', False)],
          'ebalens': [('ebal', False)],
          'eball': [('eball', False)],
          'eball-': [('eball', False)],
          'eballen': [('eball', False)],
          'eballens': [('eball', False)],
          'eballs': [('eball', False)],
          'eballs-': [('eball', False)],
          'ebals': [('ebal', False)],
          'ebals-': [('ebal', False)],
          'ebanan': [('ebana', False)],
          'ebanans': [('ebanan', False)],
          'ebandets': [('eband', False)],
          'ebane': [('ebana', False)],
          'ebane-': [('ebana', False)],
          'ebarens': [('ebar', False)],
          'ebars': [('ebar', False)],
          'ebas': [('ebas', False)],
          'ebasar': [('ebas', False)],
          'ebasars': [('ebas', False)],
          'ebass': [('ebass', False)],
          'ebass-': [('ebass', False)],
          'ebassen': [('ebass', False)],
          'ebassens': [('ebass', False)],
          'ebattens': [('ebatt', False)],
          'ebb-': [('ebb', True)],
          'ebbar': [('ebb', False)],
          'ebbarna': [('ebb', False)],
          'ebben': [('ebb', True)],
          'eben': [('eben', False)],
          'eben-': [('eben', False)],
          'ebens': [('eb', False)],
          'ebens-': [('eben', False)],
          'ebet': [('ebet', False)],
          'ebet-': [('ebet', False)],
          'ebets': [('ebet', False)],
          'ebets-': [('ebet', False)],
          'ebevis': [('ebevis', False)],
          'ebil': [('ebil', False)],
          'ebilar': [('ebil', False)],
          'ebils': [('ebil', False)],
          'ebils-': [('ebil', False)],
          'ebis': [('ebis', False)],
          'ebis-': [('ebis', False)],
          'ebit': [('ebit', False)],
          'ebits': [('ebit', False)],
          'ebits-': [('ebit', False)],
          'eblask': [('eblask', False)],
          'eblask-': [('eblask', False)],
          'eblem-': [('eblemma', False)],
          'ebloggar': [('eblogg', False)],
          'ebloggarna': [('eblogg', False)],
          'ebloggarnas': [('eblogg', False)],
          'eblom': [('eblomma', False)],
          'eblom-': [('eblomma', False)],
          'ebloms': [('eblomma', False)],
          'ebloms-': [('eblomma', False)],
          'ebolaget': [('ebolag', False)],
          'ebomb': [('ebomb', False)],
          'ebomber': [('ebomb', False)],
          'ebomberna': [('ebomb', False)],
          'ebombernas': [('ebomb', False)],
          'ebombers': [('ebomb', False)],
          'ebombs': [('ebomb', False)],
          'ebombs-': [('ebomb', False)],
          'ebond': [('ebonde', False)],
          'ebondens': [('ebonde', False)],
          'ebonds': [('ebonde', False)],
          'ebonds-': [('ebonde', False)],
          'ebor': [('ebo', False)],
          'eborgar': [('eborg', False)],
          'eborgarna': [('eborg', False)],
          'eborgarnas': [('eborg', False)],
          'eborgen': [('eborgen', False)],
          'eborgens': [('eborg', False)],
          'ebors': [('ebo', False)],
          'eboxar': [('ebox', False)],
          'eboxarna': [('ebox', False)],
          'eboxarnas': [('ebox', False)],
          'ebra': [('ebra', False)],
          'ebran': [('ebra', False)],
          'ebrans': [('ebra', False)],
          'ebras': [('ebra', False)],
          'ebrats': [('ebrat', False)],
          'ebrats-': [('ebrat', False)],
          'ebroms': [('ebroms', False)],
          'ebromsar': [('ebroms', False)],
          'ebromsarna': [('ebroms', False)],
          'ebromsarnas': [('ebroms', False)],
          'ebror': [('ebra', False)],
          'ebrors': [('ebra', False)],
          'ebrors-': [('ebrorsa', False)],
          'ebråk': [('ebråk', False)],
          'ebråks': [('ebråk', False)],
          'ebråks-': [('ebråk', False)],
          'ebs': [('eb', False)],
          'ebs-': [('ebs', False)],
          'ebubbel': [('ebubbla', False)],
          'ebubbel-': [('ebubbla', False)],
          'ebus': [('ebus', False)],
          'ebus-': [('ebus', False)],
          'ebusar': [('ebus', False)],
          'ebusarna': [('ebus', False)],
          'ebusarnas': [('ebus', False)],
          'ebusars': [('ebus', False)],
          'ebusen': [('ebus', False)],
          'ebusens': [('ebus', False)],
          'ebut': [('ebut', False)],
          'ebuts': [('ebut', False)],
          'ebälte': [('ebälte', False)],
          'ebådar': [('ebådare', False)],
          'ebådarna': [('ebådare', False)],
          'ebådarnas': [('ebådare', False)],
          'ebön': [('eböna', False)],
          'ebön-': [('eböna', False)],
          'eböne': [('eböna', False)],
          'eböne-': [('eböna', False)],
          'eböns': [('eböna', False)],
          'eböns-': [('eböna', False)],
          'ec': [('ec', False)],
          'ec-': [('ec', False)],
          'eccis': [('eccia', False)],
          'eccis-': [('eccia', False)],
          'ecell': [('ecell', False)],
          'ecellens': [('ecell', False)],
          'ecen': [('ec', False)],
          'ecens': [('ec', False)],
          'ecentrer': [('ecentrum', False)],
          'ecentrerna': [('ecentrum', False)],
          'ecentrernas': [('ecentrum', False)],
          'ecentrers': [('ecentrum', False)],
          'ecentret': [('ecentrum', False)],
          'ecentrets': [('ecentrum', False)],
          'ecer': [('ec', False)],
          'ecerna': [('ec', False)],
          'ecernas': [('ec', False)],
          'ecers': [('ec', False)],
          'echasen': [('echase', False)],
          'ecian': [('ecia', False)],
          'ecians': [('ecia', False)],
          'ecie': [('ecie', False)],
          'ecie-': [('ecie', False)],
          'ecien': [('ecie', False)],
          'eciens': [('ecie', False)],
          'ecier': [('ecie', False)],
          'ecierna': [('ecie', False)],
          'eciernas': [('ecie', False)],
          'eciers': [('ecie', False)],
          'ecin': [('eci', False)],
          'ecins': [('ecin', False)],
          'ecis': [('eci', False)],
          'eckan': [('ecka', False)],
          'eckans': [('ecka', False)],
          'eckar': [('eckare', False)],
          'eckarna': [('eckare', False)],
          'eckarnas': [('eckare', False)],
          'eckat': [('ecka', False)],
          'ecken': [('ecken', False)],
          'eckens': [('ecken', False)],
          'eckets': [('eck', False)],
          'ecklanden': [('ecklande', False)],
          'ecklandens': [('ecklande', False)],
          'ecklandet': [('ecklande', False)],
          'ecklar': [('ecklare', False)],
          'ecklarnas': [('ecklare', False)],
          'ecknar': [('ecknare', False)],
          'ecko': [('ecko', False)],
          'ecko-': [('ecka', False)],
          'eckor': [('ecko', False)],
          'eckorna': [('ecko', False)],
          'eckornas': [('ecko', False)],
          'eckors': [('ecko', False)],
          'ecs-': [('ec', False)],
          'ecsen': [('ecies', False)],
          'ecsens': [('ecies', False)],
          'ed': [('eda', True), ('ed', True)],
          'ed-': [('eda', True), ('ed', True)],
          'edagar': [('edag', False)],
          'edagarna': [('edag', False)],
          'edagarnas': [('edag', False)],
          'edagars': [('edag', False)],
          'edagen': [('edag', False)],
          'edagens': [('edag', False)],
          'edags': [('edag', False)],
          'edags-': [('edag', False)],
          'edaler': [('edal', False)],
          'edalerna': [('edal', False)],
          'edalernas': [('edal', False)],
          'edalers': [('edal', False)],
          'edan': [('eda', True)],
          'edanden': [('edande', False)],
          'edandens': [('edande', False)],
          'edans': [('eda', True)],
          'edar': [('ed', False)],
          'edar-': [('edar', False)],
          'edaren': [('edare', False)],
          'edarens': [('edar', False)],
          'edarna': [('ed', False)],
          'edarnas': [('edare', False)],
          'edars': [('ed', False)],
          'edars-': [('edar', False)],
          'edater': [('edater', False)],
          'edaterna': [('edater', False)],
          'edaternas': [('edater', False)],
          'edaters': [('edater', False)],
          'edativ': [('edativum', False)],
          'edativ-': [('edativum', False)],
          'edativen': [('edativum', False)],
          'edativens': [('edativum', False)],
          'edativer': [('edativum', False)],
          'edativerna': [('edativum', False)],
          'edativernas': [('edativum', False)],
          'edativers': [('edativum', False)],
          'edativs': [('edativum', False)],
          'edator': [('edator', False)],
          'edators': [('edator', False)],
          'edats': [('edater', False)],
          'edats-': [('edater', False)],
          'edback': [('edbacke', False)],
          'edback-': [('edback', False)],
          'edbacken': [('edback', False)],
          'edbackens': [('edbacke', False)],
          'edbacks': [('edback', False)],
          'edben': [('edbena', False)],
          'edbens-': [('edbena', False)],
          'edborgar': [('edborgare', False)],
          'edd': [('edda', True)],
          'edd-': [('edda', True)],
          'edda': [('edda', True)],
          'eddans': [('edda', True)],
          'eddock': [('eddocka', False)],
          'eddocks-': [('eddocka', False)],
          'eddon': [('eddo', False)],
          'eddons': [('eddo', False)],
          'edds': [('edda', True)],
          'edds-': [('edda', True)],
          'ede': [('eda', False)],
          'ede-': [('eda', True)],
          'edel': [('edel', False)],
          'edel-': [('edel', False)],
          'edelars': [('edel', False)],
          'edels': [('edel', False)],
          'edels-': [('edel', False)],
          'eden': [('ed', False)],
          'edens': [('ed', False)],
          'eder': [('ed', False)],
          'eder-': [('eder', False)],
          'ederits': [('ederi', False)],
          'edern': [('eder', False)],
          'ederna': [('ed', False)],
          'edernas': [('ed', False)],
          'ederns': [('eder', False)],
          'eders': [('ed', False)],
          'eders-': [('eder', False)],
          'edes': [('edes', False)],
          'edes-': [('edes', False)],
          'edet': [('ed', False)],
          'edets': [('ed', True)],
          'edfångar': [('edfånge', False)],
          'edfångarna': [('edfånge', False)],
          'edfångarnas': [('edfånge', False)],
          'edfången': [('edfånge', False)],
          'edfångens': [('edfång', False)],
          'edhjälpar': [('edhjälpare', False)],
          'edhjälparna': [('edhjälpare', False)],
          'edia': [('edium', False)],
          'edian': [('edian', False)],
          'edians': [('edian', False)],
          'edias': [('edium', False)],
          'ediens': [('ediens', False)],
          'edierna': [('edi', False)],
          'ediernas': [('edi', False)],
          'ediet': [('edium', False)],
          'ediets': [('edium', False)],
          'edin': [('edi', False)],
          'edins': [('edin', False)],
          'edisk': [('ediska', False)],
          'edisk-': [('ediska', False)],
          'ediv': [('ediv', False)],
          'ediv-': [('ediv', False)],
          'ediver': [('ediv', False)],
          'ediverna': [('ediv', False)],
          'edivernas': [('ediv', False)],
          'edivers': [('ediv', False)],
          'edivs': [('ediv', False)],
          'edjan': [('edja', False)],
          'edjans': [('edja', False)],
          'edlan': [('edlan', False)],
          'edlans': [('edlan', False)],
          'edlar': [('edel', False)],
          'edlarna': [('edel', False)],
          'edlarnas': [('edel', False)],
          'edlars': [('edel', False)],
          'edo-': [('edo', False)],
          'edock-': [('edocka', False)],
          'edocks': [('edocka', False)],
          'edocks-': [('edocka', False)],
          'edoken': [('edok', False)],
          'edomar': [('edom', False)],
          'edomarna': [('edom', False)],
          'edomarnas': [('edom', False)],
          'edomen': [('edom', False)],
          'edon': [('edon', False)],
          'edon-': [('edon', False)],
          'edona': [('edo', False)],
          'edonas': [('edo', False)],
          'edons': [('edon', False)],
          'edons-': [('edon', False)],
          'edor': [('eda', True)],
          'edorna': [('eda', True)],
          'edornas': [('eda', True)],
          'edors': [('eda', False)],
          'edos': [('edo', False)],
          'edot': [('edo', False)],
          'edramer': [('edrama', False)],
          'edramerna': [('edrama', False)],
          'edramernas': [('edrama', False)],
          'edrar': [('eder', False)],
          'edrarna': [('eder', False)],
          'edrars': [('eder', False)],
          'edrin': [('edrin', False)],
          'edringar': [('edring', False)],
          'edringarnas': [('edring', False)],
          'edringars': [('edring', False)],
          'edrinkar': [('edrinkare', False)],
          'edrinkarna': [('edrinkare', False)],
          'edrinkarnas': [('edrinkare', False)],
          'edrivar': [('edrivare', False)],
          'edrivarna': [('edrivare', False)],
          'edrivarnas': [('edrivare', False)],
          'edrömmar': [('edröm', False)],
          'edrömmarna': [('edröm', False)],
          'edrömmarnas': [('edröm', False)],
          'eds': [('eda', True), ('ed', True)],
          'eds-': [('eda', True), ('ed', True)],
          'edslås-': [('edslå', False)],
          'edsorden': [('edsord', False)],
          'edsordens': [('edsord', False)],
          'edstalet': [('edstal', False)],
          'edträna': [('edträ', False)],
          'edtränas': [('edträ', False)],
          'edung': [('edung', False)],
          'edungen': [('edung', False)],
          'edungens': [('edung', False)],
          'edungs': [('edung', False)],
          'edungs-': [('edung', False)],
          'eduns': [('eduns', False)],
          'eduns-': [('eduns', False)],
          'edvägens': [('edväg', False)],
          'edyn': [('edyn', False)],
          'edyn-': [('edyn', False)],
          'edyns': [('edyna', False)],
          'edyns-': [('edyna', False)],
          'edådre-': [('edådra', False)],
          'edödar': [('edödare', False)],
          'edödarna': [('edöd', False)],
          'edödarnas': [('edödare', False)],
          'ee': [('ee', False)],
          'ee-': [('ee', False)],
          'eear': [('ee', False)],
          'eearna': [('ee', False)],
          'eecen': [('eece', False)],
          'eecens': [('eece', False)],
          'eed': [('eed', False)],
          'eed-': [('eed', False)],
          'eedback': [('eedback', False)],
          'eedbackens': [('eedback', False)],
          'eeds': [('eed', False)],
          'een': [('ee', False)],
          'eendets': [('eende', False)],
          'eenheter': [('eenhet', False)],
          'eenheterna': [('eenhet', False)],
          'eenheternas': [('eenhet', False)],
          'eenheters': [('eenhet', False)],
          'eenhets': [('eenhet', False)],
          'eenhets-': [('eenhet', False)],
          'eens': [('een', False)],
          'eensarna': [('een', False)],
          'eensen': [('een', False)],
          'eeparnas': [('eep', False)],
          'eepens': [('eep', False)],
          'eer': [('eum', False)],
          'eer-': [('eera', False)],
          'eerans': [('eera', False)],
          'eeri': [('eeri', False)],
          'eeri-': [('eeri', False)],
          'eerier': [('eeri', False)],
          'eerierna': [('eeri', False)],
          'eeriers': [('eeri', False)],
          'eeriet': [('eeri', False)],
          'eeris': [('eeri', False)],
          'eeris-': [('eeri', False)],
          'eerit': [('eeri', False)],
          'eerna': [('eum', False)],
          'eernas': [('eum', False)],
          'eerornas': [('eera', False)],
          'eers': [('ee', False)],
          'ees': [('ee', False)],
          'ees-': [('ee', False)],
          'eesarna': [('ee', False)],
          'eesarnas': [('ee', False)],
          'eesen': [('ee', False)],
          'eesens': [('ee', False)],
          'eessen': [('eess', False)],
          'eessens': [('eess', False)],
          'eet': [('eum', False)],
          'eetarnas': [('eet', False)],
          'eeten': [('eet', False)],
          'eetens': [('eet', False)],
          'eetets': [('eet', False)],
          'eets': [('e', False)],
          'eetsen': [('eets', False)],
          'eetsens': [('eets', False)],
          'eetset': [('eets', False)],
          'eetsets': [('eets', False)],
          'ef': [('ef', False)],
          'ef-': [('ef', False)],
          'efader': [('efar', False)],
          'efader-': [('efader', False)],
          'efadern': [('efar', False)],
          'efaderns': [('efader', False)],
          'efaders': [('efader', False)],
          'efaders-': [('efar', False)],
          'efals': [('efal', False)],
          'efals-': [('efal', False)],
          'efan': [('efa', False)],
          'efans': [('efa', False)],
          'efar': [('efar', False)],
          'efar-': [('efar', False)],
          'efars': [('efar', False)],
          'efars-': [('efar', False)],
          'efas': [('efa', False)],
          'efasen': [('efas', False)],
          'efasens': [('efas', False)],
          'efat': [('efat', False)],
          'efats': [('efat', False)],
          'efekterna': [('efekt', False)],
          'efel': [('efel', False)],
          'efels': [('efel', False)],
          'efels-': [('efel', False)],
          'efemerid': [('efemerid', True), ('efemerider', True)],
          'efemerid-': [('efemerid', True), ('efemerider', True)],
          'efemerider': [('efemerid', True), ('efemerider', True)],
          'efemeriderna': [('efemerid', True), ('efemerider', True)],
          'efemeridernas': [('efemerid', True), ('efemerider', True)],
          'efemeriders': [('efemerid', True), ('efemerider', True)],
          'efemerids': [('efemerider', True), ('efemerid', True)],
          'efen': [('ef', False)],
          'efens': [('ef', False)],
          'efer': [('ef', False)],
          'eferna': [('ef', False)],
          'efernas': [('ef', False)],
          'efers': [('ef', False)],
          'effekt': [('effekt', False)],
          'effekt-': [('effekt', False)],
          'effekter': [('effekt', False)],
          'effekterna': [('effekt', True)],
          'effekternas': [('effekt', False)],
          'effekters': [('effekt', False)],
          'effekts': [('effekt', False)],
          'effekts-': [('effekt', False)],
          'efilar': [('efil', False)],
          'efilarna': [('efil', False)],
          'efilarnas': [('efil', False)],
          'efilen': [('efil', False)],
          'efilens': [('efil', False)],
          'efiller': [('efill', False)],
          'efillers': [('efill', False)],
          'efin': [('efin', False)],
          'efinnar': [('efinne', False)],
          'efinnarnas': [('efinne', False)],
          'efins': [('efin', False)],
          'efins-': [('efin', False)],
          'efirn': [('efir', False)],
          'efirns': [('efir', False)],
          'efiskar': [('efisk', False)],
          'efiskarna': [('efisk', False)],
          'efiskarnas': [('efisk', False)],
          'eflon': [('eflon', False)],
          'eflons': [('eflon', False)],
          'efläck': [('efläck', False)],
          'eflödet': [('eflöde', False)],
          'efnaskar': [('efnask', False)],
          'efnaskarna': [('efnask', False)],
          'efnaskarnas': [('efnask', False)],
          'efnaskars': [('efnask', False)],
          'efon': [('efon', False)],
          'efonis': [('efoni', False)],
          'efor': [('efor', True)],
          'efor-': [('efor', True)],
          'eforer': [('efor', True), ('eforus', True)],
          'eforerna': [('efor', True), ('eforus', True)],
          'eforernas': [('efor', True), ('eforus', True)],
          'eforers': [('efor', True), ('eforus', True)],
          'efors': [('efor', True)],
          'efors-': [('efor', True)],
          'eforten': [('efort', False)],
          'efortens': [('efort', False)],
          'efoton': [('efoto', False)],
          'efotons': [('efoto', False)],
          'efots': [('efot', False)],
          'efots-': [('efot', False)],
          'efran': [('efra', False)],
          'efrans': [('efra', False)],
          'efras': [('efra', False)],
          'efs': [('ef', False)],
          'efs-': [('ef', False)],
          'efug': [('efug', False)],
          'efug-': [('efug', False)],
          'efugs': [('efug', False)],
          'efugs-': [('efug', False)],
          'efyrar': [('efyr', False)],
          'efäder': [('efader', False)],
          'efäderna': [('efader', False)],
          'efädernas': [('efader', False)],
          'efäders': [('efader', False)],
          'efäran': [('efära', False)],
          'efärans': [('efära', False)],
          'efångar': [('efångare', False)],
          'efångarna': [('efångare', False)],
          'efångarnas': [('efångare', False)],
          'efår': [('efår', False)],
          'efår-': [('efår', False)],
          'efårs': [('efår', False)],
          'efårs-': [('efår', False)],
          'eförlust-': [('eförlust', False)],
          'eförluster': [('eförlust', False)],
          'eförlusterna': [('eförlust', False)],
          'eförlusternas': [('eförlust', False)],
          'eförsäkringar': [('eförsäkring', False)],
          'eförsäkringarna': [('eförsäkring', False)],
          'eförsäkringarnas': [('eförsäkring', False)],
          'eförsäkringars': [('eförsäkring', False)],
          'eg': [('eg', False)],
          'eg-': [('eg', False)],
          'egal': [('egal', False)],
          'egal-': [('egal', False)],
          'egale': [('egale', False)],
          'egales': [('egales', False)],
          'egalier': [('egalier', False)],
          'egalierna': [('egalier', False)],
          'egaliernas': [('egalier', False)],
          'egaliers': [('egalier', False)],
          'egaller': [('egaller', False)],
          'egallerna': [('egaller', False)],
          'egallernas': [('egaller', False)],
          'egallers': [('egaller', False)],
          'egamen': [('egame', False)],
          'egamens': [('egame', False)],
          'egamet': [('egame', False)],
          'egamets': [('egame', False)],
          'egan': [('ega', False)],
          'egandens': [('egande', False)],
          'egans': [('ega', False)],
          'egans-': [('egans', False)],
          'egarden': [('egard', True)],
          'egardens': [('egard', True)],
          'egaren': [('egare', False)],
          'egarnas': [('eg', False)],
          'egars': [('eg', False)],
          'egas': [('ega', False)],
          'egas-': [('ega', False)],
          'egaserna': [('egas', False)],
          'egasernas': [('egas', False)],
          'egasers': [('egas', False)],
          'egat': [('egat', False)],
          'egat-': [('egat', False)],
          'egaten': [('egat', False)],
          'egatens': [('egat', False)],
          'egater': [('egat', False)],
          'egaterna': [('egat', False)],
          'egaternas': [('egat', False)],
          'egaters': [('egat', False)],
          'egaton': [('egato', False)],
          'egatons': [('egato', False)],
          'egats': [('egat', False)],
          'egats-': [('egat', False)],
          'ege': [('ega', False)],
          'ege-': [('ega', False)],
          'egel': [('egel', False)],
          'egel-': [('egel', False)],
          'egelsömmar': [('egelsömmare', False)],
          'egelsömmarna': [('egelsömmare', False)],
          'egelsömmarnas': [('egelsömmare', False)],
          'egementen': [('egemente', False)],
          'egementens': [('egemente', False)],
          'egementet': [('egemente', False)],
          'egements-': [('egemente', False)],
          'egen': [('eg', False)],
          'egens': [('eg', False)],
          'eger': [('eg', False)],
          'egerna': [('ega', False)],
          'egernas': [('ega', False)],
          'egers': [('eg', False)],
          'egers-': [('eger', False)],
          'eges': [('eges', False)],
          'eges-': [('eges', False)],
          'eget': [('eg', False)],
          'egets': [('eg', False)],
          'eggar': [('egg', True)],
          'eggets': [('egg', False)],
          'eghets': [('eghet', False)],
          'egiftens': [('egifte', False)],
          'egiftet': [('egifte', False)],
          'egiftets': [('egifte', False)],
          'egifts': [('egifte', False)],
          'egifts-': [('egifte', False)],
          'egin': [('egi', False)],
          'egins': [('egi', False)],
          'egis': [('egis', False)],
          'egis-': [('egis', False)],
          'egister': [('egister', False)],
          'egisterna': [('egister', False)],
          'egisternas': [('egister', False)],
          'egisters': [('egister', False)],
          'egiv': [('egiva', False)],
          'egiv-': [('egiva', False)],
          'egivar': [('egivare', False)],
          'egivarna': [('egivare', False)],
          'egivarnas': [('egivare', False)],
          'egivs': [('egiva', False)],
          'egivs-': [('egiva', False)],
          'eglagens': [('eglage', False)],
          'eglar': [('egel', False)],
          'eglarna': [('egel', False)],
          'eglarnas': [('egel', False)],
          'eglars': [('egel', False)],
          'eglasögon': [('eglasögon', False)],
          'eglasögonen': [('eglasögon', False)],
          'eglasögonens': [('eglasögon', False)],
          'eglasögons': [('eglasögon', False)],
          'eglen': [('egel', False)],
          'eglens': [('egel', False)],
          'egman': [('egma', False)],
          'egmans': [('egma', False)],
          'egmat': [('egma', False)],
          'egnans-': [('egnans', False)],
          'egnet': [('egn', False)],
          'egnets': [('egn', False)],
          'egods': [('egods', False)],
          'egods-': [('egods', False)],
          'egon': [('ego', False)],
          'egons': [('ego', False)],
          'egor': [('ega', False)],
          'egorna': [('ega', False)],
          'egornas': [('ega', False)],
          'egors': [('ega', False)],
          'egosarnas': [('ego', False)],
          'egot': [('ego', False)],
          'egotrippar': [('egotrippare', True), ('egotripp', True)],
          'egotripparna': [('egotripp', True), ('egotrippare', True)],
          'egotripparnas': [('egotrippare', True), ('egotripp', True)],
          'egots': [('ego', False)],
          'egrafen': [('egraf', False)],
          'egrafens': [('egraf', False)],
          'egranden': [('egrand', False)],
          'egrandens': [('egrand', False)],
          'egrandet': [('egrande', False)],
          'egrandets': [('egrande', False)],
          'egrar-': [('egrare', False)],
          'egraren': [('egrare', False)],
          'egrarens': [('egrare', False)],
          'egrars': [('eger', False)],
          'egravanden': [('egravande', False)],
          'egravandens': [('egravande', False)],
          'egrej': [('egrej', False)],
          'egrej-': [('egrej', False)],
          'egrejs': [('egrej', False)],
          'egrejs-': [('egrej', False)],
          'egrill': [('egrill', False)],
          'egrills': [('egrill', False)],
          'egrills-': [('egrill', False)],
          'egrot': [('egro', False)],
          'egrots': [('egro', False)],
          'egrundans': [('egrundan', False)],
          'egrynet': [('egryn', False)],
          'egrynets': [('egryn', False)],
          'egryt': [('egryta', False)],
          'egryt-': [('egryta', False)],
          'egryts': [('egryta', False)],
          'egryts-': [('egryta', False)],
          'egränder': [('egrand', False)],
          'egränderna': [('egrand', False)],
          'egrändernas': [('egrand', False)],
          'egränders': [('egrand', False)],
          'egräns': [('egräns', False)],
          'egräns-': [('egräns', False)],
          'egs-': [('eg', False)],
          'egym': [('egymer', False)],
          'egym-': [('egymer', False)],
          'egyms': [('egymer', False)],
          'egär': [('egär', False)],
          'egär-': [('egär', False)],
          'egäran': [('egäran', False)],
          'egärans': [('egära', False)],
          'egärden': [('egärd', False)],
          'egärdens': [('egärd', False)],
          'egärs': [('egär', False)],
          'egärs-': [('egär', False)],
          'egångar': [('egång', False)],
          'egångarna': [('egång', False)],
          'egångarnas': [('egångare', False)],
          'egåve-': [('egåva', False)],
          'egåvors': [('egåva', False)],
          'ehag': [('ehag', False)],
          'ehag-': [('ehag', False)],
          'ehagen': [('ehag', False)],
          'ehagens': [('ehag', False)],
          'ehags': [('ehag', False)],
          'ehags-': [('ehag', False)],
          'ehalv': [('ehalva', False)],
          'ehalv-': [('ehalva', False)],
          'ehalvs': [('ehalva', False)],
          'ehalvs-': [('ehalva', False)],
          'ehandlar': [('ehandel', False)],
          'ehandlarna': [('ehandlare', False)],
          'ehandlarnas': [('ehandel', False)],
          'ehands': [('ehand', False)],
          'ehands-': [('ehand', False)],
          'ehets': [('ehet', False)],
          'ehets-': [('ehet', False)],
          'ehots': [('ehot', False)],
          'ehundars': [('ehund', False)],
          'ehus': [('ehus', False)],
          'ehuv': [('ehuv', False)],
          'ehuve': [('ehuva', False)],
          'ehuven': [('ehuv', False)],
          'ehuvens': [('ehuv', False)],
          'ehuvs': [('ehuv', False)],
          'ehuvs-': [('ehuv', False)],
          'ehylle': [('ehylla', False)],
          'ehylle-': [('ehylla', False)],
          'ehäfte': [('ehäfte', False)],
          'ehäften': [('ehäfte', False)],
          'ehälle': [('ehälle', False)],
          'ehälle-': [('ehälle', False)],
          'ehängen': [('ehäng', False)],
          'ehängens': [('ehäng', False)],
          'ehänget': [('ehäng', False)],
          'ehängets': [('ehäng', False)],
          'ehängs': [('ehäng', False)],
          'ehängs-': [('ehäng', False)],
          'ehål': [('ehål', False)],
          'ehåls': [('ehål', False)],
          'ehåls-': [('ehål', False)],
          'ehån': [('ehå', False)],
          'ehåns': [('ehå', False)],
          'ehörighets': [('ehörighet', False)],
          'ei': [('eum', False)],
          'ei-': [('eum', False)],
          'eiden': [('eid', False)],
          'eidens': [('eid', False)],
          'eids': [('eid', False)],
          'eids-': [('eid', False)],
          'eier': [('eier', False)],
          'eierna': [('eier', False)],
          'eige': [('eige', False)],
          'eige-': [('eige', False)],
          'eiges': [('eige', False)],
          'eiler': [('eiler', False)],
          'eilerna': [('eiler', False)],
          'eilernas': [('eiler', False)],
          'eilers': [('eiler', False)],
          'eillens': [('eille', False)],
          'eimer': [('eimer', False)],
          'ein': [('ein', False)],
          'einar-': [('einare', False)],
          'einarens': [('einare', False)],
          'einets': [('ein', False)],
          'eing': [('eing', False)],
          'eingar': [('eing', False)],
          'eingarna': [('eing', False)],
          'eingarnas': [('eing', False)],
          'eingars': [('eing', False)],
          'eingen': [('eing', False)],
          'eingens': [('eing', False)],
          'eings': [('eing', False)],
          'eings-': [('eing', False)],
          'einkomst-': [('einkomst', False)],
          'einkomster': [('einkomst', False)],
          'einkomsternas': [('einkomst', False)],
          'einkomsters': [('einkomst', False)],
          'eins': [('ein', False)],
          'eint': [('eint', False)],
          'eios': [('eios', False)],
          'eios-': [('eios', False)],
          'eiosen': [('eios', False)],
          'eiosens': [('eios', False)],
          'eiskan': [('eiska', False)],
          'eiskans': [('eiska', False)],
          'eiske': [('eiska', False)],
          'eiske-': [('eiska', False)],
          'eismer': [('eism', False)],
          'eismernas': [('eism', False)],
          'eiss': [('eiss', False)],
          'eissen': [('eiss', False)],
          'eissens': [('eiss', False)],
          'eist-': [('eist', False)],
          'eisten': [('eist', False)],
          'eistens': [('eist', False)],
          'eister': [('eist', False)],
          'eisterna': [('eist', False)],
          'eisternas': [('eist', False)],
          'eisters': [('eist', False)],
          'eit': [('eit', False)],
          'eiti': [('eiti', False)],
          'eitis': [('eiti', False)],
          'eitis-': [('eiti', False)],
          'eits': [('eit', False)],
          'eiver': [('eiver', False)],
          'eivers': [('eiver', False)],
          'eivrar': [('eivrare', False)],
          'eivrarna': [('eivrare', False)],
          'eivrarnas': [('eiver', False)],
          'eizar': [('eizare', False)],
          'eizarna': [('eizare', False)],
          'eizarnas': [('eizare', False)],
          'ej': [('ej', False)],
          'ej-': [('ej', False)],
          'ejaden': [('ejad', False)],
          'ejadens': [('ejad', False)],
          'ejakar': [('ejakare', False)],
          'ejakarna': [('ejakare', False)],
          'ejakarnas': [('ejakare', False)],
          'ejan': [('eja', False)],
          'ejans': [('eja', False)],
          'ejar': [('ej', False)],
          'ejaren': [('ejare', False)],
          'ejarna': [('ej', False)],
          'ejarnas': [('ej', False)],
          'ejars': [('ej', False)],
          'ejdar': [('ejdare', False)],
          'ejde': [('ejde', False)],
          'ejde-': [('ejde', False)],
          'ejden': [('ejde', False)],
          'ejdens': [('ejde', False)],
          'ejder': [('ejder', True)],
          'ejders': [('ejder', True)],
          'eje': [('eja', False)],
          'eje-': [('eja', False)],
          'ejen': [('ej', False)],
          'ejens': [('ej', False)],
          'ejer': [('ej', False)],
          'ejerna': [('ej', False)],
          'ejernas': [('ej', False)],
          'ejers': [('ej', False)],
          'ejet': [('ej', False)],
          'ejets': [('ej', False)],
          'ejfen': [('ejf', False)],
          'ejkar': [('ejk', False)],
          'ejkarna': [('ejkare', False)],
          'ejkarnas': [('ejk', False)],
          'ejkars': [('ejk', False)],
          'ejks-': [('ejk', False)],
          'ejon': [('ejon', False)],
          'ejoner': [('ejon', False)],
          'ejonerna': [('ejon', False)],
          'ejonernas': [('ejon', False)],
          'ejoners': [('ejon', False)],
          'ejons': [('ejon', False)],
          'ejor': [('eja', False)],
          'ejorna': [('eja', False)],
          'ejornas': [('eja', False)],
          'ejors': [('eja', False)],
          'ejs': [('ej', False)],
          'ejs-': [('ej', False)],
          'ejsarna': [('ejsare', False)],
          'ejsarnas': [('ejs', False)],
          'ejsars': [('ejsar', False)],
          'ejser': [('ejs', False)],
          'ejsers': [('ejser', False)],
          'ejsten': [('ejst', False)],
          'ejt': [('ejte', False)],
          'ejt-': [('ejte', False)],
          'ejtar': [('ejtare', False)],
          'ejtarna': [('ejtare', False)],
          'ejtarnas': [('ejt', False)],
          'ejtars': [('ejte', False)],
          'ejten': [('ejte', False)],
          'ejtens': [('ejte', False)],
          'ejts': [('ejte', False)],
          'ejts-': [('ejte', False)],
          'ek': [('eka', True), ('ek', True)],
          'ek-': [('eka', True), ('ek', True)],
          'ekad': [('ekad', False)],
          'ekad-': [('ekad', False)],
          'ekader': [('ekad', False)],
          'ekaders': [('ekad', False)],
          'ekads': [('ekad', False)],
          'ekads-': [('ekad', False)],
          'ekal': [('ekal', False)],
          'ekal-': [('ekal', False)],
          'ekalas': [('ekalas', False)],
          'ekalie': [('ekalier', False)],
          'ekalier': [('ekalier', False)],
          'ekalierna': [('ekalier', False)],
          'ekaliernas': [('ekalier', False)],
          'ekaliers': [('ekalier', False)],
          'ekals': [('ekal', False)],
          'ekals-': [('ekal', False)],
          'ekan': [('eka', False)],
          'ekan-': [('ekan', False)],
          'ekanden': [('ekande', False)],
          'ekaniker': [('ekaniker', False)],
          'ekanikerna': [('ekaniker', False)],
          'ekanikernas': [('ekaniker', False)],
          'ekanikers': [('ekaniker', False)],
          'ekans': [('eka', True)],
          'ekans-': [('ekan', False)],
          'ekar': [('ek', False)],
          'ekar-': [('ekare', False)],
          'ekare': [('ekare', False)],
          'ekaren': [('ekare', False)],
          'ekarens': [('ekar', False)],
          'ekaret': [('ekar', False)],
          'ekarets': [('ekar', False)],
          'ekaries': [('ekarie', False)],
          'ekaries-': [('ekarie', False)],
          'ekarna': [('ek', True)],
          'ekarnas': [('ek', True)],
          'ekars': [('ek', False)],
          'ekars-': [('ekar', False)],
          'ekart': [('ekart', False)],
          'ekart-': [('ekart', False)],
          'ekarts': [('ekart', False)],
          'ekarts-': [('ekart', False)],
          'ekas': [('eka', False)],
          'ekatt': [('ekatt', False)],
          'ekatt-': [('ekatt', False)],
          'ekatten': [('ekatt', False)],
          'ekattens': [('ekatt', False)],
          'ekatts': [('ekatt', False)],
          'ekatts-': [('ekatt', False)],
          'eke': [('eke', True), ('eka', True)],
          'eke-': [('eka', True), ('eke', True)],
          'ekel': [('ekel', False)],
          'ekel-': [('ekel', False)],
          'ekels-': [('ekel', False)],
          'ekelsen': [('ekelse', False)],
          'ekelsens': [('ekelse', False)],
          'eken': [('ek', False)],
          'ekens': [('ek', False)],
          'eker': [('eker', True)],
          'ekerits': [('ekeri', False)],
          'ekerna': [('ek', False)],
          'ekernas': [('ek', False)],
          'ekers': [('eker', True)],
          'ekes': [('eke', True)],
          'ekes-': [('eke', True)],
          'ekesen': [('ekes', False)],
          'ekesens': [('ekes', False)],
          'eket': [('eke', True)],
          'ekets': [('eke', False)],
          'ekfiskarna': [('ekfisk', False)],
          'ekins': [('ekin', False)],
          'ekist-': [('ekista', False)],
          'ekistan': [('ekista', False)],
          'ekistans': [('ekista', False)],
          'ekittlar': [('ekittel', False)],
          'ekittlarna': [('ekittel', False)],
          'ekittlarnas': [('ekittel', False)],
          'ekkrans-': [('ekkrans', False)],
          'eklar': [('ekel', False)],
          'eklarna': [('ekel', False)],
          'eklarnas': [('ekel', False)],
          'eklars': [('ekel', False)],
          'eklen': [('ekel', False)],
          'eklens': [('ekel', False)],
          'eklernas': [('ekel', False)],
          'eklet': [('ekel', False)],
          'eklets': [('ekel', False)],
          'ekling': [('ekling', False)],
          'ekling-': [('ekling', False)],
          'eklings': [('ekling', False)],
          'eklings-': [('ekling', False)],
          'eklipp': [('eklipp', False)],
          'eklipp-': [('eklippa', False)],
          'eklipps': [('eklipp', False)],
          'eklipps-': [('eklipp', False)],
          'eklon': [('eklo', False)],
          'eklons': [('eklo', False)],
          'eklor': [('eklo', False)],
          'eklors': [('eklo', False)],
          'eklot': [('eklot', False)],
          'eklots': [('eklot', False)],
          'eklots-': [('eklot', False)],
          'eklubb': [('eklubba', False)],
          'eklubb-': [('eklubba', False)],
          'eklubbs': [('eklubba', False)],
          'eklubbs-': [('eklubba', False)],
          'eklyft': [('eklyfta', False)],
          'eklyft-': [('eklyfta', False)],
          'eklyfts': [('eklyfta', False)],
          'eklyfts-': [('eklyfta', False)],
          'eklädes': [('ekläder', False)],
          'eklädes-': [('ekläder', False)],
          'eknagg': [('eknagg', False)],
          'eknagg-': [('eknagg', False)],
          'eknaggar': [('eknagg', False)],
          'eknaggarna': [('eknagg', False)],
          'eknaggarnas': [('eknagg', False)],
          'eknaggars': [('eknagg', False)],
          'eknaggen': [('eknagg', False)],
          'eknaggens': [('eknagg', False)],
          'eknaggs': [('eknagg', False)],
          'eknaggs-': [('eknagg', False)],
          'ekningar': [('ekning', False)],
          'ekningarna': [('ekning', False)],
          'ekningarnas': [('ekning', False)],
          'ekningars': [('ekning', False)],
          'eknings': [('ekning', False)],
          'eknings-': [('ekning', False)],
          'eknip': [('eknip', False)],
          'eknip-': [('eknip', False)],
          'eknips': [('eknip', False)],
          'eknips-': [('eknip', False)],
          'ekollon': [('ekollon', True)],
          'ekollons': [('ekollon', True)],
          'ekoman': [('ekoman', False)],
          'ekomans': [('ekoman', False)],
          'ekomst-': [('ekomst', False)],
          'ekomster': [('ekomst', False)],
          'ekomsterna': [('ekomst', False)],
          'ekomsternas': [('ekomst', False)],
          'ekomsters': [('ekomst', False)],
          'ekon': [('eko', True)],
          'ekona': [('eko', True)],
          'ekonas': [('eko', True)],
          'ekondens': [('ekond', False)],
          'ekons': [('eko', True)],
          'ekonst-': [('ekonst', False)],
          'ekonster': [('ekonst', False)],
          'ekonsterna': [('ekonst', False)],
          'ekonsternas': [('ekonst', False)],
          'ekonsters': [('ekonst', False)],
          'ekopp': [('ekopp', False)],
          'ekopp-': [('ekopp', False)],
          'ekoppar': [('ekopp', False)],
          'ekoppars': [('ekopp', False)],
          'ekopps': [('ekopp', False)],
          'ekopps-': [('ekopp', False)],
          'ekor': [('eka', False)],
          'ekord': [('ekord', False)],
          'ekord-': [('ekord', False)],
          'ekords': [('ekord', False)],
          'ekords-': [('ekord', False)],
          'ekorna': [('eka', False)],
          'ekornas': [('eka', False)],
          'ekorr': [('ekorre', True)],
          'ekorr-': [('ekorre', False)],
          'ekorren': [('ekorre', True)],
          'ekorrens': [('ekorre', False)],
          'ekorrs': [('ekorre', False)],
          'ekorrs-': [('ekorre', False)],
          'ekors': [('eka', False)],
          'ekors-': [('ekor', False)],
          'ekos': [('eko', True)],
          'ekostnader': [('ekostnad', False)],
          'ekostnaderna': [('ekostnad', False)],
          'ekostnadernas': [('ekostnad', False)],
          'ekostnads': [('ekostnad', False)],
          'ekostnads-': [('ekostnad', False)],
          'ekot': [('eko', True)],
          'ekots': [('eko', True)],
          'ekox': [('ekoxe', True)],
          'ekox-': [('ekoxe', True)],
          'ekoxen': [('ekoxe', True)],
          'ekoxens': [('ekoxe', True)],
          'ekrafter': [('ekraft', False)],
          'ekrafterna': [('ekraft', False)],
          'ekrafternas': [('ekraft', False)],
          'ekrafters': [('ekraft', False)],
          'ekrafts': [('ekraft', False)],
          'ekrafts-': [('ekraft', False)],
          'ekrans': [('ekrans', False)],
          'ekrans-': [('ekrans', False)],
          'ekrar': [('eker', True)],
          'ekrarna': [('eker', True)],
          'ekret': [('ekret', False)],
          'ekrets': [('ekret', False)],
          'ekrets-': [('ekrets', False)],
          'ekris': [('ekris', False)],
          'ekris-': [('ekris', False)],
          'ekrokarnas': [('ekrok', False)],
          'ekronan': [('ekrona', False)],
          'ekronans': [('ekrona', False)],
          'ekrons-': [('ekrona', False)],
          'ekrossar': [('ekrossare', False)],
          'ekrossarna': [('ekrossare', False)],
          'ekrossarnas': [('ekrossare', False)],
          'eks': [('eka', True), ('ek', True)],
          'eks-': [('eka', True), ('ek', True)],
          'eksaks': [('eksak', False)],
          'eksaks-': [('eksak', False)],
          'ekshögskolan': [('ekshögskola', False)],
          'ekshögskolans': [('ekshögskola', False)],
          'ekta': [('ekta', False)],
          'ektan': [('ekta', False)],
          'ektans': [('ektans', False)],
          'ektans-': [('ektans', False)],
          'ektar': [('ektar', False)],
          'ektaren': [('ektar', False)],
          'ektarnas': [('ekt', False)],
          'ektars': [('ektar', False)],
          'ektet': [('ektum', False)],
          'ektets': [('ektum', False)],
          'ektiker': [('ektiker', False)],
          'ektikerna': [('ektiker', False)],
          'ektikernas': [('ektiker', False)],
          'ektikers': [('ektiker', False)],
          'ektin': [('ektin', False)],
          'ektioner': [('ektion', False)],
          'ektionerna': [('ektion', False)],
          'ektionernas': [('ektion', False)],
          'ektioners': [('ektion', False)],
          'ektions': [('ektion', False)],
          'ektivets': [('ektiv', False)],
          'ekton': [('ekto', False)],
          'ektor': [('ektor', False)],
          'ektorie': [('ektorium', False)],
          'ektorie-': [('ektorium', False)],
          'ektorierna': [('ektorium', False)],
          'ektoriernas': [('ektorium', False)],
          'ektoriers': [('ektorium', False)],
          'ektoriet': [('ektorium', False)],
          'ektoriets': [('ektorium', False)],
          'ektors': [('ektor', False)],
          'ektos': [('ekto', False)],
          'ektos-': [('ekto', False)],
          'ektrets': [('ektrum', False)],
          'ektron': [('ektron', False)],
          'ekturs-': [('ektur', False)],
          'ektyr': [('ektyrer', False)],
          'ektyr-': [('ektyrer', False)],
          'ektyrs': [('ektyrer', False)],
          'ekull': [('ekulle', False)],
          'ekull-': [('ekulle', False)],
          'ekullar': [('ekulle', False)],
          'ekullarna': [('ekulle', False)],
          'ekullarnas': [('ekulle', False)],
          'ekullars': [('ekulle', False)],
          'ekulle': [('ekulle', False)],
          'ekulle-': [('ekulle', False)],
          'ekullen': [('ekulle', False)],
          'ekullens': [('ekulle', False)],
          'ekulls': [('ekulle', False)],
          'ekulls-': [('ekulle', False)],
          'ekuriosa': [('ekuriosa', False)],
          'ekuriosas': [('ekuriosa', False)],
          'ekurrens': [('ekurrens', False)],
          'ekurs': [('ekurs', False)],
          'ekurs-': [('ekur', False)],
          'ekurvor': [('ekurva', False)],
          'ekurvorna': [('ekurva', False)],
          'ekurvornas': [('ekurva', False)],
          'ekurvors': [('ekurva', False)],
          'ekvarter': [('ekvarter', False)],
          'ekvarters': [('ekvarter', False)],
          'ekvarts': [('ekvart', False)],
          'ekvarts-': [('ekvart', False)],
          'ekvierna': [('ekviem', False)],
          'ekyl': [('ekyl', False)],
          'ekyl-': [('ekyl', False)],
          'ekyls': [('ekyl', False)],
          'ekäll': [('ekälla', False)],
          'ekäll-': [('ekälla', False)],
          'ekämpar': [('ekämpare', False)],
          'ekämparna': [('ekämpare', False)],
          'ekämparnas': [('ekämpare', False)],
          'ekäng': [('ekäng', False)],
          'ekäng-': [('ekäng', False)],
          'ekänger': [('ekäng', False)],
          'ekängs': [('ekäng', False)],
          'ekängs-': [('ekäng', False)],
          'ekärr': [('ekärra', False)],
          'ekärr-': [('ekärra', False)],
          'ekärrs': [('ekärra', False)],
          'ekärrs-': [('ekärra', False)],
          'ekön': [('ekö', False)],
          'eköns': [('ekö', False)],
          'el': [('el', False)],
          'el-': [('el', False)],
          'elackar': [('elackare', False)],
          'elackarna': [('elackare', False)],
          'elad': [('elad', False)],
          'elad-': [('elad', False)],
          'elads': [('elad', False)],
          'elag': [('elag', False)],
          'elag-': [('elag', False)],
          'elagarna': [('elag', False)],
          'elagarnas': [('elag', False)],
          'elagen': [('elag', False)],
          'elagens': [('elag', False)],
          'elager': [('elag', False)],
          'elagerna': [('elag', False)],
          'elagernas': [('elag', False)],
          'elagers': [('elag', False)],
          'elaget': [('elag', False)],
          'elags': [('elag', False)],
          'elags-': [('elag', False)],
          'elamp-': [('elampa', False)],
          'elamps': [('elampa', False)],
          'elamps-': [('elampa', False)],
          'elan': [('ela', False)],
          'elan-': [('elan', False)],
          'elana': [('ela', False)],
          'elanas': [('ela', False)],
          'elanden': [('eland', True)],
          'elandena': [('elande', False)],
          'elandenas': [('elande', False)],
          'elandens': [('eland', True)],
          'elandet': [('elande', False)],
          'elandets': [('eland', False)],
          'elaner': [('elan', False)],
          'elanerna': [('elan', False)],
          'elanernas': [('elan', False)],
          'elaners': [('elan', False)],
          'elans': [('ela', False)],
          'elaps': [('elapa', False)],
          'elaps-': [('elapa', False)],
          'elar': [('elare', False)],
          'elare': [('elarea', False)],
          'elaren': [('elare', False)],
          'elarens': [('elar', False)],
          'elarer': [('elar', False)],
          'elarerna': [('elar', False)],
          'elarernas': [('elar', False)],
          'elarers': [('elar', False)],
          'elares': [('elarea', False)],
          'elargon': [('elargon', False)],
          'elargons': [('elargon', False)],
          'elarna': [('elare', False)],
          'elarnas': [('elare', False)],
          'elars': [('el', False)],
          'elas-': [('ela', False)],
          'elat': [('elat', False)],
          'elat-': [('elat', False)],
          'elaten': [('elat', False)],
          'elatens': [('elat', False)],
          'elater': [('elat', False)],
          'elaterna': [('elat', False)],
          'elaternas': [('elat', False)],
          'elaters': [('elat', False)],
          'elats': [('elat', False)],
          'elats-': [('elat', False)],
          'elben': [('elben', False)],
          'elblom': [('elblom', False)],
          'elblom-': [('elblom', False)],
          'elbloms': [('elblom', False)],
          'elbloms-': [('elblom', False)],
          'elborr': [('elborr', False)],
          'elborr-': [('elborr', False)],
          'elborrar': [('elborr', False)],
          'elborrarna': [('elborr', False)],
          'elborrarnas': [('elborr', False)],
          'elborrars': [('elborr', False)],
          'elborren': [('elborr', False)],
          'elborrens': [('elborr', False)],
          'elborrs': [('elborr', False)],
          'elborrs-': [('elborr', False)],
          'elbroder': [('elbror', False)],
          'elbroderns': [('elbror', False)],
          'elbrors': [('elbror', False)],
          'elbrors-': [('elbror', False)],
          'elbröderna': [('elbror', False)],
          'elbröders': [('elbror', False)],
          'elbull-': [('elbulle', False)],
          'eldans': [('eldans', False)],
          'eldans-': [('eldans', False)],
          'eldar': [('eldare', True), ('eld', True)],
          'eldarna': [('eldare', True), ('eld', True)],
          'eldarnas': [('eldare', True), ('eld', True)],
          'eldons': [('eldon', False)],
          'eldos-': [('eldosa', False)],
          'eldstormarna': [('eldstorm', True)],
          'eldstormarnas': [('eldstorm', True)],
          'ele': [('ela', False)],
          'ele-': [('ela', False)],
          'eleasen': [('elease', False)],
          'eleasens': [('elease', False)],
          'eleaser': [('elease', False)],
          'eleaserna': [('elease', False)],
          'eleasernas': [('elease', False)],
          'eleasers': [('elease', False)],
          'elegans': [('elegans', False)],
          'elegier': [('elegi', True)],
          'elegierna': [('elegi', True)],
          'elegiernas': [('elegi', True)],
          'elegiers': [('elegi', True)],
          'elek': [('elek', False)],
          'elekar': [('elek', False)],
          'elekarna': [('elek', False)],
          'elekarnas': [('elek', False)],
          'eleke-': [('eleka', False)],
          'eleken': [('elek', False)],
          'elekens': [('elek', False)],
          'eleks-': [('elek', False)],
          'elemannen': [('eleman', False)],
          'elemannens': [('eleman', False)],
          'elementets': [('element', False)],
          'elements': [('element', True)],
          'elen': [('el', False)],
          'elen-': [('elen', False)],
          'elens': [('el', False)],
          'eler': [('el', False)],
          'eler-': [('eler', False)],
          'elerins': [('elerin', False)],
          'elerna': [('el', False)],
          'elernas': [('el', False)],
          'elet': [('el', False)],
          'elets': [('el', False)],
          'elettens': [('elett', False)],
          'elevans': [('elevans', False)],
          'eleven': [('elev', False)],
          'elevens': [('elev', False)],
          'elever': [('elev', False)],
          'elevers': [('elev', True)],
          'elevs': [('elev', False)],
          'elfer': [('elfer', False)],
          'elfers': [('elfer', False)],
          'elgar': [('elgare', False)],
          'elgar-': [('elgare', False)],
          'elgarens': [('elgare', False)],
          'elgarna': [('elgare', False)],
          'elgarnas': [('elgare', False)],
          'elgiernas': [('elgier', False)],
          'elgångar': [('elgång', False)],
          'elgångarna': [('elgång', False)],
          'elgångarnas': [('elgångare', False)],
          'elgångars': [('elgång', False)],
          'elgångs': [('elgång', False)],
          'elgångs-': [('elgång', False)],
          'elhake': [('elhake', False)],
          'elhake-': [('elhaka', False)],
          'elharmonier': [('elharmonium', False)],
          'eli': [('elia', False)],
          'eli-': [('elia', False)],
          'elian': [('elia', False)],
          'elians': [('elia', False)],
          'elias': [('elia', False)],
          'elie': [('elia', False)],
          'elie-': [('elium', False)],
          'elien': [('eli', False)],
          'eliens': [('eli', False)],
          'elier': [('elium', False)],
          'elierna': [('elium', False)],
          'eliernas': [('elium', False)],
          'eliers': [('elium', False)],
          'eliet': [('elium', False)],
          'elighets': [('elighet', False)],
          'elik': [('elik', False)],
          'elik-': [('elik', False)],
          'elikan': [('elikan', False)],
          'elikans': [('elikan', False)],
          'elikar': [('elike', False)],
          'elikarna': [('elike', False)],
          'elikarnas': [('elike', False)],
          'eliken': [('elik', False)],
          'elikens': [('elike', False)],
          'eliker': [('elik', False)],
          'elikerna': [('elik', False)],
          'elikernas': [('elik', False)],
          'elikers': [('elik', False)],
          'eliks': [('elik', False)],
          'elimen': [('elim', False)],
          'elimens': [('elim', False)],
          'elimer': [('elim', False)],
          'elimerna': [('elim', False)],
          'elimernas': [('elim', False)],
          'elimers': [('elim', False)],
          'elin': [('eli', False)],
          'elin-': [('elin', False)],
          'elina': [('elina', False)],
          'elinas': [('elina', False)],
          'eline': [('eline', False)],
          'eline-': [('eline', False)],
          'elinen': [('elin', False)],
          'elinens': [('elin', False)],
          'eliner': [('elin', False)],
          'elinerna': [('elin', False)],
          'elinernas': [('elin', False)],
          'eliners': [('elin', False)],
          'elinet': [('elin', False)],
          'elins': [('elin', False)],
          'elis': [('elia', False)],
          'elis-': [('elis', False)],
          'elisen': [('elis', False)],
          'elisens': [('elis', False)],
          'elisk': [('eliska', False)],
          'elisk-': [('eliska', False)],
          'eliss-': [('eliss', False)],
          'elist': [('elist', False)],
          'elist-': [('elist', False)],
          'elit': [('elit', False)],
          'elit-': [('elit', False)],
          'eliten': [('elit', False)],
          'elitens': [('elit', False)],
          'eliter': [('elit', False)],
          'eliterna': [('elit', True)],
          'eliternas': [('elit', False)],
          'eliters': [('elit', False)],
          'elits': [('elit', False)],
          'elivs': [('eliv', False)],
          'elivs-': [('eliv', False)],
          'eljon': [('eljo', False)],
          'eljons': [('eljo', False)],
          'elkammar': [('elkam', False)],
          'elkart': [('elkart', False)],
          'elkart-': [('elkart', False)],
          'elkarts': [('elkart', False)],
          'elkarts-': [('elkart', False)],
          'elkasse-': [('elkassa', False)],
          'elkott': [('elkott', False)],
          'elkotten': [('elkott', False)],
          'elkotts-': [('elkott', False)],
          'elkrokar': [('elkrok', False)],
          'elkrokarna': [('elkrok', False)],
          'elkrokarnas': [('elkrokar', False)],
          'elkrokars': [('elkrok', False)],
          'elkroks': [('elkrok', False)],
          'elkroks-': [('elkrok', False)],
          'elkurs': [('elkur', False)],
          'elkurs-': [('elkurs', False)],
          'ell': [('ella', False)],
          'ell-': [('ella', False)],
          'ellandet': [('elland', False)],
          'ellans': [('ella', False)],
          'elle': [('elle', False)],
          'elle-': [('elle', False)],
          'ellen': [('ellen', False)],
          'ellens': [('ell', False)],
          'ellens-': [('ellens', False)],
          'elletarnas': [('ellet', False)],
          'elletten': [('ellett', False)],
          'elletter': [('ellett', False)],
          'elletterna': [('ellett', False)],
          'elletternas': [('ellett', False)],
          'elletters': [('ellett', False)],
          'ellierna': [('ellier', False)],
          'elliernas': [('ellier', False)],
          'ellis': [('ello', False)],
          'ellon': [('ello', False)],
          'ellons': [('ello', False)],
          'ellos': [('ello', False)],
          'ellos-': [('ello', False)],
          'ellrarna': [('eller', False)],
          'ellrarnas': [('eller', False)],
          'ells': [('ella', False)],
          'ellstudie': [('ellstudie', False)],
          'ellstudier': [('ellstudie', False)],
          'ellås': [('ellås', False)],
          'ellås-': [('ellås', False)],
          'elmöss': [('elmus', False)],
          'eln': [('el', False)],
          'elna': [('el', False)],
          'elnar': [('eln', False)],
          'elnarnas': [('eln', False)],
          'elnas': [('el', False)],
          'elningar': [('elning', False)],
          'elningarna': [('elning', False)],
          'elningarnas': [('elning', False)],
          'elningars': [('elning', False)],
          'elnings': [('elning', False)],
          'elnings-': [('elning', False)],
          'elns': [('el', False)],
          'elodier': [('elodi', False)],
          'elodierna': [('elodi', False)],
          'elodiernas': [('elodi', False)],
          'elodis': [('elodi', False)],
          'elonen': [('elon', False)],
          'elonens': [('elon', False)],
          'elons-': [('eloner', False)],
          'elopp': [('elopp', False)],
          'elopps': [('elopp', False)],
          'elopps-': [('elopp', False)],
          'elor': [('ela', False)],
          'elorna': [('ela', False)],
          'elornas': [('ela', False)],
          'elors': [('ela', False)],
          'elost': [('elost', False)],
          'elost-': [('elost', False)],
          'elots': [('elot', False)],
          'elots-': [('elot', False)],
          'elott': [('elott', False)],
          'elott-': [('elott', False)],
          'elottens': [('elott', False)],
          'elotts': [('elott', False)],
          'elox-': [('eloxe', False)],
          'eloxarna': [('eloxe', False)],
          'elp': [('elp', False)],
          'elpar': [('elpar', False)],
          'elparen': [('elpar', False)],
          'elparens': [('elpar', False)],
          'elpars': [('elpar', False)],
          'elpellen': [('elpelle', False)],
          'elpellens': [('elpelle', False)],
          'elpengar': [('elpengar', False)],
          'elpengarnas': [('elpengar', False)],
          'elpengars': [('elpengar', False)],
          'elps': [('elp', False)],
          'elrems': [('elrem', False)],
          'elrems-': [('elrem', False)],
          'elriggar': [('elrigg', False)],
          'elriggarna': [('elrigg', False)],
          'elriggarnas': [('elrigg', False)],
          'elroller': [('elroll', False)],
          'elrollers': [('elroll', False)],
          'els': [('el', False)],
          'els-': [('el', False)],
          'elsarna': [('el', False)],
          'else': [('else', False)],
          'else-': [('else', False)],
          'elsen': [('else', False)],
          'elsens': [('else', False)],
          'elser': [('else', False)],
          'elserna': [('else', False)],
          'elsernas': [('else', False)],
          'elsers': [('else', False)],
          'elset': [('elset', False)],
          'elsets': [('elset', False)],
          'elsken': [('elsken', False)],
          'elskens-': [('elsken', False)],
          'elskor': [('elska', False)],
          'elskorna': [('elska', False)],
          'elskornas': [('elska', False)],
          'elskors': [('elska', False)],
          'elskur': [('elskur', False)],
          'elskurs': [('elskura', False)],
          'elskurs-': [('elskura', False)],
          'elslagar': [('elslag', False)],
          'elslagarna': [('elslag', False)],
          'elslagarnas': [('elslag', False)],
          'elsnickar': [('elsnickare', False)],
          'elsnickarna': [('elsnickare', False)],
          'elsnickarnas': [('elsnickare', False)],
          'elspol': [('elspole', False)],
          'elspol-': [('elspol', False)],
          'elspolen': [('elspole', False)],
          'elspolens': [('elspol', False)],
          'elspols': [('elspole', False)],
          'elspols-': [('elspole', False)],
          'elsticks': [('elsticka', False)],
          'elsträck': [('elsträck', False)],
          'elsträck-': [('elsträck', False)],
          'elsträcks': [('elsträcka', False)],
          'elsträcks-': [('elsträck', False)],
          'elstyrkans': [('elstyrka', False)],
          'elställen': [('elställe', False)],
          'elställens': [('elställe', False)],
          'elstället': [('elställe', False)],
          'elställets': [('elställe', False)],
          'elstötar': [('elstöt', False)],
          'elstötarna': [('elstöt', False)],
          'elsvar': [('elsvar', False)],
          'elt': [('elt', False)],
          'eltan': [('elta', False)],
          'eltanden': [('eltand', False)],
          'eltandens': [('eltand', False)],
          'eltans': [('elta', False)],
          'eltat': [('elta', False)],
          'eltats': [('elta', False)],
          'elträden': [('elträd', False)],
          'elträdens': [('elträd', False)],
          'elträdet': [('elträd', False)],
          'eltränas': [('elträd', False)],
          'eltårs': [('eltå', False)],
          'eluck': [('elucka', False)],
          'eluck-': [('elucker', False)],
          'elucks': [('elucker', False)],
          'elucks-': [('elucker', False)],
          'elums': [('elum', False)],
          'elunge': [('elunge', False)],
          'elunge-': [('elunge', False)],
          'elust': [('elust', False)],
          'elvals': [('elvals', False)],
          'elvals-': [('elvals', False)],
          'elvan': [('elva', False)],
          'elvans': [('elva', True)],
          'elvar': [('elvara', False)],
          'elvers': [('elvers', False)],
          'elvers-': [('elvers', False)],
          'elvill': [('elvilla', False)],
          'elvill-': [('elvilla', False)],
          'elvills-': [('elvilla', False)],
          'elvind': [('elvind', False)],
          'elvinds': [('elvinda', False)],
          'elvinds-': [('elvinda', False)],
          'elvägen': [('elväg', False)],
          'elvägens': [('elväg', False)],
          'elyfts': [('elyft', False)],
          'elykt': [('elykta', False)],
          'elykt-': [('elykta', False)],
          'elykts': [('elykta', False)],
          'elyr': [('elyr', False)],
          'elyr-': [('elyr', False)],
          'elyrs': [('elyr', False)],
          'elyrs-': [('elyr', False)],
          'elyt': [('elyt', False)],
          'elyte': [('elyta', False)],
          'elyten': [('elyt', False)],
          'elytens': [('elyt', False)],
          'elyts': [('elyt', False)],
          'eläcks': [('eläcka', False)],
          'eläcks-': [('eläcka', False)],
          'eläggar': [('eläggare', False)],
          'eläggarna': [('eläggare', False)],
          'eläggarnas': [('eläggare', False)],
          'eländar': [('eländare', False)],
          'eländarna': [('eländare', False)],
          'elände': [('elände', False)],
          'eländen': [('elände', False)],
          'eländens': [('elände', False)],
          'eländer': [('eland', False)],
          'eländerna': [('eland', False)],
          'eländernas': [('eland', False)],
          'eländers': [('eland', False)],
          'eläng': [('eläng', False)],
          'eläng-': [('eläng', False)],
          'elängs': [('eläng', False)],
          'elängs-': [('eläng', False)],
          'elänkar': [('elänk', False)],
          'elänkarna': [('elänk', False)],
          'elänkarnas': [('elänk', False)],
          'elänkets': [('elänk', False)],
          'eläsanden': [('eläsande', False)],
          'eläsandens': [('eläsande', False)],
          'eläsarna': [('eläsare', False)],
          'eläsarnas': [('eläsare', False)],
          'elät': [('elä', False)],
          'eläts': [('elä', False)],
          'eläts-': [('eläte', False)],
          'elåns': [('elån', False)],
          'elåns-': [('elån', False)],
          'elåts': [('elåt', False)],
          'elön': [('elö', False)],
          'elöns': [('elö', False)],
          'elörn': [('elörn', False)],
          'elörns': [('elörn', False)],
          'elös': [('elö', False)],
          'elös-': [('elö', False)],
          'em': [('emma', True)],
          'em-': [('emma', True)],
          'emak': [('emak', False)],
          'emak-': [('emak', False)],
          'emaken': [('emak', False)],
          'emakens': [('emak', False)],
          'emaks': [('emak', False)],
          'emaks-': [('emak', False)],
          'emalj': [('emalj', True)],
          'emalj-': [('emalj', False)],
          'emaljs': [('emalj', True)],
          'emaljs-': [('emalj', True)],
          'eman': [('eman', False)],
          'eman-': [('eman', False)],
          'emana': [('ema', False)],
          'emanas': [('ema', False)],
          'emanden': [('emande', False)],
          'emanens': [('emanens', False)],
          'emanger': [('emanger', False)],
          'emangerna': [('emanger', False)],
          'emangernas': [('emanger', False)],
          'emangers': [('emanger', False)],
          'emaniernas': [('emani', False)],
          'emannen': [('eman', False)],
          'emannens': [('eman', False)],
          'emans': [('eman', False)],
          'emar': [('em', False)],
          'emarginaler': [('emarginal', False)],
          'emarginalerna': [('emarginal', False)],
          'emarginalernas': [('emarginal', False)],
          'emarginalers': [('emarginal', False)],
          'emarna': [('em', False)],
          'emarnas': [('em', False)],
          'emars': [('em', False)],
          'emas': [('ema', False)],
          'emas-': [('ema', False)],
          'emask': [('emask', False)],
          'emask-': [('emask', False)],
          'emaster': [('emast', False)],
          'emasters': [('emast', False)],
          'emat': [('ema', False)],
          'emata': [('ema', False)],
          'ematana': [('ema', False)],
          'ematas': [('ema', False)],
          'ematik': [('ematik', False)],
          'ematik-': [('ematik', False)],
          'ematiker': [('ematik', False)],
          'ematikerna': [('ematik', False)],
          'ematikernas': [('ematik', False)],
          'ematikers': [('ematik', False)],
          'ematiks': [('ematik', False)],
          'ematiks-': [('ematik', False)],
          'ematis': [('emati', False)],
          'ematris': [('ematri', False)],
          'emats': [('ema', False)],
          'ematt': [('ematta', False)],
          'ematt-': [('ematta', False)],
          'ematte': [('ematta', False)],
          'ematte-': [('ematta', False)],
          'ematten': [('ematt', False)],
          'emattens': [('ematt', False)],
          'ematts': [('ematt', False)],
          'ematts-': [('ematta', False)],
          'ember': [('ember', False)],
          'embers': [('ember', False)],
          'embolagets': [('embolag', False)],
          'embra': [('embrum', False)],
          'embran': [('embran', False)],
          'embrans': [('embran', False)],
          'embras': [('embrum', False)],
          'embrer': [('embrum', False)],
          'emedier': [('emedium', False)],
          'emediers': [('emedium', False)],
          'emen': [('em', False)],
          'emens': [('em', False)],
          'emens-': [('emens', False)],
          'ementets': [('ement', False)],
          'ementin': [('ementin', False)],
          'ementins': [('ementin', False)],
          'ements': [('ement', False)],
          'emer': [('em', False)],
          'emerna': [('em', False)],
          'emernas': [('em', False)],
          'emers': [('em', False)],
          'emes': [('eme', False)],
          'emes-': [('eme', False)],
          'emet': [('em', False)],
          'emetoden': [('emetod', False)],
          'emetodens': [('emetod', False)],
          'emets': [('em', False)],
          'emfas': [('emfas', True)],
          'emies': [('emie', False)],
          'emin': [('emi', False)],
          'eminens': [('eminens', True)],
          'eminister': [('eminister', False)],
          'eministers': [('eminister', False)],
          'emins': [('emi', False)],
          'emis': [('emis', False)],
          'emis-': [('emis', False)],
          'emiss': [('emiss', False)],
          'emiss-': [('emiss', False)],
          'emissar': [('emiss', False)],
          'emissarna': [('emiss', False)],
          'emissarnas': [('emiss', False)],
          'emissars': [('emiss', False)],
          'emisse': [('emissa', False)],
          'emissen': [('emiss', False)],
          'emissens': [('emiss', False)],
          'emister': [('emist', False)],
          'emisters': [('emist', False)],
          'emit': [('emit', False)],
          'emit-': [('emit', False)],
          'emits': [('emi', False)],
          'emjölk': [('emjölk', False)],
          'emjölk-': [('emjölk', False)],
          'emjölken': [('emjölk', False)],
          'emjölkens': [('emjölk', False)],
          'emjölks': [('emjölk', False)],
          'emjölks-': [('emjölk', False)],
          'eml': [('emla', False)],
          'eml-': [('emla', False)],
          'emlandet': [('emland', False)],
          'emman': [('emma', False)],
          'emmanens': [('emman', False)],
          'emmans': [('emma', True)],
          'emmar': [('em', False)],
          'emmarens': [('emmare', False)],
          'emmarna': [('em', False)],
          'emmarnas': [('em', False)],
          'emmars': [('em', False)],
          'emmen': [('em', False)],
          'emmens': [('em', False)],
          'emmer': [('emmer', True)],
          'emmerna': [('em', False)],
          'emmers': [('emmer', True)],
          'emmet': [('em', False)],
          'emmets': [('em', False)],
          'emo': [('emo', False)],
          'emoar': [('emoar', False)],
          'emoars': [('emoar', False)],
          'emoder': [('emoder', False)],
          'emoder-': [('emoder', False)],
          'emodern': [('emoder', False)],
          'emoderns': [('emoder', False)],
          'emoders': [('emoder', False)],
          'emodet': [('emod', False)],
          'emodets': [('emod', False)],
          'emods': [('emod', False)],
          'emods-': [('emod', False)],
          'emon': [('emo', True)],
          'emoner': [('emon', False)],
          'emonerna': [('emon', False)],
          'emonernas': [('emon', False)],
          'emoners': [('emon', False)],
          'emonier': [('emoni', False)],
          'emoniernas': [('emoni', False)],
          'emoniers': [('emoni', False)],
          'emonik': [('emonik', False)],
          'emonik-': [('emonik', False)],
          'emoniks': [('emonik', False)],
          'emons': [('emo', True)],
          'emonter': [('emont', False)],
          'emonters': [('emont', False)],
          'emor': [('emo', False)],
          'emor-': [('emor', False)],
          'emorian': [('emoria', False)],
          'emorians': [('emoria', False)],
          'emors': [('emo', False)],
          'emos': [('emo', True)],
          'emos-': [('emos', False)],
          'emosar': [('emo', True)],
          'emosarnas': [('emo', False)],
          'emosars': [('emo', True)],
          'emosen': [('emo', True)],
          'emosens': [('emo', True)],
          'emot': [('emo', False)],
          'emots': [('emo', True)],
          'emparnas': [('emp', False)],
          'empiren': [('empire', True), ('empir', True)],
          'empirens': [('empir', True), ('empire', True)],
          'emplar': [('emplar', False)],
          'emplar-': [('emplar', False)],
          'emplaren': [('emplare', False)],
          'emplarens': [('emplar', False)],
          'emplarna': [('emplare', False)],
          'emplarnas': [('emplare', False)],
          'emplars': [('emplar', False)],
          'emplet': [('empel', False)],
          'ems': [('emma', True)],
          'ems-': [('emma', True)],
          'emsarnas': [('ems', False)],
          'emtiden': [('emtiden', False)],
          'emul': [('emul', False)],
          'emul-': [('emul', False)],
          'emuls': [('emul', False)],
          'emums': [('emum', False)],
          'emun': [('emu', True)],
          'emuns': [('emu', True)],
          'emurar': [('emur', False)],
          'emurarna': [('emur', False)],
          'emurarnas': [('emur', False)],
          'emus': [('emu', True)],
          'emvärden': [('emvärde', False)],
          'emvärdens': [('emvärde', False)],
          'emynt': [('emynt', False)],
          'emynt-': [('emynt', False)],
          'emynts': [('emynt', False)],
          'emynts-': [('emynt', False)],
          'emys': [('emys', False)],
          'emys-': [('emys', False)],
          'emyt': [('emyt', False)],
          'emyts': [('emyt', False)],
          'emän': [('eman', False)],
          'emäns': [('eman', False)],
          'emöss': [('emössa', False)],
          'en': [('en', True)],
          'en-': [('en', False)],
          'enader': [('enad', False)],
          'enaderna': [('enad', False)],
          'enadernas': [('enad', False)],
          'enaders': [('enad', False)],
          'enads': [('enad', False)],
          'enads-': [('enad', False)],
          'enal': [('enal', False)],
          'enal-': [('enal', False)],
          'enalen': [('enal', False)],
          'enalens': [('enal', False)],
          'enaler': [('enal', False)],
          'enalerna': [('enal', False)],
          'enalernas': [('enal', False)],
          'enalers': [('enal', False)],
          'enals-': [('enal', False)],
          'enamn': [('enamn', False)],
          'enamn-': [('enamn', False)],
          'enamnen': [('enamn', False)],
          'enamnens': [('enamn', False)],
          'enamns': [('enamn', False)],
          'enamns-': [('enamn', False)],
          'enana': [('enum', False)],
          'enanas': [('enum', False)],
          'enanden': [('enande', False)],
          'enans': [('enans', False)],
          'enans-': [('enans', False)],
          'enap': [('enapa', False)],
          'enape': [('enapa', False)],
          'enapen': [('enap', False)],
          'enapens': [('enap', False)],
          'enaps': [('enapa', False)],
          'enaps-': [('enap', False)],
          'enar': [('en', False)],
          'enar-': [('enar', False)],
          'enaren': [('enare', False)],
          'enarens': [('enar', False)],
          'enariers': [('enario', False)],
          'enarna': [('en', False)],
          'enarnas': [('en', True)],
          'enars': [('en', False)],
          'enask': [('enaska', False)],
          'enat': [('enat', False)],
          'enaten': [('enat', False)],
          'enatens': [('enat', False)],
          'enater': [('enat', False)],
          'enaterna': [('enat', False)],
          'enaternas': [('enat', False)],
          'enaters': [('enat', False)],
          'enats': [('enat', False)],
          'enats-': [('enater', False)],
          'enbens': [('enben', False)],
          'enbeten': [('enbet', True)],
          'enbetens': [('enbet', True)],
          'enbetet': [('enbet', True)],
          'enbetets': [('enbet', True)],
          'enborgar': [('enborgare', False)],
          'enborgarna': [('enborgare', False)],
          'enborgarnas': [('enborgare', False)],
          'enborrar': [('enborr', False)],
          'enbrodern': [('enbroder', False)],
          'enbroderns': [('enbroder', False)],
          'enbroders': [('enbroder', False)],
          'enbröder': [('enbroder', False)],
          'encen': [('enny', False)],
          'enchar': [('ench', False)],
          'encharna': [('ench', False)],
          'enda': [('enda', False)],
          'endana': [('endum', False)],
          'endanas': [('endum', False)],
          'endans': [('endans', False)],
          'endans-': [('endans', False)],
          'endanten': [('endant', False)],
          'endantens': [('endant', False)],
          'endar': [('endar', False)],
          'endaren': [('endar', False)],
          'endars': [('endar', False)],
          'endas': [('enda', False)],
          'ende': [('ende', False)],
          'ende-': [('ende', False)],
          'endelandet': [('endeland', False)],
          'endelar': [('endel', False)],
          'endelarna': [('endel', False)],
          'endelarnas': [('endel', False)],
          'enden': [('ende', False)],
          'endena': [('ende', False)],
          'endenas': [('ende', False)],
          'endens': [('ende', False)],
          'ender': [('ender', False)],
          'endernas': [('end', False)],
          'enders': [('ender', False)],
          'endes': [('ende', False)],
          'endes-': [('ende', False)],
          'endet': [('ende', False)],
          'endier': [('endium', False)],
          'endierna': [('endium', False)],
          'endiernas': [('endium', False)],
          'endiers': [('endium', False)],
          'endis': [('end', False)],
          'endivernas': [('endiv', True)],
          'endivers': [('endiv', True)],
          'endlandet': [('endlande', False)],
          'endlandets': [('endlande', False)],
          'endon': [('endo', False)],
          'endons': [('endo', False)],
          'endos': [('endos', False)],
          'endrarnas': [('ender', False)],
          'endrer': [('endron', False)],
          'endrerna': [('endron', False)],
          'endrernas': [('endron', False)],
          'endrers': [('endron', False)],
          'endroppar': [('endroppe', False)],
          'endropparna': [('endroppe', False)],
          'endropparnas': [('endroppe', False)],
          'endroppars': [('endroppe', False)],
          'endropps': [('endroppe', False)],
          'ene': [('ene', True)],
          'ene-': [('ene', True)],
          'enegen': [('eneg', False)],
          'enegens': [('eneg', False)],
          'eneger': [('eneg', False)],
          'enegerna': [('eneg', False)],
          'enegernas': [('eneg', False)],
          'enegers': [('eneg', False)],
          'enen': [('en', False)],
          'enens': [('en', False)],
          'ener': [('en', False)],
          'enerier': [('eneri', False)],
          'enerierna': [('eneri', False)],
          'eneriernas': [('eneri', False)],
          'eneriers': [('eneri', False)],
          'enerna': [('en', False)],
          'enernas': [('en', False)],
          'eners': [('en', False)],
          'enes': [('ene', True)],
          'enes-': [('ene', True)],
          'enesen': [('enes', False)],
          'enesens': [('enes', False)],
          'enet': [('ene', True)],
          'enetiker': [('enetiker', False)],
          'enetikerna': [('enetiker', False)],
          'enets': [('ene', True)],
          'enfot': [('enfot', False)],
          'enfällen': [('enfäll', False)],
          'enfällens': [('enfäll', False)],
          'engarn': [('engarn', False)],
          'engarns': [('engarn', False)],
          'enget': [('enget', False)],
          'engets': [('enget', False)],
          'engetterna': [('enget', False)],
          'engetternas': [('enget', False)],
          'engetters': [('enget', False)],
          'englans': [('englans', False)],
          'englas': [('englas', False)],
          'engångarnas': [('engångare', False)],
          'enheter': [('enhet', True)],
          'enheterna': [('enhet', True)],
          'enheternas': [('enhet', True)],
          'enheters': [('enhet', True)],
          'enhets': [('enhet', True)],
          'enhets-': [('enhet', True)],
          'enhål': [('enhåla', False)],
          'enhål-': [('enhåla', False)],
          'enhåls': [('enhåla', False)],
          'enhåls-': [('enhåla', False)],
          'eni': [('enia', False)],
          'eni-': [('enia', False)],
          'enie-': [('enium', False)],
          'eniens': [('eniens', False)],
          'enier': [('eni', False)],
          'enierna': [('eni', False)],
          'eniernas': [('enier', False)],
          'enies': [('enie', False)],
          'eniet': [('enium', False)],
          'enik': [('enik', False)],
          'enik-': [('enik', False)],
          'eniks': [('enik', False)],
          'enillens': [('enill', False)],
          'eningstanken': [('eningstanke', False)],
          'enior': [('enior', False)],
          'eniors': [('enior', False)],
          'enis': [('enis', False)],
          'enis-': [('eni', False)],
          'enisarna': [('enis', False)],
          'enisarnas': [('enis', False)],
          'enisen': [('enis', False)],
          'enisens': [('enis', False)],
          'enissen': [('enisse', False)],
          'enissens': [('enisse', False)],
          'enist': [('enist', False)],
          'enit': [('enit', False)],
          'enitens': [('enit', False)],
          'enitet': [('enitet', False)],
          'enitets': [('enitet', False)],
          'enits': [('eni', False)],
          'enits-': [('enit', False)],
          'enk': [('enka', False)],
          'enk-': [('enka', False)],
          'enkist': [('enkista', False)],
          'enklädes': [('enkläder', False)],
          'enklädes-': [('enkläde', False)],
          'enknäckar': [('enknäckare', False)],
          'enknäckarna': [('enknäck', False)],
          'enknäckarnas': [('enknäck', False)],
          'enkopps': [('enkoppor', False)],
          'enkopps-': [('enkoppor', False)],
          'enkor': [('enko', False)],
          'enkorna': [('enko', False)],
          'enkornas': [('enko', False)],
          'enkors': [('enko', False)],
          'enkrans': [('enkrans', False)],
          'enkrans-': [('enkran', False)],
          'enks': [('enka', False)],
          'enks-': [('enka', False)],
          'enkulan': [('enkula', False)],
          'enkulans': [('enkula', False)],
          'enkurs': [('enkurs', False)],
          'enkurs-': [('enkurs', False)],
          'enkvisten': [('enkvist', False)],
          'enkvistens': [('enkvist', False)],
          'enn': [('enna', False)],
          'enn-': [('enna', False)],
          'ennals': [('ennal', False)],
          'ennan': [('enna', False)],
          'ennans': [('enna', False)],
          'enne': [('enne', False)],
          'enne-': [('enne', False)],
          'enner': [('en', False)],
          'ennerna': [('en', False)],
          'ennernas': [('enne', False)],
          'enners': [('en', False)],
          'ennes': [('enne', False)],
          'ennes-': [('enne', False)],
          'ennets': [('enn', False)],
          'enniernas': [('ennium', False)],
          'enniets': [('ennium', False)],
          'ennin': [('enni', False)],
          'enning': [('enning', False)],
          'enning-': [('enning', False)],
          'enningar': [('enning', False)],
          'enningarna': [('enning', False)],
          'enningarnas': [('enning', False)],
          'enningars': [('enning', False)],
          'ennings': [('enning', False)],
          'ennings-': [('enning', False)],
          'ennins': [('enni', False)],
          'ennis': [('enni', False)],
          'ennis-': [('ennis', False)],
          'enns': [('en', False)],
          'enns-': [('enna', False)],
          'enol': [('enol', False)],
          'enol-': [('enol', False)],
          'enols': [('enol', False)],
          'enomen': [('enom', False)],
          'enomens': [('enomen', False)],
          'enomiker': [('enomik', False)],
          'enomikerna': [('enomik', False)],
          'enomikernas': [('enomik', False)],
          'enomikers': [('enomik', False)],
          'enon': [('enon', False)],
          'enon-': [('enon', False)],
          'enons': [('enon', False)],
          'enor': [('ena', False)],
          'enor-': [('enor', False)],
          'enoren': [('enor', False)],
          'enorens': [('enor', False)],
          'enorer': [('enor', False)],
          'enorerna': [('enor', False)],
          'enorernas': [('enor', False)],
          'enorers': [('enor', False)],
          'enorna': [('ena', False)],
          'enornas': [('ena', False)],
          'enors': [('ena', False)],
          'enors-': [('enor', False)],
          'enos': [('enos', False)],
          'enos-': [('enos', False)],
          'enosen': [('enos', False)],
          'enotter': [('enott', False)],
          'enotypen': [('enotyp', False)],
          'enotypens': [('enotyp', False)],
          'enotyper': [('enotyp', False)],
          'enotyperna': [('enotyp', False)],
          'enotypernas': [('enotyp', False)],
          'enotypers': [('enotyp', False)],
          'enranden': [('enrand', False)],
          'enrandens': [('enrand', False)],
          'enringar': [('enring', False)],
          'enringars': [('enring', False)],
          'ens': [('en', True)],
          'ens-': [('en', False)],
          'ensa': [('ensa', False)],
          'ensaks': [('ensak', True)],
          'ensaks-': [('ensak', True)],
          'ensanden': [('ensande', True)],
          'ensandens': [('ensande', True)],
          'ensar': [('ensare', False)],
          'ensar-': [('ensare', False)],
          'ensarens': [('ensare', False)],
          'ensarna': [('ensare', False)],
          'ensarnas': [('en', False)],
          'ensas': [('ensa', False)],
          'ensats': [('ensats', False)],
          'ensats-': [('ensat', False)],
          'ensdagar': [('ensdag', False)],
          'ensdagarna': [('ensdag', False)],
          'ensdagarnas': [('ensdag', False)],
          'ensdagars': [('ensdag', False)],
          'ensdags': [('ensdag', False)],
          'ensdags-': [('ensdag', False)],
          'ensen': [('ensen', False)],
          'ensens': [('en', False)],
          'ensets': [('ens', False)],
          'ensilie-': [('ensilier', False)],
          'ensilierna': [('ensilier', False)],
          'ensiliernas': [('ensilier', False)],
          'enskallen': [('enskalle', False)],
          'enskallens': [('enskalle', False)],
          'enskans': [('enska', False)],
          'enskaper': [('enskap', False)],
          'enskaperna': [('enskap', False)],
          'enskapernas': [('enskap', False)],
          'enskapers': [('enskap', False)],
          'enskaps': [('enskap', False)],
          'enskar': [('ensk', False)],
          'enskarna': [('ensk', False)],
          'ensken': [('enskena', False)],
          'enskens': [('ensk', False)],
          'enskor': [('enska', False)],
          'enskorna': [('enska', False)],
          'enskornas': [('enska', False)],
          'enskors': [('enska', False)],
          'enskulls-': [('enskull', False)],
          'enskurs': [('enskurs', False)],
          'enskön': [('ensköna', False)],
          'ensköns': [('ensköna', False)],
          'enslandet': [('enslande', False)],
          'ensor': [('ensor', False)],
          'ensors': [('ensor', False)],
          'ensteinar': [('ensteinare', False)],
          'ensteinarna': [('ensteinare', False)],
          'ensteinarnas': [('enstein', False)],
          'enstranden': [('enstrand', False)],
          'enstrandens': [('enstrand', False)],
          'ent-': [('ent', False)],
          'enta': [('enta', False)],
          'entaler': [('entaler', False)],
          'entalers': [('entaler', False)],
          'entan': [('enta', False)],
          'entana': [('enta', False)],
          'entanas': [('enta', False)],
          'entant': [('entant', False)],
          'entant-': [('entant', False)],
          'entanter': [('entant', False)],
          'entanterna': [('entant', False)],
          'entanternas': [('entant', False)],
          'entanters': [('entant', False)],
          'entar': [('entare', False)],
          'entar-': [('entare', False)],
          'entaren': [('entar', False)],
          'entarens': [('entare', False)],
          'entarie': [('entarium', False)],
          'entarie-': [('entarium', False)],
          'entarier': [('entarium', False)],
          'entariernas': [('entarium', False)],
          'entarna': [('entare', False)],
          'entarnas': [('entare', False)],
          'entars': [('entar', False)],
          'entas': [('enta', False)],
          'entat': [('enta', False)],
          'entats': [('enta', False)],
          'ente': [('ente', False)],
          'ente-': [('ente', False)],
          'entens-': [('enten', False)],
          'ententen': [('entent', True), ('entente', True)],
          'ententens': [('entent', True), ('entente', True)],
          'ententer': [('entent', True), ('entente', True)],
          'ententerna': [('entente', True), ('entent', True)],
          'ententernas': [('entent', True), ('entente', True)],
          'ententers': [('entent', True), ('entente', True)],
          'enter': [('enter', False)],
          'enters': [('enter', True)],
          'entes': [('ente', False)],
          'entes-': [('ente', False)],
          'entets': [('ent', False)],
          'entiana': [('entiana', False)],
          'entianas': [('entiana', False)],
          'entiat': [('entiat', False)],
          'entiats': [('entiat', False)],
          'entien': [('enti', False)],
          'entiens': [('enti', False)],
          'entier': [('enti', False)],
          'entierna': [('entier', False)],
          'entiernas': [('enti', False)],
          'entiers': [('enti', False)],
          'entin': [('entin', False)],
          'entins': [('entin', False)],
          'entit': [('entita', True)],
          'entit-': [('entita', True)],
          'entits': [('entita', True)],
          'enton': [('ento', False)],
          'entons': [('ento', False)],
          'entor': [('entor', False)],
          'entorn': [('entorn', False)],
          'entorns': [('entorn', False)],
          'entors': [('entor', False)],
          'entra': [('entrum', False)],
          'entrarnas': [('enter', False)],
          'entrat': [('entrat', False)],
          'entrats': [('entrat', False)],
          'entros-': [('entro', False)],
          'enträden': [('enträd', False)],
          'enträdens': [('enträd', False)],
          'enträdet': [('enträd', False)],
          'ents': [('ent', False)],
          'enu': [('enua', False)],
          'enu-': [('enua', False)],
          'enua': [('enua', False)],
          'enumen': [('enum', False)],
          'enumens': [('enum', False)],
          'enus-': [('enusa', False)],
          'envägar': [('envägar', False)],
          'envägarna': [('envägar', False)],
          'envägarnas': [('envägar', False)],
          'envägars': [('envägar', False)],
          'enyans': [('enyan', False)],
          'enyheter': [('enyhet', False)],
          'enyhets': [('enyhet', False)],
          'enys': [('eny', False)],
          'enyte': [('enyta', False)],
          'enär': [('enär', False)],
          'enär-': [('enär', False)],
          'enärer': [('enär', False)],
          'enärerna': [('enär', False)],
          'enärernas': [('enär', False)],
          'enärers': [('enär', False)],
          'enärs': [('enär', False)],
          'enärs-': [('enär', False)],
          'enäst': [('enäste', False)],
          'enäst-': [('enäste', False)],
          'enäste': [('enäste', False)],
          'enästen': [('enäste', False)],
          'enästens': [('enäste', False)],
          'enästet': [('enäste', False)],
          'enästets': [('enäste', False)],
          'enät': [('enät', False)],
          'enäts': [('enät', False)],
          'enör': [('enör', False)],
          'enör-': [('enör', False)],
          'enören': [('enör', False)],
          'enörens': [('enör', False)],
          'enörs': [('enör', False)],
          'enörs-': [('enör', False)],
          'enötter': [('enöt', False)],
          'enötterna': [('enöt', False)],
          'enötternas': [('enöt', False)],
          'eodet': [('eodet', False)],
          'eodets': [('eodet', False)],
          'eofficerare': [('eofficer', False)],
          'eofficerares': [('eofficer', False)],
          'eofficerarna': [('eofficer', False)],
          'eofficerarnas': [('eofficer', False)],
          'eogen': [('eogen', False)],
          'eogens': [('eogen', False)],
          'eogrammet': [('eogram', False)],
          'eogrammets': [('eogram', False)],
          'eolar': [('eolar', False)],
          'eolaren': [('eolar', False)],
          'eolars': [('eolar', False)],
          'eoler': [('eoler', True)],
          'eolerna': [('eoler', True)],
          'eolernas': [('eoler', True)],
          'eolers': [('eoler', True)],
          'eolier': [('eolier', True)],
          'eolierna': [('eolier', True)],
          'eoliernas': [('eolier', True)],
          'eologier': [('eologi', False)],
          'eologierna': [('eologi', False)],
          'eologiers': [('eologi', False)],
          'eometer': [('eometer', False)],
          'eometers': [('eometer', False)],
          'eon': [('eon', True)],
          'eon-': [('eon', False)],
          'eonier': [('eonier', False)],
          'eonierna': [('eonier', False)],
          'eoniernas': [('eonier', False)],
          'eons': [('eon', True)],
          'eons-': [('eon', False)],
          'eonter': [('eont', False)],
          'eonters': [('eont', False)],
          'eor': [('eo', False)],
          'eorber': [('eorb', False)],
          'eorbers': [('eorb', False)],
          'eord': [('eord', False)],
          'eord-': [('eord', False)],
          'eorden': [('eord', False)],
          'eordens': [('eord', False)],
          'eordnar': [('eorden', False)],
          'eordnarna': [('eorden', False)],
          'eordnarnas': [('eorden', False)],
          'eords': [('eord', False)],
          'eorgier': [('eorgier', False)],
          'eorgierna': [('eorgier', False)],
          'eorgiernas': [('eorgier', False)],
          'eorgiers': [('eorgier', False)],
          'eori': [('eori', False)],
          'eori-': [('eori', False)],
          'eoriens': [('eori', False)],
          'eorier': [('eori', False)],
          'eorierna': [('eori', False)],
          'eoriers': [('eori', False)],
          'eorins': [('eori', False)],
          'eoris': [('eori', False)],
          'eormar': [('eorm', False)],
          'eormarna': [('eorm', False)],
          'eormarnas': [('eorm', False)],
          'eorna': [('eo', False)],
          'eornas': [('eo', False)],
          'eoros': [('eoro', False)],
          'eors': [('eo', False)],
          'eorstens': [('eorsten', False)],
          'eorten': [('eort', False)],
          'eortens': [('eort', False)],
          'eorternas': [('eort', False)],
          'eorters': [('eort', False)],
          'eorts-': [('eort', False)],
          'eos': [('eo', False)],
          'eos-': [('eo', False)],
          'eosin': [('eosin', True)],
          'eotidens': [('eotid', False)],
          'ep': [('ep', False)],
          'ep-': [('ep', False)],
          'epalt': [('epalt', False)],
          'epalts': [('epalt', False)],
          'epalts-': [('epalt', False)],
          'epande': [('epande', False)],
          'epande-': [('epande', False)],
          'epans-': [('epans', False)],
          'epar': [('ep', False)],
          'epar-': [('epare', False)],
          'eparanden': [('eparand', False)],
          'eparandens': [('eparand', False)],
          'eparen': [('epare', False)],
          'eparens': [('epare', False)],
          'epares': [('epare', False)],
          'eparna': [('ep', False)],
          'eparnas': [('epare', False)],
          'epars': [('ep', False)],
          'epatiens': [('epati', False)],
          'epatiernas': [('epati', False)],
          'epe-': [('epa', False)],
          'epelar': [('epelare', False)],
          'epelar-': [('epelare', False)],
          'epelsen': [('epelse', False)],
          'epelsens': [('epelse', False)],
          'epen': [('ep', False)],
          'epengarna': [('epeng', False)],
          'epengarnas': [('epeng', False)],
          'epengars': [('epeng', False)],
          'epenning': [('epenning', False)],
          'epenning-': [('epenning', False)],
          'epenningar': [('epenning', False)],
          'epenningarna': [('epenning', False)],
          'epenningarnas': [('epenning', False)],
          'epenningars': [('epenning', False)],
          'epennings': [('epenning', False)],
          'epennings-': [('epenning', False)],
          'epens-': [('epens', False)],
          'eperna': [('epe', False)],
          'epernas': [('epe', False)],
          'epers': [('epe', False)],
          'epet': [('ep', False)],
          'epetters': [('epetter', False)],
          'epikerna': [('epiker', True)],
          'epin': [('epi', False)],
          'epinnarnas': [('epinne', False)],
          'epinnens': [('epinne', False)],
          'epinns': [('epinne', False)],
          'epins': [('epi', False)],
          'eplanet': [('eplan', False)],
          'eplanets': [('eplan', False)],
          'epojk': [('epojke', False)],
          'epojk-': [('epojke', False)],
          'epojks': [('epojke', False)],
          'epojks-': [('epojke', False)],
          'epoker': [('epok', False)],
          'epokers': [('epok', False)],
          'eponents': [('eponent', False)],
          'eponents-': [('eponent', False)],
          'epor': [('epa', False)],
          'eporna': [('epa', False)],
          'epornas': [('epa', False)],
          'epors': [('epa', False)],
          'eportarnas': [('eport', False)],
          'eporter': [('eporter', False)],
          'eporters': [('eporter', False)],
          'epos': [('epos', True)],
          'epos-': [('epos', False)],
          'eposen': [('epos', True)],
          'eposens': [('epos', True)],
          'epositas': [('epositum', False)],
          'epostar': [('epost', True), ('epostare', True)],
          'epostarna': [('epost', True), ('epostare', True)],
          'epostarnas': [('epost', True), ('epostare', True)],
          'eposter': [('epost', False)],
          'eposters': [('epost', False)],
          'epott': [('epott', False)],
          'epott-': [('epott', False)],
          'epottarna': [('epott', False)],
          'epotts': [('epott', False)],
          'epotts-': [('epott', False)],
          'epp': [('eppe', False)],
          'epp-': [('eppe', False)],
          'eppar': [('eppar', False)],
          'eppar-': [('eppare', False)],
          'epparna': [('eppare', False)],
          'epparnas': [('eppe', False)],
          'eppars': [('eppar', False)],
          'eppbräde': [('eppbräde', False)],
          'eppe': [('eppe', False)],
          'eppen': [('eppe', False)],
          'eppens': [('eppe', False)],
          'eppets': [('epp', False)],
          'epprockar': [('epprockare', False)],
          'epps': [('eppe', False)],
          'epps-': [('eppe', False)],
          'epraktik': [('epraktika', False)],
          'epraktik-': [('epraktika', False)],
          'epraktiks': [('epraktika', False)],
          'epran': [('epra', False)],
          'eprans': [('epra', False)],
          'eproblemet': [('eproblem', False)],
          'eproblemets': [('eproblem', False)],
          'eprocessen': [('eprocess', False)],
          'eprocessens': [('eprocess', False)],
          'eprogrammet': [('eprogram', False)],
          'eprogrammets': [('eprogram', False)],
          'eps': [('ep', False)],
          'eps-': [('ep', False)],
          'epsarnas': [('eps', False)],
          'epsens': [('eps', False)],
          'epsins': [('epsi', False)],
          'epsis': [('epsi', False)],
          'epsis-': [('epsis', False)],
          'epstegen': [('epstege', False)],
          'epstegs': [('epstege', False)],
          'eptans': [('eptans', False)],
          'eptima': [('eptima', False)],
          'eptimas': [('eptima', False)],
          'eptor': [('eptor', False)],
          'eptors': [('eptor', False)],
          'epump': [('epump', False)],
          'epumps': [('epump', False)],
          'epumps-': [('epump', False)],
          'eputt': [('eputt', False)],
          'eputt-': [('eputt', False)],
          'eputtar': [('eputt', False)],
          'eputtarna': [('eputt', False)],
          'eputtarnas': [('eputt', False)],
          'eputtars': [('eputt', False)],
          'eputten': [('eputt', False)],
          'eputtens': [('eputt', False)],
          'eputter': [('eputt', False)],
          'eputters': [('eputt', False)],
          'eputts': [('eputt', False)],
          'eputts-': [('eputt', False)],
          'epån': [('epå', False)],
          'epås': [('epå', False)],
          'er': [('era', True)],
          'er-': [('era', True)],
          'era': [('era', True)],
          'erabil': [('erabilia', False)],
          'eraden': [('erad', False)],
          'eradena': [('erad', False)],
          'eradenas': [('erad', False)],
          'eradens': [('erad', False)],
          'erades': [('erad', False)],
          'eradon': [('erado', False)],
          'eradons': [('erado', False)],
          'eradors': [('erado', False)],
          'erafen': [('eraf', False)],
          'erafens': [('eraf', False)],
          'erafs': [('eraf', False)],
          'erafs-': [('eraf', False)],
          'eraj': [('eraj', False)],
          'eraj-': [('eraj', False)],
          'erajs': [('eraj', False)],
          'erajs-': [('eraj', False)],
          'eralierna': [('eral', False)],
          'eraman': [('eraman', False)],
          'eraman-': [('eraman', False)],
          'eramans': [('eraman', False)],
          'eramar': [('eram', False)],
          'eramer': [('eram', False)],
          'eramerna': [('eram', False)],
          'eramernas': [('eram', False)],
          'erams': [('eram', False)],
          'erams-': [('eram', False)],
          'eran': [('era', True)],
          'eran-': [('eran', False)],
          'erana': [('erum', False)],
          'eranas': [('erum', False)],
          'erand': [('eranda', False)],
          'erand-': [('eranda', False)],
          'eranda': [('eranda', False)],
          'erandans': [('eranda', False)],
          'erandas': [('eranda', False)],
          'erande': [('erande', False)],
          'erande-': [('erande', False)],
          'eranden': [('erande', False)],
          'erandens': [('erande', False)],
          'erandet': [('erande', False)],
          'erands': [('eranda', False)],
          'erands-': [('eranda', False)],
          'eranger': [('erang', False)],
          'erangers': [('erang', False)],
          'eranier': [('eranium', False)],
          'eranierna': [('eranium', False)],
          'eranmälningar': [('eranmälan', False)],
          'eranmälningarna': [('eranmälan', False)],
          'eranmälningarnas': [('eranmälan', False)],
          'eranmälningars': [('eranmälan', False)],
          'erans': [('era', True)],
          'erans-': [('erans', False)],
          'erap': [('erapa', False)],
          'erap-': [('erapa', False)],
          'erapar': [('erapare', False)],
          'eraparen': [('erapare', False)],
          'erape': [('erapa', False)],
          'erape-': [('erapa', False)],
          'eraps': [('erapa', False)],
          'eraps-': [('erapa', False)],
          'erar': [('erare', False)],
          'erarie': [('eraria', False)],
          'erarie-': [('eraria', False)],
          'eras': [('era', False)],
          'erassen': [('erass', False)],
          'erassens': [('erass', False)],
          'eraster': [('erast', False)],
          'erasterna': [('erast', False)],
          'erasternas': [('erast', False)],
          'erasters': [('erast', False)],
          'erat': [('erat', False)],
          'eraten': [('erat', False)],
          'eratens': [('erat', False)],
          'erater': [('erat', False)],
          'eraterna': [('erat', False)],
          'eraternas': [('erat', False)],
          'eraters': [('erat', False)],
          'eratins': [('eratin', False)],
          'erats': [('erat', False)],
          'erbagar': [('erbagare', False)],
          'erbagarna': [('erbagare', False)],
          'erbagarnas': [('erbagare', False)],
          'erbariets': [('erbarium', False)],
          'erben': [('erb', False)],
          'erbens': [('erben', False)],
          'erbens-': [('erbena', False)],
          'erber': [('erber', False)],
          'erberna': [('erber', False)],
          'erbernas': [('erber', False)],
          'erbers': [('erber', False)],
          'erbet': [('erbeta', False)],
          'erbet-': [('erbeta', False)],
          'erbets': [('erb', False)],
          'erbets-': [('erbeta', False)],
          'erbil': [('erbila', False)],
          'erbil-': [('erbila', False)],
          'erbils': [('erbila', False)],
          'erbils-': [('erbila', False)],
          'erbitar': [('erbitare', False)],
          'erbitarna': [('erbitare', False)],
          'erbitarnas': [('erbit', False)],
          'erborgen': [('erborgen', False)],
          'erborgens': [('erborgen', False)],
          'erbrors': [('erbror', False)],
          'ercher': [('erch', False)],
          'ercherna': [('erch', False)],
          'erchernas': [('erch', False)],
          'erchers': [('erch', False)],
          'erdar': [('erde', False)],
          'erdarna': [('erde', False)],
          'erdarnas': [('erde', False)],
          'erdars': [('erde', False)],
          'erde': [('erde', False)],
          'erde-': [('erde', False)],
          'erdelar': [('erdel', False)],
          'erdelarna': [('erdel', False)],
          'erdelarnas': [('erdel', False)],
          'erden': [('erde', False)],
          'erdens': [('erde', False)],
          'erdier': [('erdier', False)],
          'erdierna': [('erdier', False)],
          'erdomar': [('erdomare', False)],
          'erdomarna': [('erdom', False)],
          'erdomarnas': [('erdomare', False)],
          'erdos': [('erdos', False)],
          'erdos-': [('erdosa', False)],
          'ere': [('era', False)],
          'ere-': [('era', False)],
          'eredans': [('ereda', False)],
          'eren': [('er', False)],
          'erenarna': [('eren', False)],
          'erens': [('er', False)],
          'erens-': [('erens', False)],
          'ereon': [('ereo', False)],
          'erep': [('erep', False)],
          'erepet': [('erep', False)],
          'erepets': [('erep', False)],
          'ereps': [('erep', False)],
          'ereps-': [('erep', False)],
          'erer': [('er', False)],
          'ererna': [('er', False)],
          'erernas': [('er', False)],
          'erers': [('er', False)],
          'erese': [('eresa', False)],
          'erese-': [('eresa', False)],
          'eret': [('er', False)],
          'erets': [('er', False)],
          'erfader-': [('erfar', False)],
          'erfadern': [('erfar', False)],
          'erfaderns': [('erfar', False)],
          'erfaders': [('erfar', False)],
          'erfar': [('erfara', False)],
          'erfar-': [('erfara', False)],
          'erfarenheter': [('erfarenhet', False)],
          'erfarenheterna': [('erfarenhet', False)],
          'erfarenheternas': [('erfarenhet', False)],
          'erfarenheters': [('erfarenhet', False)],
          'erfarenhets': [('erfarenhet', False)],
          'erfarenhets-': [('erfarenhet', False)],
          'erfars': [('erfara', False)],
          'erfars-': [('erfara', False)],
          'erfem': [('erfemma', False)],
          'erfem-': [('erfemma', False)],
          'erfems': [('erfemma', False)],
          'erfiskar': [('erfisk', False)],
          'erfiskarna': [('erfisk', False)],
          'erfiskarnas': [('erfiskare', False)],
          'erflott': [('erflott', False)],
          'erflott-': [('erflott', False)],
          'erflotte': [('erflotte', False)],
          'erflotts': [('erflotte', False)],
          'erflotts-': [('erflott', False)],
          'erfläck-': [('erfläck', False)],
          'erfläcks': [('erfläck', False)],
          'erfläcks-': [('erfläck', False)],
          'erfots': [('erfötter', False)],
          'erfots-': [('erfötter', False)],
          'erfäder': [('erfar', False)],
          'erfäders': [('erfar', False)],
          'erfötter': [('erfot', False)],
          'erfötterna': [('erfot', False)],
          'erfötternas': [('erfot', False)],
          'erfötters': [('erfot', False)],
          'ergandens': [('ergand', False)],
          'ergarten': [('ergart', False)],
          'ergartens': [('ergart', False)],
          'ergen': [('ergen', False)],
          'ergens': [('ergens', False)],
          'ergens-': [('ergens', False)],
          'ergien': [('ergi', False)],
          'ergiens': [('ergi', False)],
          'ergier': [('ergi', False)],
          'ergierna': [('ergi', False)],
          'ergiers': [('ergi', False)],
          'ergin': [('ergin', False)],
          'ergins': [('ergin', False)],
          'ergis': [('ergi', False)],
          'ergsområdet': [('ergsområde', False)],
          'ergärden': [('ergärd', False)],
          'ergärdens': [('ergärd', False)],
          'erhimlens': [('erhimmel', False)],
          'erhona': [('erhona', False)],
          'erhonas': [('erhona', False)],
          'erhängen': [('erhäng', False)],
          'erhängens': [('erhäng', False)],
          'erhänget': [('erhäng', False)],
          'erhängets': [('erhäng', False)],
          'erhängs': [('erhäng', False)],
          'erhängs-': [('erhäng', False)],
          'erhöns': [('erhöna', False)],
          'erhöns-': [('erhöna', False)],
          'eri': [('erier', False)],
          'erian': [('eria', False)],
          'eriana': [('eriana', False)],
          'erians': [('eria', False)],
          'erias': [('eria', False)],
          'erick': [('erick', False)],
          'erickarnas': [('erick', False)],
          'erid': [('erid', False)],
          'erid-': [('erid', False)],
          'erider': [('erid', False)],
          'eriderna': [('erid', False)],
          'eridernas': [('erid', False)],
          'eriders': [('erid', False)],
          'erids-': [('erider', False)],
          'erie': [('erie', False)],
          'erie-': [('erie', False)],
          'erien': [('erie', False)],
          'eriens': [('erie', False)],
          'erier': [('erier', False)],
          'eriernas': [('eri', False)],
          'eries': [('erie', False)],
          'eries-': [('erie', False)],
          'eriet': [('erium', False)],
          'eriets': [('eri', False)],
          'eriffens': [('eriff', False)],
          'erikan': [('erikan', False)],
          'erikans': [('erikan', False)],
          'erike': [('erika', False)],
          'erike-': [('erika', False)],
          'eriket': [('erike', False)],
          'eriks': [('erika', False)],
          'eriks-': [('erika', False)],
          'erims': [('erim', False)],
          'erims-': [('erim', False)],
          'erin': [('eri', False)],
          'erin-': [('erin', False)],
          'erina': [('erina', False)],
          'erinas': [('erina', False)],
          'eriner': [('erin', False)],
          'erinerna': [('erin', False)],
          'erinernas': [('erin', False)],
          'eriners': [('erin', False)],
          'eringar': [('ering', False)],
          'eringarna': [('ering', False)],
          'eringarnas': [('ering', False)],
          'erinor': [('erina', False)],
          'erinorna': [('erina', False)],
          'erinornas': [('erina', False)],
          'erinors': [('erina', False)],
          'erinringar': [('erinring', True), ('erinran', True)],
          'erinringarna': [('erinran', True), ('erinring', True)],
          'erinringarnas': [('erinran', True), ('erinring', True)],
          'erinringars': [('erinring', True), ('erinran', True)],
          'erins': [('erin', False)],
          'erins-': [('erin', False)],
          'erions': [('erion', False)],
          'erisen': [('erise', False)],
          'erisens': [('erise', False)],
          'erisk': [('erisk', False)],
          'erisk-': [('erisk', False)],
          'erit-': [('erit', False)],
          'eriter': [('erit', False)],
          'eriterna': [('erit', False)],
          'eriters': [('erit', False)],
          'eritet': [('eritet', False)],
          'eritets': [('eritet', False)],
          'eritis': [('eritus', False)],
          'erits': [('eri', False)],
          'erivar': [('erivara', False)],
          'erjarna': [('erjar', False)],
          'erjarnas': [('erjar', False)],
          'erjars': [('erjar', False)],
          'erjet': [('erjet', False)],
          'erjets': [('erjet', False)],
          'erjorden': [('erjord', False)],
          'erjordens': [('erjord', False)],
          'erk': [('erka', False)],
          'erk-': [('erka', False)],
          'erkan': [('erka', False)],
          'erkans': [('erka', False)],
          'erkar': [('erkare', False)],
          'erkarna': [('erkare', False)],
          'erkas': [('erka', False)],
          'erkasse-': [('erkassa', False)],
          'erkatt': [('erkatt', False)],
          'erkatt-': [('erkatt', False)],
          'erkatts': [('erkatt', False)],
          'erkatts-': [('erkatt', False)],
          'erke': [('erke', False)],
          'erkist': [('erkista', False)],
          'erkist-': [('erkist', False)],
          'erklings-': [('erklinga', False)],
          'erklädes-': [('erkläder', False)],
          'erkläds': [('erkläder', False)],
          'erkläds-': [('erkläder', False)],
          'erkors': [('erkors', False)],
          'erkurs': [('erkurs', False)],
          'erkurs-': [('erkurs', False)],
          'erkörs': [('erkörs', False)],
          'erkörs-': [('erkörs', False)],
          'erlack': [('erlacka', False)],
          'erlack-': [('erlack', False)],
          'erlacks': [('erlack', False)],
          'erlacks-': [('erlack', False)],
          'erlanden': [('erland', False)],
          'erlandens': [('erland', False)],
          'erlandet': [('erland', False)],
          'erleks': [('erlek', False)],
          'erlik': [('erlike', False)],
          'erlikar': [('erlikare', False)],
          'erlikarna': [('erlike', False)],
          'erlikarnas': [('erlikare', False)],
          'erliken': [('erlik', False)],
          'erlikens': [('erlike', False)],
          'erliks': [('erlike', False)],
          'erliks-': [('erlike', False)],
          'erlins': [('erlina', False)],
          'erlogen': [('erloge', False)],
          'erlogens': [('erloge', False)],
          'erman': [('erma', False)],
          'ermanens': [('erman', False)],
          'ermans': [('erma', False)],
          'ermat': [('erma', False)],
          'ermats': [('erma', False)],
          'ermen': [('erm', False)],
          'ermetoden': [('ermetoden', False)],
          'ermetodens': [('ermetoden', False)],
          'ermets': [('erm', False)],
          'ermien': [('ermi', False)],
          'ermiens': [('ermi', False)],
          'erminister': [('erminist', False)],
          'erministers': [('erminist', False)],
          'ermins': [('ermi', False)],
          'ermis': [('ermi', False)],
          'ermoder': [('ermor', False)],
          'ermodet': [('ermod', False)],
          'ermodets': [('ermod', False)],
          'ermor': [('ermor', False)],
          'ermors': [('ermor', False)],
          'ermån': [('ermåne', False)],
          'ermån-': [('ermåne', False)],
          'ermånen': [('ermåne', False)],
          'ermånens': [('ermåne', False)],
          'ermåns-': [('ermåne', False)],
          'ermödrarna': [('ermor', False)],
          'ermödrarnas': [('ermor', False)],
          'ermödrars': [('ermor', False)],
          'ermöss': [('ermus', False)],
          'ern': [('er', False)],
          'erna': [('', False)],
          'ernack-': [('ernacka', False)],
          'ernacke': [('ernacka', False)],
          'ernas': [('', False)],
          'erne': [('erne', False)],
          'erne-': [('erna', False)],
          'erner': [('erner', False)],
          'erners': [('erner', False)],
          'ernes': [('erne', False)],
          'ernes-': [('erne', False)],
          'ernet': [('ernet', False)],
          'ernets': [('ernet', False)],
          'ernister': [('ernist', False)],
          'ernisters': [('ernist', False)],
          'ernitet': [('ernit', False)],
          'ernitets': [('ernit', False)],
          'erns': [('er', False)],
          'ero-': [('ero', False)],
          'eroben': [('erob', False)],
          'erobens': [('erob', False)],
          'erober': [('erob', False)],
          'eroberna': [('erob', False)],
          'erobernas': [('erob', False)],
          'erobers': [('erob', False)],
          'erock': [('erock', False)],
          'erockar': [('erock', False)],
          'erockarna': [('erock', False)],
          'erockarnas': [('erock', False)],
          'erogen': [('erogen', False)],
          'erogen-': [('erogen', False)],
          'erogener': [('erogen', False)],
          'erogenernas': [('erogen', False)],
          'erogeners': [('erogen', False)],
          'erol': [('erol', False)],
          'erol-': [('erol', False)],
          'eroller': [('eroll', False)],
          'erollerna': [('eroll', False)],
          'erollernas': [('eroll', False)],
          'erollers': [('eroll', False)],
          'erolls': [('eroll', False)],
          'erolls-': [('eroll', False)],
          'erols': [('erol', False)],
          'erols-': [('erol', False)],
          'eromans': [('eroman', False)],
          'erområdet': [('erområde', False)],
          'eroms': [('erom', False)],
          'eron': [('eron', False)],
          'eronen': [('eron', False)],
          'eronens': [('eron', False)],
          'eroner': [('eron', False)],
          'eronerna': [('eron', False)],
          'eronernas': [('eron', False)],
          'eroners': [('eron', False)],
          'erons': [('eron', False)],
          'eropar': [('eropar', False)],
          'eropar-': [('eropar', False)],
          'eroparen': [('eropar', False)],
          'eroparens': [('eropar', False)],
          'eropen': [('erop', False)],
          'erops': [('erop', False)],
          'eror': [('era', False)],
          'erorden': [('erorden', False)],
          'erordens': [('erorden', False)],
          'erorna': [('era', False)],
          'erornas': [('era', True)],
          'erors': [('era', False)],
          'eros': [('eros', False)],
          'eros-': [('eros', False)],
          'erot': [('erot', False)],
          'eroten': [('erot', False)],
          'erotens': [('erot', False)],
          'erots': [('erot', False)],
          'erots-': [('erot', False)],
          'erpen': [('erpen', False)],
          'erpeng': [('erpeng', False)],
          'erpeng-': [('erpeng', False)],
          'erpengarnas': [('erpeng', False)],
          'erpengars': [('erpeng', False)],
          'erpengs': [('erpeng', False)],
          'erpengs-': [('erpeng', False)],
          'erpens': [('erpen', False)],
          'errans': [('erran', False)],
          'errar': [('erre', False)],
          'errarna': [('erre', False)],
          'errarnas': [('erre', False)],
          'errars': [('erre', False)],
          'erras': [('erras', False)],
          'erre': [('erre', False)],
          'erre-': [('erre', False)],
          'errems-': [('erremsa', False)],
          'erren': [('erre', False)],
          'errens': [('erre', False)],
          'errens-': [('erren', False)],
          'errock-': [('errock', False)],
          'errocks': [('errock', False)],
          'errocks-': [('errock', False)],
          'erromans': [('erromans', False)],
          'error': [('error', False)],
          'errors': [('error', False)],
          'errs': [('err', False)],
          'errs-': [('erre', False)],
          'errån': [('errån', False)],
          'erråns': [('errå', False)],
          'ers': [('era', True)],
          'ers-': [('era', True)],
          'ersan': [('ersa', False)],
          'ersans': [('ersa', False)],
          'ersarna': [('er', False)],
          'ersblom': [('ersblomma', False)],
          'ersblom-': [('ersblomma', False)],
          'ersbloms': [('ersblomma', False)],
          'ersbloms-': [('ersblomma', False)],
          'ersens': [('er', False)],
          'erser': [('erser', False)],
          'erserna': [('erser', False)],
          'ersernas': [('erser', False)],
          'ersers': [('erser', False)],
          'erset': [('erus', False)],
          'ersets': [('ers', False)],
          'ersfiskar': [('ersfiskare', False)],
          'ersfiskarna': [('ersfiskare', False)],
          'ersian': [('ersian', False)],
          'ersians': [('ersian', False)],
          'ersikan': [('ersika', False)],
          'ersikans': [('ersika', False)],
          'ersikten': [('ersikt', False)],
          'ersiktens': [('ersikt', False)],
          'erskallen': [('erskall', False)],
          'erskeden': [('ersked', False)],
          'erskedens': [('ersked', False)],
          'ersken': [('ersken', False)],
          'erskiftens': [('erskifte', False)],
          'erskiftet': [('erskifte', False)],
          'erskor': [('erska', False)],
          'erskorna': [('erska', False)],
          'erskornas': [('erska', False)],
          'erskors': [('erska', False)],
          'erskris': [('erskri', False)],
          'ersläkten': [('ersläkte', False)],
          'ersläktens': [('ersläkte', False)],
          'ersläkts': [('ersläkte', False)],
          'ersläkts-': [('ersläkt', False)],
          'ersraster': [('ersrast', False)],
          'ersrasternas': [('ersrast', False)],
          'ersrasters': [('ersrast', False)],
          'erstans': [('erstans', False)],
          'ersten': [('ersten', False)],
          'erstövel': [('erstövel', False)],
          'erstövel-': [('erstövel', False)],
          'erstövels': [('erstövel', False)],
          'erstövels-': [('erstövel', False)],
          'erstövlar': [('erstövel', False)],
          'erstövlarna': [('erstövel', False)],
          'erstövlarnas': [('erstövel', False)],
          'ersås': [('erså', False)],
          'ersåten': [('ersåte', False)],
          'ersåts': [('ersåte', False)],
          'ersåts-': [('ersåte', False)],
          'ertagets': [('ertag', False)],
          'ertarnas': [('ert', False)],
          'erte': [('erte', False)],
          'erte-': [('erte', False)],
          'ertegen': [('erteg', False)],
          'erter': [('erter', False)],
          'erters': [('erter', False)],
          'ertet': [('ertet', False)],
          'ertin': [('ertin', False)],
          'ertin-': [('ertina', False)],
          'ertinens': [('ertinens', False)],
          'ertins': [('ertina', False)],
          'ertis': [('ertis', False)],
          'ertits': [('ertit', False)],
          'ertrons': [('ertro', False)],
          'erträn': [('erträd', False)],
          'ertränas': [('erträd', False)],
          'erts': [('erts', False)],
          'erts-': [('erts', False)],
          'ertsarna': [('erts', False)],
          'ertsarnas': [('erts', False)],
          'ertsen': [('erts', False)],
          'ertsens': [('erts', False)],
          'ertut': [('ertuta', False)],
          'ertut-': [('ertuta', False)],
          'eruben': [('erub', False)],
          'erubens': [('erub', False)],
          'eruk': [('eruk', False)],
          'eruk-': [('eruk', False)],
          'eruks': [('eruk', False)],
          'eruks-': [('eruk', False)],
          'erull': [('erull', False)],
          'erullen': [('erull', False)],
          'erullens': [('erull', False)],
          'erulls': [('erull', False)],
          'erulls-': [('erull', False)],
          'erum': [('erum', False)],
          'erum-': [('erum', False)],
          'erums': [('erum', False)],
          'erums-': [('erum', False)],
          'erund': [('erund', False)],
          'erundier': [('erundium', False)],
          'erundierna': [('erundium', False)],
          'erundiernas': [('erundium', False)],
          'erundiers': [('erundium', False)],
          'erunds': [('erund', False)],
          'erunds-': [('erund', False)],
          'erungen': [('erunge', False)],
          'erungens': [('erunge', False)],
          'erur': [('erur', False)],
          'erurs': [('erur', False)],
          'erus': [('erus', False)],
          'erus-': [('erus', False)],
          'ervals': [('erval', False)],
          'ervals-': [('ervals', False)],
          'ervans': [('ervans', False)],
          'ervant': [('ervante', False)],
          'ervant-': [('ervante', False)],
          'ervanten': [('ervant', False)],
          'ervantens': [('ervant', False)],
          'ervants': [('ervante', False)],
          'ervar-': [('ervare', False)],
          'ervaren': [('ervar', False)],
          'ervarens': [('ervare', False)],
          'ervars': [('erve', False)],
          'erve': [('erve', False)],
          'erve-': [('erve', False)],
          'erves': [('erve', False)],
          'ervis': [('ervisa', False)],
          'ervis-': [('ervisa', False)],
          'ery': [('ery', False)],
          'ery-': [('ery', False)],
          'eryllerna': [('eryll', False)],
          'eryllers': [('eryll', False)],
          'erys': [('ery', False)],
          'eräden': [('eräd', False)],
          'eräder': [('eräd', False)],
          'eräds-': [('eräd', False)],
          'erän': [('erän', False)],
          'erände': [('erända', False)],
          'erände-': [('erända', False)],
          'erändernas': [('erand', False)],
          'eräns': [('erän', False)],
          'erättarnas': [('erättare', False)],
          'erättens': [('erätt', False)],
          'erätters': [('erätters', False)],
          'erättigheter': [('erättighet', False)],
          'erättigheterna': [('erättighet', False)],
          'erättigheternas': [('erättighet', False)],
          'erättighets-': [('erättighet', False)],
          'eråden': [('eråd', False)],
          'erådens': [('eråd', False)],
          'erådet': [('eråd', False)],
          'erån': [('erå', False)],
          'eråns': [('erån', False)],
          'erår': [('erår', False)],
          'erårs': [('erår', False)],
          'erökar': [('erökare', False)],
          'erökarna': [('erökare', False)],
          'erökarnas': [('erökare', False)],
          'eröst': [('eröst', False)],
          'eröst-': [('eröst', False)],
          'erösten': [('eröst', False)],
          'eröstens': [('eröst', False)],
          'erötter': [('erot', False)],
          'erötterna': [('erot', False)],
          'erötternas': [('erot', False)],
          'erötters': [('erot', False)],
          'esage': [('esaga', False)],
          'esage-': [('esaga', False)],
          'esago': [('esaga', False)],
          'esago-': [('esaga', False)],
          'esaker': [('esak', False)],
          'esakerna': [('esak', False)],
          'esakernas': [('esak', False)],
          'esakers': [('esak', False)],
          'esalen': [('esal', False)],
          'esalens': [('esal', False)],
          'esamen': [('esam', False)],
          'esamens': [('esam', False)],
          'esan': [('esan', False)],
          'esanden': [('esande', False)],
          'esandens': [('esande', False)],
          'esanmälningar': [('esanmälan', False)],
          'esanmälningarna': [('esanmälan', False)],
          'esanmälningars': [('esanmälan', False)],
          'esans': [('esan', False)],
          'esar': [('es', False)],
          'esaren': [('esare', False)],
          'esarna': [('es', False)],
          'esars': [('es', False)],
          'esats': [('esats', False)],
          'esats-': [('esats', False)],
          'escens': [('escens', False)],
          'escens-': [('escens', False)],
          'escenter': [('escent', False)],
          'esch': [('esch', False)],
          'esch-': [('esch', False)],
          'eschen': [('esch', False)],
          'eschens': [('esch', False)],
          'escher': [('esch', False)],
          'eschers': [('esch', False)],
          'esed': [('eseda', False)],
          'esed-': [('eseda', False)],
          'esedan': [('eseda', False)],
          'esedans': [('eseda', False)],
          'esede': [('eseda', False)],
          'esede-': [('eseda', False)],
          'eseds': [('eseda', False)],
          'eseds-': [('eseda', False)],
          'eseffekterna': [('eseffekter', False)],
          'esegrar': [('esegrare', False)],
          'esegrarna': [('esegrare', False)],
          'esegrarnas': [('esegrare', False)],
          'esel': [('esel', False)],
          'esel-': [('esel', False)],
          'esels': [('esel', False)],
          'esels-': [('esel', False)],
          'esen': [('es', False)],
          'esens': [('es', False)],
          'esens-': [('esens', False)],
          'esentens': [('esent', False)],
          'eser': [('es', False)],
          'eserier': [('eserie', False)],
          'eserierna': [('eserie', False)],
          'eseriernas': [('eseri', False)],
          'eseriers': [('eseri', False)],
          'eserna': [('es', False)],
          'esernas': [('es', False)],
          'esers': [('es', False)],
          'eserv': [('eserv', False)],
          'eserv-': [('eserv', False)],
          'eservar': [('eservare', False)],
          'eservarna': [('eservare', False)],
          'eservarnas': [('eservare', False)],
          'eserven': [('eserv', False)],
          'eservens': [('eserv', False)],
          'eserver': [('eserv', False)],
          'eservers': [('eserv', False)],
          'eservs': [('eserv', False)],
          'eservs-': [('eserv', False)],
          'eset': [('es', False)],
          'esets': [('eset', False)],
          'esfiskarnas': [('esfiskare', False)],
          'esförsäkringars': [('esförsäkring', False)],
          'esgåvornas': [('esgåva', False)],
          'eshag': [('eshage', False)],
          'eshag-': [('eshage', False)],
          'eshagen': [('eshage', False)],
          'eshagens': [('eshage', False)],
          'eshags': [('eshage', False)],
          'eshags-': [('eshage', False)],
          'eshar': [('eshare', False)],
          'esharna': [('eshare', False)],
          'eshars': [('eshare', False)],
          'eshet': [('eshet', False)],
          'esian': [('esia', False)],
          'esians': [('esia', False)],
          'esidan': [('esida', False)],
          'esidans': [('esida', False)],
          'eside': [('esida', False)],
          'eside-': [('esida', False)],
          'esidens': [('esidens', False)],
          'esides': [('eses', False)],
          'esidier': [('esidium', False)],
          'esidiernas': [('esidium', False)],
          'esidiers': [('esidium', False)],
          'esier': [('esier', False)],
          'esierna': [('esi', False)],
          'esiernas': [('esier', False)],
          'esiers': [('esier', False)],
          'esiet': [('esi', False)],
          'esiets': [('esi', False)],
          'esin': [('esi', False)],
          'esiren': [('esir', False)],
          'esirens': [('esir', False)],
          'esis': [('esis', False)],
          'esistans': [('esistans', False)],
          'esistens': [('esistens', False)],
          'esistens-': [('esistens', False)],
          'esit': [('esi', False)],
          'esits': [('esit', False)],
          'esjukan': [('esjuka', False)],
          'eskader': [('eskader', True)],
          'eskaders': [('eskader', True)],
          'eskal': [('eskala', False)],
          'eskal-': [('eskala', False)],
          'eskals': [('eskala', False)],
          'eskals-': [('eskala', False)],
          'eskan': [('eska', False)],
          'eskans': [('eska', False)],
          'eskaps-': [('eskap', False)],
          'eskar': [('esk', False)],
          'eskarnas': [('esk', False)],
          'eskars': [('esk', False)],
          'eskatts-': [('eskatt', False)],
          'eskeden': [('eskede', False)],
          'eskedens': [('esked', False)],
          'eskedet': [('eskede', False)],
          'eskedets': [('esked', False)],
          'esken': [('esk', False)],
          'eskens': [('esk', False)],
          'eskets': [('esk', False)],
          'eskiften': [('eskifte', False)],
          'eskiftens': [('eskifte', False)],
          'eskiftets': [('eskifte', False)],
          'eskonst': [('eskonst', False)],
          'eskop': [('eskop', False)],
          'eskop-': [('eskop', False)],
          'eskops': [('eskop', False)],
          'eskops-': [('eskop', False)],
          'eskors': [('esko', False)],
          'eskotten': [('eskott', False)],
          'eskottens': [('eskott', False)],
          'eskrin': [('eskri', False)],
          'eskrins': [('eskri', False)],
          'eskriptor': [('eskriptor', False)],
          'eskriptors': [('eskriptor', False)],
          'eskrällen': [('eskräll', False)],
          'eskrällens': [('eskräll', False)],
          'eskulder': [('eskuld', False)],
          'eskytten': [('eskytt', False)],
          'eskyttens': [('eskytt', False)],
          'eskärmar': [('eskärmare', False)],
          'eskärmarna': [('eskärm', False)],
          'eskärmarnas': [('eskärm', False)],
          'eskärv': [('eskärve', False)],
          'eskärv-': [('eskärve', False)],
          'eskärvar': [('eskärve', False)],
          'eskärvarna': [('eskärve', False)],
          'eskärvarnas': [('eskärve', False)],
          'eskärvars': [('eskärve', False)],
          'eskärve': [('eskärve', False)],
          'eskärven': [('eskärve', False)],
          'eskärvens': [('eskärve', False)],
          'eskärvs': [('eskärve', False)],
          'eskärvs-': [('eskärve', False)],
          'eskår': [('eskår', False)],
          'eskåren': [('eskår', False)],
          'eskårens': [('eskår', False)],
          'eskårs': [('eskår', False)],
          'eskårs-': [('eskår', False)],
          'eslag': [('eslag', False)],
          'eslagar': [('eslagare', False)],
          'eslagarna': [('eslagare', False)],
          'eslagarnas': [('eslagare', False)],
          'eslags': [('eslag', False)],
          'eslags-': [('eslag', False)],
          'eslan': [('esla', False)],
          'eslana': [('esla', False)],
          'eslanas': [('esla', False)],
          'eslanden': [('esland', False)],
          'eslandens': [('esland', False)],
          'eslandet': [('esland', False)],
          'eslans': [('esla', False)],
          'eslar': [('esel', False)],
          'eslarna': [('esel', False)],
          'eslarnas': [('esel', False)],
          'eslarv': [('eslarv', False)],
          'eslarv-': [('eslarv', False)],
          'eslarver': [('eslarv', False)],
          'eslarvers': [('eslarv', False)],
          'eslarvs': [('eslarv', False)],
          'eslarvs-': [('eslarv', False)],
          'eslas': [('esla', False)],
          'eslas-': [('esla', False)],
          'esläkten': [('esläkt', False)],
          'esläktens': [('esläkt', False)],
          'esläkts': [('esläkt', False)],
          'esläkts-': [('esläkt', False)],
          'esmodet': [('esmod', False)],
          'esmodets': [('esmod', False)],
          'esmäll': [('esmäll', False)],
          'esmäll-': [('esmäll', False)],
          'esmällar': [('esmäll', False)],
          'esmällarna': [('esmäll', False)],
          'esmällarnas': [('esmäll', False)],
          'esmälls': [('esmäll', False)],
          'esmälls-': [('esmäll', False)],
          'esnacks': [('esnack', False)],
          'esnacks-': [('esnack', False)],
          'esnåret': [('esnåret', False)],
          'esnårets': [('esnåret', False)],
          'esolverande': [('esolverande', False)],
          'esolverande-': [('esolverande', False)],
          'esområdet': [('esområde', False)],
          'eson': [('eson', False)],
          'esoner': [('eson', False)],
          'esonerna': [('eson', False)],
          'esonernas': [('eson', False)],
          'esoners': [('eson', False)],
          'esons': [('eson', False)],
          'esopp': [('esoppa', False)],
          'esopp-': [('esoppa', False)],
          'esopps': [('esoppa', False)],
          'esopps-': [('esoppa', False)],
          'esor': [('esa', False)],
          'esorna': [('eso', False)],
          'esornas': [('esa', False)],
          'esors': [('esa', False)],
          'esp': [('espa', False)],
          'esp-': [('espa', False)],
          'espe': [('espa', False)],
          'espe-': [('espa', False)],
          'espirator': [('espirator', False)],
          'espirators': [('espirator', False)],
          'espolar': [('espolare', False)],
          'espolarna': [('espolare', False)],
          'espolarnas': [('espolare', False)],
          'espolitikerna': [('espolitiker', False)],
          'espor': [('espa', False)],
          'espors': [('espa', False)],
          'espottar': [('espottare', False)],
          'espottarna': [('espottare', False)],
          'espottarnas': [('espottare', False)],
          'esprit': [('esprit', True)],
          'esprits': [('esprit', True)],
          'esringar': [('esring', False)],
          'esros': [('esro', False)],
          'ess': [('ess', True)],
          'ess-': [('ess', False)],
          'essans': [('essa', False)],
          'essar-': [('essare', False)],
          'essaren': [('essar', False)],
          'essarens': [('essare', False)],
          'essarierna': [('essario', False)],
          'essariernas': [('essario', False)],
          'essariers': [('essario', False)],
          'essarna': [('ess', False)],
          'essarnas': [('ess', False)],
          'essars': [('essar', False)],
          'essats': [('essat', False)],
          'essats-': [('essat', False)],
          'esse': [('esse', False)],
          'esse-': [('esse', False)],
          'essen': [('ess', True)],
          'essena': [('essena', False)],
          'essenas': [('esse', False)],
          'essens': [('essens', True), ('ess', True)],
          'essenter': [('essent', False)],
          'essenterna': [('essent', False)],
          'essenternas': [('essent', False)],
          'essenters': [('essent', False)],
          'esserierna': [('esseri', False)],
          'esset': [('ess', True)],
          'essets': [('ess', False)],
          'essin': [('essin', False)],
          'essiver': [('essiv', False)],
          'essivers': [('essiv', True)],
          'esslandets': [('essland', False)],
          'essle': [('essla', False)],
          'essle-': [('essla', False)],
          'esslor': [('essla', False)],
          'esslorna': [('essla', False)],
          'esslornas': [('essla', False)],
          'esslors': [('essla', False)],
          'esso': [('esso', False)],
          'esson': [('esso', False)],
          'essons': [('esso', False)],
          'essor': [('essor', False)],
          'essors': [('essor', False)],
          'esspinnar': [('esspinnare', False)],
          'esspinnarna': [('esspinnare', False)],
          'esspinnarnas': [('esspinnare', False)],
          'essteg': [('essteg', False)],
          'essylt': [('essylta', False)],
          'est': [('est', True)],
          'est-': [('est', True)],
          'esta': [('esta', False)],
          'esta-': [('esta', False)],
          'estadie': [('estadium', False)],
          'estadie-': [('estadium', False)],
          'estadier': [('estadium', False)],
          'estadierna': [('estadium', False)],
          'estadiernas': [('estadium', False)],
          'estadiers': [('estadium', False)],
          'estadiet': [('estadium', False)],
          'estadiets': [('estadium', False)],
          'estadium': [('estadium', False)],
          'estadiums': [('estadium', False)],
          'estalets': [('estal', False)],
          'estalter': [('estalt', False)],
          'estalterna': [('estalt', False)],
          'estalternas': [('estalt', False)],
          'estalters': [('estalt', False)],
          'estalts': [('estalt', False)],
          'estalts-': [('estalt', False)],
          'estamentets': [('estamente', False)],
          'estaments': [('estamente', False)],
          'estan': [('esta', False)],
          'estans': [('estad', False)],
          'estar': [('estare', False)],
          'estar-': [('estare', False)],
          'estarna': [('estare', False)],
          'estarnas': [('est', False)],
          'estars': [('est', False)],
          'estas': [('esta', False)],
          'estator': [('estator', False)],
          'estavarna': [('estav', False)],
          'estdags': [('estdag', False)],
          'estdags-': [('estdag', False)],
          'esteg': [('esteg', False)],
          'estegen': [('esteg', False)],
          'estegens': [('esteg', False)],
          'estegs': [('esteg', False)],
          'estegs-': [('esteg', False)],
          'esten': [('est', True)],
          'estens': [('est', False)],
          'ester': [('est', True), ('ester', True)],
          'estern': [('ester', True)],
          'esterna': [('est', True)],
          'esternas': [('est', True)],
          'esterns': [('ester', True)],
          'esters': [('est', True), ('ester', True)],
          'estet': [('estet', True)],
          'estets': [('estet', True)],
          'esti': [('esti', False)],
          'esti-': [('esti', False)],
          'estick': [('estick', False)],
          'estick-': [('estick', False)],
          'esticks': [('estick', False)],
          'esticks-': [('estick', False)],
          'estigar': [('estigare', False)],
          'estigarna': [('estigare', False)],
          'estigarnas': [('estigare', False)],
          'estigen': [('estige', False)],
          'estigens': [('estige', False)],
          'estilens': [('estilens', False)],
          'estins': [('esti', False)],
          'estis': [('estis', False)],
          'estis-': [('estis', False)],
          'estol': [('estol', False)],
          'estols': [('estol', False)],
          'estols-': [('estol', False)],
          'eston': [('esto', False)],
          'estons': [('eston', False)],
          'estons-': [('eston', False)],
          'estor': [('esta', False)],
          'estorer': [('estor', False)],
          'estorerna': [('estor', False)],
          'estorernas': [('estor', False)],
          'estorers': [('estor', False)],
          'estorian': [('estorian', False)],
          'estorians': [('estorian', False)],
          'estors': [('estor', False)],
          'estos': [('estos', False)],
          'estos-': [('estos', False)],
          'estranden': [('estrande', False)],
          'estrandens': [('estrande', False)],
          'estrans': [('estra', False)],
          'estrar': [('ester', True)],
          'estrarna': [('ester', True)],
          'estrarnas': [('ester', False)],
          'estrip': [('estrip', False)],
          'estripp': [('estripp', False)],
          'estripps': [('estripp', False)],
          'estripps-': [('estripp', False)],
          'estrips': [('estrip', False)],
          'estrips-': [('estrip', False)],
          'estrums': [('estrum', False)],
          'estudie': [('estudium', False)],
          'estudie-': [('estudium', False)],
          'estudier': [('estudium', False)],
          'estudierna': [('estudium', False)],
          'estudiernas': [('estudium', False)],
          'estudiers': [('estudium', False)],
          'estupor': [('estupa', False)],
          'estupors': [('estupa', False)],
          'estycken': [('estycke', False)],
          'estyckena': [('estycke', False)],
          'estyckenas': [('estycke', False)],
          'estyckens': [('estycke', False)],
          'estycket': [('estycke', False)],
          'estyckets': [('estycke', False)],
          'estylens': [('estyle', False)],
          'estyren': [('estyr', False)],
          'estyrens': [('estyr', False)],
          'estyret': [('estyr', False)],
          'estyrets': [('estyr', False)],
          'estyrkan': [('estyrka', False)],
          'estyrke': [('estyrka', False)],
          'eställanden': [('eställande', False)],
          'eställandena': [('eställande', False)],
          'eställandenas': [('eställande', False)],
          'eställandens': [('eställande', False)],
          'eställen': [('eställ', False)],
          'eställens': [('eställ', False)],
          'estället': [('eställ', False)],
          'eställets': [('eställ', False)],
          'eställningar': [('eställning', False)],
          'eställningarna': [('eställning', False)],
          'eställningarnas': [('eställning', False)],
          'eställningars': [('eställning', False)],
          'eställnings': [('eställning', False)],
          'eställnings-': [('eställning', False)],
          'estötarnas': [('estöt', False)],
          'esur': [('esur', False)],
          'esur-': [('esur', False)],
          'esval': [('esval', False)],
          'esval-': [('esval', False)],
          'esvalen': [('esval', False)],
          'esvalens': [('esval', False)],
          'esvals': [('esval', False)],
          'esvals-': [('esval', False)],
          'esvanor': [('esvana', False)],
          'esvanorna': [('esvana', False)],
          'esvanornas': [('esvana', False)],
          'esvanors': [('esvana', False)],
          'esvar': [('esvara', False)],
          'esvarvar': [('esvarv', False)],
          'esvarvarna': [('esvarv', False)],
          'esvarvarnas': [('esvarv', False)],
          'esverken': [('esverk', False)],
          'esverkens': [('esverk', False)],
          'esverket': [('esverk', False)],
          'esverks': [('esverk', False)],
          'esverks-': [('esverk', False)],
          'esvägens': [('esväg', False)],
          'esvärden': [('esvärde', False)],
          'esvärdens': [('esvärde', False)],
          'esvärdet': [('esvärde', False)],
          'esvärdets': [('esvärde', False)],
          'esyns': [('esyn', False)],
          'esyre': [('esyra', False)],
          'esyre-': [('esyra', False)],
          'esyren': [('esyr', False)],
          'esyrens': [('esyr', False)],
          'esyrs': [('esyr', False)],
          'esyrs-': [('esyr', False)],
          'esäll': [('esäll', False)],
          'esäll-': [('esäll', False)],
          'esällen': [('esäll', False)],
          'esällens': [('esäll', False)],
          'esälls': [('esäll', False)],
          'esälls-': [('esäll', False)],
          'esändar': [('esändare', False)],
          'esändarna': [('esändare', False)],
          'esås': [('esås', False)],
          'esås-': [('esås', False)],
          'esömmar': [('esöm', False)],
          'esömmarna': [('esöm', False)],
          'esömmarnas': [('esöm', False)],
          'et': [('', False)],
          'et-': [('et', False)],
          'eta': [('eta', True)],
          'etagen': [('etage', True)],
          'etagens': [('etage', True)],
          'etaget': [('etage', True)],
          'etagets': [('etage', False)],
          'etak': [('etak', False)],
          'etaken': [('etak', False)],
          'etaket': [('etak', False)],
          'etalanden': [('etalande', False)],
          'etalandenas': [('etalande', False)],
          'etalandens': [('etalande', False)],
          'etalar': [('etalare', False)],
          'etalar-': [('etalare', False)],
          'etalaren': [('etalare', False)],
          'etalarens': [('etalare', False)],
          'etalen': [('etal', False)],
          'etalens': [('etal', False)],
          'etalet': [('etal', False)],
          'etalj': [('etalj', False)],
          'etalj-': [('etalj', False)],
          'etaljs': [('etalj', False)],
          'etaljs-': [('etalj', False)],
          'etan': [('etan', True), ('eta', True)],
          'etan-': [('etan', False)],
          'etana': [('eta', True)],
          'etanas': [('eta', True)],
          'etanden': [('etande', False)],
          'etandens': [('etande', False)],
          'etanis': [('etani', False)],
          'etanis-': [('etanis', False)],
          'etank-': [('etank', False)],
          'etankar': [('etank', False)],
          'etankarna': [('etank', False)],
          'etankarnas': [('etank', False)],
          'etankars': [('etank', False)],
          'etanken': [('etank', False)],
          'etankens': [('etank', False)],
          'etankerna': [('etanker', False)],
          'etankernas': [('etanker', False)],
          'etankers': [('etanker', False)],
          'etanks': [('etank', False)],
          'etanks-': [('etank', False)],
          'etans': [('etan', True), ('eta', True)],
          'etans-': [('etan', False)],
          'etants': [('etant', False)],
          'etar': [('et', False)],
          'etaren': [('etare', False)],
          'etarierna': [('etarium', False)],
          'etariers': [('etarium', False)],
          'etarna': [('et', False)],
          'etarnas': [('etare', False)],
          'etars': [('et', False)],
          'etas': [('eta', True)],
          'etat': [('eta', True)],
          'etatrons': [('etatron', False)],
          'etats': [('eta', True)],
          'ete': [('eta', False)],
          'ete-': [('eta', False)],
          'etekniker': [('eteknik', False)],
          'eteknikerna': [('eteknik', False)],
          'eteknikernas': [('eteknik', False)],
          'eteknikers': [('eteknik', False)],
          'eteln': [('etel', False)],
          'etelns': [('etel', False)],
          'etels': [('etel', False)],
          'eten': [('eten', True)],
          'etens': [('eten', True)],
          'etens-': [('etens', False)],
          'eter': [('eter', True)],
          'eter-': [('eter', False)],
          'eteranden': [('eterande', False)],
          'eterandens': [('eterande', False)],
          'eteri': [('eteria', False)],
          'eteri-': [('eteria', False)],
          'eterian': [('eteria', False)],
          'eterians': [('eteria', False)],
          'eterie-': [('eteria', False)],
          'eterier': [('eteri', False)],
          'eterierna': [('eteri', False)],
          'eteriernas': [('eteri', False)],
          'eteriets': [('eteri', False)],
          'eteris': [('eteria', False)],
          'eteris-': [('eteria', False)],
          'eteriternas': [('eteritum', False)],
          'eterits': [('eteri', False)],
          'etern': [('eter', False)],
          'eterna': [('et', False)],
          'eternas': [('et', False)],
          'eterns': [('eter', False)],
          'eters': [('eter', True)],
          'eters-': [('eter', False)],
          'etes': [('etes', False)],
          'etes-': [('etes', False)],
          'etesar': [('etes', False)],
          'etesarna': [('etes', False)],
          'etesarnas': [('etes', False)],
          'etestens': [('etest', False)],
          'etet': [('et', False)],
          'eteters': [('etet', False)],
          'etets': [('ete', False)],
          'ethet': [('ethet', False)],
          'ethets': [('ethet', False)],
          'etian': [('etia', False)],
          'etians': [('etia', False)],
          'etiden': [('etid', False)],
          'etidens': [('etiden', False)],
          'etider': [('etid', False)],
          'etiderna': [('etid', False)],
          'etiders': [('etid', False)],
          'etiet': [('etium', False)],
          'etighets': [('etighet', False)],
          'etik': [('etik', False)],
          'etik-': [('etik', False)],
          'etiker': [('etiker', True)],
          'etikerna': [('etiker', True)],
          'etikernas': [('etiker', True)],
          'etikers': [('etiker', True)],
          'etiks': [('etik', False)],
          'etiks-': [('etik', False)],
          'etillgångarna': [('etillgång', False)],
          'etillhörighets': [('etillhörighet', False)],
          'etillhörighets-': [('etillhörighet', False)],
          'etin': [('eti', False)],
          'etin-': [('etin', False)],
          'etinens': [('etin', False)],
          'etiner': [('etin', False)],
          'etinerna': [('etin', False)],
          'etinernas': [('etin', False)],
          'etiners': [('etin', False)],
          'etins': [('etin', False)],
          'etions-': [('etion', False)],
          'etior': [('etia', False)],
          'etis': [('eti', False)],
          'etit': [('etit', False)],
          'etit-': [('etit', False)],
          'etitan': [('etita', False)],
          'etitans': [('etita', False)],
          'etits': [('etit', False)],
          'etittar': [('etittare', False)],
          'etittarna': [('etittare', False)],
          'etittarnas': [('etittare', False)],
          'etjen': [('etjen', False)],
          'etjens': [('etjen', False)],
          'etklubb': [('etklubba', False)],
          'etklubb-': [('etklubba', False)],
          'etklubbs': [('etklubba', False)],
          'etklubbs-': [('etklubba', False)],
          'etman': [('etma', False)],
          'etmans': [('etman', False)],
          'etmask': [('etmask', False)],
          'etmask-': [('etmask', False)],
          'etmin': [('etmina', False)],
          'eto-': [('eto', False)],
          'etolkar': [('etolkare', False)],
          'etolkarna': [('etolkare', False)],
          'etolkarnas': [('etolkare', False)],
          'eton': [('eton', False)],
          'etoner': [('eton', False)],
          'etonerna': [('eton', False)],
          'etonernas': [('eton', False)],
          'etoners': [('eton', False)],
          'etons': [('eton', False)],
          'etor': [('eta', False)],
          'etorer': [('etor', False)],
          'etorerna': [('etor', False)],
          'etorernas': [('etor', False)],
          'etorers': [('etor', False)],
          'etorkar': [('etorkare', False)],
          'etorkarna': [('etorkare', False)],
          'etorkarnas': [('etorkare', False)],
          'etorn': [('etor', False)],
          'etorna': [('eta', False)],
          'etornas': [('eta', False)],
          'etorns': [('etor', False)],
          'etors': [('eta', False)],
          'etort': [('etort', False)],
          'etort-': [('etort', False)],
          'etorts': [('etort', False)],
          'etos': [('etos', False)],
          'etos-': [('etos', False)],
          'etra': [('etra', False)],
          'etrams': [('etrams', False)],
          'etran': [('etra', False)],
          'etrans': [('etra', False)],
          'etrar': [('eter', False)],
          'etrarna': [('eter', False)],
          'etrars': [('eter', False)],
          'etras': [('etra', False)],
          'etratt': [('etratt', False)],
          'etratts': [('etratt', False)],
          'etratts-': [('etratt', False)],
          'etrems': [('etremsa', False)],
          'etrev': [('etrev', False)],
          'etrev-': [('etrev', False)],
          'etrevar': [('etrev', False)],
          'etrevarna': [('etrev', False)],
          'etrevarnas': [('etrev', False)],
          'etrevs-': [('etrev', False)],
          'etrier': [('etri', False)],
          'etrierna': [('etri', False)],
          'etriers': [('etri', False)],
          'etringar': [('etring', False)],
          'etringars': [('etring', False)],
          'etringens': [('etring', False)],
          'etrins': [('etri', False)],
          'etris': [('etri', False)],
          'etron': [('etro', False)],
          'etrons': [('etron', False)],
          'etropins': [('etropi', False)],
          'etror': [('etra', False)],
          'etrorna': [('etro', False)],
          'etrornas': [('etro', False)],
          'etrors': [('etro', False)],
          'etros': [('etro', False)],
          'etros-': [('etro', False)],
          'etrusker': [('etrusk', True), ('etrusker', True)],
          'etruskerna': [('etrusk', True), ('etrusker', True)],
          'etruskernas': [('etrusk', True), ('etrusker', True)],
          'etruskers': [('etrusk', True), ('etrusker', True)],
          'etrycken': [('etryck', False)],
          'etryckens': [('etryck', False)],
          'etrycket': [('etryck', False)],
          'etryckets': [('etryck', False)],
          'etrycks': [('etryck', False)],
          'etrycks-': [('etryck', False)],
          'eträd': [('eträd', False)],
          'eträd-': [('eträd', False)],
          'eträde': [('eträde', False)],
          'eträde-': [('eträde', False)],
          'eträden': [('eträde', False)],
          'eträdens': [('eträd', False)],
          'eträdet': [('eträde', False)],
          'eträdets': [('eträd', False)],
          'eträds': [('eträd', False)],
          'eträn': [('eträd', False)],
          'eträna': [('eträd', False)],
          'etränas': [('eträd', False)],
          'eträns': [('eträd', False)],
          'eträt': [('eträ', False)],
          'eträts': [('eträ', False)],
          'ets-': [('et', False)],
          'etsar': [('etsare', False)],
          'etsar-': [('etsare', False)],
          'etsaren': [('etsare', False)],
          'etsarens': [('etsare', False)],
          'etsarna': [('etsare', False)],
          'etsarnas': [('etsare', True)],
          'etsars': [('ets', False)],
          'etsbasar': [('etsbasar', False)],
          'etsbasars': [('etsbasar', False)],
          'etscher': [('etscher', False)],
          'etschers': [('etscher', False)],
          'etsen': [('et', False)],
          'etsens': [('et', False)],
          'etset': [('etset', False)],
          'etsets': [('etset', False)],
          'etsflagg': [('etsflagg', False)],
          'etsflaggs': [('etsflagg', False)],
          'etsflaggs-': [('etsflagga', False)],
          'etslagar': [('etslag', False)],
          'etslagarna': [('etslag', False)],
          'etslagarnas': [('etslag', False)],
          'etslins-': [('etslina', False)],
          'etslopp': [('etsloppa', False)],
          'etslopps': [('etsloppa', False)],
          'etslopps-': [('etsloppa', False)],
          'etspats': [('etspa', False)],
          'etssamhällena': [('etssamhälle', False)],
          'etsteg': [('etsteg', False)],
          'etsticks': [('etsticka', False)],
          'etströmmen': [('etström', False)],
          'etsvanor': [('etsvanor', False)],
          'etsvanorna': [('etsvanor', False)],
          'etsvanornas': [('etsvanor', False)],
          'ettan': [('etta', False)],
          'ettar': [('ette', False)],
          'ettarna': [('ett', False)],
          'ettarnas': [('ett', False)],
          'ettars': [('ette', False)],
          'ette': [('ette', False)],
          'ette-': [('etta', False)],
          'ettens': [('ett', False)],
          'etter': [('etter', True)],
          'etteriers': [('etteri', False)],
          'ettermyr': [('ettermyra', True)],
          'ettermyr-': [('ettermyra', True)],
          'ettermyrs': [('ettermyra', True)],
          'ettermyrs-': [('ettermyra', True)],
          'etters': [('etter', True)],
          'ettets': [('ett', False)],
          'etti': [('etti', False)],
          'ettiden': [('ettiden', True)],
          'ettidens': [('ettiden', True)],
          'ettigheter': [('ettighet', False)],
          'ettigheterna': [('ettighet', False)],
          'ettigheternas': [('ettighet', False)],
          'ettigheters': [('ettighet', False)],
          'ettighets-': [('ettighet', False)],
          'ettis': [('etti', False)],
          'ettits': [('ettit', False)],
          'ettlanden': [('ettlande', False)],
          'ettlandens': [('ettlande', False)],
          'ettlandet': [('ettlande', False)],
          'ettlandets': [('ettland', False)],
          'etto': [('etto', False)],
          'ettor': [('etta', True)],
          'ettorna': [('etta', True)],
          'ettornas': [('etta', True)],
          'ettors': [('etta', True)],
          'ettrarnas': [('etter', False)],
          'ettsaks': [('ettsaker', False)],
          'ettsaks-': [('ettsaker', False)],
          'etum': [('etum', False)],
          'etum-': [('etum', False)],
          'etumen': [('etum', False)],
          'etumens': [('etum', False)],
          'etums': [('etum', False)],
          'etur': [('etur', False)],
          'eturerna': [('etur', False)],
          'eturernas': [('etur', False)],
          'eturers': [('etur', False)],
          'eturs': [('etur', False)],
          'eturs-': [('etur', False)],
          'etvingar': [('etvingare', False)],
          'etvingarna': [('etvingare', False)],
          'etvingarnas': [('etvingare', False)],
          'etyd': [('etyd', True)],
          'etyd-': [('etyd', True)],
          'etyds': [('etyd', True)],
          'etylen': [('etylen', True), ('etyl', True)],
          'etylens': [('etylen', True), ('etyl', True)],
          'etyn': [('etyn', True)],
          'etyns': [('etyn', True)],
          'etypen': [('etyp', False)],
          'etypens': [('etyp', False)],
          'etyper': [('etyp', False)],
          'etyperna': [('etyp', False)],
          'etypernas': [('etyp', False)],
          'etyr': [('etyr', False)],
          'etyr-': [('etyr', False)],
          'etyren': [('etyr', False)],
          'etyrens': [('etyr', False)],
          'etyrer': [('etyr', False)],
          'etyrerna': [('etyr', False)],
          'etyrernas': [('etyr', False)],
          'etyrers': [('etyr', False)],
          'etyrs': [('etyr', False)],
          'etysk': [('etyska', False)],
          'etysk-': [('etyska', False)],
          'etåg': [('etåg', False)],
          'etågs': [('etåg', False)],
          'etågs-': [('etåg', False)],
          'etår': [('etår', False)],
          'etårar': [('etår', False)],
          'etårars': [('etår', False)],
          'etårs': [('etår', False)],
          'etårs-': [('etår', False)],
          'eudd': [('eudd', False)],
          'eudd-': [('eudd', False)],
          'euddar': [('eudd', False)],
          'euddarna': [('eudd', False)],
          'euddarnas': [('eudd', False)],
          'euddars': [('eudd', False)],
          'eudden': [('eudd', False)],
          'euddens': [('eudd', False)],
          'eudds': [('eudd', False)],
          'eudds-': [('eudd', False)],
          'eundrarnas': [('eundrare', False)],
          'euron': [('euro', True)],
          'eurons': [('euro', True)],
          'euros': [('euro', True)],
          'euros-': [('euro', True)],
          'euse': [('euse', False)],
          'euse-': [('euse', False)],
          'eusen': [('euse', False)],
          'eusens': [('euse', False)],
          'euser': [('euse', False)],
          'euserna': [('euse', False)],
          'eusernas': [('euse', False)],
          'eusers': [('euse', False)],
          'eusins': [('eusi', False)],
          'eussarna': [('eussare', False)],
          'eussarnas': [('eussare', False)],
          'euteriets': [('euterium', False)],
          'eutiker': [('eutiker', False)],
          'eutikerna': [('eutiker', False)],
          'eutikernas': [('eutiker', False)],
          'eutikers': [('eutiker', False)],
          'eutredarna': [('utredare', False)],
          'ev': [('eva', True)],
          'ev-': [('eva', True)],
          'evadar': [('evad', False)],
          'evadarna': [('evad', False)],
          'evadarnas': [('evad', False)],
          'evader': [('evad', False)],
          'evaders': [('evad', False)],
          'eval': [('eval', False)],
          'eval-': [('eval', False)],
          'evalarna': [('eval', False)],
          'evalen': [('eval', False)],
          'evalens': [('eval', False)],
          'evals': [('eval', False)],
          'evals-': [('eval', False)],
          'evan': [('eva', False)],
          'evana': [('eva', False)],
          'evanas': [('eva', False)],
          'evans': [('eva', False)],
          'evans-': [('evans', False)],
          'evar': [('ev', False)],
          'evar-': [('evara', False)],
          'evaran': [('evara', False)],
          'evarans': [('evara', False)],
          'evard': [('evard', False)],
          'evard-': [('evard', False)],
          'evarden': [('evard', False)],
          'evardens': [('evard', False)],
          'evards': [('evard', False)],
          'evards-': [('evard', False)],
          'evaren': [('evare', False)],
          'evarna': [('ev', False)],
          'evas': [('eva', False)],
          'evas-': [('eva', False)],
          'evaskar': [('evaskare', False)],
          'evaskarna': [('evaskare', False)],
          'evaskarnas': [('evaskare', False)],
          'eve': [('eva', False)],
          'eve-': [('eva', True)],
          'evearnas': [('eve', False)],
          'evears': [('eve', False)],
          'evel': [('evel', False)],
          'evel-': [('evel', False)],
          'evels': [('evel', False)],
          'evels-': [('evel', False)],
          'even': [('ev', False)],
          'evens': [('ev', False)],
          'everande': [('everande', False)],
          'everande-': [('everande', False)],
          'everkets': [('everk', False)],
          'evern': [('ever', False)],
          'everna': [('ev', False)],
          'evernas': [('ev', False)],
          'everne': [('everne', False)],
          'everns': [('ever', False)],
          'evers-': [('ever', False)],
          'eversen': [('evers', False)],
          'evet': [('ev', False)],
          'evidens': [('evidens', True)],
          'evier': [('evier', False)],
          'eviers': [('evier', False)],
          'eviet': [('evium', False)],
          'eviets': [('evium', False)],
          'evik': [('evik', False)],
          'evik-': [('evik', False)],
          'eviks-': [('evik', False)],
          'evill': [('evill', False)],
          'evill-': [('evill', False)],
          'eville': [('eville', False)],
          'eville-': [('eville', False)],
          'evills': [('evilla', False)],
          'evin': [('evin', False)],
          'evin-': [('evin', False)],
          'evind': [('evind', False)],
          'evind-': [('evind', False)],
          'evindar': [('evindare', False)],
          'evindarna': [('evindare', False)],
          'evindarnas': [('evindare', False)],
          'evinds': [('evind', False)],
          'evinds-': [('evind', False)],
          'evinkar': [('evinker', False)],
          'evinkarna': [('evinker', False)],
          'evinkarnas': [('evinker', False)],
          'evinkars': [('evinker', False)],
          'evinker': [('evinker', False)],
          'evinkers': [('evinker', False)],
          'evins': [('evin', False)],
          'evins-': [('evin', False)],
          'evinsten': [('evinst', False)],
          'evinstens': [('evinst', False)],
          'evir': [('evir', False)],
          'evir-': [('evir', False)],
          'evirs': [('evir', False)],
          'evirs-': [('evir', False)],
          'evis': [('evis', False)],
          'evis-': [('evis', False)],
          'evisa': [('evisa', False)],
          'evisar': [('evisare', False)],
          'evisarna': [('evisare', False)],
          'evisarnas': [('evisare', False)],
          'evisas': [('evisum', False)],
          'evise': [('evisa', False)],
          'evisen': [('evis', False)],
          'evisens': [('evis', False)],
          'evisor': [('evisa', False)],
          'evisors': [('evisor', False)],
          'evispar': [('evisp', False)],
          'evisparna': [('evisp', False)],
          'evisparnas': [('evisp', False)],
          'evispars': [('evisp', False)],
          'evit': [('evit', False)],
          'evit-': [('evit', False)],
          'eviten': [('evit', False)],
          'evitens': [('evit', False)],
          'eviter': [('evit', False)],
          'eviterna': [('evit', False)],
          'eviters': [('evit', False)],
          'evits': [('evit', False)],
          'evlar': [('evel', False)],
          'evlaren': [('evlar', False)],
          'evlarna': [('evel', False)],
          'evlarnas': [('evel', False)],
          'evlars': [('evlar', False)],
          'evlingen': [('evling', False)],
          'evlingens': [('evling', False)],
          'evon': [('evon', False)],
          'evor': [('eva', False)],
          'evorna': [('eva', False)],
          'evornas': [('eva', False)],
          'evors': [('eva', False)],
          'evrar': [('ever', False)],
          'evrarna': [('ever', False)],
          'evs': [('eva', True)],
          'evs-': [('eva', True)],
          'evten': [('evt', False)],
          'evtens': [('evt', False)],
          'evägar': [('eväg', False)],
          'evägarna': [('eväg', False)],
          'evägarnas': [('eväg', False)],
          'evägs': [('eväg', False)],
          'evärden': [('evärde', False)],
          'evärdens': [('evärde', False)],
          'evärdet': [('evärde', False)],
          'eväsendet': [('eväsen', False)],
          'eväsendets': [('eväsen', False)],
          'evävar': [('eväv', False)],
          'evävarna': [('eväv', False)],
          'evävarnas': [('eväv', False)],
          'eväxlar': [('eväxel', False)],
          'eväxlarna': [('eväxlare', False)],
          'eväxlarnas': [('eväxel', False)],
          'ewn': [('ew', False)],
          'ex': [('ex', False)],
          'ex-': [('ex', False)],
          'exar': [('ex', False)],
          'exarna': [('ex', False)],
          'exarnas': [('ex', False)],
          'exars': [('ex', False)],
          'exe': [('exa', False)],
          'exe-': [('exa', False)],
          'exen': [('ex', False)],
          'exens': [('ex', False)],
          'exer': [('ex', False)],
          'exerna': [('ex', False)],
          'exernas': [('ex', False)],
          'exers': [('ex', False)],
          'exet': [('ex', False)],
          'exin': [('exin', True)],
          'exins': [('exin', True)],
          'existens': [('existens', False)],
          'exit': [('exit', False)],
          'exits': [('exit', False)],
          'exorna': [('exa', False)],
          'exornas': [('exa', False)],
          'extiden': [('extiden', False)],
          'extidens': [('extid', False)],
          'ey': [('ey', False)],
          'ey-': [('ey', False)],
          'eyar': [('ey', False)],
          'eyarna': [('ey', False)],
          'eyen': [('ey', False)],
          'eyens': [('ey', False)],
          'eyer': [('ey', False)],
          'eyerna': [('ey', False)],
          'eyernas': [('ey', False)],
          'eyers': [('ey', False)],
          'eykor': [('eyko', False)],
          'eykorna': [('eyko', False)],
          'eykornas': [('eyko', False)],
          'eykors': [('eyko', False)],
          'eykos': [('eyko', False)],
          'eykos-': [('eyko', False)],
          'eyn': [('ey', False)],
          'eyns': [('ey', False)],
          'eys': [('ey', False)],
          'eysarna': [('ey', False)],
          'eysen': [('ey', False)],
          'eysens': [('ey', False)],
          'ez': [('ez', False)],
          'ezer': [('ez', False)],
          'ezers': [('ez', False)],
          'ezon': [('ezon', False)],
          'ezonens': [('ezon', False)],
          'eägar': [('eägare', False)],
          'eägarna': [('eägare', False)],
          'eägarnas': [('eägare', False)],
          'eätt': [('eätt', False)],
          'eätt-': [('eätt', False)],
          'eätten': [('eätt', False)],
          'eätter': [('eätt', False)],
          'eätters': [('eätt', False)],
          'eätts': [('eätt', False)],
          'eätts-': [('eätt', False)],
          'eår': [('eår', False)],
          'eårs': [('eår', False)],
          'eårs-': [('eår', False)],
          'eés': [('eés', False)],
          'eögon': [('eögon', False)],
          'eögonen': [('eögon', False)],
          'eögonens': [('eögon', False)],
          'eögons': [('eögon', False)],
          'eörten': [('eört', False)],
          'f': [('f', True)],
          'f-': [('f', True)],
          'fa': [('fa', False)],
          'fa-': [('fa', False)],
          'fabet': [('fabet', False)],
          'fabets': [('fabet', False)],
          'fablandet': [('fablande', True)],
          'fablandets': [('fablande', True)],
          'fack-': [('fack', False)],
          'facken': [('fack', True)],
          'fackens': [('fack', False)],
          'facket': [('fack', False)],
          'fackets': [('fack', True)],
          'facks': [('fack', False)],
          'facks-': [('fack', False)],
          'faddrar': [('fadder', True)],
          'faddrarna': [('fadder', True)],
          'fader': [('fader', True), ('far', True)],
          'fader-': [('far', True), ('fader', True)],
          'fadern': [('fader', True), ('far', True)],
          'faderns': [('fader', True), ('far', True)],
          'faders': [('far', True), ('fader', True)],
          'faders-': [('fader', True), ('far', True)],
          'fage': [('fage', False)],
          'fage-': [('fage', False)],
          'fagens': [('fag', False)],
          'fager': [('fag', False)],
          'fagerna': [('fag', False)],
          'fagernas': [('fag', False)],
          'faget': [('fage', False)],
          'fagis': [('fagi', False)],
          'faires': [('faire', False)],
          'faires-': [('faires', False)],
          'fajter': [('fajt', True), ('fajter', True)],
          'fajterna': [('fajt', True), ('fajter', True)],
          'fajternas': [('fajt', True), ('fajter', True)],
          'fajters': [('fajt', True), ('fajter', True)],
          'fakins': [('faki', False)],
          'faksimilen': [('faksimile', True), ('faksimil', True)],
          'faksimilens': [('faksimile', True), ('faksimil', True)],
          'faksimiler': [('faksimil', True), ('faksimile', True)],
          'faksimilerna': [('faksimil', True), ('faksimile', True)],
          'faksimilernas': [('faksimil', True), ('faksimile', True)],
          'faksimilers': [('faksimil', True), ('faksimile', True)],
          'fakta': [('faktum', True), ('fakta', True)],
          'faktana': [('faktum', True)],
          'faktanas': [('faktum', True)],
          'faktas': [('faktum', True), ('fakta', True)],
          'fakten': [('fakt', False)],
          'fakter': [('fakt', False)],
          'fakters': [('fakt', False)],
          'faktorer': [('faktor', False)],
          'faktorers': [('faktor', False)],
          'faktur': [('faktur', True), ('faktura', True)],
          'faktur-': [('faktura', True), ('faktur', True)],
          'fakturs': [('faktura', True), ('faktur', True)],
          'fakturs-': [('faktura', False)],
          'falder': [('fald', False)],
          'falders': [('fald', False)],
          'falien': [('fali', False)],
          'falier': [('fali', False)],
          'falierna': [('fali', False)],
          'faliernas': [('fali', False)],
          'faliers': [('fali', False)],
          'falins': [('fali', False)],
          'falk': [('falk', False)],
          'falk-': [('falk', False)],
          'falkar': [('falk', False)],
          'falkarna': [('falk', False)],
          'falker': [('falk', False)],
          'falkers': [('falk', False)],
          'falks': [('falk', False)],
          'falks-': [('falk', False)],
          'fall': [('fall', False)],
          'fall-': [('fall', False)],
          'fallanden': [('fallande', False)],
          'fallandens': [('fallande', False)],
          'fallandet': [('fallande', False)],
          'fallar': [('fallare', False)],
          'fallarna': [('fallare', False)],
          'fallarnas': [('fallare', False)],
          'fallen': [('fall', False)],
          'fallos': [('fallos', True)],
          'fallos-': [('fallos', True)],
          'falls': [('fall', False)],
          'falls-': [('fall', False)],
          'fals': [('fals', True)],
          'fals-': [('fals', True)],
          'falt-': [('falt', False)],
          'faltar': [('falt', False)],
          'faltarna': [('falt', False)],
          'faltarnas': [('falt', False)],
          'falter': [('falt', False)],
          'falterna': [('falt', False)],
          'falternas': [('falt', False)],
          'falters': [('falt', False)],
          'falts': [('falt', False)],
          'famin': [('fami', False)],
          'famins': [('fami', False)],
          'famlandet': [('famlande', True)],
          'famn': [('famn', True)],
          'famn-': [('famn', True)],
          'famnar': [('famn', True)],
          'famnarna': [('famn', False)],
          'famnars': [('famn', True)],
          'famnen': [('famn', False)],
          'famnens': [('famn', False)],
          'famns': [('famn', True)],
          'famns-': [('famn', True)],
          'fan': [('fan', True), ('fana', True)],
          'fan-': [('fana', True), ('fan', True)],
          'fana': [('fana', True)],
          'fanan': [('fana', True)],
          'fanans': [('fana', True)],
          'fanas': [('fana', True)],
          'fanden': [('fande', False)],
          'fandens': [('fande', False)],
          'fandets': [('fande', False)],
          'fanens': [('fan', True)],
          'faner': [('faner', False)],
          'faners': [('faner', False)],
          'fanets': [('fan', True)],
          'fang': [('fang', False)],
          'fang-': [('fang', False)],
          'fangen': [('fang', False)],
          'fangens': [('fang', False)],
          'fanger': [('fang', False)],
          'fangerna': [('fang', False)],
          'fangernas': [('fang', False)],
          'fangers': [('fang', False)],
          'fangs': [('fang', False)],
          'fangs-': [('fang', False)],
          'fani': [('fani', False)],
          'fani-': [('fani', False)],
          'fanien': [('fani', False)],
          'faniens': [('fani', False)],
          'fanier': [('fani', False)],
          'faniers': [('fani', False)],
          'fanin': [('fani', False)],
          'fanins': [('fani', False)],
          'fanis': [('fani', False)],
          'fanken': [('fanken', True)],
          'fankens': [('fanken', True)],
          'fanor': [('fana', False)],
          'fanorna': [('fana', False)],
          'fanornas': [('fana', False)],
          'fanors': [('fana', False)],
          'fans': [('fan', True), ('fana', True)],
          'fans-': [('fan', True), ('fana', True)],
          'fansarnas': [('fan', True)],
          'fansen': [('fan', True)],
          'fansens': [('fan', True)],
          'fanstalter': [('fanstalt', False)],
          'fanstalterna': [('fanstalt', False)],
          'fanstalternas': [('fanstalt', False)],
          'fanstalters': [('fanstalt', False)],
          'fanstalts': [('fanstalt', False)],
          'fanstalts-': [('fanstalt', False)],
          'fant': [('fant', False)],
          'fanten': [('fant', False)],
          'fantens': [('fant', False)],
          'fanter': [('fant', False)],
          'fanterna': [('fant', False)],
          'fanternas': [('fant', False)],
          'fanters': [('fant', False)],
          'fants-': [('fant', False)],
          'fapet': [('fapet', False)],
          'far': [('fara', True), ('far', True)],
          'far-': [('far', True), ('fara', True)],
          'faran': [('fara', False)],
          'farans': [('fara', False)],
          'farar': [('farare', False)],
          'fararna': [('farare', False)],
          'fararnas': [('farare', False)],
          'fard': [('fard', False)],
          'fard-': [('fard', False)],
          'fardagen': [('fardag', True)],
          'fardagens': [('fardag', True)],
          'farden': [('fard', False)],
          'fardens': [('fard', False)],
          'farder': [('fard', False)],
          'farderna': [('fard', False)],
          'fardernas': [('fard', False)],
          'farders': [('fard', False)],
          'fards': [('fard', False)],
          'fards-': [('fard', False)],
          'fare': [('fara', True)],
          'faren': [('fare', False)],
          'farenhets': [('farenhet', False)],
          'farenhets-': [('farenhet', False)],
          'farens': [('fare', False)],
          'fares': [('fare', False)],
          'farfar': [('farfar', True)],
          'farfars': [('farfar', True)],
          'farfars-': [('farfar', True)],
          'fari': [('fari', False)],
          'fari-': [('fari', False)],
          'farier': [('fari', False)],
          'farierna': [('fari', False)],
          'fariernas': [('fari', False)],
          'fariers': [('fari', False)],
          'farin': [('farin', True)],
          'farins': [('farin', True)],
          'faris': [('fari', False)],
          'faris-': [('fari', False)],
          'farisarna': [('fari', False)],
          'farisens': [('fari', False)],
          'farmar': [('farm', True), ('farmare', True)],
          'farmarna': [('farm', True), ('farmare', True)],
          'farmarnas': [('farmare', True), ('farm', True)],
          'farnas': [('f', False)],
          'faro-': [('fara', False)],
          'fars': [('farsa', True), ('far', True), ('fara', True), ('fars', True)],
          'fars-': [('farsa', True), ('fara', True), ('fars', True), ('far', True)],
          'farsens': [('fars', True)],
          'farser': [('fars', False)],
          'farsers': [('fars', True)],
          'fart': [('fart', False)],
          'farten': [('fart', False)],
          'fartens': [('fart', False)],
          'farter': [('fart', False)],
          'farterna': [('fart', False)],
          'farternas': [('fart', False)],
          'farters': [('fart', False)],
          'fartranden': [('fartrand', True)],
          'fartrandens': [('fartrand', True)],
          'farts': [('fart', False)],
          'farts-': [('fart', True)],
          'fas': [('fas', True)],
          'fas-': [('fas', False)],
          'fasan': [('fasa', True), ('fasan', True)],
          'fasans': [('fasa', True), ('fasan', True)],
          'fasen': [('fasen', True), ('fas', True)],
          'fasens': [('fasen', True), ('fas', True)],
          'fasier': [('fasi', False)],
          'fasierna': [('fasi', False)],
          'fasiernas': [('fasi', False)],
          'fasins': [('fasi', False)],
          'fasis': [('fasi', False)],
          'fasoner': [('fason', True)],
          'fasonerna': [('fason', True)],
          'fasonernas': [('fason', True)],
          'fasoners': [('fason', True)],
          'fastan': [('fastan', True), ('fasta', True)],
          'fastans': [('fastan', True), ('fasta', True)],
          'faste': [('fasta', True)],
          'faste-': [('fasta', True)],
          'fastlagsbull': [('fastlagsbulla', True), ('fastlagsbulle', True)],
          'fastlagsbull-': [('fastlagsbulle', True), ('fastlagsbulla', True)],
          'fastlagsbulle': [('fastlagsbulla', True), ('fastlagsbulle', True)],
          'fastlagsbulle-': [('fastlagsbulla', True), ('fastlagsbulle', True)],
          'fastlagsbulls': [('fastlagsbulla', True), ('fastlagsbulle', True)],
          'fastlagsbulls-': [('fastlagsbulla', True), ('fastlagsbulle', True)],
          'fastors': [('fasta', True)],
          'fat': [('fat', True)],
          'fatar': [('fatar', False)],
          'fataren': [('fatar', False)],
          'fatiker': [('fatiker', False)],
          'fatikerna': [('fatiker', False)],
          'fatikernas': [('fatiker', False)],
          'fatikers': [('fatiker', False)],
          'fator': [('fator', False)],
          'fators': [('fator', False)],
          'fats': [('fat', True)],
          'fats-': [('fat', False)],
          'fatt': [('fatt', False)],
          'fatt-': [('fatt', False)],
          'fattarna': [('fattare', False)],
          'fattarnas': [('fattare', False)],
          'fatts': [('fatt', False)],
          'faun': [('faun', True), ('fauna', True)],
          'faun-': [('faun', True), ('fauna', True)],
          'fauna': [('fauna', True)],
          'faunas': [('fauna', False)],
          'fauns': [('faun', True), ('fauna', True)],
          'fauns-': [('faun', True), ('fauna', True)],
          'favor': [('favo', True)],
          'favorna': [('favo', True)],
          'favornas': [('favo', True)],
          'favors': [('favo', True)],
          'fbanan': [('fbana', False)],
          'fbanans': [('fbana', False)],
          'fbane': [('fbana', False)],
          'fbane-': [('fbana', False)],
          'fbrons': [('fbro', False)],
          'fbräds': [('fbräda', False)],
          'fbräds-': [('fbräda', False)],
          'fbyx': [('fbyxa', False)],
          'fbyx-': [('fbyxa', False)],
          'fbyxorna': [('fbyxa', False)],
          'fbyxornas': [('fbyxa', False)],
          'fbåg': [('fbåge', False)],
          'fbåg-': [('fbåge', False)],
          'fbågs': [('fbåge', False)],
          'fbågs-': [('fbåge', False)],
          'fdomar': [('fdom', False)],
          'fdomarna': [('fdom', False)],
          'fdomarnas': [('fdom', False)],
          'fdomen': [('fdom', False)],
          'fe': [('fe', False)],
          'fe-': [('fe', True)],
          'fedags': [('fedags', False)],
          'fedags-': [('fedags', False)],
          'feen': [('fe', True)],
          'feens': [('fe', True)],
          'feer': [('fe', True)],
          'feerna': [('fe', True)],
          'feernas': [('fe', False)],
          'feers': [('fe', False)],
          'feet': [('fe', False)],
          'fejar': [('fejare', False)],
          'fejarna': [('fejare', False)],
          'fejarnas': [('fejare', False)],
          'fejden': [('fejd', False)],
          'fejdens': [('fejd', False)],
          'fejder': [('fejd', True)],
          'fejders': [('fejd', True)],
          'fekt': [('fekt', False)],
          'fekt-': [('fekt', False)],
          'fekten': [('fekt', False)],
          'fektens': [('fekt', False)],
          'fekter': [('fekt', False)],
          'fekterna': [('fektum', False)],
          'fekternas': [('fekt', False)],
          'fekters': [('fekt', False)],
          'fektiven': [('fektiv', False)],
          'fektivens': [('fektiv', False)],
          'fekts': [('fekt', False)],
          'fekts-': [('fekt', False)],
          'fel': [('fela', True), ('fel', True)],
          'fel-': [('fela', True), ('fel', True)],
          'felanden': [('felande', False)],
          'felandens': [('felande', True)],
          'felandets': [('felande', True)],
          'felblom': [('felblomma', False)],
          'felblom-': [('felblomma', False)],
          'felbloms': [('felblomma', False)],
          'felbloms-': [('felblomma', False)],
          'felbull': [('felbulle', False)],
          'felbulle': [('felbulle', False)],
          'felbulle-': [('felbulle', False)],
          'felbulls': [('felbulle', False)],
          'felbulls-': [('felbulle', False)],
          'felie': [('felium', False)],
          'fels': [('fel', True), ('fela', True)],
          'fels-': [('fel', True), ('fela', True)],
          'felvals': [('felval', True)],
          'felvals-': [('felval', True)],
          'fem': [('femma', False)],
          'fem-': [('femma', False)],
          'femien': [('femi', False)],
          'femiens': [('femi', False)],
          'femier': [('femi', False)],
          'femierna': [('femi', False)],
          'femiernas': [('femi', False)],
          'femiers': [('femi', False)],
          'feminister': [('feminist', False)],
          'feministers': [('feminist', False)],
          'femis': [('femi', False)],
          'femmans': [('femma', False)],
          'fems': [('femma', False)],
          'fems-': [('femma', False)],
          'fen': [('fe', True), ('f', True), ('fena', True)],
          'fen-': [('fena', True)],
          'fena': [('fena', True)],
          'fenans': [('fena', False)],
          'fenas': [('fena', True)],
          'fene': [('fena', False)],
          'fene-': [('fena', False)],
          'fenet': [('fen', False)],
          'fenets': [('fen', False)],
          'fenheter': [('fenhet', False)],
          'fenheterna': [('fenhet', False)],
          'fenheternas': [('fenhet', False)],
          'fenheters': [('fenhet', False)],
          'fenhets-': [('fenhet', False)],
          'fenomen': [('fenomen', False)],
          'fens': [('fena', True), ('fe', True), ('f', True)],
          'fens-': [('fena', False)],
          'fensen': [('fens', False)],
          'fensens': [('fens', False)],
          'fer': [('fer', False)],
          'ferens': [('ferens', False)],
          'feri': [('feri', False)],
          'feri-': [('feri', False)],
          'ferien': [('ferie', True)],
          'feriens': [('ferie', True)],
          'ferier': [('ferie', True)],
          'ferierna': [('ferie', True)],
          'feriernas': [('ferie', True)],
          'feriers': [('ferie', True)],
          'feriet': [('feri', False)],
          'ferins': [('feri', False)],
          'feris': [('feri', False)],
          'feris-': [('feri', False)],
          'ferit': [('feri', False)],
          'ferkist-': [('ferkista', False)],
          'fermat': [('fermat', True)],
          'fermats': [('fermat', True)],
          'feromon': [('feromoner', True), ('feromon', True)],
          'feromon-': [('feromon', True), ('feromoner', True)],
          'feromoner': [('feromoner', True), ('feromon', True)],
          'feromonerna': [('feromoner', True), ('feromon', True)],
          'feromonernas': [('feromoner', True), ('feromon', True)],
          'feromoners': [('feromoner', True), ('feromon', True)],
          'feromons': [('feromoner', True), ('feromon', True)],
          'fers': [('fer', False)],
          'fers-': [('fer', False)],
          'fersarnas': [('fer', False)],
          'fertens': [('fert', False)],
          'ferter': [('fert', False)],
          'ferters': [('fert', False)],
          'ferts': [('fert', False)],
          'ferts-': [('fert', False)],
          'fes': [('fe', False)],
          'fes-': [('fe', False)],
          'feskeden': [('fesked', False)],
          'fess': [('fess', False)],
          'fessen': [('fess', False)],
          'fessens': [('fess', False)],
          'fest-': [('fest', False)],
          'festen': [('fest', False)],
          'fester': [('fest', False)],
          'festerna': [('fest', False)],
          'festernas': [('fest', False)],
          'festers': [('fest', False)],
          'festet': [('fest', False)],
          'festets': [('fest', False)],
          'feston': [('feston', True)],
          'fet': [('f', True)],
          'feten': [('fet', False)],
          'fetens': [('fet', False)],
          'feter': [('fet', False)],
          'feters': [('fet', False)],
          'fetmans': [('fetma', False)],
          'feträden': [('feträd', False)],
          'feträdet': [('feträd', False)],
          'fets': [('f', True), ('fets', True)],
          'fets-': [('fets', True)],
          'fetsen': [('fets', True)],
          'fetsens': [('fets', True)],
          'fett': [('fett', False)],
          'fett-': [('fett', False)],
          'fetten': [('fett', False)],
          'fetter': [('fett', False)],
          'fetterna': [('fett', False)],
          'fetternas': [('fett', False)],
          'fetters': [('fett', False)],
          'fettisdagsbull': [('fettisdagsbulla', True), ('fettisdagsbulle', True)],
          'fettisdagsbull-': [('fettisdagsbulle', True), ('fettisdagsbulla', True)],
          'fettisdagsbulle': [('fettisdagsbulla', True), ('fettisdagsbulle', True)],
          'fettisdagsbulle-': [('fettisdagsbulla', True), ('fettisdagsbulle', True)],
          'fettisdagsbulls': [('fettisdagsbulla', True), ('fettisdagsbulle', True)],
          'fettisdagsbulls-': [('fettisdagsbulla', True), ('fettisdagsbulle', True)],
          'fetts': [('fett', False)],
          'fetts-': [('fett', False)],
          'ff': [('ff', False)],
          'ff-': [('ff', False)],
          'ffaires': [('ffaires', False)],
          'ffaktur': [('ffaktura', False)],
          'ffaktur-': [('ffaktura', False)],
          'ffakturs': [('ffaktura', False)],
          'ffan': [('ffa', False)],
          'ffans': [('ffa', False)],
          'ffar': [('ff', False)],
          'ffar-': [('ffare', False)],
          'ffare': [('ffare', False)],
          'ffarna': [('ff', False)],
          'ffars': [('ff', False)],
          'ffas': [('ffa', False)],
          'ffe': [('ffa', False)],
          'ffe-': [('ffa', False)],
          'ffekterna': [('ffekt', False)],
          'ffel': [('ffel', False)],
          'ffel-': [('ffel', False)],
          'ffels': [('ffel', False)],
          'ffels-': [('ffel', False)],
          'ffen': [('ff', False)],
          'ffena': [('ffe', False)],
          'ffenas': [('ffe', False)],
          'ffens': [('ffe', False)],
          'ffens-': [('ffens', False)],
          'ffer-': [('ffer', False)],
          'fferier': [('fferi', False)],
          'fferierna': [('fferi', False)],
          'fferiernas': [('fferi', False)],
          'fferiers': [('fferi', False)],
          'fferna': [('ff', False)],
          'ffernas': [('ff', False)],
          'ffers': [('ff', False)],
          'ffet': [('ff', False)],
          'ffets': [('ff', False)],
          'ffin': [('ffin', False)],
          'ffins': [('ffins', False)],
          'ffit': [('ffit', False)],
          'ffits': [('ffit', False)],
          'ffla': [('ffla', False)],
          'fflag': [('fflag', False)],
          'fflags': [('fflag', False)],
          'fflags-': [('fflag', False)],
          'fflar': [('ffel', False)],
          'fflarna': [('ffel', False)],
          'fflarnas': [('ffel', False)],
          'fflas': [('ffla', False)],
          'ffle': [('ffle', False)],
          'ffle-': [('ffla', False)],
          'ffles': [('ffle', False)],
          'fflin': [('ffli', False)],
          'ffling': [('ffling', False)],
          'fflings': [('ffling', False)],
          'fflings-': [('ffling', False)],
          'fflins': [('ffli', False)],
          'fflis': [('ffli', False)],
          'fflis-': [('ffli', False)],
          'fflit': [('ffli', False)],
          'fflits': [('ffli', False)],
          'fflon': [('fflon', False)],
          'fflons': [('fflon', False)],
          'fflor': [('fflor', False)],
          'fflor-': [('fflor', False)],
          'ffon': [('ffo', False)],
          'ffons': [('ffo', False)],
          'ffor': [('ffa', False)],
          'ffors': [('ffa', False)],
          'ffot': [('ffo', False)],
          'ffots': [('ffo', False)],
          'ffran': [('ffra', False)],
          'ffrans': [('ffra', False)],
          'ffrans-': [('ffran', False)],
          'ffras': [('ffra', False)],
          'ffre': [('ffra', False)],
          'ffre-': [('ffra', False)],
          'ffs': [('ff', False)],
          'ffs-': [('ff', False)],
          'ffärs': [('ffär', False)],
          'ffärs-': [('ffär', False)],
          'ffången': [('ffånge', False)],
          'ffångens': [('ffånge', False)],
          'ffören': [('fför', False)],
          'fförens': [('fför', False)],
          'fförs': [('fför', False)],
          'fförs-': [('fför', False)],
          'fhets': [('fhet', False)],
          'fhets-': [('fhet', False)],
          'fi': [('fi', False)],
          'fi-': [('fi', False)],
          'fialen': [('fial', True)],
          'fialens': [('fial', True)],
          'fian': [('fia', True)],
          'fian-': [('fian', False)],
          'fians': [('fia', True)],
          'fiber': [('fiber', False)],
          'fibers': [('fiber', False)],
          'fibierna': [('fibie', False)],
          'fibrins': [('fibrin', True)],
          'fibul': [('fibula', True)],
          'fibul-': [('fibula', True)],
          'fibuls': [('fibula', True)],
          'fibuls-': [('fibula', True)],
          'ficer': [('ficer', False)],
          'fichets': [('fiche', False)],
          'ficie': [('ficium', False)],
          'ficie-': [('ficium', False)],
          'ficierna': [('ficium', False)],
          'ficiernas': [('ficium', False)],
          'ficitet': [('ficit', False)],
          'ficitets': [('ficit', False)],
          'fick': [('ficka', False)],
          'fiden': [('fid', False)],
          'fidens': [('fid', False)],
          'fids': [('fid', False)],
          'fie': [('fium', False)],
          'fie-': [('fium', False)],
          'fien': [('fi', False)],
          'fienden': [('fiende', False)],
          'fiendens': [('fiende', False)],
          'fienderna': [('fiende', False)],
          'fiens': [('fi', False)],
          'fier': [('fi', False)],
          'fierna': [('fi', False)],
          'fiernas': [('fi', False)],
          'fiers': [('fi', False)],
          'fiesarna': [('fies', False)],
          'fiesarnas': [('fies', False)],
          'fiet': [('fi', False)],
          'fiets': [('fi', True)],
          'figheter': [('fighet', False)],
          'figheterna': [('fighet', False)],
          'figheternas': [('fighet', False)],
          'figheters': [('fighet', False)],
          'fighets-': [('fighet', False)],
          'fighter': [('fighter', True), ('fight', True)],
          'fighterna': [('fighter', True), ('fight', True)],
          'fighternas': [('fighter', True), ('fight', True)],
          'fighters': [('fighter', True), ('fight', True)],
          'fika': [('fika', True)],
          'fikan': [('fika', True)],
          'fikandens': [('fikande', True)],
          'fikans': [('fika', True)],
          'fikans-': [('fikans', False)],
          'fikas': [('fika', True)],
          'fikat': [('fika', True)],
          'fikats': [('fika', True)],
          'fiker': [('fiker', False)],
          'fikerna': [('fiker', False)],
          'fikernas': [('fiker', False)],
          'fikers': [('fiker', False)],
          'fiket': [('fik', True)],
          'fikets': [('fik', False)],
          'fiktions-': [('fiktion', True)],
          'filar': [('filare', True), ('fil', True)],
          'filar-': [('filare', True)],
          'filarens': [('filare', True)],
          'filarna': [('filare', True), ('fil', True)],
          'filarnas': [('filare', True), ('fil', True)],
          'file': [('file', False)],
          'file-': [('file', True)],
          'fileer': [('file', True)],
          'fileerna': [('file', False)],
          'fileernas': [('file', True)],
          'filen': [('file', True), ('fil', True)],
          'filens': [('file', True), ('fil', True)],
          'fili': [('fili', False)],
          'fili-': [('fili', False)],
          'filis': [('fili', False)],
          'filis-': [('filis', False)],
          'fill': [('fill', False)],
          'fill-': [('fill', False)],
          'fillen': [('fill', False)],
          'filler': [('filler', True)],
          'filler-': [('filler', True)],
          'fillerna': [('fill', False)],
          'fillernas': [('fill', False)],
          'fillers': [('filler', True)],
          'fills': [('fill', False)],
          'fills-': [('fill', False)],
          'filt-': [('filt', False)],
          'filts': [('filt', False)],
          'filts-': [('filt', True)],
          'fimp': [('fimp', False)],
          'fimp-': [('fimp', False)],
          'fimps': [('fimp', True)],
          'fimps-': [('fimp', False)],
          'fin': [('fi', False)],
          'finandens': [('finande', False)],
          'finans': [('finanser', True), ('finans', True)],
          'finans-': [('finanser', True), ('finans', True)],
          'finas': [('fi', True)],
          'finets': [('fin', False)],
          'fing': [('fing', False)],
          'fing-': [('fing', False)],
          'fingar': [('fing', False)],
          'fingarna': [('fing', False)],
          'fingarnas': [('fing', False)],
          'fingars': [('fing', False)],
          'fingen': [('fing', False)],
          'fingens': [('fing', False)],
          'fingerkroks': [('fingerkrok', True)],
          'fingerkroks-': [('fingerkrok', True)],
          'fingrar': [('finger', True)],
          'fingrarna': [('finger', False)],
          'fings': [('fing', False)],
          'fings-': [('fing', False)],
          'finister': [('finist', False)],
          'finisters': [('finist', False)],
          'fink': [('finka', True), ('fink', True)],
          'fink-': [('fink', True), ('finka', True)],
          'finkars': [('fink', False)],
          'finks': [('finka', True), ('fink', True)],
          'finks-': [('fink', True), ('finka', True)],
          'finkter': [('finkter', False)],
          'finkters': [('finkter', False)],
          'finkungar': [('finkunge', True)],
          'finkungarna': [('finkunge', True)],
          'finkungarnas': [('finkunge', True)],
          'finkungars': [('finkunge', True)],
          'finkungen': [('finkunge', True)],
          'finkungens': [('finkunge', True)],
          'finlandssvensk': [('finlandssvensk', True), ('finlandssvenska', True)],
          'finlandssvensk-': [('finlandssvensk', True), ('finlandssvenska', True)],
          'finn': [('finne', False)],
          'finn-': [('finne', False)],
          'finnar': [('finne', True)],
          'finnarna': [('finne', True)],
          'finnarnas': [('finne', True)],
          'finnen': [('finne', False)],
          'finns-': [('finne', False)],
          'finputs': [('finputs', True)],
          'fins': [('fi', False)],
          'fins-': [('fins', False)],
          'finskor': [('finsko', True), ('finska', True)],
          'finskorna': [('finsko', True), ('finska', True)],
          'finskornas': [('finsko', True), ('finska', True)],
          'finskors': [('finsko', True), ('finska', True)],
          'fint': [('fint', True)],
          'finter': [('fint', True)],
          'finterna': [('fint', True)],
          'finternas': [('fint', True)],
          'finters': [('fint', True)],
          'fints-': [('fint', True)],
          'fiol': [('fiol', False)],
          'fiol-': [('fiol', False)],
          'fioler': [('fiol', False)],
          'fiolerna': [('fiol', False)],
          'fiolernas': [('fiol', False)],
          'fiolers': [('fiol', False)],
          'fiols': [('fiol', True)],
          'fiols-': [('fiol', False)],
          'fior': [('fia', False)],
          'fiorna': [('fia', False)],
          'fiornas': [('fia', False)],
          'fiors': [('fia', False)],
          'firarnas': [('firare', False)],
          'firer': [('fir', False)],
          'firerna': [('fir', False)],
          'firernas': [('fir', False)],
          'firers': [('fir', False)],
          'firmanden': [('firmande', False)],
          'firmandens': [('firmand', False)],
          'firn': [('firn', True)],
          'firns': [('firn', True)],
          'firr': [('firre', True)],
          'firr-': [('firre', True)],
          'firrs': [('firre', True)],
          'fis': [('fis', True), ('fi', True)],
          'fis-': [('fis', True), ('fi', True)],
          'fisans': [('fisans', False)],
          'fisk': [('fisk', False)],
          'fisk-': [('fisk', False)],
          'fiskar': [('fisk', True), ('fiskare', True)],
          'fiskarna': [('fiskare', True), ('fisk', True)],
          'fiskarnas': [('fisk', True), ('fiskare', True)],
          'fiskets': [('fiske', False)],
          'fismernas': [('fism', False)],
          'fist-': [('fist', False)],
          'fisten': [('fist', False)],
          'fistens': [('fist', False)],
          'fister': [('fist', False)],
          'fisteriernas': [('fisteri', False)],
          'fisteriets': [('fisteri', False)],
          'fisterna': [('fist', False)],
          'fisternas': [('fist', False)],
          'fisters': [('fist', False)],
          'fistik': [('fistik', False)],
          'fistik-': [('fistik', False)],
          'fistiks': [('fistik', False)],
          'fit': [('fi', False)],
          'fiternas': [('fit', False)],
          'fitet': [('fit', False)],
          'fitets': [('fit', False)],
          'fiti': [('fiti', False)],
          'fitin': [('fiti', False)],
          'fitins': [('fiti', False)],
          'fitis': [('fiti', False)],
          'fits': [('fi', True)],
          'fitte': [('fitta', True)],
          'fityr': [('fityrer', False)],
          'fityr-': [('fityrer', False)],
          'fityrer': [('fityrer', False)],
          'fityrerna': [('fityrer', False)],
          'fityrernas': [('fityrer', False)],
          'fityrers': [('fityrer', False)],
          'fityrs': [('fityrer', False)],
          'fityrs-': [('fityrer', False)],
          'fium': [('fium', False)],
          'fiums': [('fium', False)],
          'fixar': [('fixare', True), ('fix', True)],
          'fixarna': [('fix', True), ('fixare', True)],
          'fixarnas': [('fixare', True), ('fix', True)],
          'fjoll': [('fjolla', True)],
          'fjoll-': [('fjolla', True)],
          'fjolle': [('fjolla', True)],
          'fjolls': [('fjolla', True)],
          'fjolls-': [('fjolla', True)],
          'fjun': [('fjun', True)],
          'fjuns': [('fjun', False)],
          'fjäll': [('fjälla', True), ('fjäll', True)],
          'fjäll-': [('fjälla', True), ('fjäll', True)],
          'fjälls': [('fjälla', True), ('fjäll', True)],
          'fjälls-': [('fjälla', True), ('fjäll', True)],
          'fjärdarnas': [('fjärd', True)],
          'fklubb-': [('fklubba', False)],
          'fko-': [('fko', False)],
          'fkon': [('fko', False)],
          'fkons': [('fko', False)],
          'fkor': [('fko', False)],
          'fkors': [('fko', False)],
          'fkors-': [('fkors', False)],
          'fkos': [('fko', False)],
          'fkos-': [('fko', False)],
          'flabb': [('flabb', True)],
          'flabb-': [('flabb', True)],
          'flabbar': [('flabb', True)],
          'flabbarna': [('flabb', True)],
          'flabbarnas': [('flabb', True)],
          'flabbars': [('flabb', True)],
          'flabben': [('flabb', True)],
          'flabbens': [('flabb', True)],
          'flabbs': [('flabb', True)],
          'flabbs-': [('flabb', False)],
          'flag': [('flaga', True)],
          'flag-': [('flaga', True)],
          'flagans': [('flaga', False)],
          'flagarna': [('flag', False)],
          'flage': [('flaga', True)],
          'flage-': [('flaga', False)],
          'flagen': [('flag', False)],
          'flagens': [('flag', False)],
          'flaget': [('flage', False)],
          'flagets': [('flage', False)],
          'flagg': [('flagg', True), ('flagga', True)],
          'flagg-': [('flagg', True), ('flagga', True)],
          'flaggs': [('flagg', True), ('flagga', True)],
          'flaggs-': [('flagg', True), ('flagga', True)],
          'flagor': [('flaga', False)],
          'flagorna': [('flaga', False)],
          'flagornas': [('flaga', True)],
          'flagors': [('flaga', False)],
          'flags': [('flaga', True)],
          'flags-': [('flaga', True)],
          'flak': [('flak', False)],
          'flak-': [('flak', False)],
          'flaken': [('flak', False)],
          'flakens': [('flak', False)],
          'flakes': [('flakes', True)],
          'flaks': [('flak', True)],
          'flaks-': [('flak', False)],
          'flam': [('flamma', True)],
          'flam-': [('flamma', False)],
          'flams': [('flamsa', True), ('flamma', True), ('flams', True)],
          'flams-': [('flamma', True), ('flams', True), ('flamsa', True)],
          'flanden': [('flande', False)],
          'flandena': [('flande', False)],
          'flandenas': [('flande', False)],
          'flandens': [('flande', False)],
          'flandet': [('flande', False)],
          'flandets': [('flande', False)],
          'flank': [('flank', True)],
          'flank-': [('flank', True)],
          'flanks': [('flank', True)],
          'flanks-': [('flank', True)],
          'flaren': [('flare', False)],
          'flask': [('flaska', False)],
          'flask-': [('flaska', False)],
          'flasklock': [('flasklock', True)],
          'flat': [('flata', True)],
          'flat-': [('flata', False)],
          'flatans': [('flata', True)],
          'flate': [('flata', True)],
          'flatens': [('flate', False)],
          'flator': [('flata', True)],
          'flators': [('flata', True)],
          'flats': [('flata', True)],
          'flats-': [('flata', False)],
          'flen': [('fle', False)],
          'flens': [('fle', False)],
          'fler': [('fler', False)],
          'flerna': [('fel', False)],
          'flernas': [('fler', False)],
          'flers': [('fel', False)],
          'fles': [('fles', True)],
          'fles-': [('fles', True)],
          'flesar': [('fles', True)],
          'flesarna': [('fles', True)],
          'flesen': [('fles', True)],
          'flesens': [('fles', True)],
          'flet': [('fel', False)],
          'flets': [('fel', False)],
          'fli': [('fli', False)],
          'fli-': [('fli', False)],
          'flick-': [('flicka', False)],
          'flickar': [('flickare', False)],
          'flickarna': [('flickare', False)],
          'flicks': [('flicka', False)],
          'flicks-': [('flicka', False)],
          'flierna': [('fli', False)],
          'fliets': [('fli', False)],
          'fliggarna': [('fliggare', False)],
          'fliggarnas': [('fliggare', False)],
          'flighets': [('flighet', False)],
          'flik': [('flik', False)],
          'flik-': [('flik', False)],
          'flikanden': [('flikande', False)],
          'flikar': [('flik', False)],
          'flikarna': [('flik', False)],
          'flikarnas': [('flik', True)],
          'flikars': [('flik', False)],
          'fliken': [('flik', False)],
          'flikens': [('flik', False)],
          'fliks': [('flik', True)],
          'fliks-': [('flik', True)],
          'flimmer': [('flimmer', True)],
          'flimmers': [('flimmer', False)],
          'flin': [('flin', True)],
          'flin-': [('flin', True)],
          'flina': [('fli', False)],
          'flinas': [('fli', False)],
          'flinen': [('flin', True)],
          'flinens': [('flin', True)],
          'flinet': [('flin', True)],
          'fling': [('flinga', False)],
          'fling-': [('flinga', False)],
          'flings': [('flinga', True)],
          'flings-': [('flinga', False)],
          'flins': [('flin', False)],
          'flins-': [('flin', True)],
          'flint': [('flinta', True), ('flint', True)],
          'flint-': [('flint', True), ('flinta', True)],
          'flints': [('flint', True), ('flinta', True)],
          'flints-': [('flinta', True), ('flint', True)],
          'flis': [('flis', True), ('flisa', True)],
          'flis-': [('flis', True), ('flisa', True)],
          'flisen': [('flis', False)],
          'flisens': [('flis', False)],
          'flit': [('flit', False)],
          'flit-': [('flit', True)],
          'fliten': [('flit', False)],
          'flitens': [('flit', False)],
          'flits': [('flit', True)],
          'flits-': [('flit', False)],
          'flo-': [('flo', True)],
          'flockarnas': [('flock', False)],
          'floden': [('flod', False)],
          'flodens': [('flod', True)],
          'flog': [('flog', False)],
          'flog-': [('flog', False)],
          'flogen': [('flog', False)],
          'flogens': [('flog', False)],
          'flogs': [('flog', False)],
          'flogs-': [('flog', False)],
          'flok': [('floka', False)],
          'flok-': [('floka', False)],
          'floks': [('floka', False)],
          'floks-': [('floka', False)],
          'flon': [('flo', True)],
          'flonen': [('flon', False)],
          'flonens': [('flon', False)],
          'floner': [('flon', False)],
          'flonerna': [('flon', False)],
          'flonernas': [('flon', False)],
          'floners': [('flon', False)],
          'flons': [('flo', True)],
          'flopp': [('flopp', False)],
          'flopp-': [('flopp', True)],
          'flopps': [('flopp', True)],
          'flopps-': [('flopp', False)],
          'flops': [('flop', True)],
          'flops-': [('flop', True)],
          'flor': [('flora', True), ('flor', True)],
          'flor-': [('flora', True), ('flor', True)],
          'floran': [('flora', False)],
          'florans': [('flora', False)],
          'flore': [('flora', False)],
          'flore-': [('flora', False)],
          'floren': [('flor', False)],
          'florens': [('flor', False)],
          'florins': [('florin', True)],
          'flors': [('flora', True), ('flor', True)],
          'flors-': [('flora', True), ('flor', True)],
          'floss': [('flossa', True)],
          'floss-': [('flossa', True)],
          'flott': [('flotte', True), ('flotta', True), ('flott', True)],
          'flott-': [('flott', True), ('flotte', True), ('flotta', True)],
          'flottar': [('flotte', True), ('flottare', True)],
          'flottarna': [('flottare', True), ('flotte', True)],
          'flottarnas': [('flottare', True), ('flotte', True)],
          'flottars': [('flotte', False)],
          'flotte': [('flotte', True), ('flotta', True)],
          'flotte-': [('flotta', False)],
          'flotten': [('flotte', False)],
          'flottens': [('flotte', False)],
          'flotts': [('flott', True), ('flotte', True), ('flotta', True)],
          'flotts-': [('flott', True), ('flotte', True), ('flotta', True)],
          'flox': [('flox', True)],
          'floxar': [('flox', True)],
          'floxarnas': [('flox', True)],
          'floxars': [('flox', True)],
          'floxen': [('flox', True)],
          'floxens': [('flox', True)],
          'fluider': [('fluidum', True), ('fluid', True)],
          'fluiderna': [('fluid', True), ('fluidum', True)],
          'fluidernas': [('fluid', True), ('fluidum', True)],
          'fluiders': [('fluid', True), ('fluidum', True)],
          'flums': [('flum', True)],
          'flums-': [('flum', True)],
          'flus': [('flu', False)],
          'fluster': [('fluster', True)],
          'flusterna': [('fluster', True)],
          'flusternas': [('fluster', True)],
          'flusters': [('fluster', True)],
          'flykt': [('flykt', False)],
          'flykt-': [('flykt', True)],
          'flykts': [('flykt', False)],
          'flykts-': [('flykt', False)],
          'flys': [('fly', False)],
          'flyt': [('fly', True), ('flyt', True)],
          'flytet': [('flyt', False)],
          'flytets': [('flyt', True)],
          'flyts': [('fly', True), ('flyt', True)],
          'fläck': [('fläck', True)],
          'fläck-': [('fläck', False)],
          'fläckarnas': [('fläck', False)],
          'fläcks': [('fläck', True)],
          'fläcks-': [('fläck', False)],
          'fläktar': [('fläkt', False)],
          'fläktarna': [('fläkt', False)],
          'fläktarnas': [('fläkt', True)],
          'fläng': [('fläng', True)],
          'fläng-': [('fläng', True)],
          'flängets': [('fläng', True)],
          'flängs': [('fläng', True)],
          'flängs-': [('fläng', True)],
          'fläns': [('fläns', True)],
          'fläns-': [('fläns', True)],
          'fläte': [('fläta', False)],
          'flåg': [('flåg', False)],
          'flåg-': [('flåg', False)],
          'flågs': [('flåg', False)],
          'flågs-': [('flåg', False)],
          'flödet': [('flöde', True)],
          'flödets': [('flöde', False)],
          'flöj': [('flöj', True)],
          'flöj-': [('flöj', True)],
          'flöjar': [('flöj', True)],
          'flöjarna': [('flöj', True)],
          'flöjarnas': [('flöj', True)],
          'flöjen': [('flöj', True)],
          'flöjens': [('flöj', True)],
          'flöjs': [('flöj', True)],
          'flöjs-': [('flöj', True)],
          'flös-': [('flös', False)],
          'flösen': [('flös', False)],
          'flösens': [('flös', False)],
          'flöten': [('flöte', True)],
          'flötens': [('flöte', True)],
          'flöts': [('flöts', True), ('flöte', True)],
          'flöts-': [('flöte', True), ('flöts', True)],
          'fmakar': [('fmakare', False)],
          'fmakarna': [('fmakare', False)],
          'fmakarnas': [('fmakare', False)],
          'fnas': [('fnas', True)],
          'fnask-': [('fnask', True)],
          'fnaskar': [('fnasker', True)],
          'fnaskarna': [('fnasker', False)],
          'fnaskarnas': [('fnasker', True)],
          'fnaskars': [('fnasker', True)],
          'fnattens': [('fnatt', True)],
          'fniet': [('fnium', False)],
          'fniss-': [('fniss', True)],
          'fnissen': [('fniss', True)],
          'fnissens': [('fniss', True)],
          'fnsen': [('fens', False)],
          'fnsens': [('fens', False)],
          'fnset': [('fens', False)],
          'fnsets': [('fens', False)],
          'fobins': [('fobi', False)],
          'fobis': [('fobi', False)],
          'fock-': [('fock', False)],
          'fockar': [('fock', False)],
          'fockarna': [('fock', False)],
          'focken': [('fock', False)],
          'fockens': [('fock', False)],
          'focks': [('fock', False)],
          'focks-': [('fock', True)],
          'foder': [('foder', False)],
          'foderna': [('foder', False)],
          'fodernas': [('foder', False)],
          'foders': [('foder', False)],
          'fodervärden': [('fodervärde', True), ('fodervärd', True)],
          'fodervärdens': [('fodervärde', True), ('fodervärd', True)],
          'fodranden': [('fodrande', False)],
          'fodrandens': [('fodrande', False)],
          'foget': [('fog', False)],
          'fogets': [('fog', False)],
          'folie': [('folie', False)],
          'folien': [('folie', True)],
          'foliens': [('folie', True)],
          'folier': [('folie', True)],
          'folierna': [('folie', True)],
          'foliernas': [('folie', True)],
          'foliers': [('folie', False)],
          'folk': [('folk', False)],
          'folk-': [('folk', False)],
          'folks': [('folk', False)],
          'folks-': [('folk', False)],
          'follarna': [('folle', True)],
          'folle': [('folle', True)],
          'folle-': [('folle', True)],
          'follen': [('folle', True)],
          'fologier': [('fologi', False)],
          'fologierna': [('fologi', False)],
          'fologiers': [('fologi', False)],
          'fomen': [('fom', False)],
          'fomens': [('fom', False)],
          'fområdets': [('fområde', False)],
          'foms': [('fom', False)],
          'fon': [('fon', True)],
          'fon-': [('fon', False)],
          'fona': [('fo', False)],
          'fond': [('fond', False)],
          'fond-': [('fond', True)],
          'fonden': [('fond', False)],
          'fondens': [('fond', False)],
          'fonder': [('fond', False)],
          'fonders': [('fond', False)],
          'fonds': [('fond', False)],
          'fonds-': [('fond', False)],
          'fong': [('fong', False)],
          'fong-': [('fong', False)],
          'fonger': [('fong', False)],
          'fongerna': [('fong', False)],
          'fongernas': [('fong', False)],
          'fongers': [('fong', False)],
          'fongs': [('fong', False)],
          'foni': [('foni', False)],
          'foni-': [('foni', False)],
          'fonie-': [('fonia', False)],
          'fonien': [('foni', False)],
          'foniens': [('foni', False)],
          'fonierna': [('foni', False)],
          'foniers': [('foni', False)],
          'foniker': [('foniker', False)],
          'fonikerna': [('foniker', False)],
          'fonikernas': [('foniker', False)],
          'fonikers': [('foniker', False)],
          'fonin': [('foni', False)],
          'fonins': [('foni', False)],
          'fonis': [('fonia', False)],
          'fonis-': [('fonia', False)],
          'fons': [('fon', False)],
          'fons-': [('fon', False)],
          'fonsen': [('fons', False)],
          'fonsens': [('fons', False)],
          'fonsvar': [('fonsvar', False)],
          'fonter': [('font', True)],
          'fonters': [('font', True)],
          'for': [('fora', True)],
          'for-': [('fora', True)],
          'fora': [('forum', True), ('fora', True)],
          'foran': [('fora', False)],
          'forana': [('forum', True)],
          'foranas': [('forum', False)],
          'forans': [('fora', False)],
          'foras': [('fora', True), ('forum', True)],
          'foras-': [('fora', False)],
          'ford': [('ford', False)],
          'forden': [('ford', False)],
          'fordens': [('ford', False)],
          'fordran': [('fordran', False)],
          'fordrar': [('fordrare', False)],
          'fordrarna': [('fordrare', False)],
          'fordrarnas': [('fordrare', False)],
          'fordringar': [('fordran', True), ('fordring', True)],
          'fordringarna': [('fordring', True), ('fordran', True)],
          'fordringarnas': [('fordran', True), ('fordring', True)],
          'fordringars': [('fordring', True), ('fordran', True)],
          'fords': [('ford', False)],
          'fori': [('fori', False)],
          'fori-': [('fori', False)],
          'foriens': [('fori', False)],
          'forier': [('fori', False)],
          'forierna': [('fori', False)],
          'foriers': [('fori', False)],
          'forins': [('fori', False)],
          'foris': [('fori', False)],
          'formanden': [('formande', False)],
          'formar': [('formare', True), ('form', True)],
          'formarna': [('formare', True), ('form', True)],
          'formarnas': [('formare', True), ('form', True)],
          'forn': [('for', False)],
          'forns': [('for', False)],
          'foror': [('fora', True)],
          'fororna': [('fora', False)],
          'forornas': [('fora', True)],
          'forors': [('fora', False)],
          'fors': [('fors', True), ('fora', True)],
          'fors-': [('fors', True), ('fora', True)],
          'forsar': [('fors', True)],
          'forsars': [('fors', True)],
          'forskar': [('forskare', False)],
          'forskarna': [('forskare', False)],
          'fort': [('fort', True)],
          'fort-': [('fort', False)],
          'forten': [('forte', True), ('fort', True)],
          'fortens': [('forte', True), ('fort', True)],
          'fortes': [('forte', False)],
          'fortet': [('forte', True), ('fort', True)],
          'fortets': [('forte', True), ('fort', True)],
          'forts-': [('fort', True)],
          'fos': [('fo', False)],
          'fos-': [('fo', False)],
          'foss': [('foss', False)],
          'foss-': [('foss', False)],
          'fossen': [('foss', False)],
          'fossens': [('foss', False)],
          'fosterbroder': [('fosterbror', True)],
          'fosterbröderna': [('fosterbror', True)],
          'fosterbröders': [('fosterbror', True)],
          'fostran': [('fostran', True)],
          'fostrans': [('fostran', False)],
          'fostrarnas': [('fostrare', False)],
          'fot': [('fot', False)],
          'fotarnas': [('fot', False)],
          'foton': [('foton', True), ('foto', True)],
          'fotons': [('foton', True), ('foto', True)],
          'fots': [('fot', True)],
          'fots-': [('fot', True)],
          'fotände': [('fotända', True), ('fotände', True)],
          'fotände-': [('fotände', True), ('fotända', True)],
          'foulen': [('foul', True)],
          'foulens': [('foul', True)],
          'fox': [('fox', False)],
          'fox-': [('fox', False)],
          'foxar': [('fox', False)],
          'foxarna': [('fox', False)],
          'foxarnas': [('fox', False)],
          'foxars': [('fox', False)],
          'foxen': [('fox', False)],
          'foxens': [('fox', False)],
          'foyer': [('foyer', True)],
          'foyers': [('foyer', True)],
          'fpars-': [('fpar', False)],
          'fpiller': [('fpiller', False)],
          'fpillers': [('fpiller', False)],
          'fr': [('fr', True)],
          'fr-': [('fr', True)],
          'frack': [('frack', True)],
          'frack-': [('frack', False)],
          'frackar': [('frack', False)],
          'frackarna': [('frack', True)],
          'frackarnas': [('frack', True)],
          'fracks': [('frack', False)],
          'fracks-': [('frack', True)],
          'fraden': [('frad', False)],
          'fradens': [('frad', False)],
          'fragetterna': [('fragett', False)],
          'fragetternas': [('fragett', False)],
          'fragetters': [('fragett', False)],
          'frall': [('fralla', True)],
          'frall-': [('fralla', True)],
          'fralls': [('fralla', True)],
          'fralls-': [('fralla', True)],
          'framben': [('framben', True)],
          'frambens': [('framben', True)],
          'frams': [('fram', False)],
          'framställanden': [('framställande', True)],
          'framställandena': [('framställande', True)],
          'framställandenas': [('framställande', True)],
          'framställandens': [('framställande', True)],
          'framställningar': [('framställan', True), ('framställning', True)],
          'framställningarna': [('framställning', True), ('framställan', True)],
          'framställningarnas': [('framställning', True), ('framställan', True)],
          'framställningars': [('framställning', True), ('framställan', True)],
          'framände': [('framände', True), ('framända', True)],
          'framände-': [('framända', True), ('framände', True)],
          'frande': [('frande', False)],
          'frande-': [('frande', False)],
          'franden': [('frande', False)],
          'frandens': [('frande', False)],
          'frandet': [('frande', False)],
          'frank': [('frank', True)],
          'frank-': [('frank', True)],
          'franks': [('frank', True)],
          'franks-': [('frank', True)],
          'frans': [('frans', True)],
          'frans-': [('frans', True)],
          'frarnas': [('fer', False)],
          'fras': [('fras', True)],
          'fras-': [('fras', True)],
          'frasen': [('fras', False)],
          'frasens': [('fras', False)],
          'frat': [('frat', True)],
          'frats': [('frat', True)],
          'fre': [('fre', True)],
          'fre-': [('fre', True)],
          'fred': [('fred', False)],
          'fred-': [('fred', False)],
          'freden': [('fred', False)],
          'fredens': [('fred', False)],
          'freds': [('fred', False)],
          'freds-': [('fred', False)],
          'free': [('free', False)],
          'free-': [('free', False)],
          'fregatt': [('fregatt', True)],
          'fregatt-': [('fregatt', True)],
          'fregatts': [('fregatt', True)],
          'fregatts-': [('fregatt', True)],
          'frems': [('fremsa', False)],
          'frems-': [('fremsa', False)],
          'fren': [('fer', False)],
          'frens': [('fer', False)],
          'freons': [('freon', True)],
          'frers': [('fer', False)],
          'frese': [('fresa', False)],
          'frese-': [('fresa', False)],
          'fret': [('fer', False)],
          'frets': [('fer', False)],
          'friandens': [('friande', False)],
          'frid': [('frid', False)],
          'frid-': [('frid', True)],
          'frider': [('frid', True)],
          'friderna': [('frid', True)],
          'fridernas': [('frid', True)],
          'friders': [('frid', True)],
          'frighets': [('frighet', False)],
          'frikan': [('frikan', False)],
          'frikans': [('frikan', False)],
          'frikator': [('frikata', False)],
          'frikators': [('frikata', False)],
          'friktioner': [('friktion', False)],
          'friktionerna': [('friktion', False)],
          'friktionernas': [('friktion', True)],
          'friktioners': [('friktion', False)],
          'friktions': [('friktion', False)],
          'frilansar': [('frilansare', True), ('frilans', True)],
          'frilansarna': [('frilansare', True), ('frilans', True)],
          'frilansarnas': [('frilansare', True), ('frilans', True)],
          'frill': [('frilla', True)],
          'frill-': [('frilla', True)],
          'frills': [('frilla', True)],
          'frills-': [('frilla', True)],
          'frin': [('frin', False)],
          'frin-': [('frin', False)],
          'friner': [('frin', False)],
          'frinerna': [('frin', False)],
          'frinernas': [('frin', False)],
          'friners': [('frin', False)],
          'fringar': [('fring', False)],
          'fringarna': [('fring', False)],
          'fringarnas': [('fring', False)],
          'frins': [('frin', False)],
          'frins-': [('frin', False)],
          'fris': [('fris', False)],
          'fris-': [('fris', True)],
          'friser': [('fris', True)],
          'friserna': [('fris', False)],
          'frisernas': [('fris', False)],
          'frisers': [('fris', False)],
          'friss': [('frissa', True)],
          'frit': [('frit', False)],
          'frits': [('frit', False)],
          'frizon': [('frizon', True)],
          'fror': [('fra', False)],
          'frorna': [('fra', False)],
          'frornas': [('fra', False)],
          'frors': [('fra', False)],
          'froschen': [('frosch', True)],
          'froschens': [('frosch', True)],
          'fross': [('frossa', True)],
          'fross-': [('frossa', True)],
          'frossar': [('frossare', True)],
          'frossarnas': [('frossare', True)],
          'fru-': [('fru', False)],
          'frug-': [('fruga', True)],
          'frugs-': [('fruga', True)],
          'frun': [('fru', False)],
          'frundans': [('frunda', False)],
          'fruns': [('fru', False)],
          'frus': [('fru', False)],
          'frus-': [('fru', False)],
          'frys': [('frys', True)],
          'frys-': [('frys', True)],
          'frysar': [('frys', True)],
          'frysarna': [('frys', True)],
          'frysarnas': [('frys', True)],
          'fräken': [('fräken', True)],
          'fräkens': [('fräken', False)],
          'fräknar': [('fräken', True), ('fräkne', True)],
          'fräknarna': [('fräkne', True), ('fräken', True)],
          'fräknarnas': [('fräkne', True), ('fräken', True)],
          'fräknars': [('fräkne', True), ('fräken', True)],
          'fräknens': [('fräkne', True)],
          'frälsar': [('frälsare', True)],
          'frälsarna': [('frälsare', True)],
          'frälsarnas': [('frälsare', True)],
          'främ': [('främma', False)],
          'fränden': [('frände', False)],
          'frändens': [('frände', False)],
          'fränder': [('frände', False)],
          'fränderna': [('frände', False)],
          'frändernas': [('frände', False)],
          'fränders': [('frände', False)],
          'fränk': [('fränka', True)],
          'fränk-': [('fränka', True)],
          'fränks': [('fränka', True)],
          'fränks-': [('fränka', True)],
          'fräs': [('fräs', False)],
          'fräs-': [('fräs', False)],
          'fräsanden': [('fräsande', False)],
          'fräsandens': [('fräsande', False)],
          'fräsar': [('fräs', False)],
          'fräsarna': [('fräs', True)],
          'fräsarnas': [('fräs', True)],
          'frät': [('fräta', True)],
          'fräts': [('fräta', True)],
          'frågan': [('fråga', False)],
          'frågans': [('fråga', False)],
          'fråge': [('fråga', False)],
          'fråge-': [('fråga', False)],
          'fröken': [('fröken', False)],
          'frökens': [('fröken', False)],
          'frön': [('frö', False)],
          'fröns': [('frö', False)],
          'frös': [('frö', False)],
          'frös-': [('frö', True)],
          'fröt': [('frö', False)],
          'fs': [('f', True)],
          'fsanden': [('fsande', False)],
          'fsandens': [('fsande', False)],
          'fsans': [('fsa', False)],
          'fsar': [('fs', False)],
          'fsaren': [('fsare', False)],
          'fsarna': [('fs', False)],
          'fsars': [('fs', False)],
          'fsats': [('fsats', False)],
          'fsats-': [('fsats', False)],
          'fse': [('fsa', False)],
          'fse-': [('fsa', False)],
          'fsen': [('fs', False)],
          'fsens': [('fs', False)],
          'fser': [('fs', False)],
          'fserna': [('fs', False)],
          'fsernas': [('fs', False)],
          'fsers': [('fs', False)],
          'fset': [('fs', False)],
          'fsets': [('fs', False)],
          'fskytten': [('fskytt', False)],
          'fskyttens': [('fskytt', False)],
          'fsmes': [('fsmes', False)],
          'fsor': [('fsa', False)],
          'fsorna': [('fsa', False)],
          'fsornas': [('fsa', False)],
          'fsors': [('fsa', False)],
          'fst': [('fst', False)],
          'fstekar': [('fstek', False)],
          'fstekarna': [('fstek', False)],
          'fstekarnas': [('fstek', False)],
          'fsten': [('fst', False)],
          'fstens': [('fst', False)],
          'fsverken': [('fsverk', False)],
          'fsverkens': [('fsverk', False)],
          'fsverket': [('fsverk', False)],
          'fsverks': [('fsverk', False)],
          'fsverks-': [('fsverk', False)],
          'ft': [('ft', False)],
          'ft-': [('ft', False)],
          'ftaken': [('ftak', False)],
          'ftaket': [('ftak', False)],
          'ftalen': [('ftalen', False)],
          'ftalens': [('ftalen', False)],
          'ftan-': [('ftan', False)],
          'ftandar': [('ftande', False)],
          'ftandars': [('ftande', False)],
          'ftanden': [('ftande', False)],
          'ftandens': [('ftande', False)],
          'ftans': [('fta', False)],
          'ftans-': [('ftan', False)],
          'ftar': [('ft', False)],
          'ftaren': [('ftare', False)],
          'ftarna': [('ft', False)],
          'ftars': [('ft', False)],
          'fte': [('fta', False)],
          'fte-': [('fta', False)],
          'ften': [('ft', False)],
          'ftens': [('ft', False)],
          'fter': [('ft', False)],
          'fterien': [('fteri', False)],
          'fterin': [('fteri', False)],
          'fterna': [('ft', False)],
          'fternas': [('ft', False)],
          'fters': [('ft', False)],
          'ftes': [('fte', False)],
          'ftes-': [('fte', False)],
          'ftet': [('ft', False)],
          'ftets': [('fte', False)],
          'ftiden': [('ftid', False)],
          'ftider': [('ftid', False)],
          'ftiders': [('ftid', False)],
          'ftighets': [('ftighet', False)],
          'ftin': [('fti', False)],
          'ftins': [('fti', False)],
          'ftis': [('fti', False)],
          'ftmasters': [('ftmast', False)],
          'ftnarnas': [('fton', False)],
          'ftnars': [('fton', False)],
          'fton': [('fton', False)],
          'ftons': [('fton', False)],
          'ftor': [('fta', False)],
          'ftorna': [('fta', False)],
          'ftornas': [('fta', False)],
          'ftors': [('fta', False)],
          'ftpressarnas': [('ftpress', False)],
          'ftrots': [('ftrot', False)],
          'ftrots-': [('ftrot', False)],
          'ftrum': [('ftrum', False)],
          'ftrums': [('ftrum', False)],
          'ftrums-': [('ftrum', False)],
          'fts': [('ft', False)],
          'fts-': [('ft', False)],
          'ftströmmen': [('ftström', False)],
          'ftsvane': [('ftsvana', False)],
          'ftsvane-': [('ftsvana', False)],
          'ftsvanors': [('ftsvana', False)],
          'fttanden': [('fttand', False)],
          'fttandens': [('fttand', False)],
          'fttidens': [('fttid', False)],
          'ftullar': [('ftull', False)],
          'ftullarna': [('ftull', False)],
          'ftullarnas': [('ftull', False)],
          'ftvägar': [('ftvägare', False)],
          'ftvägarna': [('ftvägare', False)],
          'ftvägarnas': [('ftvägare', False)],
          'ftvägen': [('ftväg', False)],
          'ftvägens': [('ftväg', False)],
          'ftåg': [('ftåg', False)],
          'ftågs': [('ftåg', False)],
          'ftågs-': [('ftåg', False)],
          'fu': [('fu', False)],
          'fubb': [('fubb', True)],
          'fubbet': [('fubb', True)],
          'fubbets': [('fubb', True)],
          'fubbs': [('fubb', True)],
          'fuffens': [('fuffens', True)],
          'fug': [('fuga', True)],
          'fug-': [('fuga', True)],
          'fugs': [('fuga', False)],
          'fugs-': [('fuga', True)],
          'fugu': [('fugu', True)],
          'fukt': [('fukt', True)],
          'fukt-': [('fukt', True)],
          'fuktarnas': [('fuktare', False)],
          'fukts': [('fukt', True)],
          'fukts-': [('fukt', True)],
          'fularna': [('ful', True)],
          'full': [('full', False)],
          'full-': [('full', False)],
          'fullar': [('full', False)],
          'fullarna': [('full', False)],
          'fullars': [('full', False)],
          'fullmäktige': [('fullmäktig', True)],
          'fullmäktigen': [('fullmäktig', True)],
          'fullmäktigena': [('fullmäktig', False)],
          'fullmäktigenas': [('fullmäktig', False)],
          'fullmäktigens': [('fullmäktig', False)],
          'fullmäktiges': [('fullmäktig', False)],
          'fulls': [('full', False)],
          'fulls-': [('full', False)],
          'fun': [('fu', False)],
          'fund': [('fund', False)],
          'fund-': [('fund', False)],
          'fundernas': [('funder', True)],
          'funds': [('fund', False)],
          'funds-': [('fund', False)],
          'funk': [('funk', True)],
          'funk-': [('funk', True)],
          'funken': [('funk', True)],
          'funkens': [('funk', True)],
          'funks': [('funk', True)],
          'funs': [('fu', False)],
          'funt': [('funt', False)],
          'funtarna': [('funt', False)],
          'funtars': [('funt', False)],
          'funten': [('funt', False)],
          'funtens': [('funt', False)],
          'funts-': [('funt', False)],
          'fur': [('fura', True), ('fur', True)],
          'fur-': [('fura', True), ('fur', True)],
          'furan': [('fura', True), ('furan', True)],
          'furans': [('fura', True), ('furan', True)],
          'furie-': [('furie', True)],
          'furien': [('furie', True)],
          'furiernas': [('furie', True)],
          'furiers': [('furie', True)],
          'furor': [('furor', True), ('fura', True)],
          'furoren': [('furore', True), ('furor', True)],
          'furorens': [('furore', True), ('furor', True)],
          'furors': [('furor', True), ('fura', True)],
          'furstar': [('furste', False)],
          'furstarna': [('furste', False)],
          'furstarnas': [('furste', False)],
          'furstars': [('furste', False)],
          'fursten': [('furste', False)],
          'furu': [('furu', True), ('fura', True)],
          'furu-': [('fura', True), ('furu', True)],
          'furus': [('furu', True)],
          'furus-': [('furu', True)],
          'fus': [('fu', False)],
          'fusk': [('fusk', False)],
          'fusk-': [('fusk', False)],
          'fuskar': [('fuskare', False)],
          'fuskarna': [('fuskare', False)],
          'fuskarnas': [('fuskare', False)],
          'fusken': [('fusk', False)],
          'fuskens': [('fusk', False)],
          'futt': [('futt', True)],
          'futt-': [('futt', True)],
          'futtar': [('futt', True)],
          'futtars': [('futt', True)],
          'futten': [('futt', True)],
          'futts': [('futt', True)],
          'futts-': [('futt', True)],
          'futurers': [('futurum', True)],
          'fval': [('fval', False)],
          'fvalen': [('fval', False)],
          'fvalens': [('fval', False)],
          'fvals': [('fval', False)],
          'fvals-': [('fval', False)],
          'fvärden': [('fvärde', False)],
          'fvärdens': [('fvärde', False)],
          'fyll': [('fylla', True)],
          'fyll-': [('fylla', True)],
          'fyllan': [('fylla', False)],
          'fyllandet': [('fyllande', False)],
          'fylle': [('fylla', False)],
          'fylle-': [('fylla', False)],
          'fyllen': [('fyll', False)],
          'fyllet': [('fyll', False)],
          'fyllets': [('fyll', False)],
          'fylls': [('fylla', True)],
          'fynd': [('fynd', False)],
          'fynd-': [('fynd', False)],
          'fyndet': [('fynd', False)],
          'fyndets': [('fynd', False)],
          'fynds': [('fynd', False)],
          'fynds-': [('fynd', False)],
          'fyrar': [('fyr', True)],
          'fyrarna': [('fyr', True)],
          'fyrarnas': [('fyr', True)],
          'fyrers': [('fyr', False)],
          'fyrk': [('fyrk', True)],
          'fyrk-': [('fyrk', True)],
          'fyrkar': [('fyrk', True)],
          'fyrkarna': [('fyrk', True)],
          'fyrken': [('fyrk', True)],
          'fyrkens': [('fyrk', True)],
          'fyrks': [('fyrk', True)],
          'fyrks-': [('fyrk', True)],
          'fyt': [('fyt', False)],
          'fyt-': [('fyt', False)],
          'fyts': [('fyt', False)],
          'fyts-': [('fyt', False)],
          'fyx': [('fyxa', False)],
          'fyx-': [('fyxa', False)],
          'fäder': [('fader', True), ('far', True)],
          'fäderna': [('fader', True), ('far', True)],
          'fädernas': [('far', True), ('fader', True)],
          'fäders': [('fader', True), ('far', True)],
          'fäktarnas': [('fäktare', True)],
          'fälben': [('fälb', True)],
          'fälgkors': [('fälgkors', True)],
          'fäll': [('fälla', True), ('fäll', True)],
          'fäll-': [('fälla', True), ('fäll', True)],
          'fällan': [('fälla', False)],
          'fällanden': [('fällande', False)],
          'fällandena': [('fällande', False)],
          'fällandenas': [('fällande', False)],
          'fällandens': [('fällande', False)],
          'fällar': [('fäll', False)],
          'fällars': [('fäll', True)],
          'fälle': [('fälla', False)],
          'fälle-': [('fälla', False)],
          'fällen': [('fäll', True)],
          'fällens': [('fäll', True)],
          'fällningar': [('fällning', False)],
          'fällningarna': [('fällning', False)],
          'fällningarnas': [('fällning', False)],
          'fällningars': [('fällning', False)],
          'fällnings': [('fällning', False)],
          'fällnings-': [('fällning', False)],
          'fälls': [('fälla', True), ('fäll', True)],
          'fälls-': [('fälla', True), ('fäll', True)],
          'fäls': [('fäl', False)],
          'fält-': [('fält', True)],
          'fältar': [('fältare', False)],
          'fältarnas': [('fältare', False)],
          'fälten': [('fält', False)],
          'fältens': [('fält', False)],
          'fältet': [('fält', False)],
          'fälts': [('fält', False)],
          'fälts-': [('fält', False)],
          'fän': [('fä', True)],
          'fäna': [('fä', False)],
          'fänas': [('fä', False)],
          'fängen': [('fänge', False)],
          'fängens': [('fänge', False)],
          'fängets': [('fänge', False)],
          'fängs': [('fänge', False)],
          'fängs-': [('fänge', False)],
          'fängslet': [('fängsel', True)],
          'fäns': [('fä', True)],
          'färan': [('färan', False)],
          'färans': [('färan', False)],
          'färd': [('färd', False)],
          'färd-': [('färd', False)],
          'färden': [('färd', False)],
          'färdens': [('färd', False)],
          'färds': [('färd', False)],
          'färds-': [('färd', False)],
          'färdsdans': [('färdsdag', False)],
          'färgen': [('färg', False)],
          'färgens': [('färg', False)],
          'färgs': [('färg', False)],
          'färgs-': [('färg', False)],
          'färje': [('färja', False)],
          'färmar': [('färm', False)],
          'färmarna': [('färm', False)],
          'färmarnas': [('färm', False)],
          'färnorna': [('färna', True)],
          'färnornas': [('färna', True)],
          'färs': [('färs', False)],
          'färs-': [('färs', False)],
          'fäs': [('fä', False)],
          'fäs-': [('fä', False)],
          'fässens': [('fäss', False)],
          'fästets': [('fäste', False)],
          'fät': [('fä', True)],
          'fäts': [('fä', True)],
          'fål': [('fåle', False)],
          'fål-': [('fåle', True)],
          'fålar': [('fåle', False)],
          'fålarna': [('fåle', False)],
          'fålarnas': [('fåle', True)],
          'fålars': [('fåle', False)],
          'fåle': [('fåle', True)],
          'fålen': [('fåle', False)],
          'fålens': [('fåle', False)],
          'fåll': [('fålla', True), ('fåll', True)],
          'fåll-': [('fåll', True), ('fålla', True)],
          'fållan': [('fålla', True)],
          'fållanden': [('fållande', True)],
          'fållandenas': [('fållande', True)],
          'fållar': [('fåll', False)],
          'fållarna': [('fåll', False)],
          'fållarnas': [('fåll', False)],
          'fållars': [('fåll', False)],
          'fålle-': [('fålla', True)],
          'fållen': [('fåll', True)],
          'fålls': [('fålla', True), ('fåll', True)],
          'fålls-': [('fålla', True), ('fåll', True)],
          'fåls': [('fåle', True)],
          'fåls-': [('fåle', True)],
          'fån': [('fån', True)],
          'fånar': [('fåne', False)],
          'fånarnas': [('fåne', False)],
          'fåne': [('fåne', False)],
          'fånen': [('fåne', True), ('fån', True)],
          'fånens': [('fån', True), ('fåne', True)],
          'fång': [('fånge', True), ('fång', True)],
          'fång-': [('fånge', True), ('fång', True)],
          'fångar': [('fånge', False)],
          'fångarna': [('fånge', False)],
          'fångarnas': [('fånge', False)],
          'fånge': [('fånge', False)],
          'fånge-': [('fånge', False)],
          'fången': [('fånge', True), ('fång', True)],
          'fångens': [('fång', True), ('fånge', True)],
          'fångs': [('fånge', True), ('fång', True)],
          'fångs-': [('fånge', True), ('fång', True)],
          'fåns': [('fån', True)],
          'får': [('fåra', True), ('får', True)],
          'får-': [('fåra', True), ('får', True)],
          'fårs': [('fåra', True), ('får', True)],
          'fårs-': [('fåra', True), ('får', True)],
          'féerna': [('fé', False)],
          'féernas': [('fé', False)],
          'fés-': [('fé', False)],
          'födarna': [('födare', False)],
          'följ': [('följ', False)],
          'följ-': [('följ', False)],
          'följen': [('följe', True)],
          'följens': [('följe', True)],
          'följs': [('följe', True)],
          'följs-': [('följe', True)],
          'fön': [('fön', True)],
          'fönar': [('fön', True)],
          'fönarnas': [('fön', True)],
          'fönernas': [('fön', True)],
          'föns': [('fön', False)],
          'föns-': [('fön', False)],
          'fönsterbräde': [('fönsterbräde', True), ('fönsterbräda', True)],
          'förar': [('för', True), ('förare', True)],
          'förarna': [('för', True), ('förare', True)],
          'förarnas': [('för', True), ('förare', True)],
          'förbön': [('förbön', True)],
          'fördelar': [('fördelare', True), ('fördel', True)],
          'fördelarna': [('fördelare', True), ('fördel', True)],
          'fördelarnas': [('fördelare', True), ('fördel', True)],
          'fören': [('för', True), ('före', True)],
          'förens': [('för', True), ('före', True)],
          'föret': [('före', False)],
          'förlag': [('förlaga', True), ('förlag', True)],
          'förlags': [('förlag', True), ('förlaga', True)],
          'förlags-': [('förlag', True), ('förlaga', True)],
          'förlust': [('förlust', False)],
          'förlust-': [('förlust', True)],
          'förluster': [('förlust', True)],
          'förlusterna': [('förlust', True)],
          'förlusternas': [('förlust', True)],
          'förlusters': [('förlust', True)],
          'förn': [('för', False)],
          'förna': [('förna', True)],
          'förnas': [('förna', True)],
          'förns': [('för', False)],
          'förnödenheter': [('förnödenhet', True)],
          'förnödenheterna': [('förnödenhet', True)],
          'förnödenheternas': [('förnödenhet', True)],
          'förnödenheters': [('förnödenhet', True)],
          'förnödenhets': [('förnödenhet', True)],
          'förnödenhets-': [('förnödenhet', True)],
          'förs': [('före', True), ('för', True)],
          'förs-': [('för', True), ('före', True)],
          'försten': [('försten', True)],
          'förstens': [('försten', True)],
          'försäkringar': [('försäkran', True), ('försäkring', True)],
          'försäkringarna': [('försäkring', True), ('försäkran', True)],
          'försäkringarnas': [('försäkran', True), ('försäkring', True)],
          'försäkringars': [('försäkran', True), ('försäkring', True)],
          'fösar': [('fösare', False)],
          'fötter': [('fot', False)],
          'fötterna': [('fot', False)],
          'fötternas': [('fot', False)],
          'fötters': [('fot', False)],
          'g': [('g', True)],
          'g-': [('g', True)],
          'ga': [('ga', False)],
          'ga-': [('ga', False)],
          'gabbar': [('gabbare', False)],
          'gabbarna': [('gabbare', False)],
          'gabbarnas': [('gabbare', False)],
          'gadd': [('gadd', True)],
          'gaddar': [('gadd', True)],
          'gadds': [('gadd', True)],
          'gadds-': [('gadd', True)],
          'gaeder': [('gaed', False)],
          'gaeders': [('gaed', False)],
          'gaff': [('gaff', True)],
          'gaff-': [('gaff', True)],
          'gaffar': [('gaff', True)],
          'gaffarna': [('gaff', True)],
          'gaffen': [('gaff', True)],
          'gaffs': [('gaff', True)],
          'gaffs-': [('gaff', True)],
          'gage': [('gage', False)],
          'gage-': [('gage', False)],
          'gagen': [('gag', True), ('gage', True)],
          'gagens': [('gage', True), ('gag', True)],
          'gagerna': [('gage', True)],
          'gagernas': [('gage', True)],
          'gagers': [('gage', True)],
          'gaget': [('gage', True), ('gag', True)],
          'gagets': [('gag', True), ('gage', True)],
          'gagg': [('gagg', True)],
          'gagg-': [('gagg', True)],
          'gaglans': [('gaglans', False)],
          'gagn': [('gagn', True)],
          'gagn-': [('gagn', True)],
          'gagnet': [('gagn', True)],
          'gagns': [('gagn', True)],
          'gagns-': [('gagn', True)],
          'gajks-': [('gajka', False)],
          'gajs-': [('gaj', True)],
          'gakron': [('gakrona', False)],
          'gakron-': [('gakrona', False)],
          'gakrons': [('gakrona', False)],
          'gal': [('gala', False)],
          'gal-': [('gala', False)],
          'galan': [('gala', False)],
          'galandets': [('galande', True)],
          'galans': [('gala', False)],
          'galar': [('gal', False)],
          'galas': [('gala', False)],
          'galats': [('galat', True)],
          'galats-': [('galat', True)],
          'gale': [('gala', True)],
          'gale-': [('gala', False)],
          'galeas': [('galeas', True)],
          'galej': [('galeja', True), ('galej', True)],
          'galej-': [('galeja', True), ('galej', True)],
          'galejs': [('galeja', True), ('galej', True)],
          'gales-': [('gales', False)],
          'galet': [('gale', False)],
          'galg': [('galge', False)],
          'galg-': [('galge', True)],
          'galgen': [('galge', False)],
          'galgens': [('galge', False)],
          'galgs': [('galge', True)],
          'galgs-': [('galge', True)],
          'galie-': [('galier', False)],
          'galien': [('gali', False)],
          'galins': [('gali', False)],
          'gall': [('galla', True), ('gall', True)],
          'gall-': [('gall', True), ('galla', True)],
          'gallan': [('galla', True)],
          'galle': [('galla', True)],
          'galle-': [('galla', True)],
          'gallen': [('gall', True)],
          'galler': [('gall', True), ('galler', True)],
          'galler-': [('galler', False)],
          'gallerna': [('gall', True), ('galler', True)],
          'gallernas': [('gall', True), ('galler', True)],
          'gallers': [('gall', True), ('galler', True)],
          'gallon': [('gallon', True)],
          'gallons': [('gallon', True)],
          'gallor': [('galla', True)],
          'gallorna': [('galla', True)],
          'gallornas': [('galla', True)],
          'gallors': [('galla', True)],
          'galls': [('gall', True), ('galla', True)],
          'galls-': [('gall', True), ('galla', True)],
          'galoners': [('galon', True)],
          'gals': [('gala', False)],
          'gals-': [('gala', True)],
          'galt-': [('galt', False)],
          'galtar': [('galt', False)],
          'galtarna': [('galt', False)],
          'galtarnas': [('galt', True)],
          'galts': [('galt', True)],
          'galts-': [('galt', True)],
          'gam': [('gam', False)],
          'gam-': [('gam', False)],
          'gamarnas': [('gam', False)],
          'game': [('game', True)],
          'game-': [('game', True)],
          'gamen': [('gam', True), ('game', True)],
          'gamens': [('gam', True), ('game', True)],
          'gamenten': [('gament', False)],
          'gamentens': [('gament', False)],
          'gamentet': [('gament', False)],
          'gaments-': [('gament', False)],
          'gamers': [('gam', False)],
          'gamet': [('gamet', True), ('game', True)],
          'gamets': [('gamet', True), ('game', True)],
          'gamin': [('gami', False)],
          'gamins': [('gami', False)],
          'gamman': [('gamman', True), ('gamma', True)],
          'gammans': [('gamman', True), ('gamma', True)],
          'gamotten': [('gamott', False)],
          'gams': [('gam', False)],
          'gams-': [('gam', False)],
          'gan': [('gan', True)],
          'gana': [('ga', False)],
          'ganarna': [('gan', True)],
          'ganarnas': [('gan', True)],
          'ganas': [('ga', False)],
          'gand': [('gand', False)],
          'ganden': [('gande', False)],
          'gandets': [('gande', False)],
          'gandierna': [('gandier', False)],
          'gandiernas': [('gandier', False)],
          'gandiers': [('gandier', False)],
          'gands': [('gand', False)],
          'gands-': [('gand', False)],
          'ganens': [('gan', False)],
          'ganets': [('gan', False)],
          'ganister': [('ganist', False)],
          'ganisters': [('ganist', False)],
          'gankar': [('gankare', False)],
          'gankar-': [('gankare', False)],
          'ganon': [('gano', False)],
          'ganons': [('gano', False)],
          'ganos': [('gano', False)],
          'gans': [('gans', True), ('gan', True)],
          'gans-': [('gans', True), ('gan', True)],
          'gansarnas': [('gan', False)],
          'gansen': [('gans', True)],
          'gansens': [('gans', False)],
          'ganser': [('gans', False)],
          'ganserna': [('gans', False)],
          'gansernas': [('gans', False)],
          'gansers': [('gans', False)],
          'gansk': [('ganska', False)],
          'gansk-': [('ganska', False)],
          'gant': [('gant', False)],
          'ganten': [('gant', False)],
          'gantens': [('gant', False)],
          'ganter': [('gant', False)],
          'ganterna': [('gant', False)],
          'ganternas': [('gant', False)],
          'ganters': [('gant', False)],
          'gap': [('gap', False)],
          'gap-': [('gap', False)],
          'gapar': [('gapar', False)],
          'gaparen': [('gapar', False)],
          'gapars': [('gapar', False)],
          'gapets': [('gap', False)],
          'gaps': [('gap', False)],
          'gaps-': [('gap', False)],
          'gar-': [('gare', False)],
          'garas': [('garas', False)],
          'gard': [('gard', False)],
          'gard-': [('gard', True)],
          'garden': [('garde', True), ('gard', True)],
          'gardens': [('garde', True), ('gard', True)],
          'garder': [('gard', True)],
          'garderna': [('gard', True)],
          'gardernas': [('gard', True)],
          'garders': [('gard', True)],
          'gardets': [('garde', False)],
          'gardin': [('gardin', False)],
          'gardins': [('gardin', True)],
          'gards': [('gard', True)],
          'gards-': [('gard', True)],
          'gare': [('gare', False)],
          'garens': [('gare', False)],
          'gares': [('gare', False)],
          'garill': [('garill', False)],
          'garills': [('garill', False)],
          'garin': [('garin', False)],
          'garmar': [('garm', False)],
          'garmarna': [('garm', False)],
          'garmarnas': [('garm', False)],
          'garn': [('garn', False)],
          'garner': [('garn', True)],
          'garners': [('garn', True)],
          'garns': [('garn', False)],
          'garr': [('garr', False)],
          'garr-': [('garr', False)],
          'garrens': [('garr', False)],
          'garrs-': [('garr', False)],
          'gart': [('gart', False)],
          'gart-': [('gart', False)],
          'garten': [('gart', False)],
          'gartens': [('gart', False)],
          'garter': [('gart', False)],
          'garterna': [('gart', False)],
          'garters': [('gart', False)],
          'garts': [('gart', False)],
          'garts-': [('gart', False)],
          'garv': [('garv', True)],
          'garv-': [('garv', True)],
          'garvar': [('garvare', True)],
          'garvarna': [('garvare', True)],
          'garvarnas': [('garvare', True)],
          'garven': [('garv', True)],
          'garvens': [('garv', True)],
          'garvs': [('garv', True)],
          'garvs-': [('garv', True)],
          'gas': [('gas', True)],
          'gas-': [('gas', False)],
          'gasar': [('gasare', False)],
          'gasar-': [('gasare', False)],
          'gasarens': [('gasare', False)],
          'gasarna': [('gasare', False)],
          'gasarnas': [('gasare', False)],
          'gaser': [('gas', True)],
          'gaserna': [('gas', True)],
          'gasernas': [('gas', True)],
          'gasers': [('gas', True)],
          'gasin': [('gasin', False)],
          'gask': [('gask', False)],
          'gask-': [('gask', True)],
          'gaskarna': [('gask', True)],
          'gasker': [('gask', False)],
          'gaskers': [('gask', True)],
          'gasklock': [('gasklocka', True)],
          'gasklocks': [('gasklocka', True)],
          'gasklocks-': [('gasklocka', True)],
          'gasm': [('gasm', False)],
          'gasm-': [('gasm', False)],
          'gasmer': [('gasm', False)],
          'gasmerna': [('gasm', False)],
          'gasmernas': [('gasm', False)],
          'gasmers': [('gasm', False)],
          'gass': [('gass', False)],
          'gasset': [('gass', True)],
          'gast-': [('gast', True)],
          'gastar': [('gast', True)],
          'gastarna': [('gast', True)],
          'gasten': [('gast', True)],
          'gat': [('gata', False)],
          'gat-': [('gata', False)],
          'gata': [('gata', False)],
          'gatan': [('gata', False)],
          'gatarierna': [('gatarie', False)],
          'gatariers': [('gatarie', False)],
          'gatas': [('gata', True)],
          'gate': [('gate', True)],
          'gate-': [('gate', True)],
          'gatell': [('gatell', False)],
          'gatell-': [('gatell', False)],
          'gatells': [('gatell', False)],
          'gatells-': [('gatell', False)],
          'gaten': [('gate', True)],
          'gatens': [('gate', True)],
          'gater': [('gate', True)],
          'gaterna': [('gate', True)],
          'gaternas': [('gate', True)],
          'gaters': [('gate', True)],
          'gates': [('gate', True)],
          'gates-': [('gate', True)],
          'gatidens': [('gatid', False)],
          'gatider': [('gatider', False)],
          'gatiders': [('gatider', False)],
          'gatids': [('gatid', False)],
          'gatids-': [('gatid', False)],
          'gation': [('gation', False)],
          'gationen': [('gation', False)],
          'gations': [('gation', False)],
          'gativets': [('gativ', False)],
          'gaton': [('gaton', False)],
          'gatons': [('gaton', False)],
          'gator': [('gata', True)],
          'gators': [('gata', True)],
          'gatos': [('gato', False)],
          'gatron': [('gatron', False)],
          'gatrons-': [('gatron', False)],
          'gats-': [('gata', False)],
          'gatt': [('gatt', False)],
          'gatt-': [('gatt', False)],
          'gattan': [('gatta', False)],
          'gattans': [('gatta', False)],
          'gatte': [('gatta', False)],
          'gatten': [('gatt', True)],
          'gatter': [('gatt', False)],
          'gatters': [('gatt', False)],
          'gattet': [('gatt', False)],
          'gatts': [('gatt', False)],
          'gatts-': [('gatt', False)],
          'gaur': [('gaur', True)],
          'gaur-': [('gaur', True)],
          'gaurs': [('gaur', True)],
          'gave-': [('gave', False)],
          'gavelrösten': [('gavelröst', True), ('gavelröste', True)],
          'gavelröstens': [('gavelröst', True), ('gavelröste', True)],
          'gavelröstet': [('gavelröste', True), ('gavelröst', True)],
          'gavelröstets': [('gavelröst', True), ('gavelröste', True)],
          'gaven': [('gave', False)],
          'gavens': [('gave', False)],
          'gaver': [('gave', False)],
          'gaverna': [('gave', False)],
          'gavernas': [('gave', False)],
          'gavers': [('gave', False)],
          'gavlarna': [('gavel', False)],
          'gback': [('gback', False)],
          'gback-': [('gback', False)],
          'gbackar': [('gback', False)],
          'gbackarna': [('gbacke', False)],
          'gbackarnas': [('gback', False)],
          'gbackars': [('gback', False)],
          'gbacke': [('gbacke', False)],
          'gbacke-': [('gbacke', False)],
          'gbacken': [('gback', False)],
          'gbackens': [('gback', False)],
          'gbacks': [('gback', False)],
          'gbacks-': [('gbacke', False)],
          'gbagg': [('gbagge', False)],
          'gbagg-': [('gbagge', False)],
          'gbaggar': [('gbagge', False)],
          'gbaggarna': [('gbagge', False)],
          'gbaggarnas': [('gbagge', False)],
          'gbaggars': [('gbagge', False)],
          'gbaggen': [('gbagge', False)],
          'gbaggens': [('gbagge', False)],
          'gbaggs': [('gbagge', False)],
          'gbaggs-': [('gbagge', False)],
          'gball': [('gball', False)],
          'gball-': [('gball', False)],
          'gballen': [('gball', False)],
          'gballens': [('gball', False)],
          'gballs': [('gball', False)],
          'gbanan': [('gbana', False)],
          'gbanans': [('gbana', False)],
          'gbandets': [('gband', False)],
          'gbane': [('gbana', False)],
          'gbane-': [('gbana', False)],
          'gbas': [('gbas', False)],
          'gbell': [('gbella', False)],
          'gbell-': [('gbella', False)],
          'gbells': [('gbella', False)],
          'gbells-': [('gbella', False)],
          'gben': [('gben', False)],
          'gbens': [('gben', False)],
          'gbens-': [('gben', False)],
          'gbil': [('gbil', False)],
          'gbilars': [('gbil', False)],
          'gbill': [('gbilla', False)],
          'gbill-': [('gbilla', False)],
          'gbills': [('gbill', False)],
          'gbills-': [('gbilla', False)],
          'gbils': [('gbil', False)],
          'gbils-': [('gbil', False)],
          'gbit': [('gbit', False)],
          'gbitars': [('gbit', False)],
          'gbits': [('gbit', False)],
          'gbits-': [('gbit', False)],
          'gblom': [('gblomma', False)],
          'gblom-': [('gblomma', False)],
          'gbloms': [('gblomma', False)],
          'gbloms-': [('gblomma', False)],
          'gbolaget': [('gbolag', False)],
          'gbomb': [('gbomb', False)],
          'gbomber': [('gbomb', False)],
          'gbomberna': [('gbomb', False)],
          'gbombernas': [('gbomb', False)],
          'gbombers': [('gbomb', False)],
          'gbombs': [('gbomb', False)],
          'gbombs-': [('gbomb', False)],
          'gborgar': [('gborg', False)],
          'gborgarna': [('gborg', False)],
          'gborgarnas': [('gborg', False)],
          'gborgen': [('gborg', False)],
          'gborgens': [('gborg', False)],
          'gborst': [('gborste', False)],
          'gborst-': [('gborste', False)],
          'gborstar': [('gborstare', False)],
          'gborstarna': [('gborstare', False)],
          'gborstarnas': [('gborstare', False)],
          'gborsten': [('gborste', False)],
          'gborstens': [('gborste', False)],
          'gbot': [('gbo', False)],
          'gbots': [('gbo', False)],
          'gbrandens': [('gbrand', False)],
          'gbroder': [('gbror', False)],
          'gbrodern': [('gbror', False)],
          'gbroderns': [('gbror', False)],
          'gbroders': [('gbror', False)],
          'gbrons': [('gbro', False)],
          'gbrors': [('gbror', False)],
          'gbrors-': [('gbror', False)],
          'gbrytar': [('gbrytare', False)],
          'gbrytarna': [('gbrytare', False)],
          'gbrytarnas': [('gbrytare', False)],
          'gbräds': [('gbräda', False)],
          'gbräds-': [('gbräda', False)],
          'gbröder': [('gbror', False)],
          'gbröderna': [('gbror', False)],
          'gbrödernas': [('gbror', False)],
          'gbröders': [('gbror', False)],
          'gbröst': [('gbröst', False)],
          'gbröst-': [('gbröst', False)],
          'gbyx': [('gbyxa', False)],
          'gbyx-': [('gbyxa', False)],
          'gbyxorna': [('gbyxa', False)],
          'gbäcken': [('gbäck', False)],
          'gbäckens': [('gbäck', False)],
          'gbåg': [('gbåge', False)],
          'gbåg-': [('gbåge', False)],
          'gbågs': [('gbåge', False)],
          'gbågs-': [('gbåge', False)],
          'gcentrer': [('gcentrum', False)],
          'gcentrerna': [('gcentrum', False)],
          'gcentrernas': [('gcentrum', False)],
          'gcentrers': [('gcentrum', False)],
          'gcentret': [('gcentrum', False)],
          'gd': [('gd', False)],
          'gd-': [('gd', False)],
          'gdagar': [('gdag', False)],
          'gdagarna': [('gdag', False)],
          'gdagen': [('gdag', False)],
          'gdagens': [('gdag', False)],
          'gdags': [('gdags', False)],
          'gdags-': [('gdag', False)],
          'gdan': [('gda', False)],
          'gdans': [('gda', False)],
          'gdar': [('gde', False)],
          'gdarna': [('gde', False)],
          'gdarnas': [('gde', False)],
          'gdars': [('gde', False)],
          'gdbens': [('gdben', False)],
          'gde': [('gd', False)],
          'gde-': [('gd', False)],
          'gden': [('gd', False)],
          'gdens': [('gd', False)],
          'gder': [('gd', False)],
          'gderits': [('gderi', False)],
          'gderna': [('gd', False)],
          'gdernas': [('gd', False)],
          'gders': [('gd', False)],
          'gdet': [('gd', False)],
          'gdhopp': [('gdhopp', False)],
          'gdhopps': [('gdhopp', False)],
          'gdhopps-': [('gdhopp', False)],
          'gdlopp': [('gdlopp', False)],
          'gdlopps': [('gdlopp', False)],
          'gdlopps-': [('gdlopp', False)],
          'gdomar': [('gdom', False)],
          'gdomarna': [('gdom', False)],
          'gdomarnas': [('gdom', False)],
          'gdomen': [('gdom', False)],
          'gdor': [('gda', False)],
          'gdorna': [('gda', False)],
          'gdornas': [('gda', False)],
          'gdors': [('gda', False)],
          'gdramer': [('gdrama', False)],
          'gdramerna': [('gdrama', False)],
          'gdramernas': [('gdrama', False)],
          'gdrivar': [('gdrivare', False)],
          'gdrivarna': [('gdrivare', False)],
          'gdrivarnas': [('gdrivare', False)],
          'gdropp': [('gdroppe', False)],
          'gdropp-': [('gdroppe', False)],
          'gdropps': [('gdroppe', False)],
          'gdropps-': [('gdroppe', False)],
          'gds': [('gd', False)],
          'gds-': [('gd', False)],
          'gdunkar': [('gdunkare', False)],
          'gdunkarna': [('gdunkare', False)],
          'gdunkarnas': [('gdunkare', False)],
          'ge': [('ge', False)],
          'ge-': [('ge', False)],
          'gecko-': [('gecko', True)],
          'gediens': [('gedi', False)],
          'gedier': [('gedi', False)],
          'gediers': [('gedi', False)],
          'gedins': [('gedi', False)],
          'gedis': [('gedi', False)],
          'geen': [('ge', False)],
          'geens': [('ge', False)],
          'geer': [('ge', False)],
          'geerna': [('ge', False)],
          'geernas': [('ge', False)],
          'geers': [('ge', False)],
          'geets': [('geum', False)],
          'gegal': [('gegala', False)],
          'gegal-': [('gegala', False)],
          'gegale': [('gegala', False)],
          'gegals': [('gegala', False)],
          'gegals-': [('gegala', False)],
          'gegerna': [('geg', True)],
          'gegernas': [('geg', True)],
          'gegs': [('geg', True)],
          'gejden': [('gejd', True)],
          'gejdens': [('gejd', True)],
          'gejder': [('gejd', True)],
          'gejders': [('gejd', True)],
          'gejser': [('gejser', True)],
          'gel': [('gel', True)],
          'gel-': [('gel', True)],
          'geldar': [('geld', False)],
          'geldarna': [('geld', False)],
          'geldarnas': [('geld', False)],
          'gelers': [('gel', True)],
          'gelie': [('gelium', False)],
          'geliken': [('gelike', True)],
          'gelkrokar': [('gelkrokar', False)],
          'gelkrokarna': [('gelkrokar', False)],
          'gelkrokars': [('gelkrokar', False)],
          'gelkroks': [('gelkrokar', False)],
          'gelkroks-': [('gelkrokar', False)],
          'gell': [('gell', False)],
          'gell-': [('gell', False)],
          'gellen': [('gell', False)],
          'geller': [('gell', False)],
          'gellerna': [('gell', False)],
          'gellernas': [('gell', False)],
          'gellers': [('gell', False)],
          'gells': [('gell', False)],
          'gells-': [('gell', False)],
          'gelsaxar': [('gelsax', False)],
          'gelsaxarna': [('gelsax', False)],
          'gelsaxarnas': [('gelsax', False)],
          'gelset': [('gelse', False)],
          'gelsets': [('gelse', False)],
          'gelskurs': [('gelskur', False)],
          'gelskurs-': [('gelskur', False)],
          'gelslagar': [('gelslagare', False)],
          'gelslagarna': [('gelslagare', False)],
          'gelslagarnas': [('gelslagare', False)],
          'gelsträcks': [('gelsträck', False)],
          'gelställen': [('gelställ', False)],
          'gelställens': [('gelställ', False)],
          'gelstället': [('gelställ', False)],
          'gelställets': [('gelställ', False)],
          'gelsömmar': [('gelsöm', False)],
          'gelsömmarna': [('gelsöm', False)],
          'gelsömmarnas': [('gelsöm', False)],
          'geluck-': [('gelucka', False)],
          'gelucks': [('gelucka', False)],
          'gelucks-': [('gelucka', False)],
          'gelvägen': [('gelvägen', False)],
          'gelvägens': [('gelvägen', False)],
          'gem': [('gem', True)],
          'gem-': [('gem', False)],
          'gemang': [('gemang', False)],
          'gemang-': [('gemang', False)],
          'gemanger': [('gemang', False)],
          'gemangerna': [('gemang', False)],
          'gemangernas': [('gemang', False)],
          'gemangers': [('gemang', False)],
          'gemangs': [('gemang', False)],
          'gemangs-': [('gemang', False)],
          'gementen': [('gement', False)],
          'gementens': [('gement', False)],
          'gementet': [('gement', False)],
          'gementets': [('gemente', False)],
          'gements': [('gemente', False)],
          'gements-': [('gement', False)],
          'gemmer': [('gem', True)],
          'gemmers': [('gem', True)],
          'gems': [('gems', True), ('gem', True)],
          'gems-': [('gems', True), ('gem', True)],
          'gen': [('gen', True)],
          'gen-': [('gen', True)],
          'gena': [('ge', False)],
          'genar': [('genare', False)],
          'genar-': [('genare', False)],
          'genarens': [('genare', False)],
          'genarna': [('genare', False)],
          'genarnas': [('genare', False)],
          'genas': [('ge', False)],
          'gendans': [('genda', False)],
          'genden': [('gend', False)],
          'gendens': [('gend', False)],
          'gender': [('gend', False)],
          'genderna': [('gend', False)],
          'genders': [('gend', False)],
          'gener': [('gen', True)],
          'generna': [('gen', True)],
          'genernas': [('gen', True)],
          'geners': [('gen', True)],
          'genes': [('genes', False)],
          'genes-': [('genes', False)],
          'genet': [('gen', False)],
          'genets': [('gen', False)],
          'genfordringar': [('genfordran', True), ('genfordring', True)],
          'genfordringarna': [('genfordring', True), ('genfordran', True)],
          'genfordringarnas': [('genfordran', True), ('genfordring', True)],
          'genfordringars': [('genfordran', True), ('genfordring', True)],
          'genheter': [('genhet', False)],
          'genheterna': [('genhet', False)],
          'genheternas': [('genhet', False)],
          'genheters': [('genhet', False)],
          'genhets': [('genhet', False)],
          'genhets-': [('genhet', False)],
          'geni': [('geni', False)],
          'geni-': [('geni', False)],
          'genie': [('genie', True)],
          'genie-': [('genie', True)],
          'genien': [('genie', True)],
          'geniens': [('genie', True)],
          'genier': [('genie', True), ('geni', True)],
          'genierna': [('genie', True), ('geni', True)],
          'geniernas': [('genie', True), ('geni', True)],
          'geniers': [('genie', True), ('geni', True)],
          'geniet': [('geni', False)],
          'geniets': [('geni', True)],
          'genis': [('geni', True)],
          'genit': [('geni', True)],
          'genn': [('gen', False)],
          'genomens': [('genom', True)],
          'gens': [('gen', False)],
          'gens-': [('gen', True)],
          'gensarnas': [('gensare', True)],
          'gensen': [('gens', False)],
          'gensens': [('gens', False)],
          'genser': [('gens', False)],
          'genserna': [('gens', False)],
          'gensernas': [('gens', False)],
          'gensers': [('gens', False)],
          'gensk': [('genska', False)],
          'gensk-': [('genska', False)],
          'genskaps-': [('genskap', False)],
          'gent': [('gent', False)],
          'genten': [('gent', False)],
          'gentens': [('gent', False)],
          'genter': [('gent', False)],
          'genterna': [('gent', False)],
          'genternas': [('gent', False)],
          'genters': [('gent', False)],
          'gentian': [('gentiana', True)],
          'gentians': [('gentiana', True)],
          'gentier': [('gentier', False)],
          'gentiernas': [('gentier', False)],
          'gentiers': [('gentier', False)],
          'gentor': [('genta', False)],
          'gentors': [('genta', False)],
          'gents-': [('gent', False)],
          'genus': [('genua', True), ('genus', True)],
          'genus-': [('genua', True), ('genus', True)],
          'genvägar': [('genväg', True)],
          'genvägarna': [('genväg', True)],
          'genvägarnas': [('genväg', True)],
          'genvägars': [('genväg', True)],
          'ger': [('ger', False)],
          'ger-': [('ger', False)],
          'gerare': [('gerare', False)],
          'gerares': [('gerare', False)],
          'gerarna': [('gerare', False)],
          'gerarnas': [('gerare', False)],
          'gerben': [('gerben', False)],
          'gerbens-': [('gerben', False)],
          'gerborgen': [('gerborg', False)],
          'gerborgens': [('gerborg', False)],
          'gerer': [('gerer', False)],
          'gererna': [('gerer', False)],
          'gerernas': [('gerer', False)],
          'gerers': [('gerer', False)],
          'gerfots': [('gerfot', False)],
          'gerfots-': [('gerfot', False)],
          'geri': [('geri', False)],
          'geri-': [('geri', False)],
          'gerian': [('gerian', False)],
          'gerians': [('gerian', False)],
          'gerier': [('geri', False)],
          'gerierna': [('geri', False)],
          'geriernas': [('gerier', False)],
          'geriers': [('geri', False)],
          'geriet': [('geri', False)],
          'gerin': [('gerin', False)],
          'geris': [('geri', False)],
          'geris-': [('geri', False)],
          'gerit': [('geri', False)],
          'gerkrokar': [('gerkrokar', False)],
          'gerkrokarna': [('gerkrokar', False)],
          'gerkrokarnas': [('gerkrok', False)],
          'gerkrokars': [('gerkrokar', False)],
          'german': [('german', True)],
          'germans': [('german', True)],
          'gerna': [('ge', False)],
          'gernas': [('ge', False)],
          'gers': [('gers', True)],
          'gers-': [('gers', True)],
          'gersarna': [('gers', True)],
          'gersarnas': [('gers', True)],
          'gersen': [('gers', True)],
          'gersens': [('gers', True)],
          'gertens': [('gert', False)],
          'gerts': [('gert', False)],
          'gerts-': [('gert', False)],
          'gervals': [('gervals', False)],
          'gervanten': [('gervante', False)],
          'gervantens': [('gervante', False)],
          'gerån': [('gerån', False)],
          'ges': [('ge', False)],
          'ges-': [('ge', False)],
          'gesed': [('gesed', False)],
          'gesed-': [('gesed', False)],
          'gesede': [('gesed', False)],
          'gesede-': [('gesed', False)],
          'geseds': [('gesed', False)],
          'geseds-': [('gesed', False)],
          'gest-': [('gest', False)],
          'gestar': [('gest', False)],
          'gestarna': [('gest', False)],
          'gesten': [('gest', False)],
          'gester': [('gest', True)],
          'gesterna': [('gest', True)],
          'gesternas': [('gest', False)],
          'gesters': [('gest', True)],
          'gestilens': [('gestil', False)],
          'geston': [('geston', False)],
          'get': [('get', True)],
          'getarnas': [('get', False)],
          'geten': [('get', False)],
          'getens': [('get', False)],
          'geter': [('get', False)],
          'geters': [('get', False)],
          'getidens': [('getid', False)],
          'gets': [('get', True)],
          'gett': [('gett', False)],
          'gett-': [('gett', False)],
          'gette-': [('gette', False)],
          'getten': [('gett', False)],
          'gettens': [('gette', False)],
          'getter': [('get', True)],
          'getterna': [('get', True)],
          'getternas': [('get', False)],
          'getters': [('get', False)],
          'getts': [('gett', False)],
          'getts-': [('gett', False)],
          'gfasen': [('gfas', False)],
          'gfasens': [('gfas', False)],
          'gfel': [('gfel', False)],
          'gfels': [('gfel', False)],
          'gfels-': [('gfel', False)],
          'gfen': [('gfena', False)],
          'gfena': [('gfena', False)],
          'gfens': [('gfena', False)],
          'gfilar': [('gfil', False)],
          'gfilarna': [('gfil', False)],
          'gfilarnas': [('gfil', False)],
          'gfilen': [('gfil', False)],
          'gfilens': [('gfil', False)],
          'gfink': [('gfink', False)],
          'gfink-': [('gfink', False)],
          'gfinks': [('gfink', False)],
          'gfinks-': [('gfink', False)],
          'gfinnar': [('gfinnare', False)],
          'gfinnarna': [('gfinnare', False)],
          'gfinnarnas': [('gfinnare', False)],
          'gfiskar': [('gfisk', False)],
          'gfiskarna': [('gfisk', False)],
          'gfiskarnas': [('gfisk', False)],
          'gfixar': [('gfix', False)],
          'gfixarna': [('gfix', False)],
          'gfixarnas': [('gfix', False)],
          'gfjäll': [('gfjäll', False)],
          'gfjäll-': [('gfjäll', False)],
          'gfjälls': [('gfjäll', False)],
          'gfjälls-': [('gfjäll', False)],
          'gflor': [('gflor', False)],
          'gflor-': [('gflor', False)],
          'gflors': [('gflor', False)],
          'gflors-': [('gflor', False)],
          'gflotte': [('gflotta', False)],
          'gflyt': [('gfly', False)],
          'gflyts': [('gfly', False)],
          'gfläck': [('gfläck', False)],
          'gfläcks': [('gfläck', False)],
          'gflödet': [('gflöde', False)],
          'gfoton': [('gfoto', False)],
          'gfotons': [('gfoto', False)],
          'gförar': [('gförare', False)],
          'gförarna': [('gförare', False)],
          'gförarnas': [('gförare', False)],
          'gförlust-': [('gförlust', False)],
          'gförluster': [('gförlust', False)],
          'gförlusterna': [('gförlust', False)],
          'gförlusternas': [('gförlust', False)],
          'gg': [('gg', False)],
          'gg-': [('gg', False)],
          'ggan': [('gga', False)],
          'ggandens': [('ggande', False)],
          'ggans': [('gga', False)],
          'ggaren': [('ggare', False)],
          'ggarna': [('gg', False)],
          'ggarnas': [('gg', False)],
          'ggars': [('gg', False)],
          'ggas': [('gga', False)],
          'ggaserna': [('ggas', False)],
          'ggasernas': [('ggas', False)],
          'ggate': [('ggata', False)],
          'ggate-': [('ggata', False)],
          'ggator': [('ggata', False)],
          'ggators': [('ggata', False)],
          'ggats': [('ggata', False)],
          'ggdags': [('ggdag', False)],
          'ggdags-': [('ggdags', False)],
          'ggdans': [('ggdans', False)],
          'gge': [('gga', False)],
          'gge-': [('gga', False)],
          'ggel': [('ggel', False)],
          'ggel-': [('ggel', False)],
          'ggelsen': [('ggelse', False)],
          'ggelsens': [('ggelse', False)],
          'ggen': [('gg', False)],
          'ggens': [('gg', False)],
          'gger': [('gg', False)],
          'ggeriernas': [('ggeri', False)],
          'ggerna': [('gg', False)],
          'ggernas': [('gg', False)],
          'ggers': [('gg', False)],
          'ggers-': [('gger', False)],
          'ggersarna': [('gger', False)],
          'ggersarnas': [('gger', False)],
          'ggersen': [('gger', False)],
          'ggersens': [('gger', False)],
          'gget': [('gg', False)],
          'gghets': [('gghet', False)],
          'ggian': [('ggia', False)],
          'ggians': [('ggia', False)],
          'ggiernas': [('ggi', False)],
          'ggiftet': [('ggifte', False)],
          'ggiftets': [('ggifte', False)],
          'ggin': [('ggi', False)],
          'ggins': [('ggi', False)],
          'ggion': [('ggio', False)],
          'ggions': [('ggio', False)],
          'ggis-': [('ggia', False)],
          'ggla': [('ggla', False)],
          'gglagen': [('gglag', False)],
          'gglans': [('ggla', False)],
          'gglas': [('ggla', False)],
          'gglin': [('gglina', False)],
          'gglina': [('gglina', False)],
          'gglinas': [('gglina', False)],
          'gglins': [('gglina', False)],
          'gglors': [('ggla', False)],
          'gglos': [('gglo', False)],
          'ggman': [('ggma', False)],
          'ggmans': [('ggma', False)],
          'ggon': [('ggo', False)],
          'ggons': [('ggo', False)],
          'ggor': [('gga', False)],
          'ggorna': [('gga', False)],
          'ggornas': [('gga', False)],
          'ggors': [('gga', False)],
          'ggot': [('ggo', False)],
          'ggots': [('ggo', False)],
          'ggprickar': [('ggprickare', False)],
          'ggprickarna': [('ggprickare', False)],
          'ggprickarnas': [('ggprickare', False)],
          'ggrar': [('gger', False)],
          'ggrarna': [('gger', False)],
          'ggrars': [('gger', False)],
          'ggrep': [('ggrep', False)],
          'ggrepar': [('ggrep', False)],
          'ggreparna': [('ggrep', False)],
          'ggreparnas': [('ggrep', False)],
          'ggrepars': [('ggrep', False)],
          'ggrepen': [('ggrep', False)],
          'ggrepens': [('ggrep', False)],
          'ggreps': [('ggrep', False)],
          'ggreps-': [('ggrep', False)],
          'ggryt': [('ggryta', False)],
          'ggryt-': [('ggryta', False)],
          'ggryts': [('ggryta', False)],
          'ggryts-': [('ggryta', False)],
          'ggs': [('gg', False)],
          'ggs-': [('gg', False)],
          'ggsgryt': [('ggsgryta', False)],
          'ggsgryt-': [('ggsgryta', False)],
          'ggsgryts': [('ggsgryta', False)],
          'ggsgryts-': [('ggsgryta', False)],
          'ggskal': [('ggskal', False)],
          'ggskals': [('ggskal', False)],
          'ggskostnader': [('ggskostnad', False)],
          'ggskostnaderna': [('ggskostnad', False)],
          'ggskostnadernas': [('ggskostnad', False)],
          'ggskostnaders': [('ggskostnad', False)],
          'ggskostnads': [('ggskostnad', False)],
          'ggskostnads-': [('ggskostnad', False)],
          'ggstens': [('ggsten', False)],
          'ggsvärden': [('ggsvärd', False)],
          'ggsvärdets': [('ggsvärd', False)],
          'ggtanden': [('ggtand', False)],
          'ggtandens': [('ggtand', False)],
          'ggung': [('ggunga', False)],
          'ggung-': [('ggunga', False)],
          'ggungs': [('ggunga', False)],
          'ggungs-': [('ggunga', False)],
          'ggvar': [('ggvara', False)],
          'ggvar-': [('ggvar', False)],
          'ggångar': [('ggång', False)],
          'ggångarna': [('ggång', False)],
          'ggångarnas': [('ggång', False)],
          'ggås': [('ggås', False)],
          'ggås-': [('ggås', False)],
          'ggåsar': [('ggås', False)],
          'ggåsarna': [('ggås', False)],
          'ggåsarnas': [('ggås', False)],
          'ggåsars': [('ggås', False)],
          'ggåsen': [('ggås', False)],
          'ggåsens': [('ggås', False)],
          'ghamrar': [('ghammare', False)],
          'ghan': [('ghan', False)],
          'ghan-': [('ghan', False)],
          'ghandlarna': [('ghandel', False)],
          'ghandlarnas': [('ghandel', False)],
          'ghanen': [('ghan', False)],
          'ghanens': [('ghan', False)],
          'ghanes': [('ghanes', True)],
          'ghanes-': [('ghanes', True)],
          'ghans': [('ghan', False)],
          'ghar': [('gh', False)],
          'gharmonier': [('gharmoni', False)],
          'gharmonierna': [('gharmoni', False)],
          'gharmoniernas': [('gharmoni', False)],
          'gharmoniers': [('gharmoni', False)],
          'gharmonik': [('gharmonika', False)],
          'gharmonik-': [('gharmonika', False)],
          'gharmoniks': [('gharmonika', False)],
          'gharna': [('gh', False)],
          'ghars': [('gh', False)],
          'ghen': [('gh', False)],
          'ghens': [('gh', False)],
          'gherr': [('gherre', False)],
          'gherr-': [('gherre', False)],
          'gherrs': [('gherre', False)],
          'gheter': [('ghet', False)],
          'gheterna': [('ghet', False)],
          'gheternas': [('ghet', False)],
          'gheters': [('ghet', False)],
          'ghets-': [('ghet', False)],
          'ghonas': [('ghona', False)],
          'ghs-': [('gh', False)],
          'ghsarna': [('gh', False)],
          'ghsarnas': [('gh', False)],
          'ghundars': [('ghund', False)],
          'ghurts': [('ghurt', False)],
          'ghurts-': [('ghurt', False)],
          'ghus': [('ghus', False)],
          'ghylle': [('ghylla', False)],
          'ghylle-': [('ghylla', False)],
          'ghylls-': [('ghylla', False)],
          'ghyvlar': [('ghyvel', False)],
          'ghyvlarna': [('ghyvel', False)],
          'ghyvlarnas': [('ghyvel', False)],
          'ghäll': [('ghäll', False)],
          'ghäll-': [('ghäll', False)],
          'ghälls': [('ghäll', False)],
          'ghälls-': [('ghäll', False)],
          'ghänget': [('ghänge', False)],
          'ghängets': [('ghänge', False)],
          'ghängs': [('ghänge', False)],
          'ghängs-': [('ghänge', False)],
          'ghäst': [('ghäst', False)],
          'ghästar': [('ghäst', False)],
          'ghästarnas': [('ghäst', False)],
          'ghästars': [('ghäst', False)],
          'ghål': [('ghål', False)],
          'ghål-': [('ghål', False)],
          'ghåls': [('ghål', False)],
          'ghåls-': [('ghål', False)],
          'ghökar': [('ghök', False)],
          'ghökarna': [('ghök', False)],
          'ghökarnas': [('ghök', False)],
          'gi': [('gi', False)],
          'gi-': [('gi', False)],
          'gian': [('gian', False)],
          'gian-': [('gian', False)],
          'gians': [('gian', False)],
          'gians-': [('gian', False)],
          'giat': [('giat', False)],
          'giats': [('giat', False)],
          'giden': [('gid', False)],
          'gidens': [('gid', False)],
          'gids': [('gid', False)],
          'gie': [('gia', False)],
          'gie-': [('gia', False)],
          'gien': [('gi', False)],
          'giens': [('gi', False)],
          'gier': [('gi', False)],
          'gierna': [('gi', False)],
          'giernas': [('gium', False)],
          'giers': [('gi', False)],
          'giet': [('gium', False)],
          'giets': [('gium', False)],
          'gifflar': [('giffel', True)],
          'gifflarna': [('giffel', True)],
          'gifflarnas': [('giffel', True)],
          'gift': [('gift', False)],
          'gift-': [('gift', False)],
          'giften': [('gifte', True)],
          'giftens': [('gifte', True)],
          'giftet': [('gifte', True), ('gift', True)],
          'giftets': [('gift', True), ('gifte', True)],
          'gifts': [('gifte', True), ('gift', True)],
          'gifts-': [('gifte', True), ('gift', True)],
          'gig': [('giga', True), ('gig', True)],
          'gig-': [('giga', True), ('gig', True)],
          'gigan': [('giga', True)],
          'gigets': [('gig', True)],
          'gigg': [('gigg', True)],
          'gigg-': [('gigg', True)],
          'giggarna': [('gigg', True)],
          'giggarnas': [('gigg', True)],
          'giggars': [('gigg', True)],
          'giggen': [('gigg', True)],
          'giggens': [('gigg', True)],
          'giggs': [('gigg', True)],
          'giggs-': [('gigg', True)],
          'gigheter': [('gighet', False)],
          'gigheterna': [('gighet', False)],
          'gigheternas': [('gighet', False)],
          'gigheters': [('gighet', False)],
          'gighets-': [('gighet', False)],
          'gigs': [('giga', True), ('gig', True)],
          'gigs-': [('giga', True), ('gig', True)],
          'giker': [('giker', False)],
          'gikerna': [('giker', False)],
          'gikernas': [('giker', False)],
          'gikers': [('giker', False)],
          'gikten': [('gikt', True)],
          'giktens': [('gikt', True)],
          'gikts': [('gikt', True)],
          'gikts-': [('gikt', True)],
          'gilans': [('gilans', False)],
          'gilians': [('gilia', False)],
          'gilie': [('gilia', False)],
          'gilie-': [('gilia', False)],
          'gilis': [('gilia', False)],
          'gilister': [('gilist', False)],
          'gilisters': [('gilist', False)],
          'gill': [('gill', False)],
          'gill-': [('gill', False)],
          'gillen': [('gille', True)],
          'gillens': [('gille', False)],
          'gillet': [('gille', True)],
          'gillets': [('gille', True)],
          'gills': [('gille', True)],
          'gills-': [('gille', True)],
          'gimer': [('gim', False)],
          'gimers': [('gim', False)],
          'gin': [('gina', True), ('gin', True)],
          'gin-': [('gin', True), ('gina', True)],
          'gina': [('gina', False)],
          'ginandens': [('ginande', True)],
          'ginans': [('gina', True)],
          'ginas': [('gina', True)],
          'gine': [('gina', True)],
          'gine-': [('gina', True)],
          'ginen': [('gin', True)],
          'ginens': [('gin', True)],
          'ginernas': [('gine', False)],
          'gines': [('gine', False)],
          'gines-': [('gine', False)],
          'ginets': [('gin', False)],
          'ginfluens': [('ginfluensa', False)],
          'ginfluens-': [('ginfluensa', False)],
          'ging': [('ging', False)],
          'ging-': [('ging', False)],
          'gingar': [('ging', False)],
          'gingarna': [('ging', False)],
          'gingarnas': [('ging', False)],
          'gingars': [('ging', False)],
          'gingen': [('ging', False)],
          'gingens': [('ging', False)],
          'gings': [('ging', False)],
          'gings-': [('ging', False)],
          'ginkomst': [('ginkomster', False)],
          'ginkomst-': [('ginkomster', False)],
          'ginkomster': [('ginkomster', False)],
          'ginkomsterna': [('ginkomster', False)],
          'ginkomsternas': [('ginkomster', False)],
          'ginkomsters': [('ginkomster', False)],
          'ginne': [('ginna', False)],
          'ginne-': [('ginna', False)],
          'gins': [('gin', True), ('gina', True)],
          'gins-': [('gin', True), ('gina', True)],
          'ginvägar': [('ginväg', True)],
          'ginvägarna': [('ginväg', True)],
          'ginvägarnas': [('ginväg', True)],
          'ginvägars': [('ginväg', True)],
          'ginvägs': [('ginväg', True)],
          'ginvägs-': [('ginväg', True)],
          'gion': [('gion', False)],
          'gionen': [('gion', False)],
          'gionens': [('gion', False)],
          'gioner': [('gion', False)],
          'gionerna': [('gion', False)],
          'gionernas': [('gion', False)],
          'gioners': [('gion', False)],
          'gions': [('gion', False)],
          'gior': [('gia', False)],
          'giorna': [('gia', False)],
          'giornas': [('gia', False)],
          'giors': [('gia', False)],
          'giot': [('gio', False)],
          'gip': [('gip', True), ('gipa', True)],
          'gip-': [('gipa', True), ('gip', True)],
          'gipan': [('gipa', False)],
          'gipans': [('gipa', False)],
          'giparnas': [('gip', True)],
          'gipas': [('gipa', True)],
          'gipp': [('gipp', True)],
          'gipp-': [('gipp', True)],
          'gippar': [('gipp', True)],
          'gipparna': [('gipp', True)],
          'gippen': [('gipp', True)],
          'gippens': [('gipp', True)],
          'gipps': [('gipp', True)],
          'gipps-': [('gipp', True)],
          'gips': [('gips', True), ('gipa', True), ('gip', True)],
          'gips-': [('gips', True), ('gip', True), ('gipa', True)],
          'girar': [('gir', True)],
          'girarna': [('gir', False)],
          'girarnas': [('gir', False)],
          'gis': [('gi', False)],
          'gis-': [('gi', False)],
          'giskan': [('giska', False)],
          'giskans': [('giska', False)],
          'giske': [('giska', False)],
          'giske-': [('giska', False)],
          'gismer': [('gism', False)],
          'gismernas': [('gism', False)],
          'gissel': [('gissel', True)],
          'gissel-': [('gissel', True)],
          'gist-': [('gist', True)],
          'gisten': [('gist', False)],
          'gistens': [('gist', False)],
          'gister': [('gist', False)],
          'gistern': [('gister', False)],
          'gisterna': [('gist', False)],
          'gisternas': [('gist', False)],
          'gisterns': [('gister', False)],
          'gisters': [('gist', False)],
          'gistik': [('gistik', False)],
          'gistik-': [('gistik', False)],
          'gistiks': [('gistik', False)],
          'git': [('gi', False)],
          'giternas': [('git', False)],
          'gits': [('git', False)],
          'gitter': [('gitter', True)],
          'gitter-': [('gitter', False)],
          'gium': [('gium', False)],
          'giums': [('gium', False)],
          'giv': [('giv', True)],
          'giv-': [('giv', True)],
          'givar': [('giv', True), ('givare', True)],
          'givarna': [('giv', True), ('givare', True)],
          'givarnas': [('giv', True), ('givare', True)],
          'givs': [('giv', True)],
          'givs-': [('giv', True)],
          'gjan': [('gja', False)],
          'gjans': [('gja', False)],
          'gje': [('gja', False)],
          'gje-': [('gja', False)],
          'gjor': [('gja', False)],
          'gjorna': [('gja', False)],
          'gjornas': [('gja', False)],
          'gjors': [('gja', False)],
          'gjus': [('gjuse', True)],
          'gjus-': [('gjuse', True)],
          'gjusar': [('gjuse', False)],
          'gjusarna': [('gjuse', False)],
          'gjusarnas': [('gjuse', True)],
          'gjusen': [('gjuse', True)],
          'gjusens': [('gjuse', False)],
          'gjutar': [('gjutare', False)],
          'gjutarna': [('gjutare', False)],
          'gjutarnas': [('gjutare', False)],
          'gjutsanden': [('gjutsand', True)],
          'gjutsandens': [('gjutsand', True)],
          'gkammar': [('gkam', False)],
          'gkams': [('gkam', False)],
          'gkams-': [('gkam', False)],
          'gkapp': [('gkappa', False)],
          'gkapp-': [('gkapp', False)],
          'gkappe': [('gkappa', False)],
          'gkappen': [('gkapp', False)],
          'gkappens': [('gkapp', False)],
          'gkapps': [('gkappa', False)],
          'gkapps-': [('gkappa', False)],
          'gkist-': [('gkista', False)],
          'gkistan': [('gkista', False)],
          'gkistans': [('gkista', False)],
          'gkling': [('gklinga', False)],
          'gkling-': [('gklinga', False)],
          'gklings': [('gklinga', False)],
          'gklings-': [('gklinga', False)],
          'gklock': [('gklocka', False)],
          'gklopps-': [('gkloppa', False)],
          'gklot': [('gklot', False)],
          'gklots': [('gklot', False)],
          'gklots-': [('gklot', False)],
          'gklubb': [('gklubb', False)],
          'gklubbs': [('gklubb', False)],
          'gklubbs-': [('gklubb', False)],
          'gklädes': [('gkläder', False)],
          'gklädes-': [('gkläder', False)],
          'gknall': [('gknalle', False)],
          'gknall-': [('gknalle', False)],
          'gknallar': [('gknalle', False)],
          'gknallarna': [('gknalle', False)],
          'gknallarnas': [('gknalle', False)],
          'gknallars': [('gknalle', False)],
          'gknallen': [('gknalle', False)],
          'gknallens': [('gknalle', False)],
          'gknalls': [('gknalle', False)],
          'gknalls-': [('gknalle', False)],
          'gknip': [('gknipa', False)],
          'gknip-': [('gknipa', False)],
          'gknips': [('gknipa', False)],
          'gknips-': [('gknipa', False)],
          'gknut': [('gknut', False)],
          'gknuts': [('gknut', False)],
          'gknuts-': [('gknut', False)],
          'gko-': [('gko', False)],
          'gkoj': [('gkoj', False)],
          'gkojs': [('gkoj', False)],
          'gkojs-': [('gkoj', False)],
          'gkok': [('gkok', False)],
          'gkok-': [('gkok', False)],
          'gkoks': [('gkok', False)],
          'gkoks-': [('gkok', False)],
          'gkols': [('gkol', False)],
          'gkomst-': [('gkomst', False)],
          'gkomster': [('gkomst', False)],
          'gkomsterna': [('gkomst', False)],
          'gkomsternas': [('gkomst', False)],
          'gkomsters': [('gkomst', False)],
          'gkon': [('gko', False)],
          'gkons': [('gko', False)],
          'gkonst-': [('gkonst', False)],
          'gkonster': [('gkonst', False)],
          'gkonsterna': [('gkonst', False)],
          'gkonsternas': [('gkonst', False)],
          'gkonsters': [('gkonst', False)],
          'gkopp': [('gkopp', False)],
          'gkopp-': [('gkopp', False)],
          'gkoppar': [('gkopp', False)],
          'gkoppars': [('gkopp', False)],
          'gkopps': [('gkopp', False)],
          'gkopps-': [('gkopp', False)],
          'gkor': [('gko', False)],
          'gkoret': [('gkor', False)],
          'gkorets': [('gkor', False)],
          'gkors-': [('gkors', False)],
          'gkos': [('gko', False)],
          'gkos-': [('gko', False)],
          'gkostnader': [('gkostnad', False)],
          'gkostnaderna': [('gkostnad', False)],
          'gkostnadernas': [('gkostnad', False)],
          'gkrafts': [('gkraft', False)],
          'gkrafts-': [('gkraft', False)],
          'gkramar': [('gkramare', False)],
          'gkramarna': [('gkramare', False)],
          'gkramarnas': [('gkramare', False)],
          'gkrit': [('gkrita', False)],
          'gkrits-': [('gkrita', False)],
          'gkrokarnas': [('gkrok', False)],
          'gkronan': [('gkrona', False)],
          'gkronans': [('gkrona', False)],
          'gkröns-': [('gkrön', False)],
          'gkubb': [('gkubbe', False)],
          'gkubb-': [('gkubbe', False)],
          'gkubbar': [('gkubbe', False)],
          'gkubbarna': [('gkubbe', False)],
          'gkubbarnas': [('gkubbe', False)],
          'gkubbars': [('gkubbe', False)],
          'gkubben': [('gkubbe', False)],
          'gkubbens': [('gkubbe', False)],
          'gkubbs': [('gkubbe', False)],
          'gkubbs-': [('gkubbe', False)],
          'gkull': [('gkulle', False)],
          'gkull-': [('gkulle', False)],
          'gkullar': [('gkulle', False)],
          'gkullarna': [('gkulle', False)],
          'gkullarnas': [('gkulle', False)],
          'gkullars': [('gkulle', False)],
          'gkulle': [('gkulle', False)],
          'gkulle-': [('gkulle', False)],
          'gkullen': [('gkulle', False)],
          'gkullens': [('gkulle', False)],
          'gkulls': [('gkulle', False)],
          'gkulls-': [('gkulle', False)],
          'gkunskaps': [('gkunskap', False)],
          'gkurr': [('gkurre', False)],
          'gkurr-': [('gkurre', False)],
          'gkurren': [('gkurre', False)],
          'gkurrens': [('gkurre', False)],
          'gkurrs': [('gkurre', False)],
          'gkurrs-': [('gkurre', False)],
          'gkurv': [('gkurva', False)],
          'gkurv-': [('gkurva', False)],
          'gkurvor': [('gkurva', False)],
          'gkurvorna': [('gkurva', False)],
          'gkurvornas': [('gkurva', False)],
          'gkurvors': [('gkurva', False)],
          'gkurvs': [('gkurva', False)],
          'gkurvs-': [('gkurva', False)],
          'gkvarter': [('gkvarter', False)],
          'gkvarters': [('gkvarter', False)],
          'gkäll': [('gkälla', False)],
          'gkäll-': [('gkälla', False)],
          'gkärr': [('gkärra', False)],
          'gkärr-': [('gkärra', False)],
          'gkärrs': [('gkärra', False)],
          'gkärrs-': [('gkärra', False)],
          'gkår': [('gkår', False)],
          'gkåren': [('gkår', False)],
          'gkårens': [('gkår', False)],
          'gkårs': [('gkår', False)],
          'gkårs-': [('gkår', False)],
          'gkök-': [('gkök', False)],
          'gköks': [('gkök', False)],
          'gköks-': [('gkök', False)],
          'gla-': [('gel', False)],
          'glacen': [('glace', True)],
          'glad': [('glad', True), ('glada', True)],
          'glad-': [('glada', True), ('glad', True)],
          'glads': [('glada', True), ('glad', True)],
          'glads-': [('glada', True), ('glad', True)],
          'glagarna': [('glag', False)],
          'glagarnas': [('glag', False)],
          'glagen': [('glage', False)],
          'glagens': [('glag', False)],
          'glagerna': [('glager', False)],
          'glaget': [('glage', False)],
          'glagets': [('glage', False)],
          'glags': [('glag', False)],
          'glags-': [('glag', False)],
          'glak-': [('glake', False)],
          'glaks': [('glake', False)],
          'glam': [('glam', True)],
          'glam-': [('glam', True)],
          'glamat': [('glamat', False)],
          'glamats': [('glamat', False)],
          'glammet': [('glam', True)],
          'glammets': [('glam', True)],
          'glamp-': [('glampa', False)],
          'glamps': [('glampa', False)],
          'glamps-': [('glampa', False)],
          'glams': [('glam', True)],
          'glams-': [('glam', True)],
          'glan': [('gla', False)],
          'glan-': [('glan', False)],
          'glanden': [('glande', False)],
          'glandena': [('glande', False)],
          'glandenas': [('glande', False)],
          'glandens': [('glande', False)],
          'glandet': [('glande', False)],
          'glandets': [('glande', False)],
          'glans': [('glans', False)],
          'glans-': [('glans', False)],
          'glar': [('glare', False)],
          'glaren': [('glare', False)],
          'glarna': [('glare', False)],
          'glarnas': [('glare', False)],
          'glarv': [('glarv', False)],
          'glarver': [('glarv', False)],
          'glarvers': [('glarv', False)],
          'glarvs': [('glarv', False)],
          'glarvs-': [('glarv', False)],
          'glas': [('glas', False)],
          'glasen': [('glas', False)],
          'glasens': [('glas', False)],
          'glasklocks': [('glasklocka', True)],
          'glasklocks-': [('glasklocka', True)],
          'glassarnas': [('glass', True)],
          'glasögon': [('glasöga', True), ('glasögon', True)],
          'glasögonen': [('glasöga', True), ('glasögon', True)],
          'glasögonens': [('glasögon', True), ('glasöga', True)],
          'glasögons': [('glasöga', True), ('glasögon', True)],
          'glats': [('glats', False)],
          'glats-': [('glats', False)],
          'glav': [('glav', True)],
          'glav-': [('glav', False)],
          'glavar': [('glav', True)],
          'glavarna': [('glav', True)],
          'glavarnas': [('glav', True)],
          'glavars': [('glav', True)],
          'glaven': [('glav', False)],
          'glavens': [('glav', True)],
          'glavs': [('glav', True)],
          'glavs-': [('glav', False)],
          'gle': [('gla', False)],
          'gle-': [('gla', False)],
          'gleg': [('glega', False)],
          'gleg-': [('glega', False)],
          'glegans': [('glega', False)],
          'glege': [('glega', False)],
          'glegs': [('glega', False)],
          'glegs-': [('glega', False)],
          'glek': [('glek', False)],
          'glekar': [('glek', False)],
          'glekarna': [('glek', False)],
          'glekarnas': [('glek', False)],
          'gleken': [('glek', False)],
          'glekens': [('glek', False)],
          'gleks-': [('glek', False)],
          'glementen': [('glemente', False)],
          'glementens': [('glemente', False)],
          'glementet': [('glemente', False)],
          'glements-': [('glemente', False)],
          'gler': [('gel', False)],
          'glerna': [('gel', False)],
          'glers': [('gel', False)],
          'gles': [('gles', False)],
          'glesen': [('gles', False)],
          'glesens': [('gles', False)],
          'glet': [('gel', False)],
          'gletets': [('glete', False)],
          'glets': [('gel', False)],
          'gleven': [('glev', False)],
          'glevens': [('glev', False)],
          'glevs': [('glev', False)],
          'gli': [('gli', True)],
          'gli-': [('gli', True)],
          'glian': [('glia', True)],
          'glians': [('glia', True)],
          'glias': [('glia', True)],
          'glids': [('glid', True)],
          'glie-': [('glie', False)],
          'glien': [('gli', True)],
          'gliens': [('gli', True)],
          'glier': [('glie', False)],
          'glierna': [('glie', False)],
          'gliernas': [('glie', False)],
          'gliers': [('glie', False)],
          'gliet': [('gli', True)],
          'gliets': [('gli', True)],
          'gligans': [('gliga', False)],
          'gliggarna': [('gliggare', False)],
          'glighets': [('glighet', False)],
          'glik': [('glik', False)],
          'gliken': [('glik', False)],
          'glikens': [('glik', False)],
          'gliks': [('glik', False)],
          'gliks-': [('glik', False)],
          'glimmer': [('glimmer', True)],
          'glimmers': [('glimmer', False)],
          'glimp': [('glimpa', False)],
          'glimps': [('glimpa', False)],
          'glimps-': [('glimpa', False)],
          'glin': [('gli', False)],
          'glin-': [('glina', False)],
          'glina': [('gli', True)],
          'glinas': [('gli', True)],
          'gline': [('glina', False)],
          'gline-': [('glina', False)],
          'glinne': [('glinne', False)],
          'glinne-': [('glinne', False)],
          'glinnes': [('glinne', False)],
          'glinnes-': [('glinne', False)],
          'glins': [('gli', True)],
          'glins-': [('glina', False)],
          'glipas': [('glipa', False)],
          'glips': [('glipa', True)],
          'glis': [('gli', True), ('glis', True)],
          'glis-': [('glis', True)],
          'glisen': [('glis', True)],
          'glisens': [('glis', True)],
          'glist': [('glist', False)],
          'glist-': [('glist', False)],
          'glits': [('gli', True)],
          'glitter': [('glitter', False)],
          'glitter-': [('glitter', False)],
          'glitters': [('glitter', True)],
          'glivs': [('gliv', False)],
          'glivs-': [('gliv', False)],
          'glo-': [('glo', False)],
          'glok': [('glok', False)],
          'glok-': [('glok', False)],
          'gloks': [('glok', False)],
          'gloks-': [('glok', False)],
          'gloon': [('gloo', False)],
          'gloons': [('gloo', False)],
          'glopp': [('glopp', False)],
          'glopp-': [('glopp', True)],
          'glopps': [('glopp', False)],
          'glopps-': [('glopp', False)],
          'glops': [('glop', True)],
          'glops-': [('glop', True)],
          'glor': [('gla', False)],
          'glori': [('gloria', True)],
          'glori-': [('gloria', False)],
          'gloris': [('gloria', False)],
          'glorna': [('gla', False)],
          'glornas': [('gla', False)],
          'glors': [('glo', False)],
          'glos': [('glosa', True)],
          'glos-': [('glosa', True)],
          'glosar': [('glo', False)],
          'glosarnas': [('glo', False)],
          'glosars': [('glo', False)],
          'gloss': [('glossa', True)],
          'gloss-': [('glossa', True)],
          'glossar': [('glossar', True)],
          'glossaren': [('glossar', True)],
          'glossars': [('glossar', True)],
          'glot': [('glo', False)],
          'glots': [('glo', False)],
          'glott': [('glott', False)],
          'glottens': [('glott', False)],
          'glov': [('glov', False)],
          'gloven': [('glov', False)],
          'glovens': [('glov', False)],
          'glovs': [('glov', False)],
          'glovs-': [('glov', False)],
          'glunt': [('glunt', True)],
          'glunt-': [('glunt', True)],
          'glunts': [('glunt', True)],
          'glunts-': [('glunt', True)],
          'gluten': [('gluten', True)],
          'glutens': [('gluten', True)],
          'gluttar': [('gluttare', True)],
          'glädjedans': [('glädjedag', True), ('glädjedans', True)],
          'gländar': [('gländare', False)],
          'gländarna': [('gländare', False)],
          'gländer': [('gland', False)],
          'gländerna': [('gland', False)],
          'gländernas': [('gland', False)],
          'gländers': [('gland', False)],
          'glänt': [('glänta', True)],
          'glänts-': [('glänta', False)],
          'glärk': [('glärka', False)],
          'glärk-': [('glärka', False)],
          'glärks': [('glärka', False)],
          'glärks-': [('glärka', False)],
          'gläs': [('gläs', False)],
          'gläs-': [('gläs', False)],
          'glåns': [('glån', False)],
          'glås': [('glås', False)],
          'glåt': [('glåt', False)],
          'glåts': [('glåt', False)],
          'glöden': [('glöd', False)],
          'glödens': [('glöd', False)],
          'glöss': [('glus', False)],
          'glössen': [('glus', False)],
          'glössens': [('glus', False)],
          'gm': [('gm', False)],
          'gm-': [('gm', False)],
          'gmakar': [('gmakare', False)],
          'gmakarna': [('gmakare', False)],
          'gmakarnas': [('gmakare', False)],
          'gman': [('gman', False)],
          'gmana': [('gma', False)],
          'gmanas': [('gma', False)],
          'gmannen': [('gman', False)],
          'gmannens': [('gman', False)],
          'gmans': [('gman', False)],
          'gmas': [('gma', False)],
          'gmas-': [('gma', False)],
          'gmask': [('gmask', False)],
          'gmask-': [('gmask', False)],
          'gmata': [('gma', False)],
          'gmatana': [('gma', False)],
          'gmatas': [('gma', False)],
          'gmatik': [('gmatik', False)],
          'gmatik-': [('gmatik', False)],
          'gmatiks': [('gmatik', False)],
          'gmats': [('gma', False)],
          'gmatt': [('gmatta', False)],
          'gmatt-': [('gmatta', False)],
          'gmatte': [('gmatta', False)],
          'gmatte-': [('gmatta', False)],
          'gmatts': [('gmatta', False)],
          'gmatts-': [('gmatta', False)],
          'gme': [('gma', False)],
          'gme-': [('gma', False)],
          'gmen': [('gm', False)],
          'gmens': [('gm', False)],
          'gmentets': [('gment', False)],
          'gments': [('gment', False)],
          'gmer': [('gm', False)],
          'gmerna': [('gm', False)],
          'gmernas': [('gm', False)],
          'gmers': [('gm', False)],
          'gmes-': [('gmes', False)],
          'gmet': [('gm', False)],
          'gmiss': [('gmiss', False)],
          'gmiss-': [('gmiss', False)],
          'gmissar': [('gmiss', False)],
          'gmissarna': [('gmiss', False)],
          'gmissarnas': [('gmiss', False)],
          'gmissars': [('gmiss', False)],
          'gmissen': [('gmiss', False)],
          'gmissens': [('gmiss', False)],
          'gmit': [('gmit', False)],
          'gmit-': [('gmit', False)],
          'gmjölk': [('gmjölk', False)],
          'gmjölk-': [('gmjölk', False)],
          'gmjölken': [('gmjölk', False)],
          'gmjölkens': [('gmjölk', False)],
          'gmjölks': [('gmjölk', False)],
          'gmjölks-': [('gmjölk', False)],
          'gmodet': [('gmod', False)],
          'gmodets': [('gmod', False)],
          'gmods': [('gmod', False)],
          'gmods-': [('gmod', False)],
          'gmor': [('gma', False)],
          'gmor-': [('gmor', False)],
          'gmorna': [('gma', False)],
          'gmornas': [('gma', False)],
          'gmors': [('gma', False)],
          'gmors-': [('gmor', False)],
          'gmos': [('gmos', False)],
          'gmos-': [('gmos', False)],
          'gmoss': [('gmosse', False)],
          'gmoss-': [('gmosse', False)],
          'gmosse': [('gmosse', False)],
          'gms': [('gm', False)],
          'gmurar': [('gmur', False)],
          'gmurarna': [('gmur', False)],
          'gmurarnas': [('gmur', False)],
          'gmus': [('gmus', False)],
          'gmyr': [('gmyra', False)],
          'gmyr-': [('gmyra', False)],
          'gmyrs': [('gmyra', False)],
          'gmyrs-': [('gmyra', False)],
          'gmyt': [('gmyt', False)],
          'gmyts': [('gmyt', False)],
          'gmän': [('gman', False)],
          'gmäns': [('gman', False)],
          'gmärens': [('gmär', False)],
          'gmärs': [('gmär', False)],
          'gn': [('gn', False)],
          'gn-': [('gn', False)],
          'gna': [('gnum', False)],
          'gnabb': [('gnabb', False)],
          'gnabb-': [('gnabb', True)],
          'gnabben': [('gnabb', True)],
          'gnabbens': [('gnabb', True)],
          'gnabbs': [('gnabb', False)],
          'gnabbs-': [('gnabb', False)],
          'gnader': [('gnad', False)],
          'gnaderna': [('gnad', False)],
          'gnadernas': [('gnad', False)],
          'gnaders': [('gnad', False)],
          'gnads': [('gnad', False)],
          'gnads-': [('gnad', False)],
          'gnadsverket': [('gnadsverk', False)],
          'gnaget': [('gnag', True)],
          'gnal': [('gnal', False)],
          'gnal-': [('gnal', False)],
          'gnalen': [('gnal', False)],
          'gnalens': [('gnal', False)],
          'gnaler': [('gnal', False)],
          'gnalerna': [('gnal', False)],
          'gnalernas': [('gnal', False)],
          'gnalers': [('gnal', False)],
          'gnals-': [('gnal', False)],
          'gnamn': [('gnamn', False)],
          'gnamn-': [('gnamn', False)],
          'gnamnen': [('gnamn', False)],
          'gnamnens': [('gnamn', False)],
          'gnamns': [('gnamn', False)],
          'gnamns-': [('gnamn', False)],
          'gnan': [('gnan', False)],
          'gnana': [('gnum', False)],
          'gnanas': [('gnum', False)],
          'gnanden': [('gnande', False)],
          'gnans': [('gnans', False)],
          'gnans-': [('gnan', False)],
          'gnar': [('gn', False)],
          'gnar-': [('gnare', False)],
          'gnaren': [('gnare', False)],
          'gnarens': [('gnare', False)],
          'gnarna': [('gn', False)],
          'gnarnas': [('gon', False)],
          'gnars': [('gn', False)],
          'gnas': [('gnum', False)],
          'gnat': [('gnat', False)],
          'gnat-': [('gnat', True)],
          'gnaten': [('gnat', False)],
          'gnatens': [('gnat', False)],
          'gnater': [('gnat', False)],
          'gnaterna': [('gnat', False)],
          'gnaternas': [('gnat', False)],
          'gnaters': [('gnat', False)],
          'gnats': [('gnat', True)],
          'gnats-': [('gnat', False)],
          'gndroppar': [('gndroppe', False)],
          'gndropparna': [('gndroppe', False)],
          'gndropparnas': [('gndroppe', False)],
          'gndroppars': [('gndroppe', False)],
          'gndropps': [('gndroppe', False)],
          'gne-': [('gne', False)],
          'gnejs': [('gnejs', True)],
          'gnen': [('gn', False)],
          'gnens': [('gn', False)],
          'gner': [('gn', False)],
          'gnerier': [('gneri', False)],
          'gnerierna': [('gneri', False)],
          'gneriernas': [('gneri', False)],
          'gneriers': [('gneri', False)],
          'gnerna': [('gen', False)],
          'gnernas': [('gne', False)],
          'gners': [('gne', False)],
          'gnet': [('gnet', True)],
          'gnets': [('gnet', False)],
          'gnetter': [('gnet', True)],
          'gnetterna': [('gnet', True)],
          'gnetternas': [('gnet', True)],
          'gnetters': [('gnet', True)],
          'gnie-': [('gnier', False)],
          'gniernas': [('gnier', False)],
          'gniers': [('gnier', False)],
          'gnin': [('gnin', False)],
          'gnin-': [('gnin', False)],
          'gninen': [('gnin', False)],
          'gninens': [('gnin', False)],
          'gniner': [('gnin', False)],
          'gninerna': [('gnin', False)],
          'gninernas': [('gnin', False)],
          'gniners': [('gnin', False)],
          'gninet': [('gnin', False)],
          'gninets': [('gnin', False)],
          'gningsdags': [('gningsdags', False)],
          'gningsdags-': [('gningsdags', False)],
          'gnins': [('gnin', False)],
          'gnisk': [('gniska', False)],
          'gnisk-': [('gniska', False)],
          'gnist': [('gnist', True), ('gnista', True)],
          'gnist-': [('gnist', True), ('gnista', True)],
          'gnitet': [('gnitet', False)],
          'gnitets': [('gnitet', False)],
          'gnklädes': [('gnkläder', False)],
          'gnol': [('gnol', False)],
          'gnol-': [('gnol', False)],
          'gnols': [('gnol', False)],
          'gnomen': [('gnom', True)],
          'gnomens': [('gnom', True)],
          'gnos': [('gnos', False)],
          'gnos-': [('gnos', False)],
          'gnosen': [('gnos', False)],
          'gnosens': [('gnos', False)],
          'gnosis': [('gnosis', True)],
          'gns': [('gn', False)],
          'gns-': [('gn', False)],
          'gnskurs-': [('gnskur', False)],
          'gnställets': [('gnställ', False)],
          'gnu': [('gnu', True)],
          'gnu-': [('gnu', True)],
          'gnumen': [('gnum', False)],
          'gnumens': [('gnum', False)],
          'gnun': [('gnu', True)],
          'gnuns': [('gnu', True)],
          'gnys': [('gny', True)],
          'gnys-': [('gny', False)],
          'gnäbb': [('gnäbb', False)],
          'gnäbb-': [('gnäbb', False)],
          'gnäbbs': [('gnäbb', False)],
          'gnäbbs-': [('gnäbb', False)],
          'gnät': [('gnät', False)],
          'gnäts': [('gnät', False)],
          'go': [('go', True)],
          'go-': [('go', True)],
          'god': [('gode', True)],
          'god-': [('gode', True)],
          'godar': [('gode', True)],
          'godarna': [('gode', True)],
          'godarnas': [('gode', True)],
          'godars': [('gode', True)],
          'gode': [('gode', True)],
          'godel': [('godel', False)],
          'goden': [('gode', True)],
          'godens': [('gode', True)],
          'goders': [('god', False)],
          'godes-': [('gode', True)],
          'gods': [('gode', True), ('gods', True)],
          'gods-': [('gode', True), ('gods', True)],
          'goer': [('go', False)],
          'goerna': [('go', False)],
          'goernas': [('go', False)],
          'goers': [('go', False)],
          'gofficerare': [('gofficer', False)],
          'gofficerares': [('gofficer', False)],
          'gofficerarna': [('gofficer', False)],
          'gofficerarnas': [('gofficer', False)],
          'gogans': [('goga', False)],
          'gogas': [('goga', False)],
          'gogrammet': [('gogram', False)],
          'gogrammets': [('gogram', False)],
          'goj': [('goja', False)],
          'goj-': [('goja', False)],
          'gojan': [('goja', True)],
          'gojans': [('goja', True)],
          'gojs': [('goja', True)],
          'gojs-': [('goja', True)],
          'golan': [('golan', False)],
          'golandet': [('goland', False)],
          'golandets': [('goland', False)],
          'golans': [('golan', False)],
          'golfklubb': [('golfklubba', True), ('golfklubb', True)],
          'golfklubbs': [('golfklubba', True), ('golfklubb', True)],
          'golfklubbs-': [('golfklubba', True), ('golfklubb', True)],
          'golon': [('golo', False)],
          'golons': [('golo', False)],
          'golor': [('golo', False)],
          'golorna': [('golo', False)],
          'golornas': [('golo', False)],
          'golors': [('golo', False)],
          'golos': [('golo', False)],
          'golos-': [('golo', False)],
          'golv': [('golv', False)],
          'golv-': [('golv', False)],
          'golvs': [('golv', False)],
          'golvs-': [('golv', False)],
          'gomen': [('gom', False)],
          'gomens': [('gom', False)],
          'gometer': [('gometer', False)],
          'gometers': [('gometer', False)],
          'gommarna': [('gom', False)],
          'gområdets': [('gområde', False)],
          'goms': [('gom', False)],
          'goms-': [('gom', False)],
          'gon': [('gon', True)],
          'gon-': [('gon', False)],
          'gona': [('go', False)],
          'gonas': [('go', False)],
          'gondagen': [('gondag', False)],
          'gondagens': [('gondag', False)],
          'gonen': [('gon', True)],
          'gonens': [('gon', True)],
          'gong': [('gong', False)],
          'gong-': [('gong', False)],
          'gongar': [('gong', False)],
          'gongarna': [('gong', False)],
          'gongarnas': [('gong', False)],
          'gonger': [('gong', False)],
          'gongerna': [('gong', False)],
          'gongernas': [('gong', False)],
          'gongers': [('gong', False)],
          'gongs': [('gong', False)],
          'gongs-': [('gong', False)],
          'goni': [('goni', False)],
          'goni-': [('goni', False)],
          'gonie-': [('gonia', False)],
          'gonien': [('goni', False)],
          'goniens': [('goni', False)],
          'gonier': [('gonia', False)],
          'gonierna': [('goni', False)],
          'goniernas': [('gonia', False)],
          'goniers': [('goni', False)],
          'gonin': [('goni', False)],
          'gonins': [('goni', False)],
          'gonis': [('goni', False)],
          'gonk': [('gonk', False)],
          'gonk-': [('gonk', False)],
          'gonks': [('gonk', False)],
          'gonkulan': [('gonkulan', False)],
          'gonkulans': [('gonkulan', False)],
          'gonkvisten': [('gonkvisten', False)],
          'gonkvistens': [('gonkvisten', False)],
          'gonomens': [('gonom', False)],
          'gons': [('gon', True)],
          'gons-': [('gon', False)],
          'gonsten': [('gonsten', False)],
          'gonstens': [('gonsten', False)],
          'gontet': [('gont', False)],
          'gontets': [('gont', False)],
          'gonurin': [('gonurin', False)],
          'gor-': [('gora', False)],
          'gora': [('gora', False)],
          'goran': [('gora', False)],
          'gorans': [('gora', False)],
          'goras': [('gora', False)],
          'gord': [('gord', False)],
          'gord-': [('gord', False)],
          'gorden': [('gord', False)],
          'gordens': [('gord', False)],
          'gordrar': [('gorder', False)],
          'gordrarna': [('gorder', False)],
          'gords': [('gord', False)],
          'gori': [('gori', False)],
          'gori-': [('gori', False)],
          'goriens': [('gori', False)],
          'gorier': [('gori', False)],
          'gorierna': [('gori', False)],
          'goriers': [('gori', False)],
          'gorins': [('gori', False)],
          'goris': [('gori', False)],
          'goris-': [('goris', False)],
          'gormanden': [('gormande', True)],
          'gormar': [('gorm', False)],
          'gormarna': [('gorm', False)],
          'gormarnas': [('gorm', False)],
          'goror': [('gora', False)],
          'gororna': [('gora', False)],
          'gorornas': [('gora', False)],
          'gorors': [('gora', False)],
          'gorr': [('gorr', True)],
          'gorr-': [('gorr', True)],
          'gorrs': [('gorr', True)],
          'gorrs-': [('gorr', True)],
          'gors-': [('gora', False)],
          'gorten': [('gort', False)],
          'gortens': [('gort', False)],
          'gorternas': [('gort', False)],
          'gorts-': [('gort', False)],
          'gorån': [('gorån', True), ('gorå', True)],
          'goråns': [('gorån', True), ('gorå', True)],
          'gos': [('go', False)],
          'gos-': [('go', False)],
          'gosarna': [('go', False)],
          'gosen': [('go', False)],
          'gosens': [('go', False)],
          'goss-': [('gosse', False)],
          'gossarna': [('gosse', False)],
          'gossarnas': [('gosse', False)],
          'got': [('got', False)],
          'gotidens': [('gotid', False)],
          'gots': [('got', True)],
          'gott': [('gott', False)],
          'gott-': [('gott', True)],
          'gotten': [('gott', False)],
          'gotter': [('gott', True)],
          'gotterier': [('gotterier', True)],
          'gotterierna': [('gotterier', True)],
          'gotteriernas': [('gotterier', True)],
          'gotteriers': [('gotterier', True)],
          'gotterna': [('gott', False)],
          'gotternas': [('gott', False)],
          'gotters': [('gott', False)],
          'gottis': [('gottis', True)],
          'gottis-': [('gottis', True)],
          'gotts': [('gott', True)],
          'gotts-': [('gott', True)],
          'govis-': [('govisa', False)],
          'gox': [('goxe', False)],
          'goxar': [('goxe', False)],
          'goxarna': [('goxe', False)],
          'goxen': [('goxe', False)],
          'gpar-': [('gpar', False)],
          'gparens': [('gpar', False)],
          'gpars-': [('gpar', False)],
          'gpelar': [('gpelare', False)],
          'gpelar-': [('gpelare', False)],
          'gpenning': [('gpenning', False)],
          'gpenningar': [('gpenning', False)],
          'gpenningarna': [('gpenning', False)],
          'gpenningarnas': [('gpenning', False)],
          'gpenningars': [('gpenning', False)],
          'gpennings': [('gpenning', False)],
          'gpennings-': [('gpenning', False)],
          'gpetters': [('gpetter', False)],
          'gpinns': [('gpinne', False)],
          'gpipar': [('gpipare', False)],
          'gpiparna': [('gpipare', False)],
          'gpiparnas': [('gpipare', False)],
          'gpisk': [('gpiska', False)],
          'gpisk-': [('gpiska', False)],
          'gplanet': [('gplan', False)],
          'gplanets': [('gplan', False)],
          'gplants': [('gplanta', False)],
          'gplants-': [('gplanta', False)],
          'gpojk': [('gpojke', False)],
          'gpojk-': [('gpojke', False)],
          'gpojks': [('gpojke', False)],
          'gpojks-': [('gpojke', False)],
          'gpolskor': [('gpolska', False)],
          'gpolskorna': [('gpolska', False)],
          'gpolskornas': [('gpolska', False)],
          'gpolskors': [('gpolska', False)],
          'gportarnas': [('gport', False)],
          'gpressar': [('gpress', False)],
          'gpressarna': [('gpress', False)],
          'gpressarnas': [('gpress', False)],
          'gprickar': [('gprick', False)],
          'gprickarna': [('gprick', False)],
          'gprickarnas': [('gprick', False)],
          'gpricks': [('gprick', False)],
          'gpricks-': [('gprick', False)],
          'gprogrammet': [('gprogram', False)],
          'gpropeller': [('gpropeller', False)],
          'gpropellers': [('gpropeller', False)],
          'gps': [('gps', True)],
          'gpsarnas': [('gps', True)],
          'gr': [('gr', True)],
          'grabbs': [('grabb', True)],
          'gracens': [('grace', True)],
          'gracer': [('grace', True), ('gracer', True)],
          'gracerna': [('gracer', True), ('grace', True)],
          'gracernas': [('grace', True), ('gracer', True)],
          'gracers': [('grace', True), ('gracer', True)],
          'graden': [('grad', False)],
          'gradens': [('grad', False)],
          'grads': [('grad', False)],
          'grads-': [('grad', False)],
          'grafen': [('grafen', True), ('graf', True)],
          'grafens': [('grafen', True), ('graf', True)],
          'grafit': [('grafit', True)],
          'grafits': [('grafit', True)],
          'grafs': [('graf', False)],
          'grafs-': [('graf', False)],
          'graman': [('gramaner', True)],
          'gramans': [('gramaner', True)],
          'gramans-': [('gramaner', True)],
          'gramlandet': [('gramland', False)],
          'gramlandets': [('gramland', False)],
          'grammatik': [('grammatika', True), ('grammatik', True)],
          'grammatik-': [('grammatika', True), ('grammatik', True)],
          'grammatiker': [('grammatiker', True), ('grammatik', True)],
          'grammatikerna': [('grammatiker', True), ('grammatik', True)],
          'grammatikernas': [('grammatiker', True), ('grammatik', True)],
          'grammatikers': [('grammatiker', True), ('grammatik', True)],
          'grammatiks': [('grammatika', True), ('grammatik', True)],
          'grammatiks-': [('grammatika', True), ('grammatik', True)],
          'grammen': [('gram', False)],
          'grammens': [('gram', False)],
          'grammet': [('gram', False)],
          'grammets': [('gram', False)],
          'grams': [('gram', False)],
          'grams-': [('gram', False)],
          'gran': [('gran', False)],
          'gran-': [('gran', False)],
          'grande': [('grande', False)],
          'grande-': [('grande', False)],
          'granden': [('grand', True)],
          'grandens': [('grand', True)],
          'grandet': [('grand', True)],
          'grandets': [('grand', True)],
          'grann': [('grann', True), ('granne', True)],
          'grann-': [('grann', True), ('granne', True)],
          'grannen': [('granne', False)],
          'granns': [('grann', True), ('granne', True)],
          'granns-': [('grann', True), ('granne', True)],
          'grans': [('gran', False)],
          'grans-': [('gran', False)],
          'grapar': [('grape', False)],
          'graparna': [('grape', False)],
          'graparnas': [('grape', False)],
          'grapars': [('grape', False)],
          'grapen': [('grape', False)],
          'grapens': [('grape', False)],
          'grar-': [('grar', False)],
          'graren': [('grar', False)],
          'grarens': [('grar', False)],
          'grarnas': [('ger', False)],
          'gras': [('gras', False)],
          'gras-': [('gras', False)],
          'grasens': [('gras', False)],
          'gratie': [('gratie', True), ('gratier', True)],
          'gratie-': [('gratie', True), ('gratier', True)],
          'gratien': [('gratie', True)],
          'gratiens': [('gratie', True)],
          'gratier': [('gratier', True), ('gratie', True)],
          'gratierna': [('gratier', True), ('gratie', True)],
          'gratiernas': [('gratier', True), ('gratie', True)],
          'gratiers': [('gratier', True), ('gratie', True)],
          'gratins': [('gratin', True)],
          'gratisskjuts': [('gratisskjuts', True), ('gratisskjut', True)],
          'gratisskjuts-': [('gratisskjuts', True), ('gratisskjut', True)],
          'grav': [('grav', False)],
          'grav-': [('grav', True)],
          'gravanden': [('gravand', True), ('gravande', True)],
          'gravandens': [('gravand', True), ('gravande', True)],
          'gravar': [('grav', False)],
          'gravarnas': [('grav', False)],
          'gravars': [('grav', False)],
          'graven': [('grav', False)],
          'gravens': [('grav', False)],
          'gravensteiner': [('gravensteiner', True), ('gravenstein', True)],
          'gravensteinerna': [('gravensteiner', True), ('gravenstein', True)],
          'gravensteinernas': [('gravensteiner', True), ('gravenstein', True)],
          'gravensteiners': [('gravensteiner', True), ('gravenstein', True)],
          'gravrös': [('gravröse', True), ('gravrös', True)],
          'gravrös-': [('gravröse', True), ('gravrös', True)],
          'gravrösen': [('gravrös', True), ('gravröse', True)],
          'gravrösens': [('gravröse', True), ('gravrös', True)],
          'gravröset': [('gravrös', True), ('gravröse', True)],
          'gravrösets': [('gravrös', True), ('gravröse', True)],
          'gravs': [('grav', False)],
          'gravs-': [('grav', False)],
          'gray': [('gray', True)],
          'gray-': [('gray', True)],
          'green': [('green', False)],
          'greens': [('green', True)],
          'grej': [('greja', True), ('grej', True)],
          'grej-': [('greja', True), ('grej', True)],
          'grejs': [('grejs', True), ('grej', True)],
          'grejs-': [('grej', True), ('grejs', True)],
          'gremmar': [('grem', False)],
          'gremmarna': [('grem', False)],
          'gremmarnas': [('grem', False)],
          'grems': [('gremsa', False)],
          'grems-': [('gremsa', False)],
          'gren': [('gren', False)],
          'grenar': [('gren', False)],
          'grenarna': [('gren', False)],
          'grens': [('gren', True)],
          'grens-': [('gren', False)],
          'grep': [('grepe', True)],
          'grep-': [('grepe', True)],
          'grepar': [('grepe', True)],
          'greparna': [('grepe', True)],
          'greparnas': [('grepe', True)],
          'grepars': [('grepe', True)],
          'grepe': [('grepe', True)],
          'grepen': [('grepe', True)],
          'grepens': [('grepe', True)],
          'grepet': [('grep', False)],
          'grepets': [('grep', False)],
          'greps': [('grepe', True)],
          'greps-': [('grepe', True)],
          'grers': [('ger', False)],
          'grese': [('gresa', False)],
          'grese-': [('gresa', False)],
          'gret': [('ger', False)],
          'grets': [('ger', False)],
          'grev': [('greve', True)],
          'grev-': [('greve', True)],
          'grevar': [('grevar', True), ('greve', True)],
          'grevarna': [('grevar', True), ('greve', True)],
          'grevarnas': [('greve', True), ('grevar', True)],
          'grevars': [('grevar', True), ('greve', True)],
          'greve': [('greve', False)],
          'greven': [('greve', False)],
          'grevens': [('greve', True)],
          'grevs': [('greve', True)],
          'grevs-': [('greve', False)],
          'grian': [('gria', False)],
          'grians': [('gria', False)],
          'grias': [('gria', False)],
          'grighets': [('grighet', False)],
          'grill': [('grillor', True), ('grill', True), ('griller', True)],
          'grill-': [('grill', True), ('grillor', True), ('griller', True)],
          'grillarna': [('grill', True)],
          'grillarnas': [('grill', False)],
          'griller': [('griller', True)],
          'grillerna': [('griller', True)],
          'grillernas': [('griller', True)],
          'grillers': [('griller', True)],
          'grillor': [('grillor', True)],
          'grillorna': [('grillor', True)],
          'grillornas': [('grillor', True)],
          'grillors': [('grillor', True)],
          'grills': [('grillor', True), ('griller', True), ('grill', True)],
          'grills-': [('grillor', True), ('griller', True), ('grill', True)],
          'grim': [('grimma', True)],
          'grim-': [('grimma', True)],
          'grims': [('grimma', True)],
          'grims-': [('grimma', True)],
          'grin': [('grin', False)],
          'grin-': [('grin', False)],
          'griner': [('grin', False)],
          'grinerna': [('grin', False)],
          'grinernas': [('grin', False)],
          'griners': [('grin', False)],
          'gringar': [('gring', False)],
          'gringarna': [('gring', False)],
          'gringarnas': [('gring', False)],
          'gringor': [('gringo', True)],
          'gringorna': [('gringo', True)],
          'grins': [('grin', False)],
          'grins-': [('grin', False)],
          'grip': [('grip', True)],
          'grip-': [('grip', True)],
          'gripar': [('grip', False)],
          'griparna': [('grip', False)],
          'griparnas': [('grip', True)],
          'grips': [('grip', True)],
          'grips-': [('grip', True)],
          'gris': [('gris', False)],
          'gris-': [('gris', False)],
          'grisarna': [('gris', False)],
          'grisens': [('gris', False)],
          'gritet': [('gritet', False)],
          'gritets': [('gritet', False)],
          'grockar': [('grock', False)],
          'grockarna': [('grock', False)],
          'grockarnas': [('grock', False)],
          'groddar': [('grodd', False)],
          'groddarna': [('grodd', True)],
          'groddarnas': [('grodd', False)],
          'groggar': [('grogg', False)],
          'grolls': [('groll', True)],
          'grolls-': [('groll', True)],
          'gromans': [('groman', False)],
          'groms': [('grom', False)],
          'grona': [('gro', False)],
          'gronomen': [('gronom', False)],
          'gropar': [('grop', False)],
          'groparna': [('grop', False)],
          'groparnas': [('grop', False)],
          'gropars': [('grop', False)],
          'gropen': [('grop', False)],
          'gropens': [('grop', False)],
          'grops': [('grop', False)],
          'grops-': [('grop', False)],
          'gros': [('gro', False)],
          'grot': [('grot', False)],
          'groten': [('grot', False)],
          'grotens': [('grot', False)],
          'grots': [('grot', False)],
          'grots-': [('grot', False)],
          'grott': [('grotta', False)],
          'grott-': [('grotta', True)],
          'grotts': [('grotta', True)],
          'grotts-': [('grotta', False)],
          'grove': [('grove', False)],
          'grove-': [('grove', False)],
          'groven': [('grove', False)],
          'grovens': [('grove', False)],
          'grubb-': [('grubba', True)],
          'grubbs': [('grubba', True)],
          'grull': [('grulle', False)],
          'grull-': [('grulle', False)],
          'grulle': [('grulle', False)],
          'grulle-': [('grulle', False)],
          'grulls': [('grulle', False)],
          'grulls-': [('grulla', False)],
          'grum': [('grum', False)],
          'grum-': [('grum', False)],
          'grums': [('grums', True)],
          'grums-': [('grums', True)],
          'grumsets': [('grums', True)],
          'grund': [('grund', False)],
          'grund-': [('grund', True)],
          'grundan': [('grundan', False)],
          'grundans': [('grunda', False)],
          'grunds': [('grund', False)],
          'grunds-': [('grund', False)],
          'grungen': [('grunge', True)],
          'grungens': [('grunge', True)],
          'grunk': [('grunka', True)],
          'grunk-': [('grunka', True)],
          'grunks': [('grunka', True)],
          'grunks-': [('grunka', True)],
          'grus': [('grus', False)],
          'grus-': [('grus', False)],
          'gry': [('gry', True)],
          'gry-': [('gry', True)],
          'gryn': [('gryn', False)],
          'gryn-': [('gryn', False)],
          'grynen': [('gryn', False)],
          'grynens': [('gryn', False)],
          'grynet': [('gryne', True), ('gryn', True)],
          'grynets': [('gryne', True), ('gryn', True)],
          'gryns': [('gryn', False)],
          'gryns-': [('gryn', True)],
          'grys': [('gry', True)],
          'gryt': [('gryt', True), ('gryta', True), ('gry', True)],
          'gryt-': [('gryta', True), ('gryt', True)],
          'gryte': [('gryta', False)],
          'gryten': [('gryt', True)],
          'grytens': [('gryt', False)],
          'gryts': [('gry', True), ('gryt', True), ('gryta', True)],
          'gryts-': [('gryta', True), ('gryt', True)],
          'gräcke': [('gräcke', False)],
          'gräcken': [('gräcke', False)],
          'gräckens': [('gräcke', False)],
          'gräcket': [('gräcke', False)],
          'gräckets': [('gräcke', False)],
          'grädd': [('grädde', True)],
          'grädda': [('grädda', True), ('grädde', True)],
          'grädda-': [('grädda', True), ('grädde', True)],
          'grädden': [('grädde', True)],
          'gräddens': [('grädde', False)],
          'gräden': [('gräd', False)],
          'grädens': [('gräd', False)],
          'gräder': [('gräd', False)],
          'gräds-': [('gräd', False)],
          'gräk-': [('gräka', False)],
          'gräkors': [('gräka', False)],
          'gräks-': [('gräka', False)],
          'gräls': [('gräl', False)],
          'gräls-': [('gräl', False)],
          'grän': [('grän', True)],
          'gränder': [('gränd', True)],
          'gränderna': [('gränd', True)],
          'grändernas': [('gränd', True)],
          'gränders': [('gränd', True)],
          'gränn': [('gränna', False)],
          'gränn-': [('gränna', False)],
          'gränns': [('gränna', False)],
          'gränns-': [('gränna', False)],
          'gräns': [('grän', True), ('gräns', True)],
          'gräns-': [('grän', True), ('gräns', True)],
          'gräs': [('gräs', False)],
          'gräs-': [('gräs', False)],
          'gräsanden': [('gräsande', True), ('gräsand', True)],
          'gräsandens': [('gräsande', True), ('gräsand', True)],
          'grästorv': [('grästorva', True), ('grästorv', True)],
          'grästorvs': [('grästorv', True), ('grästorva', True)],
          'grästorvs-': [('grästorva', True), ('grästorv', True)],
          'gräv': [('gräv', False)],
          'grävar': [('grävare', False)],
          'grävarna': [('grävare', False)],
          'grävarnas': [('grävare', True)],
          'grävs-': [('gräv', False)],
          'gråden': [('gråd', False)],
          'grådens': [('gråd', False)],
          'gråll': [('grålla', True), ('grålle', True)],
          'gråll-': [('grålla', True), ('grålle', True)],
          'grålle': [('grålla', True), ('grålle', True)],
          'grålls': [('grålla', True), ('grålle', True)],
          'grålls-': [('grålle', True), ('grålla', True)],
          'grån': [('grån', False)],
          'gråns': [('grån', False)],
          'gråt': [('gråt', False)],
          'gråten': [('gråt', True)],
          'gråtens': [('gråt', True)],
          'gråts': [('gråt', False)],
          'gröd-': [('gröda', True)],
          'gröen': [('gröe', False)],
          'gröens': [('gröe', False)],
          'grökar': [('grökare', False)],
          'grökarna': [('grökare', False)],
          'grökarnas': [('grökare', False)],
          'grön': [('gröna', False)],
          'grön-': [('gröna', False)],
          'gröna': [('gröna', False)],
          'grönas': [('gröna', False)],
          'gröns': [('gröna', False)],
          'gröns-': [('gröna', False)],
          'grönsaker': [('grönsaker', True), ('grönsak', True)],
          'grönsakerna': [('grönsaker', True), ('grönsak', True)],
          'grönsakernas': [('grönsaker', True), ('grönsak', True)],
          'grönsakers': [('grönsaker', True), ('grönsak', True)],
          'grönsaks': [('grönsaker', True), ('grönsak', True)],
          'grönsaks-': [('grönsaker', True), ('grönsak', True)],
          'gröst': [('gröst', False)],
          'gröst-': [('gröst', False)],
          'grösten': [('gröst', False)],
          'gröstens': [('gröst', False)],
          'gröt': [('gröt', False)],
          'gröt-': [('gröt', False)],
          'gröts': [('gröt', False)],
          'grötter': [('grot', False)],
          'grötterna': [('grot', False)],
          'grötternas': [('grot', False)],
          'grötters': [('grot', False)],
          'gsage': [('gsaga', False)],
          'gsage-': [('gsaga', False)],
          'gsago': [('gsaga', False)],
          'gsago-': [('gsaga', False)],
          'gsarnas': [('g', False)],
          'gsats': [('gsats', False)],
          'gsats-': [('gsats', False)],
          'gsback': [('gsbacke', False)],
          'gsbackar': [('gsback', False)],
          'gsbackarna': [('gsbacke', False)],
          'gsbackarnas': [('gsbacke', False)],
          'gsbackars': [('gsback', False)],
          'gsbacken': [('gsback', False)],
          'gsbackens': [('gsback', False)],
          'gsbacks': [('gsbacke', False)],
          'gsbacks-': [('gsback', False)],
          'gsbete': [('gsbete', False)],
          'gsbit': [('gsbit', False)],
          'gsbloggar': [('gsbloggare', False)],
          'gsbloggarna': [('gsbloggare', False)],
          'gsbloggarnas': [('gsbloggare', False)],
          'gsbot': [('gsbot', False)],
          'gsbots': [('gsbot', False)],
          'gsbytet': [('gsbyte', False)],
          'gsböns': [('gsbön', False)],
          'gscenters': [('gscenter', False)],
          'gschas': [('gschas', False)],
          'gschips': [('gschip', False)],
          'gschips-': [('gschip', False)],
          'gsdags': [('gsdags', False)],
          'gsdags-': [('gsdags', False)],
          'gsdammen': [('gsdamm', False)],
          'gsdans': [('gsdans', False)],
          'gsdelarna': [('gsdelare', False)],
          'gsdelarnas': [('gsdel', False)],
          'gsdomar': [('gsdomare', False)],
          'gsdomarna': [('gsdomare', False)],
          'gsdomarnas': [('gsdomare', False)],
          'gseffekt': [('gseffekt', False)],
          'gseffekt-': [('gseffekt', False)],
          'gseffekter': [('gseffekt', False)],
          'gseffekternas': [('gseffekt', False)],
          'gseffekters': [('gseffekt', False)],
          'gseffekts': [('gseffekt', False)],
          'gseffekts-': [('gseffekt', False)],
          'gsegrar': [('gseger', False)],
          'gsegrarna': [('gseger', False)],
          'gsegrarnas': [('gseger', False)],
          'gsel': [('gsel', False)],
          'gsel-': [('gsel', False)],
          'gsels': [('gsel', False)],
          'gsels-': [('gsel', False)],
          'gsen': [('g', False)],
          'gser': [('gsera', False)],
          'gsera': [('gsera', False)],
          'gseras': [('gsera', False)],
          'gsers': [('gsera', False)],
          'gsfaktorer': [('gsfaktor', False)],
          'gsfaktorers': [('gsfaktor', False)],
          'gsflagg': [('gsflagga', False)],
          'gsflaggs': [('gsflagga', False)],
          'gsflaggs-': [('gsflagg', False)],
          'gsframställningar': [('gsframställan', False)],
          'gsframställningarna': [('gsframställan', False)],
          'gsframställningarnas': [('gsframställning', False)],
          'gsframställningars': [('gsframställan', False)],
          'gsfången': [('gsfånge', False)],
          'gsförsäkringar': [('gsförsäkran', False)],
          'gsförsäkringarna': [('gsförsäkran', False)],
          'gsförsäkringarnas': [('gsförsäkran', False)],
          'gsgiftets': [('gsgifte', False)],
          'gsgryt': [('gsgryt', False)],
          'gsgryt-': [('gsgryt', False)],
          'gsgryts': [('gsgryt', False)],
          'gsgryts-': [('gsgryt', False)],
          'gsgåvornas': [('gsgåva', False)],
          'gshets': [('gshets', False)],
          'gshets-': [('gshets', False)],
          'gshopp': [('gshopp', False)],
          'gshopps': [('gshopp', False)],
          'gshopps-': [('gshopp', False)],
          'gshots': [('gshot', False)],
          'gshots-': [('gshot', False)],
          'gsidan': [('gsida', False)],
          'gsidans': [('gsida', False)],
          'gside': [('gsida', False)],
          'gside-': [('gsida', False)],
          'gsides': [('gsida', False)],
          'gsikten': [('gsikt', False)],
          'gsiktens': [('gsikt', False)],
          'gsims': [('gsim', False)],
          'gsims-': [('gsim', False)],
          'gsjukan': [('gsjuka', False)],
          'gsk': [('gska', False)],
          'gsk-': [('gska', False)],
          'gskak': [('gskaka', False)],
          'gskak-': [('gskaka', False)],
          'gskaks': [('gskaka', False)],
          'gskaks-': [('gskaka', False)],
          'gskal': [('gskala', False)],
          'gskal-': [('gskala', False)],
          'gskalas': [('gskalas', False)],
          'gskallen': [('gskalle', False)],
          'gskallens': [('gskalle', False)],
          'gskals': [('gskala', False)],
          'gskals-': [('gskal', False)],
          'gskammar': [('gskam', False)],
          'gskan': [('gska', False)],
          'gskans': [('gska', False)],
          'gskartans': [('gskarta', False)],
          'gskasse-': [('gskassa', False)],
          'gskatts-': [('gskatt', False)],
          'gskeden': [('gsked', False)],
          'gskedens': [('gsked', False)],
          'gskiftet': [('gskifte', False)],
          'gskiftets': [('gskifte', False)],
          'gsklocks': [('gsklocka', False)],
          'gsklocks-': [('gsklocka', False)],
          'gsknäppen': [('gsknäppe', False)],
          'gsknäppens': [('gsknäppe', False)],
          'gsko': [('gsko', False)],
          'gskon': [('gsko', False)],
          'gskonst': [('gskonst', False)],
          'gskor': [('gsko', False)],
          'gskorna': [('gsko', False)],
          'gskornas': [('gsko', False)],
          'gskors': [('gsko', False)],
          'gskoter': [('gskoter', False)],
          'gskoters': [('gskoter', False)],
          'gskott': [('gskott', False)],
          'gskotten': [('gskott', False)],
          'gskottens': [('gskott', False)],
          'gskotts-': [('gskott', False)],
          'gskramarnas': [('gskramare', False)],
          'gskrans': [('gskran', False)],
          'gskrans-': [('gskran', False)],
          'gskrap': [('gskrapa', False)],
          'gskrap-': [('gskrapa', False)],
          'gskraps': [('gskrapa', False)],
          'gskraps-': [('gskrapa', False)],
          'gskrev': [('gskreva', False)],
          'gskrev-': [('gskreva', False)],
          'gskrevs': [('gskreva', False)],
          'gskrevs-': [('gskreva', False)],
          'gskrön': [('gskrön', False)],
          'gskröns': [('gskrön', False)],
          'gskröns-': [('gskrön', False)],
          'gskulor': [('gskula', False)],
          'gskulorna': [('gskula', False)],
          'gskulornas': [('gskula', False)],
          'gskulors': [('gskula', False)],
          'gskungar': [('gskung', False)],
          'gskungarna': [('gskung', False)],
          'gskungarnas': [('gskung', False)],
          'gskungars': [('gskung', False)],
          'gskungen': [('gskung', False)],
          'gskungens': [('gskung', False)],
          'gskurs': [('gskurs', False)],
          'gskurs-': [('gskurs', False)],
          'gskytten': [('gskytt', False)],
          'gskyttens': [('gskytt', False)],
          'gskäll': [('gskälla', False)],
          'gskäll-': [('gskälla', False)],
          'gskälls': [('gskälla', False)],
          'gskälls-': [('gskälla', False)],
          'gsladdar': [('gsladdare', False)],
          'gsladdarna': [('gsladdare', False)],
          'gsladdarnas': [('gsladdare', False)],
          'gslag': [('gslag', False)],
          'gslager': [('gslager', False)],
          'gslagernas': [('gslager', False)],
          'gslagers': [('gslager', False)],
          'gslags': [('gslag', False)],
          'gslags-': [('gslag', False)],
          'gslan': [('gslan', False)],
          'gslandet': [('gsland', False)],
          'gslans': [('gslan', False)],
          'gslans-': [('gslan', False)],
          'gslar': [('gsel', False)],
          'gslarna': [('gsel', False)],
          'gslarnas': [('gsel', False)],
          'gslarver': [('gslarv', False)],
          'gsle': [('gsle', False)],
          'gsle-': [('gsle', False)],
          'gslegionen': [('gslegion', False)],
          'gslegionens': [('gslegion', False)],
          'gsleken': [('gslek', False)],
          'gslekens': [('gslek', False)],
          'gsleks': [('gslek', False)],
          'gsleks-': [('gslek', False)],
          'gslin': [('gslina', False)],
          'gslin-': [('gslina', False)],
          'gsling': [('gsling', False)],
          'gslings': [('gsling', False)],
          'gslings-': [('gsling', False)],
          'gslån': [('gslån', False)],
          'gslåns': [('gslån', False)],
          'gslås': [('gslås', False)],
          'gslås-': [('gslås', False)],
          'gsmatt': [('gsmatta', False)],
          'gsmatt-': [('gsmatta', False)],
          'gsmatts': [('gsmatta', False)],
          'gsmatts-': [('gsmatta', False)],
          'gsmuts': [('gsmuts', False)],
          'gsmäll': [('gsmälla', False)],
          'gsmäll-': [('gsmälla', False)],
          'gsmälls': [('gsmälla', False)],
          'gsmälls-': [('gsmälla', False)],
          'gsmöss': [('gsmus', False)],
          'gsnacks': [('gsnack', False)],
          'gsnacks-': [('gsnack', False)],
          'gsniffar': [('gsniff', False)],
          'gsnyckel': [('gsnyckel', False)],
          'gsnyckel-': [('gsnyckel', False)],
          'gsnyckels': [('gsnyckel', False)],
          'gsnyckels-': [('gsnyckel', False)],
          'gsnycklar': [('gsnyckel', False)],
          'gsnycklarna': [('gsnyckel', False)],
          'gsnycklarnas': [('gsnyckel', False)],
          'gsnycklars': [('gsnyckel', False)],
          'gsområdet': [('gsområde', False)],
          'gsort-': [('gsort', False)],
          'gspad': [('gspad', False)],
          'gspads': [('gspad', False)],
          'gspads-': [('gspad', False)],
          'gspat': [('gspat', False)],
          'gspats': [('gspat', False)],
          'gspeng': [('gspeng', False)],
          'gspeng-': [('gspeng', False)],
          'gspengar': [('gspeng', False)],
          'gspengarna': [('gspeng', False)],
          'gspengarnas': [('gspeng', False)],
          'gspengars': [('gspeng', False)],
          'gspengs': [('gspeng', False)],
          'gspengs-': [('gspeng', False)],
          'gspets': [('gspets', False)],
          'gspets-': [('gspets', False)],
          'gspiller': [('gspiller', False)],
          'gspiller-': [('gspiller', False)],
          'gspilt': [('gspilt', False)],
          'gspilt-': [('gspilt', False)],
          'gspilts': [('gspilt', False)],
          'gspilts-': [('gspilt', False)],
          'gspolitikerna': [('gspolitiker', False)],
          'gspris': [('gspris', False)],
          'gsprivilegie': [('gsprivilegium', False)],
          'gsprivilegie-': [('gsprivilegium', False)],
          'gsprivilegier': [('gsprivilegium', False)],
          'gsprivilegierna': [('gsprivilegium', False)],
          'gsprivilegiers': [('gsprivilegium', False)],
          'gsprogrammet': [('gsprogrammet', False)],
          'gsprogrammets': [('gsprogrammet', False)],
          'gsprut': [('gspruta', False)],
          'gsprut-': [('gspruta', False)],
          'gspruts': [('gspruta', False)],
          'gspruts-': [('gspruta', False)],
          'gspån': [('gspån', False)],
          'gspåns': [('gspån', False)],
          'gspåns-': [('gspån', False)],
          'gsranden': [('gsrand', False)],
          'gsrandens': [('gsrand', False)],
          'gsrasterna': [('gsrast', False)],
          'gsregionen': [('gsregion', False)],
          'gsregionens': [('gsregion', False)],
          'gsringar': [('gsring', False)],
          'gsrättigheter': [('gsrättighet', False)],
          'gsrättighets': [('gsrättighet', False)],
          'gsråns': [('gsrå', False)],
          'gsserier': [('gsserie', False)],
          'gsseriernas': [('gsserie', False)],
          'gsseriers': [('gsserie', False)],
          'gsskalas': [('gsskala', False)],
          'gssken-': [('gsskena', False)],
          'gsskiften': [('gsskifte', False)],
          'gsskiftens': [('gsskifte', False)],
          'gssteg': [('gssteg', False)],
          'gssteg-': [('gssteg', False)],
          'gsstegens': [('gssteg', False)],
          'gsstegs-': [('gssteg', False)],
          'gsstudiers': [('gsstudie', False)],
          'gst': [('gst', False)],
          'gstadie': [('gstadium', False)],
          'gstadie-': [('gstadium', False)],
          'gstadier': [('gstadium', False)],
          'gstadierna': [('gstadium', False)],
          'gstadiernas': [('gstadium', False)],
          'gstadiers': [('gstadium', False)],
          'gstadiet': [('gstadium', False)],
          'gstadiets': [('gstadium', False)],
          'gstadium': [('gstadium', False)],
          'gstadiums': [('gstadium', False)],
          'gstalets': [('gstal', False)],
          'gstank-': [('gstanke', False)],
          'gstankarna': [('gstanke', False)],
          'gstankarnas': [('gstanke', False)],
          'gstankens': [('gstanke', False)],
          'gstanks': [('gstanke', False)],
          'gstanks-': [('gstanke', False)],
          'gstar': [('gst', False)],
          'gstarnas': [('gst', False)],
          'gstars': [('gst', False)],
          'gstarter': [('gstart', False)],
          'gstarterna': [('gstart', False)],
          'gstarternas': [('gstart', False)],
          'gstarters': [('gstart', False)],
          'gstavarna': [('gstav', False)],
          'gstdags': [('gstdag', False)],
          'gstdags-': [('gstdag', False)],
          'gste': [('gste', False)],
          'gste-': [('gste', False)],
          'gstegen': [('gstege', False)],
          'gstegens': [('gstege', False)],
          'gstekar': [('gstek', False)],
          'gstekarna': [('gstek', False)],
          'gstekarnas': [('gstek', False)],
          'gstekniker': [('gsteknik', False)],
          'gsteknikerna': [('gsteknik', False)],
          'gsteknikernas': [('gsteknik', False)],
          'gsteknikers': [('gsteknik', False)],
          'gsten': [('gsten', False)],
          'gstet': [('gste', False)],
          'gstick': [('gstick', False)],
          'gsticks': [('gstick', False)],
          'gsticks-': [('gstick', False)],
          'gstillgångar': [('gstillgång', False)],
          'gstillgångarna': [('gstillgång', False)],
          'gstillgångars': [('gstillgång', False)],
          'gstillgångs': [('gstillgång', False)],
          'gstim': [('gstimme', False)],
          'gstim-': [('gstimme', False)],
          'gstimmen': [('gstimme', False)],
          'gstimmens': [('gstimme', False)],
          'gstims': [('gstimme', False)],
          'gstims-': [('gstimme', False)],
          'gstol': [('gstol', False)],
          'gstols': [('gstol', False)],
          'gstols-': [('gstol', False)],
          'gstomten': [('gstomt', False)],
          'gston': [('gston', False)],
          'gstons': [('gston', False)],
          'gstons-': [('gston', False)],
          'gstoppar': [('gstopp', False)],
          'gstopparna': [('gstopp', False)],
          'gstorn': [('gstorn', False)],
          'gstorns': [('gstorn', False)],
          'gstrarnas': [('gster', False)],
          'gstrion': [('gstrio', False)],
          'gsträck': [('gsträcka', False)],
          'gsträck-': [('gsträcka', False)],
          'gsträcks': [('gsträcka', False)],
          'gsträcks-': [('gsträcka', False)],
          'gsträna': [('gsträd', False)],
          'gstränas': [('gsträd', False)],
          'gstråns': [('gstrå', False)],
          'gstråt': [('gstrå', False)],
          'gstråts': [('gstrå', False)],
          'gstubb': [('gstubb', False)],
          'gstubben': [('gstubb', False)],
          'gstubbens': [('gstubb', False)],
          'gstubbs': [('gstubb', False)],
          'gstubbs-': [('gstubb', False)],
          'gstudsar': [('gstudsare', False)],
          'gstudsarna': [('gstudsare', False)],
          'gstudsarnas': [('gstudsare', False)],
          'gstup': [('gstup', False)],
          'gstups': [('gstup', False)],
          'gstups-': [('gstup', False)],
          'gstycken': [('gstycke', False)],
          'gstyckena': [('gstycke', False)],
          'gstyckenas': [('gstycke', False)],
          'gstyckens': [('gstycke', False)],
          'gstycket': [('gstycke', False)],
          'gstyckets': [('gstycke', False)],
          'gstycks': [('gstycke', False)],
          'gstyrkan': [('gstyrka', False)],
          'gstyrke': [('gstyrka', False)],
          'gställanden': [('gställande', False)],
          'gställandenas': [('gställande', False)],
          'gställandens': [('gställande', False)],
          'gställen': [('gställe', False)],
          'gställens': [('gställe', False)],
          'gstället': [('gställe', False)],
          'gställets': [('gställe', False)],
          'gställningar': [('gställning', False)],
          'gställningarna': [('gställning', False)],
          'gställningarnas': [('gställning', False)],
          'gställningars': [('gställning', False)],
          'gställnings': [('gställning', False)],
          'gställnings-': [('gställning', False)],
          'gstövlars': [('gstövel', False)],
          'gsval': [('gsval', False)],
          'gsvalar': [('gsvalare', False)],
          'gsvalarna': [('gsvalare', False)],
          'gsvalarnas': [('gsvalare', False)],
          'gsvalen': [('gsval', False)],
          'gsvalens': [('gsval', False)],
          'gsvals': [('gsval', False)],
          'gsvals-': [('gsval', False)],
          'gsvanor': [('gsvana', False)],
          'gsvanorna': [('gsvana', False)],
          'gsvanornas': [('gsvana', False)],
          'gsvanors': [('gsvana', False)],
          'gsvans': [('gsvans', False)],
          'gsvans-': [('gsvan', False)],
          'gsvensk': [('gsvensk', False)],
          'gsvensk-': [('gsvensk', False)],
          'gsverken': [('gsverk', False)],
          'gsverkens': [('gsverk', False)],
          'gsverket': [('gsverk', False)],
          'gsverks': [('gsverk', False)],
          'gsverks-': [('gsverk', False)],
          'gsvikarna': [('gsvik', False)],
          'gsvits': [('gsvits', False)],
          'gsvits-': [('gsvits', False)],
          'gsvägens': [('gsväg', False)],
          'gsvärden': [('gsvärde', False)],
          'gsvärdens': [('gsvärd', False)],
          'gsvärdet': [('gsvärd', False)],
          'gsvärdets': [('gsvärde', False)],
          'gsvärmar': [('gsvärm', False)],
          'gsvärmarna': [('gsvärm', False)],
          'gsvärmarnas': [('gsvärm', False)],
          'gsväsendet': [('gsväsen', False)],
          'gsylt': [('gsylt', False)],
          'gsylt-': [('gsylt', False)],
          'gsylts': [('gsylt', False)],
          'gsylts-': [('gsylt', False)],
          'gsyns': [('gsyn', False)],
          'gsyre': [('gsyra', False)],
          'gsyre-': [('gsyra', False)],
          'gsäden': [('gsäd', False)],
          'gsädens': [('gsäd', False)],
          'gsädes': [('gsäd', False)],
          'gsäds': [('gsäd', False)],
          'gsäds-': [('gsäd', False)],
          'gsändar': [('gsände', False)],
          'gsändarna': [('gsände', False)],
          'gsändarnas': [('gsände', False)],
          'gsärterna': [('gsärter', False)],
          'gsärternas': [('gsärter', False)],
          'gsärters': [('gsärter', False)],
          'gsärts-': [('gsärter', False)],
          'gsåder': [('gsådra', False)],
          'gsåder-': [('gsådra', False)],
          'gsådra': [('gsådra', False)],
          'gsådrans': [('gsådra', False)],
          'gsådras': [('gsådra', False)],
          'gsådre-': [('gsådra', False)],
          'gsådror': [('gsådra', False)],
          'gsådrorna': [('gsådra', False)],
          'gsömmar': [('gsöm', False)],
          'gsömmarna': [('gsöm', False)],
          'gsömmarnas': [('gsöm', False)],
          'gsörn': [('gsörn', False)],
          'gt': [('g', False)],
          'gtaken': [('gtak', False)],
          'gtaket': [('gtak', False)],
          'gtalar': [('gtalare', False)],
          'gtalar-': [('gtalare', False)],
          'gtalaren': [('gtalare', False)],
          'gtalarens': [('gtalare', False)],
          'gtan': [('gtan', False)],
          'gtans': [('gtan', False)],
          'gtans-': [('gtan', False)],
          'gtaxis': [('gtaxi', False)],
          'gtaxis-': [('gtaxi', False)],
          'gtekniker': [('gteknik', False)],
          'gteknikerna': [('gteknik', False)],
          'gteknikernas': [('gteknik', False)],
          'gteknikers': [('gteknik', False)],
          'gteranden': [('gterande', False)],
          'gterandens': [('gterande', False)],
          'gtermer': [('gterm', False)],
          'gtermerna': [('gterm', False)],
          'gtermernas': [('gterm', False)],
          'gtermers': [('gterm', False)],
          'gtestens': [('gtest', False)],
          'gthet': [('gthet', False)],
          'gthets': [('gthet', False)],
          'gtiden': [('gtid', False)],
          'gtider': [('gtid', False)],
          'gtiders': [('gtid', False)],
          'gtillgångar': [('gtillgång', False)],
          'gtillgångarna': [('gtillgång', False)],
          'gtillgångarnas': [('gtillgång', False)],
          'gtillgångars': [('gtillgång', False)],
          'gtillgångs': [('gtillgång', False)],
          'gtillgångs-': [('gtillgång', False)],
          'gtilt': [('gtilta', False)],
          'gtilt-': [('gtilta', False)],
          'gtilts': [('gtilta', False)],
          'gtilts-': [('gtilta', False)],
          'gtim': [('gtimme', False)],
          'gtim-': [('gtimme', False)],
          'gtittar': [('gtittare', False)],
          'gtittarna': [('gtittare', False)],
          'gtittarnas': [('gtittare', False)],
          'gtolkar': [('gtolk', False)],
          'gtolkarna': [('gtolk', False)],
          'gtolkarnas': [('gtolk', False)],
          'gton': [('gton', False)],
          'gtonerna': [('gton', False)],
          'gtonernas': [('gton', False)],
          'gtopparnas': [('gtopp', False)],
          'gtork': [('gtork', False)],
          'gtorkarnas': [('gtork', False)],
          'gtras': [('gtrasa', False)],
          'gtros': [('gtrosa', False)],
          'gtros-': [('gtrosa', False)],
          'gtrums': [('gtrumma', False)],
          'gtrycken': [('gtryck', False)],
          'gtryckens': [('gtryck', False)],
          'gtrycket': [('gtryck', False)],
          'gtryckets': [('gtryck', False)],
          'gtrycks': [('gtryck', False)],
          'gtrycks-': [('gtryck', False)],
          'gträn': [('gträ', False)],
          'gträna': [('gträ', False)],
          'gtränas': [('gträ', False)],
          'gträns': [('gträ', False)],
          'gträt': [('gträ', False)],
          'gträts': [('gträ', False)],
          'gts': [('g', False)],
          'gtullar': [('gtull', False)],
          'gtullarna': [('gtull', False)],
          'gtullarnas': [('gtull', False)],
          'gtur': [('gtur', False)],
          'gturer': [('gtur', False)],
          'gturerna': [('gtur', False)],
          'gturernas': [('gtur', False)],
          'gturs': [('gtur', False)],
          'gturs-': [('gtur', False)],
          'gtysk': [('gtyska', False)],
          'gtysk-': [('gtyska', False)],
          'gtänder': [('gtand', False)],
          'gtänderna': [('gtand', False)],
          'gtänger': [('gtång', False)],
          'gtängers': [('gtång', False)],
          'gtåg': [('gtåg', False)],
          'gtågs': [('gtåg', False)],
          'gtågs-': [('gtåg', False)],
          'gtång': [('gtång', False)],
          'gtång-': [('gtång', False)],
          'gtången': [('gtång', False)],
          'gtångens': [('gtång', False)],
          'gtångs': [('gtång', False)],
          'gu': [('gu', False)],
          'guan': [('guan', False)],
          'guans': [('guan', False)],
          'guar': [('guar', False)],
          'guar-': [('guar', False)],
          'guaren': [('guar', False)],
          'guarens': [('guar', False)],
          'gubb': [('gubbe', True)],
          'gubb-': [('gubbe', False)],
          'gubbar': [('gubbe', True)],
          'gubben': [('gubbe', False)],
          'gubbs': [('gubbs', True), ('gubbe', True)],
          'gubbs-': [('gubbe', True)],
          'guen': [('gue', False)],
          'guer': [('gue', False)],
          'guerna': [('gue', False)],
          'guernas': [('gu', False)],
          'guers': [('gu', False)],
          'guetten': [('guette', False)],
          'guetter': [('guette', False)],
          'guetterna': [('guette', False)],
          'guetternas': [('guette', False)],
          'guide-': [('guide', False)],
          'guinean': [('guinea', True), ('guinean', True)],
          'guineans': [('guinea', True), ('guinean', True)],
          'gul': [('gula', True)],
          'gul-': [('gula', True)],
          'gula': [('gula', True)],
          'gulan': [('gula', False)],
          'gulans': [('gula', False)],
          'gular': [('gular', False)],
          'gulars': [('gular', False)],
          'gulas': [('gula', False)],
          'gulden': [('gulden', True), ('guld', True)],
          'guldens': [('guld', True), ('gulden', True)],
          'gull': [('gull', False)],
          'gull-': [('gull', False)],
          'gulls-': [('gull', True)],
          'guls': [('gula', True)],
          'guls-': [('gula', True)],
          'gult-': [('gult', False)],
          'gults': [('gult', False)],
          'gum': [('gumma', False)],
          'gum-': [('gumma', False)],
          'gummarna': [('gum', False)],
          'gummarnas': [('gum', False)],
          'gumme': [('gumma', False)],
          'gumme-': [('gumma', False)],
          'gummin': [('gummi', False)],
          'gummins': [('gummi', False)],
          'gump': [('gump', True)],
          'gump-': [('gump', True)],
          'gumps': [('gump', True)],
          'gumps-': [('gump', True)],
          'gums': [('gumma', True), ('gumse', True)],
          'gums-': [('gumse', True), ('gumma', True)],
          'gumsarnas': [('gumse', True)],
          'gun': [('gu', False)],
          'gund': [('gund', False)],
          'gund-': [('gund', False)],
          'gunds': [('gund', False)],
          'gung': [('gung', True), ('gunga', True)],
          'gung-': [('gung', True), ('gunga', True)],
          'gungbräde': [('gungbräda', True), ('gungbräde', True)],
          'gunge': [('gunga', False)],
          'gunge-': [('gunga', True)],
          'gungor': [('gunga', False)],
          'gungorna': [('gunga', False)],
          'gungs': [('gung', True), ('gunga', True)],
          'gungs-': [('gung', True), ('gunga', True)],
          'guns': [('gu', False)],
          'guns-': [('gun', False)],
          'gupp': [('gupp', True)],
          'gupp-': [('gupp', True)],
          'gupps': [('gupp', False)],
          'gupps-': [('gupp', False)],
          'guran': [('gura', True)],
          'gurans': [('gura', True)],
          'gurin': [('gurin', False)],
          'gurn': [('gurn', False)],
          'gurns': [('gurn', False)],
          'guru': [('guru', True)],
          'guruer': [('guru', False)],
          'guruerna': [('guru', False)],
          'guruers': [('guru', False)],
          'gurus': [('guru', False)],
          'gurus-': [('guru', True)],
          'gurusarna': [('guru', True)],
          'gus': [('gu', False)],
          'guss': [('guss', True)],
          'gussar': [('guss', True)],
          'gussars': [('guss', True)],
          'gussen': [('guss', True)],
          'gussens': [('guss', True)],
          'gust-': [('gust', False)],
          'guster': [('gust', False)],
          'gusterna': [('gust', False)],
          'gusternas': [('gust', False)],
          'gusters': [('gust', False)],
          'gustis': [('gusti', False)],
          'gutar': [('gute', True)],
          'gutarna': [('gute', True)],
          'gutars': [('gute', True)],
          'gute': [('gute', True)],
          'gute-': [('gute', True)],
          'guten': [('gute', True), ('gut', True)],
          'gutens': [('gute', True), ('gut', True)],
          'gutier': [('guti', False)],
          'gutierna': [('guti', False)],
          'gutiernas': [('guti', False)],
          'gutiers': [('guti', False)],
          'gutins': [('guti', False)],
          'gutt': [('gutt', True)],
          'gutt-': [('gutt', True)],
          'gutten': [('gutt', True)],
          'gutts': [('gutt', True)],
          'gutts-': [('gutt', True)],
          'gval': [('gval', False)],
          'gvalen': [('gval', False)],
          'gvalens': [('gval', False)],
          'gvallar': [('gvall', False)],
          'gvallarna': [('gvall', False)],
          'gvallarnas': [('gvall', False)],
          'gvals': [('gval', False)],
          'gvals-': [('gval', False)],
          'gvamen': [('gvam', False)],
          'gvamens': [('gvam', False)],
          'gvana': [('gvana', False)],
          'gvanas': [('gvana', False)],
          'gvane-': [('gvana', False)],
          'gvanors': [('gvana', False)],
          'gvant': [('gvante', False)],
          'gvant-': [('gvante', False)],
          'gvante': [('gvante', False)],
          'gvanten': [('gvante', False)],
          'gvantens': [('gvante', False)],
          'gvants': [('gvante', False)],
          'gvants-': [('gvante', False)],
          'gvar-': [('gvara', False)],
          'gvaran': [('gvara', False)],
          'gvarans': [('gvara', False)],
          'gvarar': [('gvar', False)],
          'gvararna': [('gvar', False)],
          'gvararnas': [('gvar', False)],
          'gvarens': [('gvar', False)],
          'gverkets': [('gverk', False)],
          'gviktar': [('gviktare', False)],
          'gviktarna': [('gviktare', False)],
          'gvin': [('gvin', False)],
          'gvin-': [('gvin', False)],
          'gvind': [('gvind', False)],
          'gvinds': [('gvind', False)],
          'gvinds-': [('gvind', False)],
          'gvins': [('gvin', False)],
          'gvins-': [('gvin', False)],
          'gvinsten': [('gvinst', False)],
          'gvinstens': [('gvinst', False)],
          'gvis': [('gvisa', False)],
          'gvis-': [('gvisa', False)],
          'gvisa': [('gvisa', False)],
          'gvisar': [('gvisare', False)],
          'gvisarna': [('gvisare', False)],
          'gvisarnas': [('gvisare', False)],
          'gvisas': [('gvisa', False)],
          'gvise': [('gvisa', False)],
          'gvisor': [('gvisa', False)],
          'gvispar': [('gvisp', False)],
          'gvisparna': [('gvisp', False)],
          'gvisparnas': [('gvisp', False)],
          'gvispars': [('gvisp', False)],
          'gvist': [('gvist', False)],
          'gvist-': [('gvist', False)],
          'gvisten': [('gvist', False)],
          'gvistens': [('gvist', False)],
          'gvitas': [('gvita', False)],
          'gvite': [('gvita', False)],
          'gvägar': [('gväg', False)],
          'gvägarna': [('gväg', False)],
          'gvägarnas': [('gväg', False)],
          'gvägars': [('gväg', False)],
          'gvägen': [('gväg', False)],
          'gvägs': [('gväg', False)],
          'gvägs-': [('gväg', False)],
          'gvält': [('gvält', False)],
          'gvält-': [('gvält', False)],
          'gvälts': [('gvält', False)],
          'gvälts-': [('gvält', False)],
          'gvärden': [('gvärd', False)],
          'gvärdens': [('gvärd', False)],
          'gvärmar': [('gvärmare', False)],
          'gvärmarna': [('gvärmare', False)],
          'gvärmarnas': [('gvärmare', False)],
          'gväsendet': [('gväsen', False)],
          'gväsendets': [('gväsen', False)],
          'gväxlar': [('gväxel', False)],
          'gväxlarna': [('gväxel', False)],
          'gväxlarnas': [('gväxel', False)],
          'gvågar': [('gvåg', False)],
          'gvågarna': [('gvåg', False)],
          'gvård': [('gvårda', False)],
          'gvård-': [('gvårda', False)],
          'gvårdar': [('gvårdare', False)],
          'gvårdarna': [('gvårdare', False)],
          'gvårdarnas': [('gvårdare', False)],
          'gvårds': [('gvårda', False)],
          'gvårds-': [('gvårda', False)],
          'gyar': [('gyar', False)],
          'gyar-': [('gyar', False)],
          'gyarens': [('gyar', False)],
          'gyars': [('gyar', False)],
          'gyckel': [('gyckel', True)],
          'gyckel-': [('gyckel', False)],
          'gyckels': [('gyckel', False)],
          'gycklarna': [('gycklare', False)],
          'gycklarnas': [('gycklare', False)],
          'gyllandet': [('gyllande', False)],
          'gyllarna': [('gyllare', False)],
          'gyllarnas': [('gyllare', False)],
          'gyllena': [('gyllen', False)],
          'gyllenas': [('gyllen', True)],
          'gyllens': [('gyllen', True)],
          'gylt': [('gylta', False)],
          'gylte': [('gylta', False)],
          'gym': [('gym', True)],
          'gym-': [('gym', True)],
          'gymer': [('gymer', False)],
          'gymerna': [('gymer', False)],
          'gymernas': [('gymer', False)],
          'gymers': [('gymer', False)],
          'gymmen': [('gymm', True)],
          'gymmens': [('gymm', True)],
          'gymmet': [('gymm', True)],
          'gymmets': [('gymm', True)],
          'gyms': [('gym', True)],
          'gyms-': [('gymer', False)],
          'gyni': [('gyni', False)],
          'gyni-': [('gyni', False)],
          'gynis': [('gyni', False)],
          'gyx': [('gyxa', False)],
          'gyx-': [('gyxa', False)],
          'gäck': [('gäck', False)],
          'gäck-': [('gäck', False)],
          'gäcken': [('gäck', False)],
          'gäckens': [('gäck', False)],
          'gäcks': [('gäck', False)],
          'gäcks-': [('gäck', False)],
          'gädd-': [('gädda', False)],
          'gädde': [('gädda', False)],
          'gädde-': [('gädda', False)],
          'gägar': [('gägare', False)],
          'gägarna': [('gägare', False)],
          'gägarnas': [('gägare', False)],
          'gälden': [('gäld', False)],
          'gäldens': [('gäld', False)],
          'gälder': [('gäld', False)],
          'gälderna': [('gäld', False)],
          'gäldernas': [('gäld', False)],
          'gälders': [('gäld', False)],
          'gälds': [('gäld', False)],
          'gälds-': [('gäld', False)],
          'gäll': [('gäll', False)],
          'gäll-': [('gäll', False)],
          'gällanden': [('gällande', False)],
          'gällandena': [('gällande', False)],
          'gällandenas': [('gällande', False)],
          'gällandens': [('gällande', False)],
          'gällen': [('gäll', False)],
          'gället': [('gäll', False)],
          'gällets': [('gäll', False)],
          'gällningar': [('gällning', False)],
          'gällningarna': [('gällning', False)],
          'gällningarnas': [('gällning', False)],
          'gällningars': [('gällning', False)],
          'gällnings': [('gällning', False)],
          'gällnings-': [('gällning', False)],
          'gälls': [('gäll', False)],
          'gälls-': [('gäll', False)],
          'gäls': [('gäl', True)],
          'gäms': [('gäms', True)],
          'gäms-': [('gäms', True)],
          'gänd': [('gända', False)],
          'gänd-': [('gända', False)],
          'gändar': [('gände', False)],
          'gändarna': [('gände', False)],
          'gänds': [('gända', False)],
          'gänds-': [('gända', False)],
          'gäng': [('gänga', True), ('gäng', True)],
          'gäng-': [('gänga', True), ('gäng', True)],
          'gängar': [('gängare', False)],
          'gängarna': [('gängare', False)],
          'gängarnas': [('gängare', False)],
          'gänge': [('gänga', True), ('gänge', True)],
          'gängen': [('gänge', True), ('gäng', True)],
          'gängens': [('gänge', True), ('gäng', True)],
          'gänget': [('gänge', True), ('gäng', True)],
          'gängets': [('gänge', True), ('gäng', True)],
          'gängs': [('gänga', True), ('gänge', True), ('gäng', True)],
          'gängs-': [('gänga', True), ('gänge', True), ('gäng', True)],
          'gärd': [('gärd', False)],
          'gärd-': [('gärd', False)],
          'gärden': [('gärd', True), ('gärde', True)],
          'gärdens': [('gärde', True), ('gärd', True)],
          'gärdets': [('gärde', True)],
          'gärds': [('gärd', False)],
          'gärds-': [('gärd', False)],
          'gärdslen': [('gärdsle', True), ('gärdsel', True)],
          'gärdslens': [('gärdsle', True), ('gärdsel', True)],
          'gärdslet': [('gärdsel', True), ('gärdsle', True)],
          'gärdslets': [('gärdsle', True), ('gärdsel', True)],
          'gärs': [('gärs', True)],
          'gärs-': [('gärs', True)],
          'gäss': [('gås', False)],
          'gässen': [('gås', False)],
          'gässens': [('gås', True)],
          'gäst-': [('gäst', False)],
          'gästen': [('gäst', False)],
          'gästens': [('gäst', True)],
          'gäster': [('gäst', True)],
          'gästers': [('gäst', False)],
          'gåker': [('gåker', False)],
          'gåkers': [('gåker', False)],
          'gång': [('gång', False)],
          'gång-': [('gång', False)],
          'gångar': [('gångare', True), ('gång', True)],
          'gångarna': [('gångare', True), ('gång', True)],
          'gångarnas': [('gångare', True), ('gång', True)],
          'gångars': [('gång', False)],
          'gången': [('gång', False)],
          'gångens': [('gång', False)],
          'gånger': [('gång', False)],
          'gångers': [('gång', True)],
          'gångs': [('gång', False)],
          'gångs-': [('gång', False)],
          'gård': [('gård', False)],
          'gård-': [('gård', False)],
          'gårdar': [('gård', False)],
          'gårdarna': [('gård', False)],
          'gårds': [('gård', False)],
          'gårds-': [('gård', False)],
          'gås': [('gåse', True), ('gås', True)],
          'gås-': [('gåse', True), ('gås', True)],
          'gåsar': [('gåse', True)],
          'gåsarna': [('gåse', True)],
          'gåsarnas': [('gåse', True)],
          'gåsars': [('gåse', True)],
          'gåse': [('gåse', True)],
          'gåsen': [('gåse', True), ('gås', True)],
          'gåsens': [('gåse', True), ('gås', True)],
          'gåt': [('gåta', True), ('gåt', True)],
          'gåt-': [('gåt', True), ('gåta', True)],
          'gåtarnas': [('gåt', True)],
          'gåts': [('gåt', True), ('gåta', True)],
          'gåts-': [('gåt', True), ('gåta', True)],
          'gåv': [('gåva', True)],
          'gåve': [('gåva', True)],
          'gåve-': [('gåva', True)],
          'gåvor': [('gåva', True)],
          'gåvorna': [('gåva', True)],
          'gåvornas': [('gåva', False)],
          'gåvors': [('gåva', True)],
          'gåvs': [('gåva', True)],
          'gåvs-': [('gåva', True)],
          'géerna': [('gé', False)],
          'géernas': [('gé', False)],
          'göden': [('göd', False)],
          'gödens': [('göd', False)],
          'göderna': [('göd', False)],
          'gödernas': [('göd', False)],
          'göders': [('göd', False)],
          'gökarnas': [('gök', False)],
          'göken': [('gök', False)],
          'gökens': [('gök', False)],
          'gökurs': [('gökur', True)],
          'gökurs-': [('gökur', True)],
          'göm': [('gömma', False)],
          'göm-': [('gömma', False)],
          'gömmar': [('gömmare', False)],
          'gömmarna': [('gömmare', False)],
          'gömmarnas': [('gömmare', False)],
          'gömme': [('gömme', True), ('gömma', True)],
          'gömme-': [('gömme', True), ('gömma', True)],
          'gömmen': [('gömme', False)],
          'gömmens': [('gömme', False)],
          'gömmet': [('gömme', False)],
          'göms': [('gömme', False)],
          'göms-': [('gömma', False)],
          'göpen': [('göpen', True)],
          'göpens': [('göpen', True)],
          'görarna': [('görare', False)],
          'görarnas': [('görare', False)],
          'gören': [('gör', False)],
          'görens': [('gör', False)],
          'görten': [('gört', False)],
          'görtens': [('gört', False)],
          'gös': [('gös', True)],
          'gös-': [('gös', True)],
          'gösarna': [('gös', True)],
          'gösarnas': [('gös', True)],
          'göt': [('göt', True)],
          'göt-': [('göt', False)],
          'götar': [('göt', True)],
          'götarna': [('göt', True)],
          'götarnas': [('göt', True)],
          'götars': [('göt', True)],
          'göte': [('göte', True)],
          'göte-': [('göte', False)],
          'göten': [('göt', True), ('göte', True)],
          'götens': [('göt', True), ('göte', True)],
          'göter': [('göt', True)],
          'göterna': [('göt', True)],
          'göternas': [('göt', True)],
          'göters': [('göt', True)],
          'götes': [('göte', False)],
          'götes-': [('göte', False)],
          'götet': [('göte', True), ('göt', True)],
          'götets': [('göt', True), ('göte', True)],
          'göts': [('göt', True)],
          'göts-': [('göt', True)],
          'gött': [('gött', True)],
          'gött-': [('gött', True)],
          'götter': [('gött', True)],
          'götterna': [('gött', True)],
          'götternas': [('gött', True)],
          'götters': [('gött', True)],
          'götts': [('gött', True)],
          'götts-': [('gött', True)],
          'h': [('h', True)],
          'h-': [('h', True)],
          'h-ins': [('h-in', False)],
          'ha': [('ha', False)],
          'haberna': [('haber', False)],
          'habernas': [('haber', False)],
          'habers': [('haber', False)],
          'hack': [('hack', True), ('hacka', True)],
          'hack-': [('hacka', True), ('hack', True)],
          'hackarnas': [('hackare', False)],
          'hackbräde': [('hackbräde', True)],
          'hacke': [('hacka', True)],
          'hacke-': [('hacka', False)],
          'hackel': [('hackel', False)],
          'hackel-': [('hackel', False)],
          'hacken': [('hack', True)],
          'hackens': [('hack', True)],
          'hackersens': [('hacker', True)],
          'hacket': [('hack', False)],
          'hackets': [('hack', False)],
          'hacklandets': [('hacklande', False)],
          'hackor': [('hacka', True), ('hackor', True)],
          'hackorna': [('hacka', True)],
          'hackornas': [('hacka', False)],
          'hackors': [('hacka', False)],
          'hacks': [('hack', True), ('hacka', True)],
          'hacks-': [('hacka', True), ('hack', True)],
          'hadier': [('hadier', False)],
          'hadiernas': [('hadier', False)],
          'hadiers': [('hadier', False)],
          'haff': [('haff', True)],
          'haff-': [('haff', True)],
          'haffen': [('haff', True)],
          'haffer': [('haff', True)],
          'haffers': [('haff', True)],
          'haffs': [('haff', True)],
          'hafs': [('hafs', True)],
          'hafs-': [('hafs', True)],
          'hag': [('hage', False)],
          'hag-': [('hage', False)],
          'hagar': [('hage', True)],
          'hagarna': [('hage', False)],
          'hagarnas': [('hage', True)],
          'hagars': [('hage', False)],
          'hage': [('hage', False)],
          'hage-': [('hage', False)],
          'hagen': [('hage', True)],
          'hagens': [('hage', False)],
          'hagets': [('hag', False)],
          'hagg': [('hagga', True)],
          'hagg-': [('hagga', True)],
          'hagge': [('hagga', True)],
          'hagge-': [('hagga', True)],
          'haggen': [('hagg', False)],
          'haggens': [('hagg', False)],
          'haggs': [('hagga', True)],
          'haggs-': [('hagga', True)],
          'hags': [('hage', False)],
          'hags-': [('hage', False)],
          'hajjen': [('hajj', True)],
          'hajjens': [('hajj', True)],
          'hajk': [('hajk', True)],
          'hajk-': [('hajk', True)],
          'hajks': [('hajk', True)],
          'hajs-': [('haj', False)],
          'hak': [('hak', True), ('haka', True), ('hake', True)],
          'hak-': [('hak', True), ('haka', True), ('hake', True)],
          'haka': [('haka', False)],
          'hakan': [('haka', True)],
          'hakans': [('haka', True)],
          'hakar': [('hake', False)],
          'hakarna': [('hake', False)],
          'hakarnas': [('hake', False)],
          'hakars': [('hake', False)],
          'hakas': [('haka', False)],
          'hake': [('haka', True), ('hake', True)],
          'hake-': [('haka', True)],
          'haken': [('hak', True), ('hake', True)],
          'hakens': [('hak', True), ('hake', True)],
          'haker': [('haker', False)],
          'hakerna': [('haker', False)],
          'hakernas': [('haker', False)],
          'hakers': [('haker', False)],
          'hakes': [('hake', False)],
          'hakets': [('hak', False)],
          'hakins': [('haki', False)],
          'hakors': [('haka', True)],
          'haks': [('haka', True), ('hake', True), ('hak', True)],
          'haks-': [('hake', True), ('hak', True), ('haka', True)],
          'haktin': [('hakti', False)],
          'hakås': [('hakå', False)],
          'halandets': [('halande', False)],
          'halans': [('halans', False)],
          'halans-': [('halans', False)],
          'halar': [('hal', False)],
          'halar-': [('halare', False)],
          'halarens': [('halare', False)],
          'halarna': [('halare', False)],
          'halarnas': [('halare', False)],
          'halkan': [('halka', True)],
          'halkans': [('halka', False)],
          'hall': [('hall', False)],
          'hall-': [('hall', False)],
          'hallar': [('hall', False)],
          'hallars': [('hall', False)],
          'hallen': [('hall', False)],
          'haller': [('hall', False)],
          'hallerna': [('hall', False)],
          'hallernas': [('hall', False)],
          'hallers': [('hall', False)],
          'hallon': [('hallon', False)],
          'hallons': [('hallon', False)],
          'halls': [('hall', False)],
          'halls-': [('hall', False)],
          'hallå': [('hallåa', True), ('hallå', True)],
          'hallå-': [('hallåa', True), ('hallå', True)],
          'hallås': [('hallåa', True), ('hallå', True)],
          'hallåts': [('hallå', True)],
          'halmas': [('halma', True)],
          'haloer': [('halo', True)],
          'haloerna': [('halo', True)],
          'haloernas': [('halo', True)],
          'haloers': [('halo', True)],
          'halogen': [('halogen', True)],
          'halogens': [('halogen', True)],
          'halon': [('halo', True)],
          'halons': [('halo', True)],
          'halor': [('halo', True)],
          'halorna': [('halo', True)],
          'halornas': [('halo', True)],
          'halors': [('halo', True)],
          'halos': [('halo', True)],
          'halos-': [('halo', True)],
          'hals': [('hals', False)],
          'hals-': [('hals', True)],
          'halt-': [('halt', False)],
          'halter': [('halt', False)],
          'halterna': [('halt', False)],
          'halternas': [('halt', False)],
          'halters': [('halt', False)],
          'halts': [('halt', False)],
          'halts-': [('halt', False)],
          'halv': [('halv', True), ('halva', True)],
          'halv-': [('halv', True), ('halva', True)],
          'halvar': [('halv', False)],
          'halvarna': [('halv', False)],
          'halvarnas': [('halv', False)],
          'halvars': [('halv', False)],
          'halvor': [('halva', False)],
          'halvorna': [('halva', False)],
          'halvornas': [('halva', False)],
          'halvors': [('halva', False)],
          'halvs': [('halv', True), ('halva', True)],
          'halvs-': [('halv', True), ('halva', True)],
          'ham': [('ham', False)],
          'ham-': [('ham', False)],
          'hambors': [('hambo', True)],
          'hamlandet': [('hamlande', True)],
          'hamlar': [('hammel', True)],
          'hamlarna': [('hammel', True)],
          'hammar': [('hammare', False)],
          'hammers': [('hammer', False)],
          'hamn': [('hamn', False)],
          'hamn-': [('hamn', False)],
          'hamnar': [('hamn', False)],
          'hamnarna': [('hamn', True)],
          'hamnars': [('hamn', False)],
          'hamnen': [('hamn', False)],
          'hamnens': [('hamn', False)],
          'hamns': [('hamn', False)],
          'hamns-': [('hamn', False)],
          'hamottens': [('hamotte', False)],
          'hamrar': [('hammare', True)],
          'hamrarna': [('hammare', False)],
          'hamrarnas': [('hammare', False)],
          'hamrars': [('hammare', True)],
          'hams': [('ham', False)],
          'hams-': [('ham', False)],
          'han': [('hane', True)],
          'han-': [('hane', False)],
          'hanar': [('hane', False)],
          'hanarnas': [('hane', False)],
          'hanars': [('hane', False)],
          'hand': [('hand', False)],
          'hand-': [('hand', False)],
          'handen': [('hand', False)],
          'handens': [('hand', False)],
          'handets': [('hande', False)],
          'handflat-': [('handflata', True)],
          'handflate': [('handflata', True)],
          'handflats': [('handflata', True)],
          'handflats-': [('handflata', True)],
          'handlar': [('handlare', True), ('handel', True)],
          'handlarna': [('handlare', True), ('handel', True)],
          'handlarnas': [('handlare', True), ('handel', True)],
          'handrems': [('handrem', True)],
          'handrems-': [('handrem', True)],
          'hands': [('hands', True), ('hand', True)],
          'hands-': [('hands', True), ('hand', True)],
          'hane': [('hane', False)],
          'hanen': [('hane', True)],
          'hanens': [('hane', False)],
          'hanes': [('hane', False)],
          'hanes-': [('hane', False)],
          'hang': [('hang', False)],
          'hang-': [('hang', False)],
          'hangar': [('hangar', False)],
          'hangar-': [('hangar', False)],
          'hangarens': [('hangar', True)],
          'hangarn': [('hangar', False)],
          'hangarns': [('hangar', False)],
          'hangen': [('hang', False)],
          'hangens': [('hang', False)],
          'hangs': [('hang', False)],
          'hangs-': [('hang', False)],
          'hank': [('hank', True)],
          'hank-': [('hank', False)],
          'hankar': [('hank', False)],
          'hankarna': [('hank', False)],
          'hankarnas': [('hank', True)],
          'hankars': [('hank', False)],
          'hanken': [('hank', False)],
          'hankens': [('hank', False)],
          'hanks': [('hank', False)],
          'hanks-': [('hank', False)],
          'hann': [('hanne', False)],
          'hann-': [('hanne', False)],
          'hannars': [('hanne', False)],
          'hannen': [('hanne', False)],
          'hannens': [('hanne', False)],
          'hanns': [('hanne', False)],
          'hanns-': [('hanne', False)],
          'hans': [('hane', True)],
          'hans-': [('hane', True)],
          'hansen': [('hans', False)],
          'hansens': [('hans', False)],
          'hanser': [('hans', False)],
          'hanserna': [('hans', False)],
          'hansernas': [('hans', False)],
          'hansers': [('hans', False)],
          'hansk': [('hanska', False)],
          'hansk-': [('hanska', False)],
          'happen': [('happ', False)],
          'happens': [('happ', False)],
          'happs': [('happ', False)],
          'har': [('har', True), ('hare', True)],
          'har-': [('har', True), ('hare', True)],
          'hararnas': [('hare', False)],
          'hare': [('hare', False)],
          'haren': [('hare', True)],
          'harens': [('hare', False)],
          'hares': [('hare', False)],
          'hares-': [('hare', False)],
          'harmonier': [('harmonium', True), ('harmoni', True)],
          'harmonierna': [('harmonium', True), ('harmoni', True)],
          'harmoniernas': [('harmonium', True), ('harmoni', True)],
          'harmoniers': [('harmoni', True), ('harmonium', True)],
          'harmonik': [('harmonik', True), ('harmonika', True)],
          'harmonik-': [('harmonik', True), ('harmonika', True)],
          'harmoniks': [('harmonik', True), ('harmonika', True)],
          'harnas': [('h', False)],
          'harps-': [('harpa', True)],
          'harr': [('harr', True)],
          'harr-': [('harr', True)],
          'harrar': [('harr', True)],
          'harrarna': [('harr', True)],
          'harrarnas': [('harr', True)],
          'harrars': [('harr', True)],
          'harrens': [('harr', True)],
          'harrs-': [('harr', True)],
          'hars': [('hare', False)],
          'hars-': [('hare', False)],
          'harsis': [('harsis', False)],
          'harsis-': [('harsis', False)],
          'harsklandet': [('harsklande', True)],
          'hartans': [('harta', False)],
          'harter': [('harter', False)],
          'harters': [('harter', False)],
          'harts': [('harts', True)],
          'harts-': [('harts', False)],
          'harv': [('harv', True)],
          'harv-': [('harv', True)],
          'harvar': [('harv', False)],
          'harvarna': [('harv', False)],
          'harvarnas': [('harv', True)],
          'harvars': [('harv', False)],
          'harven': [('harv', True)],
          'harvens': [('harv', True)],
          'harvs': [('harv', False)],
          'harvs-': [('harv', True)],
          'has': [('has', True)],
          'has-': [('has', False)],
          'hasar': [('has', False)],
          'hasarna': [('has', True)],
          'hasarnas': [('has', False)],
          'hase': [('hase', False)],
          'hase-': [('hase', False)],
          'hasen': [('has', True)],
          'hasens': [('has', True)],
          'haser': [('hase', False)],
          'haserna': [('hase', False)],
          'hasernas': [('hase', False)],
          'hasers': [('hase', False)],
          'hasor': [('has', False)],
          'hasorna': [('has', False)],
          'hasornas': [('has', True)],
          'hasors': [('has', True)],
          'haspar': [('hasp', False)],
          'haspars': [('hasp', False)],
          'hasslar': [('hassel', True)],
          'hasslarna': [('hassel', True)],
          'hasslarnas': [('hassel', True)],
          'hast-': [('hast', True)],
          'hasten': [('hast', True)],
          'hatar': [('hatare', False)],
          'hatar-': [('hatare', False)],
          'hatarens': [('hatare', True)],
          'hatarna': [('hatare', False)],
          'hatarnas': [('hatare', True)],
          'hatars': [('hat', False)],
          'hatell': [('hatell', False)],
          'hatell-': [('hatell', False)],
          'hatells': [('hatell', False)],
          'hatells-': [('hatell', False)],
          'hatmans': [('hatma', False)],
          'hatmor': [('hatma', False)],
          'hats-': [('hat', False)],
          'hatt': [('hatt', False)],
          'hatt-': [('hatt', True)],
          'hattar': [('hatt', False)],
          'hattars': [('hatt', False)],
          'hatten': [('hatt', False)],
          'hatteranden': [('hatterande', False)],
          'hatterandens': [('hatterande', False)],
          'hatts': [('hatt', False)],
          'hatts-': [('hatt', False)],
          'haussen': [('hausse', True)],
          'haussens': [('hausse', True)],
          'havanden': [('havande', False)],
          'havandens': [('havande', False)],
          'havar': [('havare', False)],
          'havarnas': [('havare', False)],
          'haven': [('hav', False)],
          'havens': [('hav', False)],
          'havet': [('hav', False)],
          'havets': [('hav', False)],
          'havrens': [('havre', False)],
          'havsområdet': [('havsområde', True)],
          'havsområdets': [('havsområde', True)],
          'hbanan': [('hbana', False)],
          'hbanans': [('hbana', False)],
          'hbane': [('hbana', False)],
          'hbane-': [('hbana', False)],
          'hdags': [('hdags', False)],
          'hdans': [('hdans', False)],
          'he': [('he', False)],
          'he-': [('he', False)],
          'hean': [('hean', False)],
          'heans': [('hean', False)],
          'heck': [('heck', False)],
          'heck-': [('heck', False)],
          'heckar': [('heck', False)],
          'heckarna': [('heck', False)],
          'heckarnas': [('heck', False)],
          'hecken': [('heck', False)],
          'heckens': [('heck', False)],
          'hecks': [('heck', False)],
          'hecks-': [('heck', False)],
          'hed': [('hed', False)],
          'hed-': [('hed', False)],
          'hedarnas': [('hed', True)],
          'heder': [('heder', False)],
          'heders': [('heder', False)],
          'hedin': [('hedin', False)],
          'heds': [('hed', True)],
          'heds-': [('hed', False)],
          'heer': [('he', False)],
          'heerna': [('he', False)],
          'heernas': [('he', False)],
          'heers': [('he', False)],
          'heet': [('he', False)],
          'hejar': [('hejare', True)],
          'hejarna': [('hejare', False)],
          'hejarnas': [('hejare', True)],
          'hel': [('hela', True)],
          'hel-': [('hela', True)],
          'helanden': [('helande', True)],
          'helandens': [('helande', True)],
          'helandets': [('helande', True)],
          'helie': [('helium', False)],
          'hellens': [('hellen', True)],
          'hellens-': [('hellen', True)],
          'hels': [('hela', True)],
          'hels-': [('hela', True)],
          'hem': [('hem', False)],
          'hem-': [('hem', True)],
          'heman': [('hema', False)],
          'hemans': [('hema', False)],
          'hementen': [('hement', False)],
          'hementens': [('hement', False)],
          'hementet': [('hement', False)],
          'hements-': [('hement', False)],
          'hemman': [('hemman', False)],
          'hemmans': [('hemman', False)],
          'hems': [('hem', False)],
          'hems-': [('hem', False)],
          'hen': [('hen', True)],
          'henarnas': [('hen', True)],
          'henden': [('hend', False)],
          'hendens': [('hend', False)],
          'hender': [('hend', False)],
          'henderna': [('hend', False)],
          'henders': [('hend', False)],
          'heniets': [('henium', False)],
          'hens': [('hen', False)],
          'hent': [('hent', False)],
          'henten': [('hent', False)],
          'hentens': [('hent', False)],
          'henter': [('hent', False)],
          'henterna': [('hent', False)],
          'henternas': [('hent', False)],
          'henters': [('hent', False)],
          'hents-': [('hent', False)],
          'her-': [('her', False)],
          'heran': [('heran', False)],
          'herans': [('heran', False)],
          'herdomar': [('herdom', False)],
          'herdomarnas': [('herdom', False)],
          'herens': [('herens', False)],
          'herie': [('herier', False)],
          'herie-': [('herier', False)],
          'herierna': [('herier', False)],
          'heriernas': [('herier', False)],
          'heriers': [('herier', False)],
          'hermer': [('herm', True)],
          'hermerna': [('herm', True)],
          'hermernas': [('herm', True)],
          'hermers': [('herm', True)],
          'herr': [('herr', True), ('herre', True)],
          'herr-': [('herr', True), ('herre', True)],
          'herrs': [('herre', True), ('herr', True)],
          'hers-': [('her', False)],
          'hersarnas': [('her', False)],
          'hersen': [('her', False)],
          'hes': [('he', False)],
          'hes-': [('he', False)],
          'hesier': [('hesium', False)],
          'hesierna': [('hesium', False)],
          'hesiernas': [('hesium', False)],
          'hesiers': [('hesium', False)],
          'hesiet': [('hesium', False)],
          'hesiets': [('hesium', False)],
          'hessen': [('hesse', False)],
          'hessens': [('hesse', False)],
          'hester': [('hester', False)],
          'hesters': [('hester', False)],
          'het': [('het', False)],
          'heta': [('heta', False)],
          'hetan': [('heta', False)],
          'hetans': [('heta', False)],
          'hetat': [('heta', False)],
          'hete': [('hete', False)],
          'hete-': [('hete', False)],
          'heten': [('het', False)],
          'hetens': [('het', False)],
          'heters': [('hete', False)],
          'hetes': [('hete', False)],
          'hetes-': [('hete', False)],
          'hetets': [('het', False)],
          'hetman': [('hetman', True)],
          'hets': [('hets', True)],
          'hets-': [('hets', False)],
          'hetsarnas': [('hetsare', False)],
          'hetsen': [('hets', False)],
          'hetsens': [('hets', False)],
          'hetsflaggs-': [('hetsflagg', False)],
          'hett': [('hett', False)],
          'hett-': [('hett', False)],
          'hette': [('hetta', False)],
          'hette-': [('hette', False)],
          'hetts': [('hett', False)],
          'hetts-': [('hett', False)],
          'hhak': [('hhaka', False)],
          'hhak-': [('hhaka', False)],
          'hhake': [('hhaka', False)],
          'hhaks': [('hhaka', False)],
          'hhaks-': [('hhaka', False)],
          'hhets': [('hhet', False)],
          'hhets-': [('hhet', False)],
          'hhundars': [('hhund', False)],
          'hhylle': [('hhylla', False)],
          'hhylle-': [('hhylla', False)],
          'hi': [('hi', False)],
          'hi-': [('hi', False)],
          'hias': [('hias', False)],
          'hias-': [('hias', False)],
          'hibbar': [('hibbe', False)],
          'hibbarna': [('hibbe', False)],
          'hibbarnas': [('hibbe', False)],
          'hibben': [('hibbe', False)],
          'hibbens': [('hibbe', False)],
          'hichet': [('hichet', False)],
          'hie': [('hia', False)],
          'hie-': [('hia', False)],
          'hien': [('hi', False)],
          'hiens': [('hi', False)],
          'hier': [('hier', False)],
          'hierna': [('hier', False)],
          'hiffer-': [('hiffer', False)],
          'highets-': [('highet', False)],
          'hilen': [('hilen', False)],
          'hilens': [('hilen', False)],
          'hili': [('hili', False)],
          'hili-': [('hili', False)],
          'hilis': [('hili', False)],
          'hilister': [('hilist', False)],
          'hilisters': [('hilist', False)],
          'hillan': [('hilla', False)],
          'hille': [('hilla', False)],
          'hille-': [('hilla', False)],
          'hillor': [('hilla', False)],
          'hillorna': [('hilla', False)],
          'hillornas': [('hilla', False)],
          'hillors': [('hilla', False)],
          'himlen': [('himmel', True)],
          'himlens': [('himmel', False)],
          'himpans': [('himpans', False)],
          'hin': [('hin', True)],
          'hina': [('hi', False)],
          'hinas': [('hi', False)],
          'hind': [('hind', True)],
          'hind-': [('hind', True)],
          'hindar': [('hind', True)],
          'hindarna': [('hind', True)],
          'hinds': [('hind', True)],
          'hinds-': [('hind', True)],
          'hing': [('hing', False)],
          'hing-': [('hing', False)],
          'hingar': [('hing', False)],
          'hingarna': [('hing', False)],
          'hingarnas': [('hing', False)],
          'hingars': [('hing', False)],
          'hingel': [('hingel', False)],
          'hingel-': [('hingel', False)],
          'hingen': [('hing', False)],
          'hingens': [('hing', False)],
          'hings': [('hing', False)],
          'hings-': [('hing', False)],
          'hini': [('hini', False)],
          'hini-': [('hini', False)],
          'hinin': [('hini', False)],
          'hinins': [('hini', False)],
          'hinis': [('hini', False)],
          'hink': [('hink', True)],
          'hinkars': [('hink', False)],
          'hinks': [('hink', False)],
          'hinn': [('hinna', True)],
          'hinne': [('hinna', False)],
          'hinne-': [('hinna', False)],
          'hinns': [('hinna', True)],
          'hinns-': [('hinna', True)],
          'hins': [('hin', True)],
          'hior': [('hia', False)],
          'hiorna': [('hia', False)],
          'hiornas': [('hia', False)],
          'hiors': [('hia', False)],
          'hipp': [('hippa', True)],
          'hippe': [('hippa', False)],
          'hippe-': [('hippa', True)],
          'hippen': [('hipp', False)],
          'hippens': [('hipp', False)],
          'hippet': [('hipp', False)],
          'hippets': [('hipp', False)],
          'hipps': [('hippa', True)],
          'hipps-': [('hippa', True)],
          'hirs': [('hirs', True)],
          'hirs-': [('hirs', True)],
          'his': [('hi', False)],
          'his-': [('hia', False)],
          'hiskan': [('hiska', False)],
          'hiskans': [('hiska', False)],
          'hiske': [('hiska', False)],
          'hiske-': [('hiska', False)],
          'hismer': [('hism', False)],
          'hismernas': [('hism', False)],
          'hiss': [('hiss', True)],
          'hissar': [('hiss', False)],
          'hissars': [('hiss', True)],
          'hissen': [('hiss', False)],
          'hissens': [('hiss', False)],
          'hist-': [('hist', False)],
          'histen': [('hist', False)],
          'histens': [('hist', False)],
          'hister': [('hist', False)],
          'histerna': [('hist', False)],
          'histernas': [('hist', False)],
          'histers': [('hist', False)],
          'historier': [('historia', False)],
          'historierna': [('historia', False)],
          'historiernas': [('historia', False)],
          'historiers': [('historia', False)],
          'historiker': [('historik', True), ('historiker', True)],
          'historikerna': [('historik', True), ('historiker', True)],
          'historikernas': [('historik', True), ('historiker', True)],
          'historikers': [('historik', True), ('historiker', True)],
          'hit': [('hit', True)],
          'hitet': [('hit', False)],
          'hitets': [('hit', False)],
          'hits': [('hit', False)],
          'hitsarna': [('hit', True)],
          'hitsarnas': [('hit', True)],
          'hitt': [('hitt', False)],
          'hitt-': [('hitt', False)],
          'hittarnas': [('hittare', False)],
          'hitten': [('hitt', False)],
          'hitts': [('hitt', False)],
          'hitts-': [('hitt', False)],
          'hjon': [('hjon', False)],
          'hjoner': [('hjon', False)],
          'hjonerna': [('hjon', False)],
          'hjonernas': [('hjon', False)],
          'hjoners': [('hjon', False)],
          'hjons': [('hjon', False)],
          'hjorts': [('hjort', True)],
          'hjälpar': [('hjälpare', True), ('hjälp', True)],
          'hjälparna': [('hjälp', True), ('hjälpare', True)],
          'hjälparnas': [('hjälpare', True), ('hjälp', True)],
          'hjärn': [('hjärna', False)],
          'hjärn-': [('hjärna', True)],
          'hjärns': [('hjärna', False)],
          'hjärns-': [('hjärna', False)],
          'hjärt': [('hjärta', False)],
          'hjärt-': [('hjärta', False)],
          'hjärts': [('hjärta', False)],
          'hjärts-': [('hjärta', False)],
          'hk': [('hk', True)],
          'hk-': [('hk', True)],
          'hkana': [('hkana', False)],
          'hkanas': [('hkana', False)],
          'hkräm': [('hkräm', False)],
          'hkulornas': [('hkula', False)],
          'hkulors': [('hkula', False)],
          'hlen': [('hle', False)],
          'hlens': [('hle', False)],
          'hlet': [('hle', False)],
          'hlets': [('hle', False)],
          'hli': [('hlia', False)],
          'hli-': [('hlia', False)],
          'hlian': [('hlia', False)],
          'hlians': [('hlia', False)],
          'hlias': [('hlia', False)],
          'hlie': [('hlia', False)],
          'hlie-': [('hlia', False)],
          'hlighets': [('hlighet', False)],
          'hlis': [('hlia', False)],
          'hlis-': [('hlia', False)],
          'hls-': [('hl', False)],
          'hm-': [('hm', False)],
          'hman': [('hman', False)],
          'hmannen': [('hman', False)],
          'hmannens': [('hman', False)],
          'hmar': [('hmare', False)],
          'hmar-': [('hmare', False)],
          'hmare': [('hmare', False)],
          'hmaren': [('hmare', False)],
          'hmarna': [('hmare', False)],
          'hmarnas': [('hmare', False)],
          'hmas': [('hma', False)],
          'hmen': [('hm', False)],
          'hmens': [('hm', False)],
          'hmer': [('hma', False)],
          'hmerer': [('hmer', False)],
          'hmererna': [('hmer', False)],
          'hmerernas': [('hmer', False)],
          'hmerers': [('hmer', False)],
          'hmers': [('hmer', False)],
          'hmetoden': [('hmetod', False)],
          'hmän': [('hman', False)],
          'hmäns': [('hman', False)],
          'hn': [('h', False)],
          'hn-': [('hn', False)],
          'hnamn': [('hnamn', False)],
          'hnamn-': [('hnamn', False)],
          'hnamnen': [('hnamn', False)],
          'hnamnens': [('hnamn', False)],
          'hnamns': [('hnamn', False)],
          'hnamns-': [('hnamn', False)],
          'hnen': [('hn', False)],
          'hnens': [('hn', False)],
          'hnie-': [('hnier', False)],
          'hniernas': [('hnier', False)],
          'hniers': [('hnier', False)],
          'hno': [('hno', False)],
          'hno-': [('hno', False)],
          'hnon': [('hno', False)],
          'hnons': [('hno', False)],
          'hnos': [('hno', False)],
          'hns': [('hn', False)],
          'hnötter': [('hnöt', False)],
          'hnötterna': [('hnöt', False)],
          'hnötternas': [('hnöt', False)],
          'ho': [('ho', False)],
          'hoar': [('ho', False)],
          'hoars': [('ho', True)],
          'hock-': [('hock', False)],
          'hocken': [('hock', False)],
          'hockens': [('hock', False)],
          'hocker': [('hock', False)],
          'hockers': [('hock', False)],
          'hocks': [('hock', False)],
          'hocks-': [('hock', False)],
          'hoen': [('ho', False)],
          'hoer': [('ho', False)],
          'hoerna': [('ho', False)],
          'hoernas': [('ho', False)],
          'hoers': [('ho', False)],
          'hoff': [('hoff', False)],
          'hoff-': [('hoff', False)],
          'hoffs': [('hoff', False)],
          'hokar': [('hoke', False)],
          'hokarna': [('hoke', False)],
          'hokarnas': [('hoke', False)],
          'hokars': [('hoke', False)],
          'hoke': [('hoke', False)],
          'hoke-': [('hoke', False)],
          'hoken': [('hoke', False)],
          'hokens': [('hoke', False)],
          'holk': [('holk', True)],
          'holk-': [('holk', True)],
          'holkar': [('holk', True)],
          'holkarna': [('holk', False)],
          'holks': [('holk', False)],
          'holks-': [('holk', False)],
          'holm': [('holme', False)],
          'holm-': [('holme', True)],
          'holmar': [('holme', True)],
          'holmarna': [('holme', True)],
          'holmarnas': [('holme', False)],
          'holmars': [('holme', True)],
          'holmen': [('holme', True)],
          'holmens': [('holme', True)],
          'holms': [('holme', False)],
          'holms-': [('holme', True)],
          'holt-': [('holt', False)],
          'holts': [('holt', True)],
          'holts-': [('holt', False)],
          'hom': [('homma', True)],
          'hom-': [('homma', False)],
          'homme': [('homma', False)],
          'homme-': [('homma', True)],
          'homs': [('homma', True)],
          'homs-': [('homma', False)],
          'hon': [('hona', True), ('ho', True)],
          'hon-': [('hona', True)],
          'hona': [('hona', False)],
          'honan': [('hona', False)],
          'honans': [('hona', False)],
          'honar': [('hone', False)],
          'honarna': [('hone', False)],
          'honars': [('hone', False)],
          'honas': [('hona', True)],
          'hone': [('hona', True)],
          'hone-': [('hona', True)],
          'honen': [('hone', False)],
          'honens': [('hone', False)],
          'honer': [('hone', False)],
          'honerna': [('hone', False)],
          'honernas': [('hone', False)],
          'honers': [('hone', False)],
          'hones': [('hone', False)],
          'hones-': [('hone', False)],
          'honesen': [('hone', False)],
          'honesens': [('hone', False)],
          'hong': [('hong', False)],
          'hong-': [('hong', False)],
          'honger': [('hong', False)],
          'hongerna': [('hong', False)],
          'hongernas': [('hong', False)],
          'hongers': [('hong', False)],
          'hongs': [('hong', False)],
          'hongs-': [('hong', False)],
          'honie-': [('honia', False)],
          'honis': [('honia', False)],
          'honis-': [('honia', False)],
          'honkön': [('honkön', True)],
          'honköns': [('honkön', True)],
          'hons': [('hona', True), ('ho', True)],
          'hons-': [('hona', True)],
          'hopar': [('hop', True)],
          'hoparens': [('hopare', False)],
          'hoparna': [('hop', True)],
          'hoparnas': [('hop', False)],
          'hoper': [('hoper', True)],
          'hopers': [('hoper', True)],
          'hopp': [('hopp', False)],
          'hopp-': [('hopp', True)],
          'hoppar': [('hoppare', False)],
          'hopparen': [('hoppare', False)],
          'hopparens': [('hoppare', False)],
          'hopparnas': [('hoppare', False)],
          'hoppbackar': [('hoppbacke', True)],
          'hoppbackarna': [('hoppbacke', True)],
          'hoppbackarnas': [('hoppbacke', True)],
          'hoppe': [('hoppa', False)],
          'hoppe-': [('hoppa', False)],
          'hoppen': [('hopp', False)],
          'hoppens': [('hopp', False)],
          'hoppor': [('hoppa', False)],
          'hopporna': [('hoppa', False)],
          'hoppornas': [('hoppa', False)],
          'hoppors': [('hoppa', False)],
          'hopps': [('hopp', False)],
          'hopps-': [('hopp', False)],
          'hopsarnas': [('hop', False)],
          'hor': [('hor', True), ('hora', True)],
          'hor-': [('hor', True), ('hora', True)],
          'hora': [('hora', False)],
          'horan': [('hora', False)],
          'horans': [('hora', False)],
          'horas': [('hora', False)],
          'hord': [('hord', True)],
          'hord-': [('hord', True)],
          'horden': [('hord', True)],
          'hordens': [('hord', False)],
          'horder': [('hord', True)],
          'horderna': [('hord', True)],
          'hordernas': [('hord', False)],
          'horders': [('hord', True)],
          'hords': [('hord', False)],
          'horn': [('horn', False)],
          'horn-': [('horn', True)],
          'hornen': [('horn', False)],
          'hornens': [('horn', False)],
          'horns': [('horn', False)],
          'horns-': [('horn', False)],
          'horor': [('hora', True)],
          'hororna': [('hora', True)],
          'horornas': [('hora', False)],
          'horors': [('hora', False)],
          'hors': [('hor', True), ('hora', True)],
          'hors-': [('hora', True), ('hor', True)],
          'horst': [('horst', True)],
          'horstar': [('horst', True)],
          'horsten': [('horst', True)],
          'horstens': [('horst', True)],
          'horten': [('hort', False)],
          'horternas': [('hort', False)],
          'horts': [('hort', False)],
          'hos': [('ho', False)],
          'hos-': [('ho', False)],
          'hose': [('hoser', False)],
          'hose-': [('hoser', False)],
          'host': [('host', True), ('hosta', True)],
          'host-': [('host', True), ('hosta', True)],
          'hostan': [('hosta', False)],
          'hostans': [('hosta', False)],
          'hoste': [('hosta', False)],
          'hot': [('hot', False)],
          'hotarnas': [('hot', False)],
          'hots': [('hot', True)],
          'hots-': [('hot', True)],
          'hott': [('hott', False)],
          'hott-': [('hott', False)],
          'hottar': [('hott', False)],
          'hottarnas': [('hott', False)],
          'hottars': [('hott', False)],
          'hotten': [('hott', False)],
          'hotter': [('hott', False)],
          'hotterna': [('hott', False)],
          'hotternas': [('hott', False)],
          'hotters': [('hott', False)],
          'hottis': [('hottis', False)],
          'hottis-': [('hottis', False)],
          'hotts': [('hott', False)],
          'hotts-': [('hott', False)],
          'hovar': [('hov', False)],
          'hpelar': [('hpelare', False)],
          'hpelar-': [('hpelare', False)],
          'hr-': [('hr', True)],
          'hrack': [('hrack', False)],
          'hrack-': [('hrack', False)],
          'hrackar': [('hrack', False)],
          'hrackarna': [('hrack', False)],
          'hrackarnas': [('hrack', False)],
          'hracks': [('hrack', False)],
          'hracks-': [('hrack', False)],
          'hrarnas': [('her', False)],
          'hraster': [('hrast', False)],
          'hrasterna': [('hrast', False)],
          'hrasternas': [('hrast', False)],
          'hrasters': [('hrast', False)],
          'hriller': [('hriller', False)],
          'hrillers': [('hriller', False)],
          'hrum': [('hrum', False)],
          'hrums-': [('hrum', False)],
          'hråden': [('hråd', False)],
          'hrådens': [('hråd', False)],
          'hrådet': [('hråd', False)],
          'hs': [('h', False)],
          'hs-': [('ha', False)],
          'hsaren': [('hsare', False)],
          'hsarna': [('hsare', False)],
          'hsarnas': [('hsare', False)],
          'hsen': [('h', False)],
          'hsens': [('h', False)],
          'hsi': [('hsia', False)],
          'hsi-': [('hsia', False)],
          'hsian': [('hsia', False)],
          'hsians': [('hsia', False)],
          'hsie': [('hsia', False)],
          'hsie-': [('hsia', False)],
          'hsis': [('hsia', False)],
          'hsis-': [('hsia', False)],
          'hställen': [('hställe', False)],
          'hställens': [('hställe', False)],
          'hstället': [('hställe', False)],
          'hställets': [('hställe', False)],
          'ht': [('ht', False)],
          'ht-': [('ht', False)],
          'htagar': [('htag', False)],
          'htagarna': [('htag', False)],
          'htagarnas': [('htag', False)],
          'htagen': [('htag', False)],
          'htagens': [('htag', False)],
          'htaggar': [('htagg', False)],
          'htaggarna': [('htagg', False)],
          'htaggarnas': [('htagg', False)],
          'htalens': [('htal', False)],
          'hten': [('ht', False)],
          'htens': [('ht', False)],
          'hter': [('ht', False)],
          'hter-': [('hter', False)],
          'htern': [('hter', False)],
          'hterna': [('ht', False)],
          'hternas': [('ht', False)],
          'hterns': [('hter', False)],
          'hters': [('ht', False)],
          'hters-': [('hter', False)],
          'htersen': [('hter', False)],
          'htersens': [('hter', False)],
          'htestens': [('htest', False)],
          'htet': [('ht', False)],
          'htets': [('ht', False)],
          'hthet': [('hthet', False)],
          'hthets': [('hthet', False)],
          'htiden': [('htid', False)],
          'htider': [('htid', False)],
          'htim': [('htimme', False)],
          'htim-': [('htimme', False)],
          'htimmarna': [('htimme', False)],
          'htomten': [('htomte', False)],
          'htomtens': [('htomte', False)],
          'hträd': [('hträd', False)],
          'hträd-': [('hträd', False)],
          'hträden': [('hträd', False)],
          'hträdens': [('hträd', False)],
          'hträdet': [('hträd', False)],
          'hträdets': [('hträd', False)],
          'hträds': [('hträd', False)],
          'hträn': [('hträd', False)],
          'hträna': [('hträd', False)],
          'htränas': [('hträd', False)],
          'hträns': [('hträd', False)],
          'hts': [('ht', False)],
          'hts-': [('ht', False)],
          'htsarna': [('ht', False)],
          'htsarnas': [('ht', False)],
          'htsen': [('ht', False)],
          'htsens': [('ht', False)],
          'hu': [('hu', False)],
          'huana': [('huana', False)],
          'huanas': [('huana', False)],
          'huck': [('huck', False)],
          'huck-': [('huck', False)],
          'huckar': [('huck', False)],
          'huckarna': [('huck', False)],
          'huckle': [('huckle', True)],
          'hucks': [('huck', False)],
          'hucks-': [('huck', False)],
          'huer': [('hu', False)],
          'huerna': [('hu', False)],
          'huernas': [('hu', False)],
          'huers': [('hu', False)],
          'huettens': [('huett', False)],
          'huetters': [('huett', False)],
          'hug-': [('hug', True)],
          'hugg': [('hugg', False)],
          'hugg-': [('hugg', True)],
          'huggen': [('hugg', False)],
          'huggens': [('hugg', False)],
          'huggs': [('hugg', False)],
          'huggs-': [('hugg', False)],
          'hugs-': [('hug', True)],
          'hukarnas': [('huk', False)],
          'hula': [('hula', False)],
          'hulan': [('hula', False)],
          'hulans': [('hula', False)],
          'hulas': [('hula', False)],
          'huli': [('huli', False)],
          'hulin': [('huli', False)],
          'hulins': [('huli', False)],
          'hulis': [('huli', False)],
          'hulit': [('huli', False)],
          'hulits': [('huli', False)],
          'hulk': [('hulk', True)],
          'hull': [('hull', True)],
          'hull-': [('hull', True)],
          'hult-': [('hult', False)],
          'hultar': [('hult', False)],
          'hultarna': [('hult', False)],
          'hultars': [('hult', False)],
          'hulten': [('hult', False)],
          'hultens': [('hult', False)],
          'hulter': [('hult', True)],
          'hultet': [('hult', False)],
          'hults': [('hult', False)],
          'hults-': [('hult', False)],
          'humle': [('humla', True), ('humle', True)],
          'humle-': [('humla', True), ('humle', True)],
          'humor': [('humor', False)],
          'hun': [('hu', False)],
          'hund': [('hund', False)],
          'hund-': [('hund', False)],
          'hundans': [('hundan', True)],
          'hundans-': [('hundan', True)],
          'hundar': [('hund', False)],
          'hundarna': [('hund', False)],
          'hundars': [('hundare', True), ('hund', True)],
          'hundringar': [('hundring', True)],
          'hundringarna': [('hundring', True)],
          'hundringarnas': [('hundring', True)],
          'hundringars': [('hundring', True)],
          'hunds': [('hund', False)],
          'hunds-': [('hund', False)],
          'hunk': [('hunk', True)],
          'hunk-': [('hunk', True)],
          'hunkarnas': [('hunk', True)],
          'hunkars': [('hunk', True)],
          'hunken': [('hunk', True)],
          'hunkens': [('hunk', True)],
          'hunks': [('hunk', True)],
          'hunks-': [('hunk', True)],
          'hunnen': [('hunn', True)],
          'hunnens': [('hunn', True)],
          'hunner': [('hunn', True), ('hunner', True)],
          'hunnerna': [('hunn', True), ('hunner', True)],
          'hunnernas': [('hunn', True), ('hunner', True)],
          'hunners': [('hunn', True), ('hunner', True)],
          'hunns': [('hunn', True)],
          'huns': [('hu', False)],
          'hunt': [('hunt', False)],
          'huntarna': [('hunt', False)],
          'huntars': [('hunt', False)],
          'hunten': [('hunt', False)],
          'huntens': [('hunt', False)],
          'hunts-': [('hunt', False)],
          'huri': [('huri', False)],
          'huri-': [('huri', False)],
          'huriens': [('huri', False)],
          'hurier': [('huri', False)],
          'hurierna': [('huri', False)],
          'huriers': [('huri', False)],
          'hurin': [('huri', False)],
          'hurins': [('huri', False)],
          'huris': [('huri', False)],
          'hurr': [('hurra', False)],
          'hurr-': [('hurra', False)],
          'hurre': [('hurra', False)],
          'hurrs': [('hurra', False)],
          'hurrs-': [('hurra', False)],
          'hurt': [('hurt', False)],
          'hurt-': [('hurt', False)],
          'hurts': [('hurts', True)],
          'hurts-': [('hurts', True)],
          'hus': [('hus', True)],
          'husan': [('husa', True)],
          'husans': [('husa', True)],
          'husar': [('husar', True)],
          'husaren': [('husar', True)],
          'husars': [('husar', True)],
          'huskors': [('huskors', True)],
          'huss-': [('husse', True)],
          'hussar': [('husse', True)],
          'hussarna': [('husse', True)],
          'hussarnas': [('husse', True)],
          'hustomten': [('hustomte', True), ('hustomt', True)],
          'hustomtens': [('hustomt', True), ('hustomte', True)],
          'hutar': [('hutare', False)],
          'hutarna': [('hutare', False)],
          'hutarnas': [('hutare', False)],
          'hutt': [('hutt', True)],
          'hutt-': [('hutt', True)],
          'huttar': [('hutt', True)],
          'huttars': [('hutt', True)],
          'hutten': [('hutt', True)],
          'hutts': [('hutt', True)],
          'hutts-': [('hutt', True)],
          'huv': [('huva', True), ('huv', True)],
          'huv-': [('huv', True), ('huva', True)],
          'huve': [('huve', True), ('huva', True)],
          'huven': [('huve', True), ('huv', True)],
          'huvens': [('huve', True), ('huv', True)],
          'huvs': [('huve', True), ('huva', True), ('huv', True)],
          'huvs-': [('huva', True), ('huv', True), ('huve', True)],
          'hvana': [('hvana', False)],
          'hvanas': [('hvana', False)],
          'hvane': [('hvana', False)],
          'hvane-': [('hvana', False)],
          'hvanors': [('hvana', False)],
          'hvårar': [('hvårare', False)],
          'hvårarna': [('hvårare', False)],
          'hvårarnas': [('hvårare', False)],
          'hy': [('hy', False)],
          'hy-': [('hy', False)],
          'hyckel': [('hyckel', True)],
          'hyckel-': [('hyckel', True)],
          'hyckels': [('hyckel', True)],
          'hycklarna': [('hycklare', True)],
          'hycklarnas': [('hycklare', True)],
          'hydd-': [('hydda', False)],
          'hyen': [('hyena', True)],
          'hyen-': [('hyena', True)],
          'hyens': [('hyena', True)],
          'hyer': [('hy', False)],
          'hyerna': [('hy', False)],
          'hyernas': [('hy', False)],
          'hyers': [('hy', False)],
          'hyfs': [('hyf', True), ('hyfs', True)],
          'hyfs-': [('hyf', True), ('hyfs', True)],
          'hyggets': [('hygge', False)],
          'hyggs': [('hygge', False)],
          'hyggs-': [('hygge', False)],
          'hyllan': [('hylla', False)],
          'hyllandet': [('hyllande', True)],
          'hylle': [('hylla', True), ('hylle', True)],
          'hylle-': [('hylle', True), ('hylla', True)],
          'hyllen': [('hylle', True)],
          'hyllens': [('hylle', True)],
          'hylls': [('hylla', True)],
          'hylls-': [('hylla', True)],
          'hyls': [('hylsa', False)],
          'hyls-': [('hylsa', False)],
          'hymen': [('hymen', True)],
          'hymens': [('hymen', True)],
          'hyn': [('hy', False)],
          'hyndan': [('hynda', True)],
          'hyns': [('hy', False)],
          'hype': [('hype', True)],
          'hype-': [('hype', True)],
          'hypen': [('hype', True)],
          'hypens': [('hype', True)],
          'hyperits': [('hyperit', True)],
          'hypet': [('hype', True)],
          'hyr': [('hyra', True)],
          'hyr-': [('hyra', False)],
          'hyrers': [('hyr', False)],
          'hyrs': [('hyra', False)],
          'hyrs-': [('hyra', False)],
          'hys': [('hy', False)],
          'hysteriernas': [('hysteri', False)],
          'hysteriets': [('hysteri', True)],
          'hytt': [('hytta', True), ('hytt', True)],
          'hytt-': [('hytta', True), ('hytt', True)],
          'hytte': [('hytta', True)],
          'hytten': [('hytt', False)],
          'hyttens': [('hytt', False)],
          'hytter': [('hytt', False)],
          'hytters': [('hytt', False)],
          'hytts': [('hytta', True), ('hytt', True)],
          'hytts-': [('hytta', True), ('hytt', True)],
          'hyvlar': [('hyvlare', True), ('hyvel', True)],
          'hyvlarna': [('hyvlare', True), ('hyvel', True)],
          'hyvlarnas': [('hyvlare', True), ('hyvel', True)],
          'häck': [('häck', False)],
          'häck-': [('häck', True)],
          'häckar': [('häck', False)],
          'häckarna': [('häck', False)],
          'häcken': [('häck', False)],
          'häckens': [('häck', False)],
          'häcklarna': [('häcklare', True)],
          'häcks': [('häck', False)],
          'häcks-': [('häck', False)],
          'hädar': [('hädare', True)],
          'hädarna': [('hädare', True)],
          'häft': [('häfta', True)],
          'häft-': [('häfta', True)],
          'häfte': [('häfta', True), ('häfte', True)],
          'häften': [('häfte', True)],
          'häftens': [('häfte', True)],
          'häftet': [('häfte', True)],
          'häftets': [('häfte', False)],
          'häfts': [('häfta', True)],
          'häfts-': [('häfta', True)],
          'hägar': [('hägare', False)],
          'hägg-': [('hägg', True)],
          'häggarna': [('hägg', True)],
          'häggarnas': [('hägg', True)],
          'häggs': [('hägg', True)],
          'hägrarnas': [('häger', False)],
          'häkte': [('häkta', True), ('häkte', True)],
          'häktets': [('häkte', True)],
          'häkts-': [('häkta', True)],
          'hälar': [('hälare', True), ('häl', True)],
          'hälarna': [('hälare', True), ('häl', True)],
          'hälarnas': [('hälare', True), ('häl', True)],
          'hälbens': [('hälben', True)],
          'häll': [('hälla', True), ('häll', True)],
          'häll-': [('hälla', True), ('häll', True)],
          'hällan': [('hälla', False)],
          'hällanden': [('hällande', True)],
          'hällandena': [('hällande', True)],
          'hällandenas': [('hällande', True)],
          'hällandens': [('hällande', True)],
          'hällar': [('häll', False)],
          'hällars': [('häll', False)],
          'hälle': [('hälla', True)],
          'hälle-': [('hälla', True)],
          'hällen': [('häll', False)],
          'hällens': [('häll', True)],
          'hällningar': [('hällning', True)],
          'hällningarna': [('hällning', True)],
          'hällningarnas': [('hällning', True)],
          'hällningars': [('hällning', True)],
          'hällnings': [('hällning', True)],
          'hällnings-': [('hällning', True)],
          'hälls': [('hälla', True), ('häll', True)],
          'hälls-': [('hälla', True), ('häll', True)],
          'häls': [('häl', False)],
          'hälse': [('hälsa', False)],
          'hälse-': [('hälsa', False)],
          'hält': [('hälta', True)],
          'hämmar': [('hämmare', False)],
          'hämmarna': [('hämmare', False)],
          'hämmarnas': [('hämmare', False)],
          'hän': [('hä', False)],
          'häna': [('hä', False)],
          'hänas': [('hä', False)],
          'häng': [('häng', False)],
          'häng-': [('häng', True)],
          'hängar': [('hängare', False)],
          'hängarna': [('hängare', False)],
          'hängarnas': [('hängare', False)],
          'hängen': [('hänge', True)],
          'hängens': [('hänge', True)],
          'hänget': [('hänge', True), ('häng', True)],
          'hängets': [('häng', True), ('hänge', True)],
          'hängs': [('hänge', True), ('häng', True)],
          'hängs-': [('hänge', True), ('häng', True)],
          'hängslen': [('hängsle', True)],
          'hängslens': [('hängsle', True)],
          'hängslets': [('hängsle', True)],
          'häns': [('hä', False)],
          'härar': [('här', False)],
          'härarna': [('här', False)],
          'härd': [('härd', False)],
          'härd-': [('härd', False)],
          'härdar': [('härd', False)],
          'härdarna': [('härd', False)],
          'härdars': [('härd', False)],
          'härden': [('härd', False)],
          'härdens': [('härd', False)],
          'härds': [('härd', False)],
          'härds-': [('härd', False)],
          'härk': [('härk', True)],
          'härk-': [('härk', True)],
          'härkar': [('härk', True)],
          'härkarna': [('härk', True)],
          'härken': [('härk', True)],
          'härkens': [('härk', True)],
          'härks': [('härk', True)],
          'härks-': [('härk', True)],
          'härmar': [('härmare', False)],
          'härmarna': [('härmare', False)],
          'härmarnas': [('härmare', False)],
          'härskare': [('härskara', True), ('härskare', True)],
          'härve': [('härva', False)],
          'häs': [('hä', False)],
          'häs-': [('hä', False)],
          'häsarna': [('häs', False)],
          'häsarnas': [('häs', False)],
          'häst': [('häst', True)],
          'häst-': [('häst', False)],
          'hästar': [('häst', True)],
          'hästarna': [('häst', False)],
          'hästarnas': [('häst', True)],
          'hästars': [('häst', True)],
          'hästen': [('häst', False)],
          'hästens': [('häst', False)],
          'hät': [('hä', False)],
          'häts': [('hä', False)],
          'hätt': [('hätta', True)],
          'hätt-': [('hätta', False)],
          'hätte': [('hätta', False)],
          'hätte-': [('hätta', False)],
          'hätts': [('hätta', False)],
          'hätts-': [('hätta', False)],
          'hävd': [('hävd', True), ('hävder', True)],
          'hävd-': [('hävder', True), ('hävd', True)],
          'hävder': [('hävder', True), ('hävd', True)],
          'hävderna': [('hävd', True), ('hävder', True)],
          'hävdernas': [('hävder', True), ('hävd', True)],
          'hävders': [('hävder', True), ('hävd', True)],
          'hävds': [('hävder', True), ('hävd', True)],
          'hävds-': [('hävd', True), ('hävder', True)],
          'hävlar': [('hävel', True)],
          'hävor': [('hävor', False)],
          'hävorna': [('hävor', False)],
          'hävornas': [('hävor', False)],
          'hävors': [('hävor', False)],
          'häx': [('häxa', True)],
          'häx-': [('häxa', True)],
          'hå': [('hå', False)],
          'hå-': [('hå', False)],
          'håar': [('hå', False)],
          'håarna': [('hå', False)],
          'håg': [('håg', True)],
          'håg-': [('håg', True)],
          'hågs': [('håg', True)],
          'hågs-': [('håg', True)],
          'håken': [('håken', True)],
          'håkens': [('håken', True)],
          'håker': [('håk', False)],
          'håkers': [('håk', False)],
          'hål': [('hål', True), ('håla', True)],
          'hål-': [('håla', True), ('hål', True)],
          'hålen': [('hål', False)],
          'håligheter': [('hålighet', False)],
          'håligheterna': [('hålighet', True)],
          'håligheternas': [('hålighet', False)],
          'håligheters': [('hålighet', True)],
          'hålighets-': [('hålighet', True)],
          'håll': [('håll', False)],
          'håll-': [('håll', False)],
          'hållan': [('hållan', False)],
          'hållanden': [('hållande', False)],
          'hållandena': [('hållande', False)],
          'hållandenas': [('hållande', False)],
          'hållandens': [('hållande', False)],
          'hållans': [('hållan', False)],
          'hållarna': [('hållare', False)],
          'hållen': [('håll', False)],
          'hålls': [('håll', False)],
          'hålls-': [('håll', False)],
          'håls': [('håla', True), ('hål', True)],
          'håls-': [('hål', True), ('håla', True)],
          'hån': [('hån', True)],
          'håns': [('hån', True)],
          'hår': [('hår', False)],
          'hår-': [('hår', False)],
          'hårdvar': [('hårdvara', True)],
          'hårdvar-': [('hårdvara', True)],
          'hårmodet': [('hårmode', True)],
          'hårmodets': [('hårmode', True)],
          'hårs': [('hår', False)],
          'hårs-': [('hår', False)],
          'hås': [('hå', False)],
          'hås-': [('hå', False)],
          'håt': [('hå', False)],
          'håts': [('hå', False)],
          'håv-': [('håv', True)],
          'håvarnas': [('håv', True)],
          'håvor': [('håvor', True)],
          'håvorna': [('håvor', True)],
          'håvors': [('håvor', True)],
          'héerna': [('hé', False)],
          'héernas': [('hé', False)],
          'höften': [('höft', True)],
          'höftens': [('höft', True)],
          'högskolan': [('högskola', True)],
          'högskolans': [('högskola', True)],
          'höjar': [('höjare', False)],
          'höjarna': [('höjare', False)],
          'höjarnas': [('höjare', False)],
          'hökar': [('hökare', True), ('hök', True)],
          'hökarna': [('hökare', True), ('hök', True)],
          'hökarnas': [('hökare', True), ('hök', True)],
          'höken': [('hök', False)],
          'hökens': [('hök', False)],
          'hölje': [('hölja', True), ('hölje', True)],
          'höljs': [('hölje', False)],
          'hön': [('höna', False)],
          'hön-': [('höna', True)],
          'höns': [('höna', True), ('höns', True)],
          'höns-': [('höna', True), ('höns', True)],
          'hörarna': [('hörare', True)],
          'hörarnas': [('hörare', False)],
          'hören': [('hör', False)],
          'hörens': [('hör', False)],
          'höret': [('hör', False)],
          'hörets': [('hör', False)],
          'hörigheter': [('hörighet', False)],
          'hörigheterna': [('hörighet', False)],
          'hörigheternas': [('hörighet', False)],
          'hörigheters': [('hörighet', False)],
          'hörighets-': [('hörighet', False)],
          'hörn': [('hörna', True), ('hörn', True)],
          'hörn-': [('hörna', True), ('hörn', True)],
          'hörna': [('hörna', False)],
          'hörnas': [('hörna', False)],
          'hörne': [('hörna', False)],
          'hörnen': [('hörn', False)],
          'hörnens': [('hörn', False)],
          'hörnet': [('hörn', False)],
          'hörns': [('hörna', True), ('hörn', True)],
          'hörns-': [('hörna', True), ('hörn', True)],
          'hös': [('hö', True)],
          'hös-': [('hös', False)],
          'höst-': [('höst', True)],
          'höstar': [('höst', False)],
          'höstarna': [('höst', False)],
          'hösten': [('höst', True)],
          'höt': [('hö', False)],
          'höts': [('hö', False)],
          'i': [('i', True)],
          'i-': [('i', True)],
          'ia': [('ia', False)],
          'ia-': [('ia', False)],
          'iacin': [('iacin', False)],
          'iadammen': [('iadamm', False)],
          'iadammens': [('iadamm', False)],
          'iaff': [('iaff', False)],
          'iaff-': [('iaff', False)],
          'iaffen': [('iaff', False)],
          'iaffer': [('iaff', False)],
          'iaffers': [('iaff', False)],
          'iaffs': [('iaff', False)],
          'iaffs-': [('iaff', False)],
          'iage': [('iage', False)],
          'iage-': [('iage', False)],
          'iagen': [('iage', False)],
          'iagens': [('iage', False)],
          'iagerna': [('iage', False)],
          'iagernas': [('iage', False)],
          'iagers': [('iage', False)],
          'iaget': [('iage', False)],
          'iak-': [('iak', False)],
          'iakons': [('iakon', False)],
          'iaks': [('iak', False)],
          'iaks-': [('iak', False)],
          'ialandet': [('ialand', False)],
          'ialar': [('ialare', False)],
          'ialar-': [('ialare', False)],
          'ialarens': [('ialare', False)],
          'ialarna': [('ialare', False)],
          'ialarnas': [('ialare', False)],
          'iallandets': [('ialland', False)],
          'iallor': [('iallo', False)],
          'iallorna': [('iallo', False)],
          'iallornas': [('iallo', False)],
          'iallors': [('iallo', False)],
          'iallön': [('iallön', False)],
          'ials': [('ial', False)],
          'ials-': [('ial', False)],
          'ialvar': [('ialvara', False)],
          'ialvar-': [('ialvara', False)],
          'iam': [('iam', False)],
          'iames': [('iames', False)],
          'iameter': [('iameter', False)],
          'iameters': [('iameter', False)],
          'iamin': [('iamin', False)],
          'iamins': [('iamin', False)],
          'ian': [('ia', False)],
          'iana': [('ium', False)],
          'ianan': [('iana', False)],
          'ianans': [('iana', False)],
          'ianar': [('ianare', False)],
          'ianarna': [('ianare', False)],
          'ianas': [('ia', False)],
          'iandens': [('iande', False)],
          'iandets': [('iande', False)],
          'iands': [('iand', False)],
          'iands-': [('iand', False)],
          'ianens': [('ian', False)],
          'ianets': [('ian', False)],
          'ianister': [('ianist', False)],
          'ianisters': [('ianist', False)],
          'ianits': [('ianit', False)],
          'ianol': [('ianola', False)],
          'ianol-': [('ianola', False)],
          'ianols': [('ianola', False)],
          'ianon': [('iano', False)],
          'ianons': [('iano', False)],
          'ianor': [('iana', False)],
          'ianordnar': [('ianorden', False)],
          'ianordnarna': [('ianorden', False)],
          'ianordnarnas': [('ianorden', False)],
          'ianorna': [('iana', False)],
          'ianornas': [('iana', False)],
          'ianors': [('iana', False)],
          'ianos': [('iano', False)],
          'ianot': [('iano', False)],
          'ianots': [('iano', False)],
          'ians': [('ia', False)],
          'ians-': [('iana', False)],
          'iansen': [('ians', False)],
          'iansens': [('ians', False)],
          'ianser': [('ians', False)],
          'ianserna': [('ians', False)],
          'iansernas': [('ians', False)],
          'iansers': [('ians', False)],
          'iansk': [('ianska', False)],
          'iansk-': [('ianska', False)],
          'iant': [('iant', False)],
          'ianten': [('iant', False)],
          'iantens': [('iant', False)],
          'ianter': [('iant', False)],
          'ianterna': [('iant', False)],
          'ianternas': [('iant', False)],
          'ianters': [('iant', False)],
          'iantin': [('ianti', False)],
          'iantins': [('ianti', False)],
          'iantis': [('ianti', False)],
          'iants-': [('iant', False)],
          'iar': [('iare', False)],
          'iar-': [('iare', False)],
          'iaran': [('iara', False)],
          'iard': [('iard', False)],
          'iard-': [('iard', False)],
          'iarden': [('iard', False)],
          'iardens': [('iard', False)],
          'iarder': [('iard', False)],
          'iarderna': [('iard', False)],
          'iardernas': [('iard', False)],
          'iarders': [('iard', False)],
          'iards': [('iard', False)],
          'iare': [('iare', False)],
          'iaren': [('iar', False)],
          'iarens': [('iare', False)],
          'iares': [('iare', False)],
          'iarie': [('iarium', False)],
          'iarie-': [('iarium', False)],
          'iarier': [('iarium', False)],
          'iarierna': [('iarium', False)],
          'iariernas': [('iarium', False)],
          'iariers': [('iarium', False)],
          'iarna': [('iare', False)],
          'iarnas': [('iare', False)],
          'iars': [('ie', False)],
          'iars-': [('iara', False)],
          'ias': [('ia', False)],
          'ias-': [('ia', False)],
          'iasegrar': [('iasegrare', False)],
          'iasegrarna': [('iasegrare', False)],
          'iasm': [('iasm', False)],
          'iasm-': [('iasm', False)],
          'iasmer': [('iasm', False)],
          'iasmerna': [('iasm', False)],
          'iasmernas': [('iasmer', False)],
          'iasmers': [('iasm', False)],
          'iast-': [('iast', False)],
          'iastas': [('iastas', False)],
          'iasten': [('iast', False)],
          'iaster': [('iast', False)],
          'iasterna': [('iast', False)],
          'iasternas': [('iast', False)],
          'iasters': [('iast', False)],
          'iat': [('ia', False)],
          'iateket': [('iatek', False)],
          'iatekets': [('iatek', False)],
          'iater': [('iater', False)],
          'iaters': [('iater', False)],
          'iatiker': [('iatiker', False)],
          'iatikerna': [('iatiker', False)],
          'iatikernas': [('iatiker', False)],
          'iatikers': [('iatiker', False)],
          'iation': [('iation', False)],
          'iationen': [('iation', False)],
          'iations': [('iation', False)],
          'iativets': [('iativ', False)],
          'iator': [('iator', False)],
          'iators': [('iator', False)],
          'iatos': [('iato', False)],
          'iatrin': [('iatri', False)],
          'iats': [('ia', False)],
          'iats-': [('iat', False)],
          'iauns': [('iau', False)],
          'ib': [('ib', False)],
          'ibagar': [('ibag', False)],
          'ibagarna': [('ibag', False)],
          'ibagarnas': [('ibag', False)],
          'ibal': [('ibal', False)],
          'ibal-': [('ibal', False)],
          'ibalen': [('ibal', False)],
          'ibalens': [('ibal', False)],
          'ibals': [('ibal', False)],
          'iban': [('iban', False)],
          'iban-': [('iban', False)],
          'ibanan': [('ibana', False)],
          'ibanans': [('ibana', False)],
          'ibandets': [('iband', False)],
          'ibane': [('ibana', False)],
          'ibane-': [('ibana', False)],
          'ibaner': [('iban', False)],
          'ibaners': [('iban', False)],
          'ibanes': [('ibanes', False)],
          'ibans': [('iban', False)],
          'ibars': [('ibar', False)],
          'ibb-': [('ibb', False)],
          'ibbar': [('ibb', False)],
          'ibbarna': [('ibb', False)],
          'ibbarnas': [('ib', False)],
          'ibbars': [('ibbe', False)],
          'ibbe': [('ibbe', False)],
          'ibbe-': [('ibbe', False)],
          'ibbel': [('ibbla', False)],
          'ibbel-': [('ibbla', False)],
          'ibben': [('ibb', False)],
          'ibbens': [('ib', False)],
          'ibble': [('ibbla', False)],
          'ibel': [('ibel', False)],
          'ibel-': [('ibel', False)],
          'ibels': [('ibel', False)],
          'ibels-': [('ibel', False)],
          'iben': [('ib', False)],
          'ibens': [('ib', False)],
          'iber': [('ib', False)],
          'iberier': [('iberier', False)],
          'iberierna': [('iberier', False)],
          'iberna': [('ib', False)],
          'ibernas': [('ib', False)],
          'ibers': [('ib', False)],
          'ibet': [('ibet', False)],
          'ibet-': [('ibet', False)],
          'ibetan': [('ibetan', False)],
          'ibetans': [('ibetan', False)],
          'ibeten': [('ibet', False)],
          'ibetens': [('ibet', False)],
          'ibets': [('ibet', False)],
          'ibets-': [('ibet', False)],
          'ibevis': [('ibevis', False)],
          'ibevis-': [('ibevis', False)],
          'ibie': [('ibie', False)],
          'ibie-': [('ibie', False)],
          'ibien': [('ibie', False)],
          'ibiens': [('ibie', False)],
          'ibier': [('ibie', False)],
          'ibierna': [('ibier', False)],
          'ibiernas': [('ibie', False)],
          'ibiers': [('ibie', False)],
          'ibies': [('ibie', False)],
          'ibies-': [('ibie', False)],
          'ibil': [('ibil', False)],
          'ibilar': [('ibil', False)],
          'ibilars': [('ibil', False)],
          'ibils': [('ibil', False)],
          'ibils-': [('ibil', False)],
          'ibin': [('ibi', False)],
          'ibis': [('ibis', True)],
          'ibis-': [('ibis', True)],
          'ibit': [('ibi', False)],
          'ibits': [('ibit', False)],
          'ibits-': [('ibit', False)],
          'iblar': [('ibel', False)],
          'iblarna': [('ibel', False)],
          'iblarnas': [('ibel', False)],
          'iblernas': [('ibel', False)],
          'iblessens': [('iblesse', False)],
          'iblom': [('iblomma', False)],
          'iblom-': [('iblomma', False)],
          'ibloms': [('iblomma', False)],
          'ibloms-': [('iblomma', False)],
          'ibomb': [('ibomb', False)],
          'ibomber': [('ibomb', False)],
          'ibomberna': [('ibomb', False)],
          'ibombernas': [('ibomb', False)],
          'ibombers': [('ibomb', False)],
          'ibombs': [('ibomb', False)],
          'ibombs-': [('ibomb', False)],
          'ibond': [('ibonde', False)],
          'ibonds': [('ibonde', False)],
          'ibos': [('ibos', False)],
          'ibos-': [('ibos', False)],
          'ibosen': [('ibos', False)],
          'ibosens': [('ibos', False)],
          'ibrer': [('iber', False)],
          'ibrerna': [('iber', False)],
          'ibrernas': [('iber', False)],
          'ibrill': [('ibrill', False)],
          'ibrill-': [('ibrill', False)],
          'ibrills': [('ibrill', False)],
          'ibrills-': [('ibrill', False)],
          'ibrin': [('ibrin', False)],
          'ibrins': [('ibri', False)],
          'ibrion': [('ibrion', False)],
          'ibrions': [('ibrion', False)],
          'ibroms': [('ibrom', False)],
          'ibs': [('ib', False)],
          'ibs-': [('ib', False)],
          'ibul': [('ibul', False)],
          'ibul-': [('ibul', False)],
          'ibulens': [('ibul', False)],
          'ibuls': [('ibul', False)],
          'ibuls-': [('ibul', False)],
          'ibun': [('ibun', False)],
          'ibuns': [('ibun', False)],
          'ibus': [('ibus', False)],
          'ibus-': [('ibus', False)],
          'ibusar': [('ibus', False)],
          'ibusarna': [('ibus', False)],
          'ibusarnas': [('ibus', False)],
          'ibusars': [('ibus', False)],
          'ibusen': [('ibus', False)],
          'ibusens': [('ibus', False)],
          'ibut': [('ibut', False)],
          'ibuts': [('ibut', False)],
          'ibyer': [('ibyer', False)],
          'ibyernas': [('ibyer', False)],
          'ibyers': [('ibyer', False)],
          'ibygget': [('ibygge', False)],
          'ibyx': [('ibyxa', False)],
          'ibyx-': [('ibyxa', False)],
          'ibön': [('iböna', False)],
          'ibön-': [('iböna', False)],
          'iböne': [('iböna', False)],
          'iböne-': [('iböna', False)],
          'iböns': [('iböna', False)],
          'iböns-': [('iböna', False)],
          'icador': [('icador', False)],
          'ican': [('ican', False)],
          'icans': [('ican', False)],
          'icar': [('ice', False)],
          'icarnas': [('ice', False)],
          'icell': [('iceller', False)],
          'icell-': [('iceller', False)],
          'iceller': [('iceller', False)],
          'icellerna': [('iceller', False)],
          'icellernas': [('iceller', False)],
          'icellers': [('iceller', False)],
          'icells': [('iceller', False)],
          'icells-': [('iceller', False)],
          'icen': [('ic', False)],
          'icens': [('icens', False)],
          'icentrer': [('icentrum', False)],
          'icentrerna': [('icentrum', False)],
          'icentrernas': [('icentrum', False)],
          'icentrers': [('icentrum', False)],
          'icentret': [('icentrum', False)],
          'icentrets': [('icentrum', False)],
          'icer': [('ice', False)],
          'icern': [('icer', False)],
          'icerns': [('icer', False)],
          'icers': [('icer', False)],
          'ichar': [('ich', False)],
          'icharnas': [('ich', False)],
          'ichars': [('ich', False)],
          'iche': [('iche', False)],
          'iche-': [('iche', False)],
          'ichen': [('iche', False)],
          'ichens': [('iche', False)],
          'icher': [('iche', False)],
          'icherna': [('iche', False)],
          'ichernas': [('iche', False)],
          'ichers': [('iche', False)],
          'ichet': [('iche', False)],
          'icheten': [('ichet', False)],
          'ichetens': [('ichet', False)],
          'ichets': [('ichet', False)],
          'ichman': [('ichman', False)],
          'ici': [('ikus', False)],
          'icider': [('icid', False)],
          'iciders': [('icid', False)],
          'icie': [('icier', False)],
          'icie-': [('icier', False)],
          'icier': [('icium', False)],
          'icierna': [('icy', False)],
          'iciernas': [('icier', False)],
          'iciers': [('icium', False)],
          'icina': [('ici', False)],
          'icinas': [('ici', False)],
          'icins': [('icin', False)],
          'icis': [('ici', False)],
          'icitet': [('icitet', False)],
          'icitets': [('icitet', False)],
          'ick': [('ick', False)],
          'ick-': [('icka', False)],
          'ickan': [('icka', False)],
          'ickans': [('icka', False)],
          'ickar': [('ickare', False)],
          'ickarna': [('ickare', False)],
          'ickarnas': [('ick', False)],
          'ickat': [('icka', False)],
          'ickats': [('ickat', False)],
          'ickels': [('ickels', False)],
          'ickelsen': [('ickels', False)],
          'ickelsens': [('ickelse', False)],
          'icker': [('icker', False)],
          'ickers': [('icker', False)],
          'ickersens': [('ickers', False)],
          'ickets': [('ick', False)],
          'ickfiskarna': [('ickfiskare', False)],
          'icklanden': [('icklande', False)],
          'icklandens': [('icklande', False)],
          'icklandet': [('icklande', False)],
          'icklarna': [('ickel', False)],
          'ickles': [('ickles', False)],
          'icks': [('icka', False)],
          'icks-': [('icka', False)],
          'icksanden': [('icksande', False)],
          'icksandens': [('icksande', False)],
          'icksen': [('icks', False)],
          'icksens': [('ick', False)],
          'icoten': [('icot', False)],
          'icotens': [('icot', False)],
          'icoter': [('icot', False)],
          'icoterna': [('icot', False)],
          'icoternas': [('icot', False)],
          'icoters': [('icot', False)],
          'icots': [('icot', False)],
          'ics': [('ics', False)],
          'ics-': [('ice', False)],
          'icsen': [('ics', False)],
          'icsens': [('ics', False)],
          'id': [('id', False)],
          'id-': [('id', False)],
          'ida': [('idum', False)],
          'idagar': [('idag', False)],
          'idagarna': [('idag', False)],
          'idagarnas': [('idag', False)],
          'idagars': [('idag', False)],
          'idagen': [('idag', False)],
          'idagens': [('idag', False)],
          'idags': [('idag', False)],
          'idags-': [('idag', False)],
          'idan': [('ida', False)],
          'idanden': [('idande', False)],
          'idandens': [('idande', False)],
          'idans': [('ida', False)],
          'idans-': [('idan', False)],
          'idar': [('id', False)],
          'idaren': [('idare', False)],
          'idarna': [('id', True)],
          'idarnas': [('id', True)],
          'idars': [('id', False)],
          'idas': [('idum', False)],
          'idas-': [('idas', False)],
          'idat': [('idat', False)],
          'idaten': [('idat', False)],
          'idatens': [('idat', False)],
          'idater': [('idat', False)],
          'idaterna': [('idat', False)],
          'idaternas': [('idat', False)],
          'idaters': [('idat', False)],
          'idator': [('idator', False)],
          'idators': [('idator', False)],
          'idats': [('idat', False)],
          'idback': [('idbacke', False)],
          'idbackens': [('idbacke', False)],
          'idben': [('idbena', False)],
          'idbens-': [('idbena', False)],
          'idd-': [('idd', False)],
          'iddan': [('iddag', False)],
          'iddar': [('iddare', False)],
          'iddarna': [('iddare', False)],
          'idder': [('idder', False)],
          'idders': [('idder', False)],
          'ide': [('ide', True)],
          'ide-': [('ida', False)],
          'iden': [('ide', True), ('id', True)],
          'idender': [('idender', False)],
          'idenderna': [('idend', False)],
          'idendernas': [('idend', False)],
          'idenders': [('idender', False)],
          'idens': [('ide', True), ('id', True)],
          'idens-': [('iden', False)],
          'ider': [('id', False)],
          'ider-': [('ider', False)],
          'iderit': [('iderit', False)],
          'iderits': [('ideri', False)],
          'idern': [('ider', False)],
          'iderna': [('id', False)],
          'idernas': [('id', False)],
          'iderns': [('ider', False)],
          'iders': [('id', False)],
          'iders-': [('ider', False)],
          'ides': [('ide', True)],
          'ides-': [('ida', False)],
          'idet': [('ide', True), ('id', True)],
          'idets': [('id', True), ('ide', True)],
          'idextrin': [('idextri', False)],
          'idextrins': [('idextri', False)],
          'idge': [('idge', False)],
          'idge-': [('idge', False)],
          'idian': [('idian', False)],
          'idians': [('idian', False)],
          'idiet': [('idium', False)],
          'idiets': [('idium', False)],
          'idiken': [('idik', False)],
          'idikens': [('idik', False)],
          'idin': [('idi', False)],
          'iding': [('iding', False)],
          'iding-': [('iding', False)],
          'idingar': [('iding', False)],
          'idingarna': [('iding', False)],
          'idingarnas': [('iding', False)],
          'idingars': [('iding', False)],
          'idingen': [('iding', False)],
          'idingens': [('iding', False)],
          'idings': [('iding', False)],
          'idings-': [('iding', False)],
          'idins': [('idin', False)],
          'idis-': [('idis', False)],
          'idiv': [('idiv', False)],
          'idiv-': [('idiv', False)],
          'idivs': [('idiv', False)],
          'idjan': [('idja', False)],
          'idjans': [('idja', False)],
          'idkar': [('idkare', False)],
          'idkarens': [('idkare', True)],
          'idmån': [('idmåne', False)],
          'idmånen': [('idmåne', False)],
          'idmånens': [('idmåne', False)],
          'idmåns-': [('idmåne', False)],
          'idna': [('id', False)],
          'idnas': [('id', False)],
          'ido': [('ido', True)],
          'ido-': [('ido', False)],
          'idolen': [('idol', False)],
          'idolens': [('idol', False)],
          'idoler': [('idol', True)],
          'idolerna': [('idol', False)],
          'idolernas': [('idol', False)],
          'idolers': [('idol', False)],
          'idon': [('idon', False)],
          'idon-': [('idon', False)],
          'idona': [('ido', False)],
          'idonas': [('ido', False)],
          'idons': [('idon', False)],
          'idor': [('ida', False)],
          'idorer': [('idor', False)],
          'idorerna': [('idor', False)],
          'idorernas': [('idor', False)],
          'idorers': [('idor', False)],
          'idorna': [('ida', False)],
          'idornas': [('ida', False)],
          'idors': [('ida', False)],
          'idos': [('ido', True)],
          'idos-': [('idos', False)],
          'idosen': [('idos', False)],
          'idot': [('ido', False)],
          'idots': [('idot', False)],
          'idrar': [('ider', False)],
          'idrarna': [('ider', False)],
          'idrars': [('ider', False)],
          'idrisk': [('idrisk', False)],
          'idrisk-': [('idrisk', False)],
          'idrottar': [('idrottare', False)],
          'idrottarna': [('idrottare', False)],
          'idrottarnas': [('idrottare', True)],
          'ids': [('ide', True), ('id', True)],
          'ids-': [('ide', True), ('id', True)],
          'idsdagar': [('idsdag', False)],
          'idsdagarna': [('idsdag', False)],
          'idsdagarnas': [('idsdag', False)],
          'idsdagars': [('idsdag', False)],
          'idsdags': [('idsdag', False)],
          'idsdags-': [('idsdag', False)],
          'idsdomar': [('idsdom', False)],
          'idsdomarna': [('idsdom', False)],
          'idsdomarnas': [('idsdom', False)],
          'idslandets': [('idsland', False)],
          'idstalet': [('idstal', False)],
          'idt': [('id', False)],
          'iduas': [('iduum', False)],
          'idue': [('iduum', False)],
          'iduerna': [('iduum', False)],
          'idus-': [('idus', False)],
          'idvägens': [('idväg', False)],
          'idån': [('idå', False)],
          'idåns': [('idå', False)],
          'idås': [('idå', False)],
          'ie': [('ie', False)],
          'ie-': [('ie', False)],
          'ieborgens': [('ieborgen', False)],
          'iecen': [('iece', False)],
          'iecens': [('iece', False)],
          'iecer': [('iece', False)],
          'iecerna': [('iece', False)],
          'iecernas': [('iece', False)],
          'iecers': [('iece', False)],
          'ieer': [('ieera', False)],
          'ieers': [('ieera', False)],
          'iegas': [('iegas', False)],
          'iegas-': [('iegas', False)],
          'iehandlarna': [('iehandel', False)],
          'iekurs-': [('iekurs', False)],
          'ielar': [('iel', False)],
          'ielarna': [('iel', False)],
          'ielarnas': [('iel', False)],
          'iellen': [('ielle', False)],
          'iellens': [('ielle', False)],
          'ieller': [('ielle', False)],
          'iellerna': [('iello', False)],
          'iellernas': [('ielle', False)],
          'iellers': [('iello', False)],
          'iem': [('iem', False)],
          'iem-': [('iem', False)],
          'iemens': [('iemens', False)],
          'iems': [('iem', False)],
          'iems-': [('iem', False)],
          'ien': [('i', True)],
          'iena': [('ie', False)],
          'ienans': [('iena', False)],
          'ienar': [('ienare', False)],
          'ienar-': [('ienare', False)],
          'ienarens': [('ienare', False)],
          'ienarna': [('ienare', False)],
          'ienarnas': [('ienare', False)],
          'ienas': [('ium', False)],
          'ienden': [('iend', False)],
          'iendens': [('iend', False)],
          'iender': [('iende', False)],
          'ienderna': [('iend', False)],
          'iendernas': [('iende', False)],
          'ienders': [('iende', False)],
          'iendets': [('iende', False)],
          'ienet': [('ien', False)],
          'ienets': [('ien', False)],
          'ienn': [('ienn', False)],
          'ienn-': [('ienn', False)],
          'iennen': [('ienn', False)],
          'iennens': [('ienn', False)],
          'ienner': [('ienn', False)],
          'iennerna': [('ienn', False)],
          'iennernas': [('ienn', False)],
          'ienners': [('ienn', False)],
          'ienns': [('ienn', False)],
          'ienns-': [('ienn', False)],
          'iens': [('i', True)],
          'iens-': [('iens', False)],
          'iensarnas': [('iensare', False)],
          'iensen': [('iens', False)],
          'iensens': [('iens', False)],
          'ienser': [('iens', False)],
          'ienserna': [('iens', False)],
          'iensernas': [('iens', False)],
          'iensers': [('iens', False)],
          'iensk': [('ienska', False)],
          'iensk-': [('ienska', False)],
          'ient': [('ient', False)],
          'ientaler': [('iental', False)],
          'ientalers': [('iental', False)],
          'ienten': [('ient', False)],
          'ientens': [('ient', False)],
          'ienter': [('ient', False)],
          'ienterna': [('ient', False)],
          'ienternas': [('ient', False)],
          'ienters': [('ient', False)],
          'ients-': [('ient', False)],
          'ier-': [('ier', False)],
          'ieri': [('ieri', False)],
          'ieri-': [('ieri', False)],
          'ierier': [('ieri', False)],
          'ierierna': [('ieri', False)],
          'ieriers': [('ieri', False)],
          'ieriet': [('ieri', False)],
          'ieris': [('ieri', False)],
          'ieris-': [('ieri', False)],
          'ierit': [('ieri', False)],
          'iernas': [('ier', False)],
          'iers': [('ier', False)],
          'iers-': [('ier', False)],
          'iersläkten': [('iersläkt', False)],
          'iersläktens': [('iersläkt', False)],
          'iersläkts': [('iersläkt', False)],
          'ies': [('ie', False)],
          'ies-': [('ie', False)],
          'iesarna': [('y', False)],
          'iesarnas': [('y', False)],
          'iesen': [('ie', False)],
          'iesens': [('ie', False)],
          'iesets': [('ies', False)],
          'ieskiftet': [('ieskifte', False)],
          'iest': [('iesta', False)],
          'iest-': [('iesta', False)],
          'iestans': [('iesta', False)],
          'iestors': [('iesta', False)],
          'iestudier': [('iestudie', False)],
          'iet': [('i', True)],
          'ieten': [('iet', False)],
          'ietens': [('iet', False)],
          'ieter': [('iet', False)],
          'ieters': [('iet', False)],
          'ietet': [('ietet', False)],
          'ietets': [('ietet', False)],
          'ietiden': [('ietiden', False)],
          'ietidens': [('ietid', False)],
          'iets': [('i', False)],
          'iett': [('iett', False)],
          'iett-': [('iett', False)],
          'ietten': [('iett', False)],
          'ietter': [('iett', False)],
          'ietterna': [('iett', False)],
          'ietternas': [('iett', False)],
          'ietters': [('iett', False)],
          'ietts': [('iett', False)],
          'ietts-': [('iett', False)],
          'iever': [('iever', False)],
          'ieverket': [('ieverk', False)],
          'ievers': [('iever', False)],
          'if': [('if', False)],
          'if-': [('if', False)],
          'ifat': [('ifat', False)],
          'ifats': [('ifat', False)],
          'ifen': [('if', False)],
          'ifens': [('if', False)],
          'ifer': [('if', False)],
          'iferien': [('iferi', False)],
          'iferiens': [('iferi', False)],
          'iferier': [('iferi', False)],
          'iferierna': [('iferi', False)],
          'iferiernas': [('iferi', False)],
          'iferiers': [('iferi', False)],
          'iferna': [('if', False)],
          'ifernas': [('if', False)],
          'ifers': [('if', False)],
          'iffarnas': [('iff', False)],
          'iffe': [('iffe', False)],
          'iffe-': [('iffe', False)],
          'iffens': [('iff', False)],
          'iffer': [('iffer', False)],
          'iffer-': [('iffra', False)],
          'iffers': [('iffer', False)],
          'ifflar': [('ifflare', False)],
          'ifflarna': [('ifflare', False)],
          'ifflarnas': [('ifflare', False)],
          'iffle-': [('iffle', False)],
          'ifikans': [('ifikans', False)],
          'ifikat': [('ifikat', False)],
          'ifikats': [('ifikat', False)],
          'iflage': [('iflage', False)],
          'iflage-': [('iflage', False)],
          'iflott': [('iflotta', False)],
          'iflott-': [('iflotta', False)],
          'iflotte': [('iflotta', False)],
          'iflotts': [('iflotta', False)],
          'iflotts-': [('iflotta', False)],
          'iflödet': [('iflöde', False)],
          'ifolien': [('ifolium', False)],
          'ifoliens': [('ifolium', False)],
          'ifolier': [('ifolium', False)],
          'ifolierna': [('ifolium', False)],
          'ifoliernas': [('ifolium', False)],
          'ifoliers': [('ifolium', False)],
          'ifonis': [('ifoni', False)],
          'ifordringar': [('ifordring', False)],
          'ifräsar': [('ifräsare', False)],
          'ifräsarna': [('ifräsare', False)],
          'ifräsarnas': [('ifräsare', False)],
          'ifs': [('if', False)],
          'ift': [('ifta', False)],
          'ift-': [('ifta', False)],
          'iftan': [('ifta', False)],
          'iftans': [('iftan', False)],
          'iftar': [('iftare', False)],
          'iftarna': [('iftare', False)],
          'ifte': [('ifte', False)],
          'ifte-': [('ifte', False)],
          'iftets': [('ift', False)],
          'ifts-': [('ifta', False)],
          'ifug': [('ifug', False)],
          'ifug-': [('ifug', False)],
          'ifugs': [('ifug', False)],
          'ifugs-': [('ifug', False)],
          'ifyrar': [('ifyr', False)],
          'iförlust-': [('iförlust', False)],
          'iförluster': [('iförlust', False)],
          'iförlusternas': [('iförlust', False)],
          'iförsäkringar': [('iförsäkring', False)],
          'iförsäkringarna': [('iförsäkring', False)],
          'iförsäkringarnas': [('iförsäkring', False)],
          'iförsäkringars': [('iförsäkring', False)],
          'ig': [('ig', False)],
          'ig-': [('ig', False)],
          'igal': [('igal', False)],
          'igal-': [('igal', False)],
          'igalen': [('igal', False)],
          'igalens': [('igal', False)],
          'igals': [('igal', False)],
          'igals-': [('igal', False)],
          'igan': [('igan', False)],
          'igandens': [('igande', False)],
          'igans': [('iga', False)],
          'igansen': [('igan', False)],
          'igansens': [('igan', False)],
          'igar': [('ig', False)],
          'igaren': [('igare', False)],
          'igarna': [('ig', False)],
          'igarnas': [('ig', False)],
          'igars': [('ig', False)],
          'igas': [('iga', False)],
          'igat': [('igat', False)],
          'igat-': [('igat', False)],
          'igate': [('igata', False)],
          'igate-': [('igata', False)],
          'igaten': [('igat', False)],
          'igatens': [('igat', False)],
          'igater': [('igat', False)],
          'igaterna': [('igat', False)],
          'igaternas': [('igat', False)],
          'igaters': [('igat', False)],
          'igator': [('igator', False)],
          'igators': [('igator', False)],
          'igats': [('igata', False)],
          'igdags': [('igdag', False)],
          'ige': [('iga', False)],
          'ige-': [('iga', False)],
          'igel': [('igel', True)],
          'igen': [('ig', False)],
          'igen-': [('igen', False)],
          'igens': [('ig', False)],
          'igens-': [('igen', False)],
          'igentian': [('igentia', False)],
          'igentians': [('igentia', False)],
          'igerna': [('ig', False)],
          'igernas': [('iger', False)],
          'igers': [('ig', False)],
          'igers-': [('iger', False)],
          'iget': [('ig', False)],
          'igets': [('ige', False)],
          'iggar': [('igg', False)],
          'iggarna': [('iggare', False)],
          'iggarnas': [('iggare', False)],
          'iggdags': [('iggdags', False)],
          'igge': [('igge', False)],
          'igger': [('igger', False)],
          'iggers': [('igger', False)],
          'iggets': [('igg', False)],
          'iggvar': [('iggvar', False)],
          'ighets': [('ighet', False)],
          'ighter': [('ight', False)],
          'ighterna': [('ight', False)],
          'ighternas': [('ight', False)],
          'ighters': [('ight', False)],
          'igiftet': [('igift', False)],
          'igiftets': [('igift', False)],
          'igifts': [('igift', False)],
          'igifts-': [('igift', False)],
          'igillen': [('igill', False)],
          'igillens': [('igill', False)],
          'igillet': [('igill', False)],
          'igillets': [('igill', False)],
          'igills': [('igill', False)],
          'igills-': [('igill', False)],
          'igin': [('igin', False)],
          'igin-': [('igin', False)],
          'iginen': [('igin', False)],
          'igins': [('igin', False)],
          'iglar': [('igel', False)],
          'iglarna': [('igel', False)],
          'iglarnas': [('igel', False)],
          'iglars': [('igel', False)],
          'iglor': [('iglo', False)],
          'iglorna': [('iglo', True)],
          'iglornas': [('iglo', True)],
          'iglos': [('iglo', False)],
          'igman': [('igma', False)],
          'igmans': [('igma', False)],
          'igmat': [('igma', False)],
          'igmats': [('igmat', False)],
          'igms-': [('igm', False)],
          'igner': [('igner', False)],
          'ignerna': [('igner', False)],
          'ignernas': [('igner', False)],
          'igners': [('igner', False)],
          'ignet': [('ignet', False)],
          'ignorans': [('ignorans', True)],
          'igon': [('igo', False)],
          'igonen': [('igon', False)],
          'igonens': [('igon', False)],
          'igons': [('igo', False)],
          'igor': [('iga', False)],
          'igorna': [('iga', False)],
          'igornas': [('iga', False)],
          'igors': [('iga', False)],
          'igotterier': [('igotteri', False)],
          'igotterierna': [('igotteri', False)],
          'igotteriernas': [('igotteri', False)],
          'igotteriers': [('igotteri', False)],
          'igrafen': [('igraf', False)],
          'igrafens': [('igraf', False)],
          'igrar': [('iger', False)],
          'igrarna': [('iger', False)],
          'igrars': [('iger', False)],
          'igräns': [('igrän', False)],
          'igs': [('ig', False)],
          'igs-': [('ig', False)],
          'igsens': [('ig', False)],
          'igsfångens': [('igsfånge', False)],
          'iguernas': [('igue', False)],
          'iguers': [('igue', False)],
          'iguster': [('iguster', False)],
          'igusters': [('iguster', False)],
          'igvar': [('igvara', False)],
          'igvård': [('igvård', False)],
          'igvårds': [('igvård', False)],
          'igvårds-': [('igvård', False)],
          'ihandlar': [('ihandlare', False)],
          'ihandlarna': [('ihandlare', False)],
          'ihandlarnas': [('ihandlare', False)],
          'iheter': [('ihet', False)],
          'iheterna': [('ihet', False)],
          'iheternas': [('ihet', False)],
          'iheters': [('ihet', False)],
          'ihets': [('ihet', False)],
          'ihets-': [('ihet', False)],
          'iholts': [('iholt', False)],
          'ihuve': [('ihuva', False)],
          'ihylle': [('ihylla', False)],
          'ihylle-': [('ihylla', False)],
          'ihåg': [('ihåg', False)],
          'ihåg-': [('ihåg', False)],
          'ihågs': [('ihåg', False)],
          'iinkomster': [('iinkomst', False)],
          'iinkomsternas': [('iinkomst', False)],
          'iinkomsters': [('iinkomst', False)],
          'iit': [('iit', False)],
          'iiternas': [('iit', False)],
          'iits': [('iit', False)],
          'ik': [('ik', False)],
          'ik-': [('ik', False)],
          'ika': [('ikon', False)],
          'ikad': [('ikad', False)],
          'ikad-': [('ikad', False)],
          'ikadans': [('ikada', False)],
          'ikadens': [('ikad', False)],
          'ikader': [('ikad', False)],
          'ikaders': [('ikad', False)],
          'ikador': [('ikada', False)],
          'ikadorna': [('ikada', False)],
          'ikadornas': [('ikada', False)],
          'ikadors': [('ikada', False)],
          'ikads': [('ikad', False)],
          'ikads-': [('ikad', False)],
          'ikal': [('ikal', False)],
          'ikal-': [('ikal', False)],
          'ikalie': [('ikalier', False)],
          'ikalie-': [('ikalie', False)],
          'ikalier': [('ikalie', False)],
          'ikalierna': [('ikalie', False)],
          'ikaliernas': [('ikalier', False)],
          'ikaliers': [('ikalier', False)],
          'ikals': [('ikal', False)],
          'ikals-': [('ikal', False)],
          'ikan': [('ikan', False)],
          'ikan-': [('ikan', False)],
          'ikanden': [('ikande', False)],
          'ikans': [('ikan', False)],
          'ikans-': [('ikan', False)],
          'ikapp': [('ikapp', False)],
          'ikapp-': [('ikapp', False)],
          'ikappen': [('ikapp', False)],
          'ikappens': [('ikapp', False)],
          'ikapps': [('ikapp', False)],
          'ikapps-': [('ikapp', False)],
          'ikar': [('ik', False)],
          'ikar-': [('ikare', False)],
          'ikare': [('ikare', False)],
          'ikaren': [('ikare', False)],
          'ikarens': [('ikare', False)],
          'ikaries': [('ikarie', False)],
          'ikaries-': [('ikarie', False)],
          'ikarna': [('ik', False)],
          'ikarnas': [('ikare', False)],
          'ikars': [('ik', False)],
          'ikas': [('ikon', False)],
          'ikas-': [('ika', False)],
          'ikat': [('ikat', False)],
          'ikaten': [('ikat', False)],
          'ikatens': [('ikat', False)],
          'ikatet': [('ikat', False)],
          'ikatets': [('ikat', False)],
          'ikativ': [('ikativ', False)],
          'ikativ-': [('ikativ', False)],
          'ikativs': [('ikativ', False)],
          'ikativs-': [('ikativ', False)],
          'ikats': [('ikat', False)],
          'ikats-': [('ikat', False)],
          'ike': [('ika', False)],
          'ike-': [('ika', False)],
          'ikeens': [('ike', False)],
          'ikel': [('ikel', False)],
          'ikel-': [('ikel', False)],
          'ikels': [('ikel', False)],
          'ikels-': [('ikel', False)],
          'ikelsen': [('ikelse', False)],
          'ikelsens': [('ikelse', False)],
          'iken': [('ik', False)],
          'ikens': [('ik', False)],
          'iker': [('ik', False)],
          'ikerna': [('ik', False)],
          'ikernas': [('ik', False)],
          'ikers': [('ik', False)],
          'iket': [('iket', False)],
          'ikets': [('ike', False)],
          'ikier': [('ikier', False)],
          'ikierna': [('ikier', False)],
          'ikiernas': [('ikier', False)],
          'ikiers': [('ikier', False)],
          'ikin': [('iki', False)],
          'ikinin': [('ikini', False)],
          'ikinins': [('ikini', False)],
          'ikinos': [('ikinos', False)],
          'ikins': [('ikin', False)],
          'ikis': [('iki', False)],
          'ikis-': [('iki', False)],
          'ikisarna': [('iki', False)],
          'ikisarnas': [('iki', False)],
          'ikklubb': [('ikklubba', False)],
          'ikklubbs': [('ikklubba', False)],
          'ikklubbs-': [('ikklubba', False)],
          'ikkrans': [('ikkran', False)],
          'iklamp': [('iklampa', False)],
          'iklamp-': [('iklampa', False)],
          'iklamps': [('iklampa', False)],
          'iklamps-': [('iklampa', False)],
          'iklar': [('ikel', False)],
          'iklarna': [('ikel', False)],
          'iklarnas': [('ikel', False)],
          'iklars': [('ikel', False)],
          'ikliniker': [('iklinik', False)],
          'iklinikerna': [('iklinik', False)],
          'iklinikernas': [('iklinik', False)],
          'iklinikers': [('iklinik', False)],
          'iklins': [('iklin', False)],
          'ikningar': [('ikning', False)],
          'ikningarna': [('ikning', False)],
          'ikningarnas': [('ikning', False)],
          'ikningars': [('ikning', False)],
          'iknings': [('ikning', False)],
          'iknings-': [('ikning', False)],
          'iknippe': [('iknippe', False)],
          'iknippe-': [('iknippe', False)],
          'ikolor': [('ikolor', False)],
          'ikolors': [('ikolor', False)],
          'ikon': [('ikon', True)],
          'ikon-': [('ikon', False)],
          'ikona': [('iko', False)],
          'ikonas': [('iko', False)],
          'ikons': [('ikon', False)],
          'ikons-': [('ikon', False)],
          'ikonst-': [('ikonst', False)],
          'ikonsternas': [('ikonst', False)],
          'ikonsters': [('ikonst', False)],
          'ikopter': [('ikopter', False)],
          'ikopters': [('ikopter', False)],
          'ikor': [('ika', False)],
          'ikord': [('ikord', False)],
          'ikord-': [('ikord', False)],
          'ikords': [('ikord', False)],
          'ikords-': [('ikord', False)],
          'ikorna': [('ika', False)],
          'ikornas': [('ika', False)],
          'ikors': [('ika', False)],
          'ikos': [('ikos', False)],
          'ikos-': [('ikos', False)],
          'ikot': [('iko', False)],
          'ikots': [('iko', False)],
          'ikrafts-': [('ikraft', False)],
          'ikrets-': [('ikrets', False)],
          'ikrokar': [('ikrokar', False)],
          'ikrokarna': [('ikrokar', False)],
          'ikrokarnas': [('ikrokar', False)],
          'ikrokars': [('ikrokar', False)],
          'ikroks': [('ikrokar', False)],
          'ikroks-': [('ikrokar', False)],
          'ikron-': [('ikron', False)],
          'ikronan': [('ikrona', False)],
          'ikronans': [('ikrona', False)],
          'ikrons-': [('ikron', False)],
          'ikror': [('ikro', False)],
          'ikrorna': [('ikro', False)],
          'ikrornas': [('ikro', False)],
          'ikrors': [('ikro', False)],
          'ikros': [('ikro', False)],
          'ikros-': [('ikro', False)],
          'iks': [('ik', False)],
          'iks-': [('ik', False)],
          'iksens': [('iks', False)],
          'iksläng-': [('ikslänga', False)],
          'ikslängs': [('ikslänga', False)],
          'iksportarnas': [('iksport', False)],
          'ikställen': [('ikställe', False)],
          'ikställens': [('ikställe', False)],
          'ikstället': [('ikställe', False)],
          'ikställets': [('ikställe', False)],
          'iksvägen': [('iksväg', False)],
          'iktank': [('iktank', False)],
          'iktank-': [('iktank', False)],
          'iktanks': [('iktank', False)],
          'iktanks-': [('iktank', False)],
          'iktar': [('iktare', False)],
          'iktar-': [('iktare', False)],
          'iktarens': [('iktare', False)],
          'iktarna': [('iktare', False)],
          'iktarnas': [('ikt', False)],
          'ikte': [('ikte', False)],
          'ikte-': [('ikte', False)],
          'iktet': [('ikte', False)],
          'iktets': [('ikt', False)],
          'iktin': [('iktin', False)],
          'iktioner': [('iktion', False)],
          'iktionerna': [('iktion', False)],
          'iktionernas': [('iktion', False)],
          'iktioners': [('iktion', False)],
          'iktions': [('iktion', False)],
          'iktor': [('iktor', False)],
          'iktorierna': [('iktorium', False)],
          'iktoriernas': [('iktorium', False)],
          'iktoriers': [('iktorium', False)],
          'iktoriet': [('iktorium', False)],
          'iktoriets': [('iktorium', False)],
          'iktoris-': [('iktoria', False)],
          'iktors': [('iktor', False)],
          'ikultar': [('ikultare', False)],
          'ikultarna': [('ikultare', False)],
          'ikultarnas': [('ikultare', False)],
          'ikungar': [('ikunge', False)],
          'ikungarna': [('ikunge', False)],
          'ikungarnas': [('ikunge', False)],
          'ikungars': [('ikunge', False)],
          'ikungen': [('ikunge', False)],
          'ikungens': [('ikunge', False)],
          'ikurs': [('ikurs', False)],
          'ikurs-': [('ikurs', False)],
          'ikus': [('ikus', False)],
          'ikus-': [('ikus', False)],
          'ikusar': [('ikus', False)],
          'ikusarna': [('ikus', False)],
          'ikusarnas': [('ikus', False)],
          'ikusars': [('ikus', False)],
          'ikusen': [('ikus', False)],
          'ikusens': [('ikus', False)],
          'ikut': [('iku', False)],
          'ikuts': [('iku', False)],
          'ikvarie': [('ikvarie', False)],
          'ikvarie-': [('ikvarie', False)],
          'ikvarierna': [('ikvarie', False)],
          'ikvariers': [('ikvarie', False)],
          'ikvidan': [('ikvida', False)],
          'ikvidans': [('ikvida', False)],
          'ikyl': [('ikyl', False)],
          'ikyl-': [('ikyl', False)],
          'ikäll': [('ikälla', False)],
          'ikäll-': [('ikälla', False)],
          'ikår': [('ikår', False)],
          'ikåren': [('ikår', False)],
          'ikårens': [('ikår', False)],
          'ikårs': [('ikår', False)],
          'ikårs-': [('ikår', False)],
          'ikås': [('ikå', False)],
          'ikör': [('ikör', False)],
          'ikör-': [('ikör', False)],
          'ikörs': [('ikör', False)],
          'ikörs-': [('ikör', False)],
          'il': [('il', False)],
          'il-': [('il', False)],
          'ilag': [('ilag', False)],
          'ilagans': [('ilaga', False)],
          'ilagarna': [('ilag', False)],
          'ilage': [('ilaga', False)],
          'ilage-': [('ilaga', False)],
          'ilagen': [('ilag', False)],
          'ilaget': [('ilage', False)],
          'ilagets': [('ilage', False)],
          'ilagor': [('ilaga', False)],
          'ilagorna': [('ilaga', False)],
          'ilagornas': [('ilaga', False)],
          'ilagors': [('ilaga', False)],
          'ilags': [('ilag', False)],
          'ilags-': [('ilag', False)],
          'ilamp-': [('ilampa', False)],
          'ilamps': [('ilampa', False)],
          'ilamps-': [('ilampa', False)],
          'ilan': [('ila', False)],
          'ilanden': [('ilande', False)],
          'ilandena': [('ilande', False)],
          'ilandenas': [('ilande', False)],
          'ilandens': [('ilande', False)],
          'ilandet': [('ilande', False)],
          'ilandets': [('ilande', True)],
          'ilans': [('ila', False)],
          'ilans-': [('ilans', False)],
          'ilar': [('il', False)],
          'ilar-': [('ilar', False)],
          'ilaren': [('ilare', False)],
          'ilarens': [('ilar', False)],
          'ilarer': [('ilar', False)],
          'ilarerna': [('ilar', False)],
          'ilarernas': [('ilar', False)],
          'ilarers': [('ilar', False)],
          'ilarna': [('il', False)],
          'ilarnas': [('il', False)],
          'ilars': [('il', False)],
          'ilars-': [('ilar', False)],
          'ilaster': [('ilaster', False)],
          'ilasters': [('ilaster', False)],
          'ilat': [('ilat', False)],
          'ilat-': [('ilat', False)],
          'ilaten': [('ilat', False)],
          'ilatens': [('ilat', False)],
          'ilats': [('ilat', False)],
          'ilats-': [('ilat', False)],
          'ilbefordran': [('ilbefordran', True), ('ilbefodran', True)],
          'ilben': [('ilben', False)],
          'ild': [('ilde', False)],
          'ild-': [('ilde', False)],
          'ildanden': [('ildand', False)],
          'ildandens': [('ildand', False)],
          'ildar': [('ilde', False)],
          'ildarna': [('ilde', False)],
          'ildarnas': [('ildare', False)],
          'ildars': [('ilde', False)],
          'ilde': [('ilde', False)],
          'ilden': [('ilde', False)],
          'ildens': [('ilde', False)],
          'ildon': [('ildo', False)],
          'ildos': [('ildo', False)],
          'ildos-': [('ildo', False)],
          'ildrar': [('ildrare', False)],
          'ildrarna': [('ildrare', False)],
          'ilds': [('ilde', False)],
          'ilds-': [('ilde', False)],
          'ildside': [('ildsida', False)],
          'ildsten': [('ildsten', False)],
          'ildstens': [('ildsten', False)],
          'ildstormar': [('ildstormare', False)],
          'ile': [('ila', False)],
          'ile-': [('ila', False)],
          'ileer': [('ileum', False)],
          'ileerna': [('ileum', False)],
          'ileernas': [('ileum', False)],
          'ileers': [('ile', False)],
          'ilegie': [('ilegium', False)],
          'ilegie-': [('ilegium', False)],
          'ilegier': [('ilegium', False)],
          'ilegierna': [('ilegium', False)],
          'ilegiers': [('ilegium', False)],
          'ilen': [('il', False)],
          'ilen-': [('ilen', False)],
          'ilena': [('ilena', False)],
          'ilenas': [('ilena', False)],
          'ilens': [('il', False)],
          'iler': [('il', False)],
          'iler-': [('iler', False)],
          'ilerna': [('il', False)],
          'ilernas': [('il', False)],
          'ilers': [('il', False)],
          'ilers-': [('iler', False)],
          'ilet': [('il', False)],
          'ileten': [('ilet', False)],
          'iletens': [('ilet', False)],
          'ilets': [('il', False)],
          'ilets-': [('ilet', False)],
          'iletten': [('ilette', False)],
          'ilettens': [('ilett', False)],
          'ili': [('ilia', False)],
          'ili-': [('ilia', False)],
          'ilian': [('ilia', False)],
          'ilias': [('ilia', False)],
          'ilibriernas': [('ilibrium', False)],
          'ilie': [('ilier', False)],
          'ilien': [('ili', False)],
          'iliens': [('ili', False)],
          'ilier': [('ilier', False)],
          'ilierna': [('ilie', False)],
          'iliers': [('ilier', False)],
          'iliet': [('ilium', False)],
          'ilighets': [('ilighet', False)],
          'ilin': [('ili', False)],
          'ilin-': [('ilin', False)],
          'ilinen': [('ilin', False)],
          'ilinens': [('ilin', False)],
          'ilins': [('ili', False)],
          'ilis-': [('ilia', False)],
          'ilisen': [('ilis', False)],
          'ilisens': [('ilis', False)],
          'ilist': [('ilist', False)],
          'ilist-': [('ilist', False)],
          'ilister': [('ilister', False)],
          'ilisters': [('ilister', False)],
          'ilistiker': [('ilistiker', False)],
          'ilistikerna': [('ilistiker', False)],
          'ilistikernas': [('ilistiker', False)],
          'ilistikers': [('ilistiker', False)],
          'iliternas': [('iliter', False)],
          'ilitet': [('ilitet', False)],
          'ilitets': [('ilitet', False)],
          'ilivs': [('iliv', False)],
          'ilivs-': [('iliv', False)],
          'iljans': [('ilja', False)],
          'ilje': [('ilj', False)],
          'ilje-': [('ilj', False)],
          'iljen': [('ilje', False)],
          'iljens': [('ilje', False)],
          'iljs': [('ilje', False)],
          'ilkarnas': [('ilk', False)],
          'ilke': [('ilke', False)],
          'ilke-': [('ilke', False)],
          'ilken': [('ilke', False)],
          'ilkens': [('ilke', False)],
          'ilket': [('ilke', False)],
          'ilks': [('ilke', False)],
          'ilks-': [('ilke', False)],
          'ilkurs-': [('ilkurs', False)],
          'ill': [('illa', False)],
          'ill-': [('illa', False)],
          'illagens': [('illag', False)],
          'illan': [('illan', False)],
          'illandets': [('illande', False)],
          'illans': [('illa', False)],
          'illar': [('illare', False)],
          'illar-': [('illare', False)],
          'illarna': [('ill', False)],
          'illarnas': [('ill', False)],
          'illars': [('ille', False)],
          'ille': [('ille', False)],
          'ille-': [('ille', False)],
          'illen': [('ille', False)],
          'illena': [('ille', False)],
          'illenas': [('ille', False)],
          'illens': [('ill', False)],
          'iller': [('iller', False)],
          'iller-': [('iller', True)],
          'illerna': [('iller', False)],
          'illernas': [('iller', False)],
          'illers': [('iller', False)],
          'illet': [('ille', False)],
          'illetar': [('illetare', False)],
          'illetarna': [('illetare', False)],
          'illets': [('ille', False)],
          'illettens': [('illette', False)],
          'illins-': [('illin', False)],
          'illots': [('illots', False)],
          'illrar': [('iller', True)],
          'illrarna': [('iller', False)],
          'illrarnas': [('iller', False)],
          'illrars': [('iller', True)],
          'ills': [('illa', False)],
          'ills-': [('illa', False)],
          'illtets': [('illte', False)],
          'illändar': [('illände', False)],
          'illändarna': [('illände', False)],
          'illås': [('illås', False)],
          'illås-': [('illås', False)],
          'ilmar': [('ilmare', False)],
          'ilmarens': [('ilmare', False)],
          'ilmarna': [('ilmare', False)],
          'ilms': [('ilm', False)],
          'iln': [('il', False)],
          'ilningar': [('ilning', False)],
          'ilningarna': [('ilning', False)],
          'ilningarnas': [('ilning', False)],
          'ilningars': [('ilning', False)],
          'ilnings': [('ilning', False)],
          'ilnings-': [('ilning', False)],
          'ilns': [('il', False)],
          'ilo': [('ila', False)],
          'ilo-': [('ilo', False)],
          'ilog': [('ilog', False)],
          'ilog-': [('ilog', False)],
          'ilogen': [('ilog', False)],
          'ilogens': [('ilog', False)],
          'iloger': [('ilog', False)],
          'ilogerna': [('ilog', False)],
          'ilogernas': [('ilog', False)],
          'ilogers': [('ilog', False)],
          'ilogiernas': [('ilogi', False)],
          'ilogs': [('ilog', False)],
          'ilonen': [('ilon', False)],
          'ilonens': [('ilon', False)],
          'ilops': [('ilop', False)],
          'ilops-': [('ilop', False)],
          'ilor': [('ila', False)],
          'ilorna': [('ila', False)],
          'ilornas': [('ila', False)],
          'ilors': [('ila', False)],
          'ilot': [('ilo', False)],
          'ilots': [('ilot', False)],
          'ilots-': [('ilot', False)],
          'ilott': [('ilott', False)],
          'ilott-': [('ilott', False)],
          'ilottens': [('ilott', False)],
          'ilotts': [('ilott', False)],
          'ilotts-': [('ilott', False)],
          'ilov': [('ilov', False)],
          'ilov-': [('ilov', False)],
          'iloven': [('ilov', False)],
          'ilovens': [('ilov', False)],
          'ilovs': [('ilov', False)],
          'ilovs-': [('ilov', False)],
          'ilrar': [('iler', False)],
          'ilrarna': [('iler', False)],
          'ilrars': [('iler', False)],
          'ilrems': [('ilrem', False)],
          'ilrems-': [('ilrem', False)],
          'ils': [('il', False)],
          'ils-': [('il', False)],
          'ilsarna': [('il', False)],
          'ilsdomar': [('ilsdom', False)],
          'ilsdomarna': [('ilsdom', False)],
          'ilsdomarnas': [('ilsdom', False)],
          'ilsen': [('il', False)],
          'ilsens': [('il', False)],
          'ilt': [('ilt', False)],
          'iltan': [('ilta', False)],
          'iltans': [('ilta', False)],
          'iltarnas': [('ilt', False)],
          'ilter': [('ilter', False)],
          'ilterna': [('ilter', False)],
          'ilternas': [('ilter', False)],
          'ilters': [('ilter', False)],
          'iltets': [('ilt', False)],
          'iltorna': [('ilta', False)],
          'ilträden': [('ilträd', False)],
          'ilträdens': [('ilträd', False)],
          'ilträdet': [('ilträd', False)],
          'ilut': [('ilut', False)],
          'ilut-': [('ilut', False)],
          'iluten': [('ilut', False)],
          'iluts': [('ilut', False)],
          'iluts-': [('ilut', False)],
          'ilver': [('ilver', False)],
          'ilverna': [('ilver', False)],
          'ilvernas': [('ilver', False)],
          'ilvers': [('ilver', False)],
          'ilvägen': [('ilväg', False)],
          'ilvägens': [('ilväg', False)],
          'ilyx': [('ilyxa', False)],
          'ilyx-': [('ilyxa', False)],
          'iländar': [('iländare', False)],
          'iländarna': [('iländare', False)],
          'iländer': [('iland', False)],
          'iländerna': [('iland', False)],
          'iländernas': [('iland', False)],
          'iländers': [('iland', False)],
          'ilåns-': [('ilån', False)],
          'ilön': [('ilön', False)],
          'im': [('im', False)],
          'im-': [('im', False)],
          'ima': [('imum', False)],
          'imaliernas': [('imalier', False)],
          'imaliers': [('imalier', False)],
          'iman': [('ima', False)],
          'imana': [('imum', False)],
          'imanas': [('imum', False)],
          'imanden': [('imande', False)],
          'imandens': [('imand', False)],
          'imannens': [('iman', False)],
          'imas': [('imum', False)],
          'imas-': [('imas', False)],
          'imasen': [('imas', False)],
          'imaser': [('imas', False)],
          'imasers': [('imas', False)],
          'imat': [('imat', False)],
          'imatanas': [('imatum', False)],
          'imaten': [('imat', False)],
          'imatens': [('imat', False)],
          'imaterien': [('imateria', False)],
          'imateriens': [('imateria', False)],
          'imatet': [('imat', False)],
          'imatets': [('imat', False)],
          'imats': [('imat', False)],
          'imb': [('imba', False)],
          'imb-': [('imba', False)],
          'imbon': [('imbo', False)],
          'imbons': [('imbo', False)],
          'imbor': [('imbo', False)],
          'imborna': [('imbo', False)],
          'imbornas': [('imbo', False)],
          'imbors': [('imba', False)],
          'imborst': [('imborste', False)],
          'imbos': [('imbo', False)],
          'imbosen': [('imbo', False)],
          'imbosens': [('imbo', False)],
          'imbrers': [('imbrer', False)],
          'imbs': [('imba', False)],
          'imbs-': [('imba', False)],
          'imbus': [('imbus', False)],
          'imediers': [('imedium', False)],
          'imen': [('im', False)],
          'imens': [('im', False)],
          'imens-': [('imen', False)],
          'imentets': [('iment', False)],
          'iments': [('iment', False)],
          'imerna': [('im', False)],
          'imernas': [('im', False)],
          'imersen': [('imer', False)],
          'imersens': [('imer', False)],
          'imes': [('ime', False)],
          'imet': [('imum', False)],
          'imets': [('imum', False)],
          'imfen': [('imfena', False)],
          'imfens': [('imfena', False)],
          'imicklarna': [('imickel', False)],
          'imil': [('imil', False)],
          'imil-': [('imil', False)],
          'imile': [('imile', False)],
          'imile-': [('imile', False)],
          'imilet': [('imil', False)],
          'imilets': [('imil', False)],
          'imilis': [('imili', False)],
          'imilis-': [('imili', False)],
          'imils': [('imil', False)],
          'imils-': [('imil', False)],
          'imin': [('imi', False)],
          'imina': [('imen', False)],
          'iminas': [('imen', False)],
          'iminister': [('iminister', False)],
          'imins': [('imi', False)],
          'imister': [('imist', False)],
          'imisters': [('imist', False)],
          'imit': [('imit', False)],
          'imit-': [('imit', False)],
          'imits-': [('imit', False)],
          'imixer': [('imix', False)],
          'imixerna': [('imix', False)],
          'imixernas': [('imix', False)],
          'imixers': [('imix', False)],
          'iml': [('imla', False)],
          'iml-': [('imla', False)],
          'imlandets': [('imlande', False)],
          'imlarnas': [('immel', False)],
          'imman': [('imma', False)],
          'immar': [('imme', False)],
          'immarens': [('immare', False)],
          'immarnas': [('immare', False)],
          'imme': [('imme', False)],
          'imme-': [('imme', False)],
          'immen': [('im', False)],
          'immens': [('im', False)],
          'immer': [('immer', False)],
          'immerna': [('im', False)],
          'immernas': [('immer', False)],
          'immersen': [('immer', False)],
          'immersens': [('immer', False)],
          'immet': [('im', False)],
          'immets': [('im', False)],
          'imo': [('imo', False)],
          'imojs': [('imojs', False)],
          'imojs-': [('imojs', False)],
          'imon': [('imon', False)],
          'imoner': [('imon', False)],
          'imonerna': [('imon', False)],
          'imonernas': [('imon', False)],
          'imoners': [('imon', False)],
          'imonierna': [('imonium', False)],
          'imons': [('imon', False)],
          'imor': [('ima', False)],
          'imorfin': [('imorfi', False)],
          'imorfins': [('imorfi', False)],
          'imorna': [('ima', False)],
          'imornas': [('ima', False)],
          'imors': [('ima', False)],
          'imos': [('imosa', False)],
          'imos-': [('imosa', False)],
          'imot': [('imo', False)],
          'imots': [('imo', False)],
          'imp': [('impa', False)],
          'imp-': [('impa', False)],
          'impan': [('impa', False)],
          'impans': [('impa', False)],
          'imparnas': [('imp', False)],
          'impas': [('impa', False)],
          'imperiernas': [('imperium', True)],
          'imperiers': [('imperium', True)],
          'imperiets': [('imperium', True)],
          'imps': [('impa', False)],
          'imps-': [('impa', False)],
          'imrar': [('immer', False)],
          'imrarna': [('immer', False)],
          'imrarnas': [('immer', False)],
          'imrars': [('immer', False)],
          'imröret': [('imrör', True)],
          'imrörets': [('imrör', True)],
          'ims': [('im', False)],
          'ims-': [('im', False)],
          'imtar': [('imt', False)],
          'imtarna': [('imt', False)],
          'imtarnas': [('imt', False)],
          'imturs': [('imtur', False)],
          'imturs-': [('imturs', False)],
          'imul': [('imula', False)],
          'imul-': [('imula', False)],
          'imulans': [('imula', False)],
          'imule': [('imula', False)],
          'imulor': [('imula', False)],
          'imulors': [('imula', False)],
          'imuls': [('imula', False)],
          'imuls-': [('imula', False)],
          'imums': [('imum', False)],
          'imurar': [('imurare', False)],
          'imurarna': [('imurare', False)],
          'imurarnas': [('imurare', False)],
          'imus': [('imus', False)],
          'imut': [('imut', False)],
          'imut-': [('imut', False)],
          'imuts': [('imut', False)],
          'imuts-': [('imut', False)],
          'imän': [('iman', False)],
          'imäns': [('iman', False)],
          'imärens': [('imär', False)],
          'imärs': [('imär', False)],
          'imån': [('imå', False)],
          'imån-': [('imåne', False)],
          'imåns': [('imåne', False)],
          'imåns-': [('imåne', False)],
          'imås': [('imå', False)],
          'imör': [('imör', False)],
          'imörs': [('imör', False)],
          'in': [('i', True)],
          'in-': [('in', False)],
          'ina': [('i', True)],
          'inader': [('inad', False)],
          'inaderna': [('inad', False)],
          'inadernas': [('inad', False)],
          'inaders': [('inad', False)],
          'inads': [('inad', False)],
          'inads-': [('inad', False)],
          'inagets': [('inage', False)],
          'inal': [('inal', False)],
          'inal-': [('inal', False)],
          'inaldags': [('inaldags', False)],
          'inaldags-': [('inaldags', False)],
          'inalen': [('inal', False)],
          'inalens': [('inal', False)],
          'inaler': [('inal', False)],
          'inalerna': [('inal', False)],
          'inalernas': [('inal', False)],
          'inalers': [('inal', False)],
          'inals-': [('inal', False)],
          'inamn': [('inamn', False)],
          'inamn-': [('inamn', False)],
          'inamnen': [('inamn', False)],
          'inamnens': [('inamn', False)],
          'inamns': [('inamn', False)],
          'inamns-': [('inamn', False)],
          'inanden': [('inande', False)],
          'inandens': [('inand', False)],
          'inans': [('inans', False)],
          'inans-': [('inans', False)],
          'inanser': [('inanser', False)],
          'inanserna': [('inanser', False)],
          'inansernas': [('inanser', False)],
          'inansers': [('inanser', False)],
          'inap': [('inapa', False)],
          'inape': [('inapa', False)],
          'inaps': [('inapa', False)],
          'inaps-': [('inapa', False)],
          'inaren': [('inare', False)],
          'inarie': [('inarium', False)],
          'inarie-': [('inarie', False)],
          'inarier': [('inarium', False)],
          'inarierna': [('inarium', False)],
          'inariernas': [('inarium', False)],
          'inariers': [('inarie', False)],
          'inarnas': [('inare', False)],
          'inars': [('in', False)],
          'inas': [('i', True)],
          'inat': [('inat', False)],
          'inat-': [('inat', False)],
          'inate': [('inata', False)],
          'inate-': [('inata', False)],
          'inaten': [('inat', False)],
          'inatens': [('inat', False)],
          'inater': [('inat', False)],
          'inaterna': [('inat', False)],
          'inaternas': [('inat', False)],
          'inaters': [('inat', False)],
          'inats': [('inat', False)],
          'inattens': [('inatt', False)],
          'inaver': [('inav', False)],
          'inavers': [('inav', False)],
          'inda': [('inda', False)],
          'indans': [('inda', False)],
          'indans-': [('indans', False)],
          'indar': [('indare', False)],
          'indar-': [('indare', False)],
          'indarens': [('indare', False)],
          'indarna': [('indare', False)],
          'indarnas': [('ind', False)],
          'indas': [('inda', False)],
          'indblom': [('indblomma', False)],
          'indblom-': [('indblomma', False)],
          'indbloms': [('indblomma', False)],
          'indelandets': [('indelande', True)],
          'indelar': [('indel', False)],
          'indelarna': [('indel', False)],
          'indelarnas': [('indel', False)],
          'inder': [('inder', False)],
          'inderna': [('inder', False)],
          'indernas': [('inder', False)],
          'inders': [('inder', False)],
          'indets': [('ind', False)],
          'indi': [('indi', False)],
          'indier': [('indier', True)],
          'indis': [('indi', False)],
          'indkåren': [('indkåre', False)],
          'indkårens': [('indkåre', False)],
          'indlandet': [('indlande', False)],
          'indlandets': [('indlande', False)],
          'indolens': [('indolens', True)],
          'indos': [('indos', False)],
          'indrarnas': [('inder', False)],
          'indringarna': [('indring', False)],
          'indrotens': [('indrote', False)],
          'induens': [('indu', False)],
          'induer': [('indu', False)],
          'induernas': [('indu', False)],
          'induers': [('indu', False)],
          'ine': [('ina', False)],
          'ine-': [('ina', False)],
          'inee': [('inee', False)],
          'inee-': [('inee', False)],
          'inen': [('in', False)],
          'inens': [('in', False)],
          'inens-': [('inens', False)],
          'inents': [('inent', False)],
          'inents-': [('inent', False)],
          'iner': [('in', False)],
          'inerier': [('ineri', False)],
          'inerierna': [('ineri', False)],
          'ineriernas': [('ineri', False)],
          'ineriers': [('ineri', False)],
          'inerna': [('in', False)],
          'inernas': [('in', False)],
          'iners': [('in', False)],
          'ines': [('ines', False)],
          'ines-': [('ines', False)],
          'inesarna': [('inesare', False)],
          'inesarnas': [('inesare', False)],
          'inesen': [('ines', False)],
          'inesens': [('ines', False)],
          'inesierna': [('inesi', False)],
          'iness-': [('iness', False)],
          'inet': [('in', False)],
          'influens': [('influens', True)],
          'influens-': [('influens', True)],
          'infordringar': [('infordring', True)],
          'infordringarnas': [('infordring', True)],
          'infordringars': [('infordring', True)],
          'infots': [('info', True)],
          'inga': [('inga', False)],
          'ingan': [('inga', False)],
          'ingans': [('inga', False)],
          'ingar-': [('ingare', False)],
          'ingarens': [('ingare', False)],
          'ingarn': [('ingarn', False)],
          'ingarna': [('inge', False)],
          'ingarns': [('ingarn', False)],
          'ingars': [('inge', False)],
          'ingas': [('inga', False)],
          'inge': [('inge', False)],
          'inge-': [('inge', False)],
          'ingel': [('ingla', False)],
          'ingel-': [('ingla', False)],
          'ingenten': [('ingent', False)],
          'ingentens': [('ingent', False)],
          'inger': [('inger', False)],
          'ingerkroks': [('ingerkrokar', False)],
          'ingerkroks-': [('ingerkrokar', False)],
          'ingers': [('inger', False)],
          'inges': [('inge', False)],
          'inges-': [('inge', False)],
          'ingets': [('ing', False)],
          'inglar': [('inglare', False)],
          'inglarna': [('inglare', False)],
          'inglarnas': [('inglare', False)],
          'inglas': [('inglas', False)],
          'inglott': [('inglott', False)],
          'ingmoder': [('ingmoder', False)],
          'ingmödrarna': [('ingmoder', False)],
          'ingon': [('ingo', False)],
          'ingons': [('ingo', False)],
          'ingor': [('ingo', False)],
          'ingorna': [('ingo', False)],
          'ingornas': [('inga', False)],
          'ingors': [('inga', False)],
          'ingos': [('ingo', False)],
          'ingos-': [('ingo', False)],
          'ingosen': [('ingo', False)],
          'ingosens': [('ingo', False)],
          'ingot': [('ingot', False)],
          'ingots': [('ingot', False)],
          'ingrar': [('ingrare', False)],
          'ingrarna': [('ingrare', False)],
          'ingrarnas': [('inger', False)],
          'ingrävar': [('ingrävare', False)],
          'ingrävarna': [('ingrävare', False)],
          'ingrävarnas': [('ingrävare', False)],
          'ingsbot': [('ingsbot', False)],
          'ingsbots': [('ingsbot', False)],
          'ingscentrer': [('ingscenter', False)],
          'ingscentrerna': [('ingscenter', False)],
          'ingscentrernas': [('ingscenter', False)],
          'ingscentrers': [('ingscentrum', False)],
          'ingscentret': [('ingscentrum', False)],
          'ingscentrets': [('ingscentrum', False)],
          'ingsen': [('ing', False)],
          'ingsfiskar': [('ingsfisk', False)],
          'ingsfiskarna': [('ingsfisk', False)],
          'ingsfång': [('ingsfånge', False)],
          'ingsfång-': [('ingsfång', False)],
          'ingsfången': [('ingsfånge', False)],
          'ingsfångens': [('ingsfång', False)],
          'ingsfångs': [('ingsfång', False)],
          'ingsfångs-': [('ingsfånge', False)],
          'ingskalas': [('ingskalas', False)],
          'ingskasse': [('ingskasse', False)],
          'ingskasse-': [('ingskassa', False)],
          'ingskor': [('ingsko', False)],
          'ingskorna': [('ingsko', False)],
          'ingskornas': [('ingsko', False)],
          'ingskors': [('ingsko', False)],
          'ingskurs': [('ingskurs', False)],
          'ingskurs-': [('ingskurs', False)],
          'ingslandet': [('ingsland', False)],
          'ingslins': [('ingslins', False)],
          'ingslins-': [('ingslins', False)],
          'ingsställen': [('ingsställe', False)],
          'ingsstället': [('ingsställe', False)],
          'ingsställets': [('ingsställe', False)],
          'ingstank': [('ingstank', False)],
          'ingstankar': [('ingstank', False)],
          'ingstens': [('ingst', False)],
          'ingsvärmen': [('ingsvärme', False)],
          'ingsvärmens': [('ingsvärme', False)],
          'ingångar': [('ingång', False)],
          'ingångarna': [('ingång', True)],
          'ingöten': [('ingöte', True), ('ingöt', True)],
          'ingötens': [('ingöte', True), ('ingöt', True)],
          'ingötet': [('ingöte', True), ('ingöt', True)],
          'ingötets': [('ingöte', True), ('ingöt', True)],
          'ingöts': [('ingöte', True), ('ingöt', True)],
          'ingöts-': [('ingöt', True), ('ingöte', True)],
          'ini': [('inia', False)],
          'ini-': [('inia', False)],
          'inie': [('inia', False)],
          'inier': [('inion', False)],
          'inierna': [('ini', False)],
          'iniernas': [('inier', False)],
          'iniers': [('inier', False)],
          'iniet': [('inium', False)],
          'inik': [('inik', False)],
          'inik-': [('inik', False)],
          'inikan': [('inikan', False)],
          'inikans': [('inikan', False)],
          'iniks': [('inik', False)],
          'iniks-': [('inik', False)],
          'inimet': [('inimum', False)],
          'inimets': [('inimum', False)],
          'inin-': [('inin', False)],
          'ininen': [('inin', False)],
          'ininens': [('inin', False)],
          'ininet': [('inin', False)],
          'ininets': [('inin', False)],
          'inins': [('ininum', False)],
          'inior': [('inior', False)],
          'iniors': [('inior', False)],
          'inis': [('inia', False)],
          'inis-': [('ini', False)],
          'inisk': [('iniska', False)],
          'inisk-': [('iniska', False)],
          'inist': [('inist', False)],
          'init': [('init', False)],
          'initet': [('initet', False)],
          'initets': [('initet', False)],
          'inje': [('inje', False)],
          'inje-': [('inje', False)],
          'injen': [('inje', False)],
          'injens': [('inje', False)],
          'injer': [('inje', False)],
          'injerna': [('inje', False)],
          'injernas': [('inje', False)],
          'injers': [('inje', False)],
          'injors': [('inja', False)],
          'ink': [('ink', True)],
          'ink-': [('ink', True)],
          'inkar': [('ink', False)],
          'inkarna': [('ink', False)],
          'inkarnas': [('ink', False)],
          'inkars': [('ink', True)],
          'inkart': [('inkart', False)],
          'inkarts': [('inkart', False)],
          'inkarts-': [('inkart', False)],
          'inker': [('inker', False)],
          'inkerna': [('inker', False)],
          'inkernas': [('inker', False)],
          'inkers': [('inker', False)],
          'inkets': [('ink', False)],
          'inklernas': [('inkler', False)],
          'inklädes': [('inkläder', False)],
          'inkomst': [('inkomst', False)],
          'inkomst-': [('inkomst', True)],
          'inkomster': [('inkomst', True)],
          'inkomsterna': [('inkomst', True)],
          'inkomsternas': [('inkomst', True)],
          'inkomsters': [('inkomst', True)],
          'inkoppor': [('inkoppa', False)],
          'inkopporna': [('inkoppa', False)],
          'inkoppornas': [('inkoppa', False)],
          'inkoppors': [('inkoppa', False)],
          'inks': [('ink', True)],
          'inks-': [('ink', True)],
          'inkter': [('inkt', False)],
          'inkterna': [('inkt', False)],
          'inkternas': [('inkt', False)],
          'inkters': [('inkt', False)],
          'inkungar': [('inkung', False)],
          'inkungarna': [('inkung', False)],
          'inkungarnas': [('inkung', False)],
          'inkungars': [('inkung', False)],
          'inkungen': [('inkung', False)],
          'inkungens': [('inkung', False)],
          'inlag': [('inlaga', True)],
          'inlags': [('inlaga', False)],
          'inlags-': [('inlaga', False)],
          'inlopp': [('inlopp', True)],
          'inlopps': [('inlopp', True)],
          'inlopps-': [('inlopp', True)],
          'inn': [('inn', False)],
          'inn-': [('inna', False)],
          'innan': [('inna', False)],
          'innans': [('inna', False)],
          'innar': [('inne', False)],
          'innarna': [('innare', False)],
          'innarnas': [('inne', False)],
          'inne': [('inne', False)],
          'inne-': [('inne', False)],
          'innen': [('inn', False)],
          'innens': [('inne', False)],
          'inner': [('inner', False)],
          'inners': [('inner', False)],
          'innes': [('inne', False)],
          'innes-': [('inne', False)],
          'innet': [('inne', False)],
          'innets': [('inn', False)],
          'inning': [('inning', False)],
          'inning-': [('inning', False)],
          'inningar': [('inning', False)],
          'inningarna': [('inning', False)],
          'inningarnas': [('inning', False)],
          'inningars': [('inning', False)],
          'innings': [('inning', False)],
          'innings-': [('inning', False)],
          'inns': [('inne', False)],
          'ino': [('ino', False)],
          'ino-': [('ino', False)],
          'inogen': [('inogen', False)],
          'inoll': [('inolle', False)],
          'inoll-': [('inolle', False)],
          'inolle': [('inolle', False)],
          'inolls': [('inolle', False)],
          'inolls-': [('inolle', False)],
          'inomen': [('inom', False)],
          'inomens': [('inom', False)],
          'inon': [('ino', False)],
          'inon-': [('inon', False)],
          'inona': [('ino', False)],
          'inonas': [('ino', False)],
          'inor': [('ina', False)],
          'inorden': [('inorden', False)],
          'inordens': [('inorden', False)],
          'inordnarna': [('inorden', False)],
          'inorna': [('ina', False)],
          'inornas': [('ina', False)],
          'inors': [('ina', False)],
          'inos-': [('ino', False)],
          'inosarna': [('ino', False)],
          'inosarnas': [('ino', False)],
          'inosen': [('inos', False)],
          'inosens': [('ino', False)],
          'inot': [('ino', False)],
          'inots': [('ino', False)],
          'inputs': [('input', True)],
          'inrar': [('inner', True)],
          'inrarna': [('inner', True)],
          'inrarnas': [('inner', True)],
          'inrars': [('inner', True)],
          'inringar': [('inring', False)],
          'inringars': [('inring', False)],
          'ins': [('i', True)],
          'ins-': [('in', False)],
          'insarnas': [('ins', False)],
          'insats': [('insats', False)],
          'inscher': [('inscher', False)],
          'inschers': [('inscher', False)],
          'insets': [('ins', False)],
          'insider': [('insider', True)],
          'insiders': [('insider', True)],
          'insiktens': [('insikt', True)],
          'insikts': [('insikt', True)],
          'insikts-': [('insikt', True)],
          'inskal': [('inskal', False)],
          'inskals': [('inskal', False)],
          'inskals-': [('inskal', False)],
          'inskans': [('inska', False)],
          'insko-': [('insko', False)],
          'inskor': [('inska', False)],
          'inskorna': [('inska', False)],
          'inskornas': [('inska', False)],
          'inskors': [('inska', False)],
          'inskåp': [('inskåp', False)],
          'inskåps': [('inskåp', False)],
          'inskåps-': [('inskåp', False)],
          'insorden': [('insord', False)],
          'insordens': [('insord', False)],
          'insort': [('insort', False)],
          'insorter': [('insort', False)],
          'insorterna': [('insort', False)],
          'insorternas': [('insort', False)],
          'insorters': [('insort', False)],
          'insorts': [('insort', False)],
          'insorts-': [('insort', False)],
          'inst-': [('inst', False)],
          'instans': [('instans', True)],
          'insten': [('inst', False)],
          'instens': [('inst', False)],
          'inster': [('inst', False)],
          'insterna': [('inst', False)],
          'insternas': [('inst', False)],
          'insters': [('inst', False)],
          'institutet': [('institut', True)],
          'instrumentbräde': [('instrumentbräda', True), ('instrumentbräde', True)],
          'insvar': [('insvara', False)],
          'int-': [('int', False)],
          'inta': [('inta', False)],
          'intagets': [('intag', False)],
          'intalanden': [('intalande', True), ('intalan', True)],
          'intalandena': [('intalan', True), ('intalande', True)],
          'intalandenas': [('intalan', True), ('intalande', True)],
          'intalandens': [('intalan', True), ('intalande', True)],
          'intan': [('inta', False)],
          'intar': [('int', False)],
          'intarnas': [('int', False)],
          'intas': [('inta', False)],
          'intern': [('intern', True)],
          'intern-': [('intern', True)],
          'interns': [('intern', True)],
          'interns-': [('intern', True)],
          'intet': [('intet', True)],
          'intierna': [('inti', False)],
          'inton': [('into', False)],
          'intons': [('into', False)],
          'intrarnas': [('inter', False)],
          'intras': [('intras', False)],
          'intringarna': [('intring', False)],
          'intringarnas': [('intring', False)],
          'inträden': [('inträde', True)],
          'inträdens': [('inträde', True)],
          'inträdet': [('inträde', True)],
          'inträdets': [('inträde', False)],
          'ints': [('int', False)],
          'ints-': [('inta', False)],
          'inuas': [('inuum', False)],
          'inuet': [('inuum', False)],
          'inuets': [('inuum', False)],
          'inurin': [('inuri', False)],
          'inus': [('inus', False)],
          'inus-': [('inus', False)],
          'inut': [('inut', False)],
          'inut-': [('inut', False)],
          'inuts': [('inut', False)],
          'inventarie': [('inventarium', True), ('inventarier', True)],
          'inventarie-': [('inventarier', True), ('inventarium', True)],
          'inventarier': [('inventarium', True), ('inventarier', True)],
          'inventarierna': [('inventarier', True), ('inventarium', True)],
          'inventariernas': [('inventarium', True), ('inventarier', True)],
          'inventariers': [('inventarier', True), ('inventarium', True)],
          'inär': [('inär', False)],
          'inär-': [('inär', False)],
          'inärer': [('inär', False)],
          'inärerna': [('inär', False)],
          'inärernas': [('inär', False)],
          'inärers': [('inär', False)],
          'inärs': [('inär', False)],
          'inärs-': [('inär', False)],
          'inåret': [('inår', False)],
          'inårets': [('inår', False)],
          'inör': [('inör', False)],
          'inör-': [('inör', False)],
          'inören': [('inör', False)],
          'inörens': [('inör', False)],
          'inörs': [('inör', False)],
          'inörs-': [('inör', False)],
          'io': [('io', False)],
          'iodar': [('iodare', False)],
          'iodarna': [('iodare', False)],
          'iodarnas': [('iodare', False)],
          'ioden': [('iod', False)],
          'iodens': [('iod', False)],
          'ioders': [('iod', False)],
          'iodlarnas': [('iodlare', False)],
          'iods': [('iod', False)],
          'iods-': [('iod', False)],
          'iofficerare': [('iofficer', False)],
          'iofficerares': [('iofficer', False)],
          'iofficerarna': [('iofficer', False)],
          'iofficerarnas': [('iofficer', False)],
          'iogrammet': [('iogram', False)],
          'iogrammets': [('iogram', False)],
          'iojan': [('ioja', False)],
          'iojans': [('ioja', False)],
          'iokan': [('ioka', False)],
          'iolarie-': [('iolarie', False)],
          'iolarierna': [('iolarie', False)],
          'ioler': [('iolus', False)],
          'iolerna': [('iolus', False)],
          'iolernas': [('iolus', False)],
          'iolers': [('iolus', False)],
          'ioli': [('ioli', False)],
          'iolis': [('ioli', False)],
          'iologier': [('iologi', False)],
          'iologierna': [('iologi', False)],
          'iologiers': [('iologi', False)],
          'iomans-': [('ioman', False)],
          'iomen': [('iom', False)],
          'iomens': [('iom', False)],
          'iometer': [('iometer', False)],
          'iometers': [('iometer', False)],
          'ioms': [('iom', False)],
          'ioms-': [('iom', False)],
          'ion': [('io', False)],
          'ion-': [('ion', False)],
          'iona': [('io', False)],
          'ionar': [('ion', False)],
          'ionarnas': [('ion', False)],
          'ionars': [('ion', False)],
          'ionas': [('io', False)],
          'iondets': [('ionde', False)],
          'ionomens': [('ionom', False)],
          'ions-': [('ion', False)],
          'ionter': [('iont', False)],
          'ionters': [('iont', False)],
          'ioptris': [('ioptri', False)],
          'iora': [('iora', False)],
          'ioran': [('iora', False)],
          'iorans': [('iora', False)],
          'ioras': [('iora', False)],
          'ioras-': [('iora', False)],
          'iordrar': [('iorder', False)],
          'iorn': [('ior', False)],
          'iorns': [('ior', False)],
          'ios': [('io', False)],
          'ios-': [('io', False)],
          'iosa': [('iosa', False)],
          'iosan': [('iosa', False)],
          'iosana': [('iosa', False)],
          'iosanas': [('iosa', False)],
          'iosans': [('iosa', False)],
          'iosas': [('iosa', False)],
          'iosats': [('iosats', False)],
          'iosen': [('io', False)],
          'iosens': [('io', False)],
          'iosis': [('iosus', False)],
          'iosk': [('iosk', False)],
          'iosk-': [('iosk', False)],
          'ioskurs': [('ioskur', False)],
          'ioson': [('ioso', False)],
          'iosons': [('ioso', False)],
          'iosots': [('ioso', False)],
          'iot': [('iot', False)],
          'iota': [('iota', True)],
          'iotas': [('iota', True)],
          'iotekniker': [('ioteknik', False)],
          'ioteknikerna': [('ioteknik', False)],
          'ioteknikernas': [('ioteknik', False)],
          'iotiden': [('iotiden', False)],
          'iotier': [('ioti', False)],
          'iotierna': [('ioti', False)],
          'iotiernas': [('ioti', False)],
          'iotiers': [('ioti', False)],
          'iotins': [('ioti', False)],
          'iots': [('io', False)],
          'ioxin': [('ioxin', False)],
          'ip': [('ip', False)],
          'ip-': [('ip', False)],
          'ipakets': [('ipaket', False)],
          'ipals': [('ipal', False)],
          'ipals-': [('ipal', False)],
          'ipan': [('ipan', False)],
          'ipande': [('ipande', False)],
          'ipande-': [('ipande', False)],
          'ipans': [('ipan', False)],
          'ipar': [('ip', False)],
          'ipar-': [('ipare', False)],
          'iparen': [('ipare', False)],
          'iparens': [('ipare', False)],
          'ipares': [('ipare', False)],
          'iparna': [('ip', False)],
          'ipars': [('ip', False)],
          'ipatiens': [('ipati', False)],
          'ipatiernas': [('ipati', False)],
          'ipation': [('ipation', False)],
          'ipations': [('ipation', False)],
          'ipe': [('ipa', False)],
          'ipe-': [('ipa', False)],
          'ipelsen': [('ipelse', False)],
          'ipelsens': [('ipelse', False)],
          'ipen': [('ip', False)],
          'ipens': [('ip', False)],
          'iper': [('ip', False)],
          'iperiernas': [('iperi', False)],
          'iperiers': [('iperi', False)],
          'iperiets': [('iperi', False)],
          'iperits': [('iperi', False)],
          'iperna': [('ip', False)],
          'ipernas': [('ip', False)],
          'ipers': [('ip', False)],
          'ipers-': [('iper', False)],
          'ipet': [('ip', False)],
          'ipets': [('ip', False)],
          'ipetter': [('ipett', False)],
          'ipie': [('ipium', False)],
          'ipie-': [('ipium', False)],
          'ipier': [('ipium', False)],
          'ipierna': [('ipium', False)],
          'ipiernas': [('ipium', False)],
          'ipiers': [('ipium', False)],
          'ipiet': [('ipium', False)],
          'ipiets': [('ipium', False)],
          'ipin': [('ipin', False)],
          'ipin-': [('ipin', False)],
          'ipiner': [('ipin', False)],
          'ipinerna': [('ipin', False)],
          'ipinernas': [('ipin', False)],
          'ipiners': [('ipin', False)],
          'ipins': [('ipin', False)],
          'iplanets': [('iplan', False)],
          'iplar': [('ipel', False)],
          'iplarna': [('ipel', False)],
          'iplarnas': [('ipel', False)],
          'iplars': [('ipel', False)],
          'iplin': [('iplin', False)],
          'iplins': [('iplin', False)],
          'ipol': [('ipol', False)],
          'ipolen': [('ipol', False)],
          'ipolens': [('ipol', False)],
          'ipols': [('ipol', False)],
          'ipor': [('ipa', False)],
          'iporna': [('ipa', False)],
          'ipornas': [('ipa', False)],
          'ipors': [('ipa', False)],
          'iposter': [('ipost', False)],
          'iposters': [('ipost', False)],
          'ipp': [('ippa', False)],
          'ipp-': [('ippa', False)],
          'ippar-': [('ippare', False)],
          'ipparnas': [('ipp', False)],
          'ippen': [('ippe', False)],
          'ippens': [('ippe', False)],
          'ipper': [('ipp', False)],
          'ipperna': [('ipper', False)],
          'ippernas': [('ipper', False)],
          'ippers': [('ipper', False)],
          'ippet': [('ippe', False)],
          'ippiesarna': [('ippie', False)],
          'ippiesarnas': [('ippie', False)],
          'ippis': [('ippi', False)],
          'ippis-': [('ippi', False)],
          'ippisar': [('ippisar', False)],
          'ippisars': [('ippisar', False)],
          'ipplanden': [('ipplande', False)],
          'ipplandens': [('ipplande', False)],
          'ipplandet': [('ipplande', False)],
          'ippran': [('ippran', False)],
          'ipprans': [('ippran', False)],
          'ipps': [('ippa', False)],
          'ipps-': [('ippa', False)],
          'iprogrammet': [('iprogram', False)],
          'ips': [('ip', False)],
          'ips-': [('ip', False)],
          'ipsarnas': [('ips', False)],
          'ipsens': [('ips', False)],
          'iptan': [('ipta', False)],
          'ipyren': [('ipyr', False)],
          'ipyrens': [('ipyr', False)],
          'ipyrer': [('ipyr', False)],
          'ipyrerna': [('ipyr', False)],
          'ipyrernas': [('ipyr', False)],
          'ipyrs': [('ipyr', False)],
          'ipyrs-': [('ipyr', False)],
          'ir': [('ir', False)],
          'ir-': [('ir', False)],
          'iracket': [('iracket', False)],
          'irackets': [('iracket', False)],
          'iraden': [('irad', False)],
          'irak': [('irak', False)],
          'irak-': [('irak', False)],
          'iraken': [('irak', False)],
          'irakens': [('irak', False)],
          'iraks': [('irak', False)],
          'iran': [('ira', False)],
          'irande': [('irande', False)],
          'irande-': [('irande', False)],
          'iranden': [('irande', False)],
          'irandens': [('irande', False)],
          'irandet': [('irande', False)],
          'iraniernas': [('iranier', True)],
          'iraniers': [('iranier', True)],
          'irans': [('ira', False)],
          'iraps': [('irap', False)],
          'iraps-': [('irap', False)],
          'irar': [('irare', False)],
          'irarna': [('irare', False)],
          'irarnas': [('ire', False)],
          'irars': [('ir', False)],
          'iras': [('ira', False)],
          'irat': [('irat', False)],
          'irata': [('irata', False)],
          'iraten': [('irat', False)],
          'iratens': [('irat', False)],
          'irater': [('irat', False)],
          'iraterna': [('irat', False)],
          'iraternas': [('irat', False)],
          'iraters': [('irat', False)],
          'iratier': [('iratier', False)],
          'iratierna': [('iratier', False)],
          'iratiernas': [('iratier', False)],
          'iratiers': [('iratier', False)],
          'irats': [('irat', False)],
          'irays': [('iraya', False)],
          'irays-': [('iraya', False)],
          'ire': [('ira', False)],
          'ire-': [('ira', False)],
          'irean': [('irea', False)],
          'iremens': [('irem', False)],
          'iremer': [('irem', False)],
          'iremerna': [('irem', False)],
          'iremernas': [('irem', False)],
          'iremers': [('irem', False)],
          'irems': [('irem', False)],
          'irems-': [('irem', False)],
          'iren': [('ir', False)],
          'irens': [('ir', False)],
          'irer': [('irer', True)],
          'irerna': [('irer', True)],
          'irernas': [('irer', True)],
          'irers': [('irer', True)],
          'ires-': [('irea', False)],
          'irese': [('iresa', False)],
          'irese-': [('iresa', False)],
          'iresen': [('ires', False)],
          'iresens': [('ires', False)],
          'iret': [('ir', False)],
          'irets': [('ir', False)],
          'irfilar': [('irfilare', False)],
          'irfilarna': [('irfilare', False)],
          'irfilarnas': [('irfilare', False)],
          'iri': [('iri', False)],
          'iri-': [('iri', False)],
          'iridin': [('iridi', False)],
          'irien': [('iri', False)],
          'irier': [('irier', False)],
          'irierna': [('irier', False)],
          'iriernas': [('irier', False)],
          'iriers': [('irier', False)],
          'iriet': [('irium', False)],
          'iriets': [('irium', False)],
          'irighets': [('irighet', False)],
          'irill-': [('irill', False)],
          'irin': [('iri', False)],
          'irin-': [('irin', False)],
          'iriner': [('irin', False)],
          'irinerna': [('irin', False)],
          'irinernas': [('irin', False)],
          'iriners': [('irin', False)],
          'iringar': [('iring', False)],
          'iringarna': [('iring', False)],
          'iringarnas': [('iring', False)],
          'irins-': [('irin', False)],
          'iris': [('iris', True)],
          'iris-': [('iris', True)],
          'irisarna': [('iris', True)],
          'irisk': [('iriska', True)],
          'irisk-': [('iriska', True)],
          'irit': [('iri', False)],
          'irits': [('iri', False)],
          'irkan': [('irka', False)],
          'irkans': [('irka', False)],
          'irkarnas': [('irk', False)],
          'irkas': [('irka', False)],
          'irke': [('irke', False)],
          'irke-': [('irke', False)],
          'irket': [('irke', False)],
          'irkets': [('irk', False)],
          'irkon': [('irkon', False)],
          'irkon-': [('irkon', False)],
          'irkons': [('irkon', False)],
          'irlanden': [('irland', False)],
          'irlandens': [('irland', False)],
          'irman': [('irma', False)],
          'irmans': [('irma', False)],
          'irogen': [('irog', False)],
          'irogens': [('irog', False)],
          'iroller': [('iroller', False)],
          'irollerna': [('iroll', False)],
          'irollernas': [('iroll', False)],
          'irollers': [('iroller', False)],
          'irolls': [('iroll', False)],
          'irolls-': [('iroll', False)],
          'irona': [('iro', False)],
          'iror': [('ira', False)],
          'irorna': [('ira', False)],
          'irornas': [('ira', False)],
          'irors': [('ira', False)],
          'iros': [('iro', False)],
          'irot': [('iro', False)],
          'iroten': [('irot', False)],
          'irotens': [('irot', False)],
          'irots': [('iro', False)],
          'irots-': [('irot', False)],
          'irps-': [('irp', False)],
          'irr': [('irra', False)],
          'irr-': [('irra', False)],
          'irran': [('irra', False)],
          'irrar': [('irre', False)],
          'irrarna': [('irre', False)],
          'irrarnas': [('irre', False)],
          'irrars': [('irre', False)],
          'irre': [('irre', False)],
          'irre-': [('irre', False)],
          'irren': [('irre', False)],
          'irrens': [('irre', False)],
          'irrs': [('irr', False)],
          'irrs-': [('irre', False)],
          'irs': [('ir', False)],
          'irs-': [('ir', False)],
          'irsen': [('irs', False)],
          'irtarnas': [('irt', False)],
          'irulle': [('irulle', False)],
          'irulle-': [('irulle', False)],
          'irum': [('irum', False)],
          'irum-': [('irum', False)],
          'irums': [('irum', False)],
          'irums-': [('irum', False)],
          'irus': [('irus', False)],
          'irus-': [('irus', False)],
          'irvlandet': [('irvlande', False)],
          'irvlandets': [('irvlande', False)],
          'iråden': [('iråd', False)],
          'irådens': [('iråd', False)],
          'irötter': [('irot', False)],
          'irötterna': [('irot', False)],
          'irötternas': [('irot', False)],
          'irötters': [('irot', False)],
          'is': [('i', True), ('is', True)],
          'is-': [('is', False)],
          'isaker': [('isak', False)],
          'isakerna': [('isak', False)],
          'isakernas': [('isak', False)],
          'isakers': [('isak', False)],
          'isalen': [('isal', False)],
          'isalens': [('isal', False)],
          'isamen': [('isam', False)],
          'isamens': [('isam', False)],
          'isamhällena': [('isamhälle', False)],
          'isan': [('isan', False)],
          'isana': [('isum', False)],
          'isanas': [('isum', False)],
          'isanden': [('isande', False)],
          'isandens': [('isande', False)],
          'isanmälningarnas': [('isanmälning', False)],
          'isans': [('isan', False)],
          'isans-': [('isans', False)],
          'isar': [('is', False)],
          'isaren': [('isare', False)],
          'isarin': [('isarin', False)],
          'isarins': [('isarin', False)],
          'isarna': [('is', False)],
          'isarnas': [('is', True)],
          'isars': [('is', False)],
          'isats': [('isats', False)],
          'isats-': [('isats', False)],
          'isbit': [('isbit', True)],
          'isboxar': [('isboxare', False)],
          'isboxarna': [('isboxare', False)],
          'isboxarnas': [('isboxare', False)],
          'iscens': [('iscens', False)],
          'iscens-': [('iscens', False)],
          'isch': [('isch', False)],
          'isch-': [('isch', False)],
          'ischan': [('ischa', False)],
          'ischen': [('isch', False)],
          'ischens': [('isch', False)],
          'ischer': [('isch', False)],
          'ischers': [('isch', False)],
          'isdans': [('isdans', True)],
          'isdomar': [('isdomare', False)],
          'isdomarna': [('isdomare', False)],
          'isdomarnas': [('isdomare', False)],
          'ise': [('isa', False)],
          'ise-': [('isa', False)],
          'iseffekt': [('iseffekt', False)],
          'iseffekt-': [('iseffekt', False)],
          'iseffekter': [('iseffekt', False)],
          'iseffekternas': [('iseffekt', False)],
          'iseffekters': [('iseffekt', False)],
          'iseffekts': [('iseffekt', False)],
          'iseffekts-': [('iseffekt', False)],
          'isel': [('isel', False)],
          'isel-': [('isel', False)],
          'isels': [('isel', False)],
          'isels-': [('isel', False)],
          'isemestrar': [('isemester', False)],
          'isemestrarna': [('isemester', False)],
          'isemestrarnas': [('isemester', False)],
          'isen': [('is', False)],
          'isen-': [('isen', False)],
          'isens': [('is', False)],
          'isens-': [('isen', False)],
          'isentens': [('isent', False)],
          'iser': [('is', False)],
          'iserier': [('iseri', False)],
          'iserierna': [('iseri', False)],
          'iseriernas': [('iseri', False)],
          'iseriers': [('iseri', False)],
          'iserna': [('is', False)],
          'isernas': [('is', False)],
          'isers': [('is', False)],
          'iset': [('is', False)],
          'isets': [('is', False)],
          'isetter': [('isett', False)],
          'isetters': [('isett', False)],
          'isgatan': [('isgata', True)],
          'ish': [('isha', False)],
          'ish-': [('isha', False)],
          'ishandlar': [('ishandlare', False)],
          'ishans': [('isha', False)],
          'isharnas': [('ish', False)],
          'ishas': [('isha', False)],
          'ishet': [('ishet', False)],
          'ishors': [('isha', False)],
          'isie': [('isie', False)],
          'isie-': [('isie', False)],
          'isien': [('isie', False)],
          'isiens': [('isie', False)],
          'isier': [('isier', False)],
          'isierna': [('isier', False)],
          'isiernas': [('isier', False)],
          'isiers': [('isier', False)],
          'isims': [('isim', False)],
          'isims-': [('isim', False)],
          'isiren': [('isir', False)],
          'isirens': [('isir', False)],
          'isitas': [('isita', False)],
          'isiter': [('isit', False)],
          'isiterna': [('isit', False)],
          'isiters': [('isit', False)],
          'isitet': [('isit', False)],
          'isits': [('isit', False)],
          'isits-': [('isit', False)],
          'isk': [('iska', False)],
          'isk-': [('iska', False)],
          'iskak': [('iskaka', False)],
          'iskak-': [('iskaka', False)],
          'iskaks': [('iskaka', False)],
          'iskaks-': [('iskaka', False)],
          'iskal': [('iskal', False)],
          'iskal-': [('iskal', False)],
          'iskals': [('iskal', False)],
          'iskals-': [('iskal', False)],
          'iskan': [('iskana', True)],
          'iskan-': [('iskana', True)],
          'iskans': [('iskana', True)],
          'iskans-': [('iskana', True)],
          'iskar': [('isk', False)],
          'iskar-': [('iskare', False)],
          'iskare': [('iskare', False)],
          'iskare-': [('iskara', False)],
          'iskarens': [('iskare', False)],
          'iskarna': [('iskare', False)],
          'iskarnas': [('isk', False)],
          'iskars': [('isk', False)],
          'iskart': [('iskart', False)],
          'iskarts': [('iskart', False)],
          'iskarts-': [('iskart', False)],
          'iskatts-': [('iskatt', False)],
          'iske': [('iske', False)],
          'iske-': [('iske', False)],
          'isken': [('isk', False)],
          'iskena': [('iske', False)],
          'iskens': [('isk', False)],
          'iskes': [('iske', False)],
          'iskes-': [('iske', False)],
          'isket': [('iske', False)],
          'iskets': [('isk', False)],
          'isko': [('isko', False)],
          'isko-': [('iska', False)],
          'iskon': [('iskon', False)],
          'iskons': [('iskon', False)],
          'iskonvaljen': [('iskonvalje', True), ('iskonvalj', True)],
          'iskonvaljens': [('iskonvalj', True), ('iskonvalje', True)],
          'iskonvaljer': [('iskonvalje', True), ('iskonvalj', True)],
          'iskonvaljerna': [('iskonvalje', True), ('iskonvalj', True)],
          'iskonvaljernas': [('iskonvalje', True), ('iskonvalj', True)],
          'iskonvaljers': [('iskonvalje', True), ('iskonvalj', True)],
          'iskop': [('iskop', False)],
          'iskop-': [('iskop', False)],
          'iskops': [('iskop', False)],
          'iskops-': [('iskop', False)],
          'iskor': [('iska', False)],
          'iskorna': [('iska', False)],
          'iskornas': [('iska', False)],
          'iskors': [('iska', False)],
          'iskos': [('iskos', False)],
          'iskos-': [('iskos', False)],
          'iskot': [('isko', False)],
          'iskotanden': [('iskotand', False)],
          'iskotandens': [('iskotand', False)],
          'iskots': [('isko', False)],
          'iskungar': [('iskung', False)],
          'iskungarna': [('iskung', False)],
          'iskungarnas': [('iskung', False)],
          'iskungars': [('iskung', False)],
          'iskungen': [('iskung', False)],
          'iskungens': [('iskung', False)],
          'iskurs': [('iskurs', False)],
          'iskurs-': [('iskurs', False)],
          'iskvin': [('iskvin', False)],
          'iskvins': [('iskvin', False)],
          'iskvis': [('iskvi', False)],
          'iskytten': [('iskytt', False)],
          'iskyttens': [('iskytt', False)],
          'iskåp': [('iskåpa', False)],
          'iskåp-': [('iskåpa', False)],
          'iskåps': [('iskåpa', False)],
          'iskåps-': [('iskåpa', False)],
          'iskår': [('iskår', False)],
          'iskåren': [('iskår', False)],
          'iskårens': [('iskår', False)],
          'iskårs': [('iskår', False)],
          'iskårs-': [('iskår', False)],
          'islag': [('islag', False)],
          'islag-': [('islag', False)],
          'islags': [('islag', False)],
          'islags-': [('islag', False)],
          'islams': [('islam', True)],
          'islanden': [('island', False)],
          'islar': [('isel', False)],
          'islarna': [('isel', False)],
          'islarnas': [('isel', False)],
          'islets': [('isel', False)],
          'isling': [('isling', False)],
          'isling-': [('isling', False)],
          'islings': [('isling', False)],
          'islings-': [('isling', False)],
          'ismajor': [('ismajor', False)],
          'ismajors': [('ismajor', False)],
          'isman': [('isma', False)],
          'ismans': [('isma', False)],
          'ismar': [('ismare', False)],
          'ismer': [('ism', True)],
          'ismerna': [('ism', True)],
          'ismernas': [('ism', True)],
          'ismers': [('ism', True)],
          'isms': [('ism', False)],
          'ismuts': [('ismut', False)],
          'isnacks': [('isnack', False)],
          'isnacks-': [('isnack', False)],
          'ison': [('ison', False)],
          'isoner': [('ison', False)],
          'isonerna': [('ison', False)],
          'isonernas': [('ison', False)],
          'isoners': [('ison', False)],
          'isons': [('ison', False)],
          'isop': [('isop', True)],
          'isop-': [('isop', True)],
          'isops': [('isop', True)],
          'isor': [('isa', False)],
          'isorna': [('isa', False)],
          'isornas': [('isa', False)],
          'isors': [('isa', False)],
          'isp': [('ispa', False)],
          'isp-': [('ispa', False)],
          'ispad': [('ispade', False)],
          'ispad-': [('ispade', False)],
          'ispads': [('ispade', False)],
          'ispads-': [('ispade', False)],
          'isparnas': [('isp', False)],
          'ispe': [('ispa', False)],
          'ispe-': [('ispa', False)],
          'ispen': [('isp', False)],
          'ispens': [('ispens', False)],
          'ispens-': [('ispens', False)],
          'ispet': [('isp', False)],
          'ispets': [('isp', False)],
          'ispor': [('ispa', False)],
          'ispors': [('ispa', False)],
          'isranden': [('isrand', True)],
          'israndens': [('isrand', True)],
          'isringar': [('isring', False)],
          'iss': [('issa', False)],
          'iss-': [('iss', False)],
          'issage': [('issage', False)],
          'issage-': [('issage', False)],
          'issalen': [('issale', False)],
          'issalens': [('issale', False)],
          'issans': [('issa', False)],
          'issar': [('isse', False)],
          'issarie-': [('issarie', False)],
          'issarier': [('issarie', False)],
          'issarierna': [('issarie', False)],
          'issariers': [('issarie', False)],
          'issarna': [('iss', False)],
          'issarnas': [('iss', False)],
          'issars': [('isse', False)],
          'isse': [('isse', False)],
          'isse-': [('isse', False)],
          'issel': [('issla', False)],
          'issel-': [('issla', False)],
          'issen': [('isse', False)],
          'issens': [('isse', False)],
          'isser': [('isser', False)],
          'isserier': [('isserie', False)],
          'isserierna': [('isseri', False)],
          'isseriernas': [('isserie', False)],
          'isseriers': [('isserie', False)],
          'isserna': [('isser', False)],
          'issernas': [('isser', False)],
          'issers': [('isser', False)],
          'issets': [('iss', False)],
          'issis': [('issis', False)],
          'issivets': [('issiv', False)],
          'isslan': [('isslan', False)],
          'isslanden': [('isslande', False)],
          'isslandens': [('isslande', False)],
          'isslandet': [('isslande', False)],
          'isslans': [('isslan', False)],
          'isslar': [('isslare', False)],
          'isslarna': [('isslare', False)],
          'isslarnas': [('isslare', False)],
          'issle': [('issla', False)],
          'issle-': [('issla', False)],
          'isslor': [('issla', False)],
          'isslorna': [('issla', False)],
          'isslornas': [('issla', False)],
          'isslors': [('issla', False)],
          'ist': [('ist', False)],
          'ista': [('ista', False)],
          'ista-': [('ista', False)],
          'istagen': [('istage', False)],
          'istagens': [('istage', False)],
          'istak': [('istak', False)],
          'istaken': [('istak', False)],
          'istakens': [('istak', False)],
          'istaket': [('istak', False)],
          'istakets': [('istak', False)],
          'istaks': [('istak', False)],
          'istaks-': [('istak', False)],
          'istan': [('ista', False)],
          'istank': [('istanke', False)],
          'istank-': [('istanke', False)],
          'istankarna': [('istanke', False)],
          'istankarnas': [('istanke', False)],
          'istanken': [('istanke', False)],
          'istankens': [('istanke', False)],
          'istanks': [('istanke', False)],
          'istanks-': [('istanke', False)],
          'istans': [('ista', False)],
          'istar': [('ist', False)],
          'istar-': [('istare', False)],
          'istarnas': [('ist', False)],
          'istars': [('ist', False)],
          'istas': [('ista', False)],
          'iste': [('iste', False)],
          'istel': [('istel', False)],
          'istel-': [('istel', False)],
          'istels': [('istel', False)],
          'istels-': [('istel', False)],
          'istens-': [('istens', False)],
          'ister': [('ister', False)],
          'isterhake': [('isterhaka', True)],
          'isterhaks-': [('isterhaka', True)],
          'isteri': [('isteri', False)],
          'isteri-': [('isteri', False)],
          'isterie-': [('isterium', False)],
          'isterier': [('isteri', False)],
          'isterierna': [('isteri', False)],
          'isteriernas': [('isterium', False)],
          'isteriers': [('isteri', False)],
          'isteriet': [('isteri', False)],
          'isteriets': [('isterium', False)],
          'isteris': [('isteri', False)],
          'isteris-': [('isteri', False)],
          'istern': [('istern', False)],
          'isterns': [('istern', False)],
          'isters': [('ister', False)],
          'istick': [('istick', False)],
          'isticks': [('istick', False)],
          'isticks-': [('istick', False)],
          'istika': [('istika', False)],
          'istikas': [('istika', False)],
          'istill': [('istill', False)],
          'istill-': [('istill', False)],
          'istills': [('istill', False)],
          'istis': [('istia', False)],
          'istol': [('istol', False)],
          'istol-': [('istol', False)],
          'istols': [('istol', False)],
          'istols-': [('istol', False)],
          'istor': [('istor', False)],
          'istorer': [('istor', False)],
          'istorerna': [('istor', False)],
          'istorernas': [('istor', False)],
          'istorers': [('istor', False)],
          'istorier': [('istorium', False)],
          'istorierna': [('istorium', False)],
          'istoriernas': [('istorium', False)],
          'istoriers': [('istorium', False)],
          'istors': [('istor', False)],
          'istranden': [('istrande', False)],
          'istrandens': [('istrande', False)],
          'istrarnas': [('ister', False)],
          'istringens': [('istring', False)],
          'istron': [('istron', False)],
          'istronen': [('istron', False)],
          'istronens': [('istron', False)],
          'istrons': [('istron', False)],
          'istuv': [('istuva', False)],
          'istuv-': [('istuva', False)],
          'istuvs': [('istuva', False)],
          'istuvs-': [('istuva', False)],
          'istycken': [('istycke', False)],
          'istyckena': [('istycke', False)],
          'istyckenas': [('istycke', False)],
          'istyckens': [('istycke', False)],
          'istycket': [('istycke', False)],
          'istyckets': [('istycke', False)],
          'istylen': [('istyl', False)],
          'istyren': [('istyr', False)],
          'istyrens': [('istyr', False)],
          'istyrke': [('istyrke', False)],
          'istön': [('istö', False)],
          'istöns': [('istö', False)],
          'istövlars': [('istövel', False)],
          'isun': [('isu', False)],
          'isuns': [('isu', False)],
          'isus': [('isu', False)],
          'isvak': [('isvak', True)],
          'isvaks': [('isvak', True)],
          'isval': [('isval', False)],
          'isvalen': [('isval', False)],
          'isvalens': [('isval', False)],
          'isvals': [('isval', False)],
          'isvals-': [('isval', False)],
          'isvensk': [('isvenska', False)],
          'isvensk-': [('isvenska', False)],
          'isvärden': [('isvärde', False)],
          'isvärdens': [('isvärde', False)],
          'isvärdet': [('isvärde', False)],
          'isvärdets': [('isvärde', False)],
          'isvärmar': [('isvärm', False)],
          'isvärmarna': [('isvärm', False)],
          'isvärmarnas': [('isvärm', False)],
          'isväsendets': [('isväsende', False)],
          'isyre': [('isyra', False)],
          'isyre-': [('isyra', False)],
          'isyren': [('isyr', False)],
          'isyrens': [('isyr', False)],
          'isyrs': [('isyr', False)],
          'isyrs-': [('isyr', False)],
          'isysslor': [('isyssla', False)],
          'isysslornas': [('isyssla', False)],
          'isysslors': [('isyssla', False)],
          'isås': [('isås', False)],
          'isås-': [('isås', False)],
          'iséer': [('isé', False)],
          'iséers': [('isé', False)],
          'isögon': [('isöga', False)],
          'isören': [('isör', False)],
          'isörens': [('isör', False)],
          'isörns': [('isör', False)],
          'isös-': [('isös', False)],
          'it': [('i', True), ('it', True)],
          'it-': [('it', False)],
          'itafs': [('itaf', False)],
          'itagen': [('itage', False)],
          'itagens': [('itage', False)],
          'itaget': [('itage', False)],
          'itagets': [('itage', False)],
          'itak': [('itak', False)],
          'itaken': [('itak', False)],
          'itaktiker': [('itaktik', False)],
          'itaktikerna': [('itaktik', False)],
          'itaktikernas': [('itaktik', False)],
          'itaktikers': [('itaktik', False)],
          'italen': [('ital', False)],
          'italens': [('ital', False)],
          'italer': [('italer', True)],
          'italerna': [('italer', True)],
          'italernas': [('italer', True)],
          'italers': [('italer', True)],
          'italet': [('ital', False)],
          'itamentets': [('itament', False)],
          'itaments': [('itament', False)],
          'itan-': [('itan', False)],
          'itana': [('itum', False)],
          'itanas': [('itum', False)],
          'itanden': [('itande', False)],
          'itandens': [('itande', False)],
          'itani': [('itania', False)],
          'itani-': [('itania', False)],
          'itank': [('itanke', False)],
          'itank-': [('itanke', False)],
          'itankar': [('itanke', False)],
          'itankarna': [('itanke', False)],
          'itankarnas': [('itanke', False)],
          'itankars': [('itanke', False)],
          'itanke': [('itanke', False)],
          'itanke-': [('itanke', False)],
          'itanken': [('itanke', False)],
          'itankens': [('itanke', False)],
          'itanks': [('itanke', False)],
          'itanks-': [('itanke', False)],
          'itans': [('ita', False)],
          'itans-': [('itans', False)],
          'itar': [('it', False)],
          'itar-': [('itar', False)],
          'itaren': [('itare', False)],
          'itarens': [('itar', False)],
          'itarie': [('itarie', False)],
          'itarie-': [('itarie', False)],
          'itarier': [('itarie', False)],
          'itariernas': [('itarie', False)],
          'itariers': [('itarie', False)],
          'itarna': [('it', False)],
          'itarnas': [('itare', False)],
          'itars': [('it', False)],
          'itas-': [('itas', False)],
          'itat': [('itat', False)],
          'itats': [('itat', False)],
          'itbet': [('itbeta', False)],
          'itbets': [('itbeta', False)],
          'itbets-': [('itbeta', False)],
          'ite': [('ita', False)],
          'ite-': [('ita', False)],
          'itel': [('itel', False)],
          'itelen': [('itel', False)],
          'itelens': [('itel', False)],
          'itell': [('itella', False)],
          'itell-': [('itella', False)],
          'itellans': [('itella', False)],
          'itells': [('itella', False)],
          'itells-': [('itella', False)],
          'iteln': [('itel', False)],
          'itelns': [('itel', False)],
          'itels': [('itel', False)],
          'itels-': [('itel', False)],
          'iten': [('it', False)],
          'itens': [('it', False)],
          'itens-': [('itens', False)],
          'iter': [('it', False)],
          'iter-': [('iter', False)],
          'iteranden': [('iterande', False)],
          'iterandens': [('iterande', False)],
          'iterie': [('iterium', False)],
          'iterier': [('iteri', False)],
          'iterierna': [('iterium', False)],
          'iteriernas': [('iteri', False)],
          'iteriers': [('iterium', False)],
          'iteriet': [('iterium', False)],
          'iteriets': [('iteri', False)],
          'iterits': [('iteri', False)],
          'itern': [('iter', False)],
          'iterna': [('it', False)],
          'iterns': [('iter', False)],
          'iterorden': [('iterorden', False)],
          'iterordens': [('iterorden', False)],
          'iters': [('it', False)],
          'iters-': [('iter', False)],
          'itersen': [('iter', False)],
          'itersens': [('iter', False)],
          'ites': [('ite', False)],
          'ites-': [('ites', False)],
          'itet': [('itet', False)],
          'iteters': [('itet', False)],
          'itetet': [('itet', False)],
          'itets': [('itet', False)],
          'itfiskarna': [('itfisk', False)],
          'ithakens': [('ithak', False)],
          'ithet': [('ithet', False)],
          'ithets': [('ithet', False)],
          'iti': [('itus', False)],
          'itiden': [('itid', False)],
          'itier': [('itier', False)],
          'itierna': [('itier', False)],
          'itiernas': [('itier', False)],
          'itiers': [('itier', False)],
          'itiet': [('itium', False)],
          'itik': [('itik', False)],
          'itik-': [('itik', False)],
          'itiks': [('itik', False)],
          'itillhörighets': [('itillhörighet', False)],
          'itillhörighets-': [('itillhörighet', False)],
          'itin': [('itin', False)],
          'itin-': [('itin', False)],
          'itina': [('itus', False)],
          'itinas': [('itus', False)],
          'itinens': [('itin', False)],
          'itiner': [('itin', False)],
          'itinerna': [('itin', False)],
          'itinernas': [('itin', False)],
          'itiners': [('itin', False)],
          'itins': [('itin', False)],
          'itins-': [('itin', False)],
          'itinstitutet': [('itinstitut', False)],
          'itions-': [('ition', False)],
          'itis-': [('itis', False)],
          'itiv': [('itiv', False)],
          'itiv-': [('itiv', False)],
          'itive': [('itiva', False)],
          'itive-': [('itiva', False)],
          'itiven': [('itiv', False)],
          'itivens': [('itiv', False)],
          'itiver': [('itiv', False)],
          'itiverna': [('itiv', False)],
          'itivernas': [('itiv', False)],
          'itivers': [('itiv', False)],
          'itivet': [('itiv', False)],
          'itivs': [('itiv', False)],
          'itjarnas': [('itj', False)],
          'itkors': [('itkors', False)],
          'itlandets': [('itlande', False)],
          'itlar': [('itel', False)],
          'itlarna': [('itel', False)],
          'itlarnas': [('itel', False)],
          'ito-': [('ito', False)],
          'iton': [('iton', False)],
          'itoner': [('iton', False)],
          'itonerna': [('iton', False)],
          'itonernas': [('iton', False)],
          'itopparnas': [('itopp', False)],
          'itor': [('ita', False)],
          'itorden': [('itorden', False)],
          'itordens': [('itorden', False)],
          'itorer': [('itor', False)],
          'itorerna': [('itor', False)],
          'itorernas': [('itor', False)],
          'itorers': [('itor', False)],
          'itorier': [('itorium', False)],
          'itoriet': [('itorium', False)],
          'itoris': [('itoris', False)],
          'itoris-': [('itori', False)],
          'itorn': [('itor', False)],
          'itorna': [('ita', False)],
          'itornas': [('ita', False)],
          'itorns': [('itor', False)],
          'itors': [('ita', False)],
          'itos': [('ito', False)],
          'itos-': [('ito', False)],
          'itra': [('itra', False)],
          'itran': [('itra', False)],
          'itrans': [('itra', False)],
          'itrar': [('iter', False)],
          'itrarna': [('iter', False)],
          'itrars': [('iter', False)],
          'itras': [('itra', False)],
          'itrav': [('itrav', False)],
          'itrav-': [('itrav', False)],
          'itraven': [('itrav', False)],
          'itravens': [('itrav', False)],
          'itravers': [('itrav', False)],
          'itravs': [('itrav', False)],
          'itrean': [('itrean', False)],
          'itreans': [('itrean', False)],
          'itricks': [('itrick', False)],
          'itricks-': [('itrick', False)],
          'itrin': [('itrin', False)],
          'itrins': [('itrin', False)],
          'itripp-': [('itripp', False)],
          'itripparna': [('itripp', False)],
          'itripps-': [('itripp', False)],
          'itris': [('itris', False)],
          'itron': [('itron', False)],
          'itrons': [('itron', False)],
          'itror': [('itra', False)],
          'itrycken': [('itryck', False)],
          'itryckens': [('itryck', False)],
          'itrycket': [('itryck', False)],
          'itryckets': [('itryck', False)],
          'itrycks': [('itryck', False)],
          'itrycks-': [('itryck', False)],
          'iträd': [('iträd', False)],
          'iträd-': [('iträd', False)],
          'iträde': [('iträde', False)],
          'iträden': [('iträde', False)],
          'iträdens': [('iträde', False)],
          'iträdet': [('iträde', False)],
          'iträdets': [('iträde', False)],
          'iträds': [('iträd', False)],
          'iträn': [('iträd', False)],
          'iträna': [('iträd', False)],
          'itränas': [('iträd', False)],
          'iträns': [('iträd', False)],
          'iträv': [('iträv', False)],
          'iträv-': [('iträv', False)],
          'iträvar': [('iträv', False)],
          'iträvarna': [('iträv', False)],
          'iträvarnas': [('iträv', False)],
          'its': [('i', True)],
          'its-': [('it', False)],
          'itsaks': [('itsak', False)],
          'itsaks-': [('itsak', False)],
          'itsar': [('itsare', False)],
          'itsar-': [('itsare', False)],
          'itsaren': [('itsare', False)],
          'itsarens': [('itsare', False)],
          'itsarna': [('itsare', False)],
          'itsarnas': [('its', False)],
          'itsars': [('its', False)],
          'itsen': [('it', False)],
          'itsens': [('it', False)],
          'itstans': [('itstans', False)],
          'itställen': [('itställe', False)],
          'itstället': [('itställe', False)],
          'itt': [('itta', False)],
          'itt-': [('itta', False)],
          'ittan': [('itta', False)],
          'ittar': [('ittare', False)],
          'ittarna': [('ittare', False)],
          'ittarnas': [('itt', False)],
          'ittben': [('ittben', False)],
          'ittbens': [('ittben', False)],
          'ittbens-': [('ittben', False)],
          'itte-': [('itta', False)],
          'itten': [('itten', False)],
          'ittens': [('itt', False)],
          'ittens-': [('ittens', False)],
          'itter-': [('ittra', False)],
          'itteriers': [('itteri', False)],
          'itterna': [('itter', False)],
          'itternas': [('itter', False)],
          'itters': [('itter', False)],
          'ittets': [('itt', False)],
          'ittidens': [('ittid', False)],
          'ittigheter': [('ittighet', False)],
          'ittigheterna': [('ittighet', False)],
          'ittigheternas': [('ittighet', False)],
          'ittigheters': [('ittighet', False)],
          'ittighets-': [('ittighet', False)],
          'ittlanden': [('ittlande', False)],
          'ittlandens': [('ittlande', False)],
          'ittlandet': [('ittlande', False)],
          'ittnen': [('ittne', False)],
          'itto': [('itto', False)],
          'ittrar': [('ittrare', False)],
          'ittrarna': [('ittrare', False)],
          'ittrarnas': [('itter', False)],
          'ittre': [('ittra', False)],
          'ittre-': [('ittra', False)],
          'itts': [('itta', False)],
          'itts-': [('itta', False)],
          'ituds': [('itud', False)],
          'ituds-': [('itud', False)],
          'itum': [('itum', False)],
          'itum-': [('itum', False)],
          'itums': [('itum', False)],
          'itup': [('itup', False)],
          'itup-': [('itup', False)],
          'itups': [('itup', False)],
          'itups-': [('itup', False)],
          'itur': [('itur', False)],
          'itur-': [('itur', False)],
          'iturerna': [('itur', False)],
          'iturernas': [('itur', False)],
          'iturers': [('itur', False)],
          'iturs': [('itur', False)],
          'iturs-': [('itur', False)],
          'itus': [('itus', False)],
          'itus-': [('itus', False)],
          'itut': [('itut', False)],
          'itut-': [('itut', False)],
          'itutet': [('itut', False)],
          'ituts': [('itut', False)],
          'ituts-': [('itut', False)],
          'ityd': [('ityd', False)],
          'ityd-': [('ityd', False)],
          'ityds': [('ityd', False)],
          'ityr': [('ityr', False)],
          'ityr-': [('ityr', False)],
          'ityren': [('ityr', False)],
          'ityrens': [('ityr', False)],
          'ityrer': [('ityr', False)],
          'ityrerna': [('ityr', False)],
          'ityrernas': [('ityr', False)],
          'ityrers': [('ityr', False)],
          'ityret': [('ityr', False)],
          'ityrets': [('ityr', False)],
          'ityrs': [('ityr', False)],
          'ityrs-': [('ityr', False)],
          'itälskan': [('itälskan', False)],
          'itälskans': [('itälskan', False)],
          'itärterna': [('itärter', False)],
          'itärternas': [('itärter', False)],
          'itår': [('itår', False)],
          'itårs': [('itår', False)],
          'itögat': [('itögat', False)],
          'itögats': [('itögat', False)],
          'iuernas': [('iuer', False)],
          'iuers': [('iuer', False)],
          'iusarnas': [('ius', False)],
          'iv': [('iv', False)],
          'iv-': [('iv', False)],
          'ivack': [('ivack', False)],
          'ivack-': [('ivack', False)],
          'ivacks': [('ivack', False)],
          'ival': [('ival', False)],
          'ival-': [('ival', False)],
          'ivalen': [('ival', False)],
          'ivalens': [('ival', False)],
          'ivals': [('ival', False)],
          'ivals-': [('ival', False)],
          'ivan': [('iva', False)],
          'ivana': [('iva', False)],
          'ivanas': [('iva', False)],
          'ivanernas': [('ivan', False)],
          'ivankarnas': [('ivankare', False)],
          'ivans': [('iva', False)],
          'ivar-': [('ivare', False)],
          'ivaran': [('ivara', False)],
          'ivarans': [('ivara', False)],
          'ivaren': [('ivare', False)],
          'ivarier': [('ivarie', False)],
          'ivarierna': [('ivarius', False)],
          'ivariernas': [('ivarie', False)],
          'ivariers': [('ivarie', False)],
          'ivarna': [('iv', False)],
          'ivarnas': [('iv', False)],
          'ivars': [('iv', False)],
          'ivas': [('iva', False)],
          'ivas-': [('iva', False)],
          'ivator': [('ivata', False)],
          'ivators': [('ivata', False)],
          'ive': [('iva', False)],
          'ive-': [('iva', False)],
          'iveck': [('ivecka', False)],
          'iveck-': [('ivecka', False)],
          'ivecks': [('ivecka', False)],
          'ivecks-': [('ivecka', False)],
          'ivel': [('ivel', False)],
          'ivel-': [('ivel', False)],
          'ivels': [('ivel', False)],
          'ivels-': [('ivel', False)],
          'iven': [('iv', False)],
          'ivens': [('iv', False)],
          'iver': [('iver', True)],
          'iverande': [('iverande', False)],
          'iverande-': [('iverande', False)],
          'ivern': [('iver', False)],
          'iverna': [('iv', False)],
          'ivernas': [('iv', False)],
          'iverns': [('iver', False)],
          'ivers': [('iver', True)],
          'ivers-': [('iver', False)],
          'iversarna': [('iver', False)],
          'iversarnas': [('iver', False)],
          'iversen': [('iver', False)],
          'iversens': [('iver', False)],
          'ivet': [('iv', False)],
          'ivid': [('ivid', False)],
          'ivid-': [('ivid', False)],
          'ividen': [('ivid', False)],
          'ividens': [('ivid', False)],
          'ivider': [('ivid', False)],
          'ividers': [('ivid', False)],
          'ividet': [('ivid', False)],
          'ividets': [('ivid', False)],
          'ivids': [('ivid', False)],
          'ivids-': [('ivid', False)],
          'ivier': [('ivier', False)],
          'ivierna': [('ivier', False)],
          'iviernas': [('ivier', False)],
          'iviers': [('ivier', False)],
          'ivin': [('ivin', False)],
          'ivin-': [('ivin', False)],
          'ivins': [('ivin', False)],
          'ivins-': [('ivin', False)],
          'ivinsten': [('ivinst', False)],
          'ivinstens': [('ivinst', False)],
          'ivis': [('ivis', False)],
          'ivis-': [('ivis', False)],
          'ivisen': [('ivis', False)],
          'ivisens': [('ivis', False)],
          'ivisor': [('ivisor', False)],
          'ivisors': [('ivisor', False)],
          'ivist': [('ivist', False)],
          'ivist-': [('ivist', False)],
          'ivisten': [('ivist', False)],
          'ivistens': [('ivist', False)],
          'ivit': [('ivit', False)],
          'ivit-': [('ivit', False)],
          'ivitas': [('ivitas', False)],
          'iviten': [('ivit', False)],
          'ivitens': [('ivit', False)],
          'ivitet': [('ivitet', False)],
          'ivitets': [('ivitet', False)],
          'ivits': [('ivit', False)],
          'ivlan': [('ivlan', False)],
          'ivlans': [('ivlan', False)],
          'ivlar-': [('ivlare', False)],
          'ivlarens': [('ivlare', False)],
          'ivlars': [('ivel', False)],
          'ivlen': [('ivel', False)],
          'ivlens': [('ivel', False)],
          'ivlingen': [('ivling', False)],
          'ivlingens': [('ivling', False)],
          'ivlins': [('ivlins', False)],
          'ivlins-': [('ivlina', False)],
          'ivmoder-': [('ivmoder', False)],
          'ivmodern': [('ivmoder', False)],
          'ivmoderns': [('ivmoder', False)],
          'ivmoders': [('ivmoder', False)],
          'ivmoders-': [('ivmoder', False)],
          'ivor': [('iva', False)],
          'ivorna': [('iva', False)],
          'ivornas': [('iva', False)],
          'ivors': [('iva', False)],
          'ivots': [('ivot', False)],
          'ivrar': [('ivrare', True)],
          'ivrarna': [('ivrare', True)],
          'ivrarnas': [('ivrare', True)],
          'ivs': [('iv', False)],
          'ivs-': [('iv', False)],
          'ivsanden': [('ivsand', False)],
          'ivsandens': [('ivsand', False)],
          'ivsens': [('ivs', False)],
          'ivslagar': [('ivslag', False)],
          'ivslagarna': [('ivslag', False)],
          'ivslagarnas': [('ivslag', False)],
          'ivstudie-': [('ivstudie', False)],
          'ivstudiernas': [('ivstudie', False)],
          'ivstudiers': [('ivstudie', False)],
          'ivägar': [('iväg', False)],
          'ivägarna': [('iväg', False)],
          'ivägarnas': [('iväg', False)],
          'ivägars': [('iväg', False)],
          'ivärden': [('ivärde', False)],
          'ivärdens': [('ivärde', False)],
          'ivån': [('ivå', False)],
          'ivåns': [('ivå', False)],
          'iwier': [('iwi', False)],
          'ix': [('ix', False)],
          'ix-': [('ix', False)],
          'ixar': [('ix', False)],
          'ixarna': [('ix', False)],
          'ixarnas': [('ix', False)],
          'ixars': [('ix', False)],
          'ixen': [('ix', False)],
          'ixens': [('ix', False)],
          'ixer': [('ix', False)],
          'ixerna': [('ix', False)],
          'ixernas': [('ix', False)],
          'ixers': [('ix', False)],
          'ixet': [('ix', False)],
          'iz': [('iz', False)],
          'izar': [('iz', False)],
          'izarna': [('iz', False)],
          'izarnas': [('iz', False)],
          'izer': [('iz', False)],
          'izers': [('iz', False)],
          'izonen': [('izon', False)],
          'izonens': [('izon', False)],
          'izor': [('iza', False)],
          'izorna': [('iza', False)],
          'izornas': [('iza', False)],
          'izors': [('iza', False)],
          'iärn': [('iär', False)],
          'iärns': [('iär', False)],
          'iår': [('iår', False)],
          'iårs': [('iår', False)],
          'iårs-': [('iår', False)],
          'iéerna': [('ié', False)],
          'iéernas': [('ié', False)],
          'iören': [('iör', False)],
          'iörens': [('iör', False)],
          'j': [('j', True)],
          'j-': [('j', True)],
          'j:t': [('j', True)],
          'ja': [('ja', False)],
          'ja-': [('ja', False)],
          'jabb': [('jabb', True)],
          'jabb-': [('jabb', True)],
          'jabbarna': [('jabb', True)],
          'jabbarnas': [('jabb', True)],
          'jabbars': [('jabb', True)],
          'jabbens': [('jabb', True)],
          'jabbs': [('jabb', True)],
          'jabbs-': [('jabb', True)],
          'jaber': [('jaber', False)],
          'jaberna': [('jaber', False)],
          'jabernas': [('jaber', False)],
          'jabots': [('jabot', True)],
          'jack': [('jack', True), ('jacka', True)],
          'jack-': [('jack', True), ('jacka', True)],
          'jackar': [('jack', True)],
          'jackarna': [('jack', True)],
          'jackars': [('jack', False)],
          'jacke': [('jacka', False)],
          'jacke-': [('jacka', False)],
          'jacken': [('jack', False)],
          'jackens': [('jack', True)],
          'jacket': [('jack', False)],
          'jackets': [('jack', False)],
          'jackor': [('jacka', False)],
          'jackorna': [('jacka', False)],
          'jackornas': [('jacka', False)],
          'jackors': [('jacka', True)],
          'jacks': [('jack', True), ('jacka', True)],
          'jacks-': [('jacka', True), ('jack', True)],
          'jade': [('jade', True)],
          'jade-': [('jade', True)],
          'jaden': [('jade', True)],
          'jadens': [('jade', True)],
          'jades': [('jade', True)],
          'jafs': [('jafs', False)],
          'jafs-': [('jafs', False)],
          'jagar': [('jagare', False)],
          'jagar-': [('jagare', True)],
          'jagarna': [('jagare', True)],
          'jagarnas': [('jagare', False)],
          'jagens': [('jag', False)],
          'jager': [('jag', False)],
          'jagerna': [('jag', False)],
          'jagernas': [('jag', False)],
          'jagets': [('jag', False)],
          'jagg': [('jagg', False)],
          'jagg-': [('jagg', False)],
          'jaggen': [('jagg', False)],
          'jaggens': [('jagg', False)],
          'jaggs': [('jagg', False)],
          'jaggs-': [('jagg', False)],
          'jak-': [('jak', False)],
          'jakar': [('jak', True)],
          'jakarna': [('jak', True)],
          'jakarnas': [('jak', True)],
          'jaks': [('jak', False)],
          'jaks-': [('jak', True)],
          'jakter': [('jakt', False)],
          'jakters': [('jakt', False)],
          'jalar': [('jal', False)],
          'jalet': [('jal', False)],
          'jalets': [('jal', False)],
          'jalk': [('jalk', False)],
          'jalk-': [('jalk', False)],
          'jalkar': [('jalk', False)],
          'jalkarna': [('jalk', False)],
          'jalks': [('jalk', False)],
          'jalks-': [('jalk', False)],
          'jall': [('jall', False)],
          'jall-': [('jall', False)],
          'jallanden': [('jallande', False)],
          'jallandens': [('jallande', False)],
          'jallandet': [('jallande', False)],
          'jallar': [('jallare', False)],
          'jallarna': [('jallare', False)],
          'jallarnas': [('jallare', False)],
          'jalls': [('jall', False)],
          'jalls-': [('jall', False)],
          'jals': [('jal', False)],
          'jals-': [('jal', False)],
          'jam': [('jam', True)],
          'jam-': [('jam', True)],
          'jamar': [('jamare', True)],
          'jamarna': [('jamare', True)],
          'jamas': [('jamas', False)],
          'jamb': [('jamb', True)],
          'jamb-': [('jamb', True)],
          'jamben': [('jamb', True)],
          'jambens': [('jamb', True)],
          'jambs': [('jamb', True)],
          'jambs-': [('jamb', True)],
          'jamet': [('jam', True)],
          'jamets': [('jam', True)],
          'jamin': [('jamin', False)],
          'jamins': [('jamin', False)],
          'jammers': [('jammer', False)],
          'jams': [('jams', True), ('jam', True)],
          'jams-': [('jam', True), ('jams', True)],
          'jan': [('jan', True), ('ja', True)],
          'jan-': [('jan', True)],
          'jana': [('ja', True)],
          'janan': [('jana', False)],
          'janans': [('jana', False)],
          'janarna': [('jan', True)],
          'janarnas': [('jan', True)],
          'janas': [('ja', True)],
          'janden': [('jande', False)],
          'jandens': [('jande', False)],
          'jandets': [('jande', False)],
          'janens': [('jan', False)],
          'jang': [('jang', False)],
          'jang-': [('jang', False)],
          'jangen': [('jang', False)],
          'jangens': [('jang', False)],
          'jangs': [('jangs', False)],
          'jangs-': [('jangs', False)],
          'jann': [('janne', False)],
          'jann-': [('janne', False)],
          'jannars': [('janne', False)],
          'jannen': [('janne', False)],
          'jannens': [('janne', False)],
          'janns': [('janne', False)],
          'janns-': [('janne', False)],
          'janor': [('jana', False)],
          'janorna': [('jana', False)],
          'janornas': [('jana', False)],
          'janors': [('jana', False)],
          'jans': [('jan', True), ('ja', True)],
          'jans-': [('jan', False)],
          'jansen': [('jans', False)],
          'jansens': [('jans', False)],
          'janser': [('jans', False)],
          'janserna': [('jans', False)],
          'jansernas': [('jans', False)],
          'jansers': [('jans', False)],
          'jansk': [('janska', False)],
          'jansk-': [('janska', False)],
          'jant': [('jant', False)],
          'jantar': [('jant', False)],
          'jantarna': [('jant', False)],
          'jantars': [('jant', False)],
          'janten': [('jant', False)],
          'jantens': [('jant', False)],
          'janter': [('jant', False)],
          'janterna': [('jant', False)],
          'janternas': [('jant', False)],
          'janters': [('jant', False)],
          'jantet': [('jant', False)],
          'jantets': [('jant', False)],
          'jants-': [('jant', False)],
          'japan': [('japan', True)],
          'japans': [('japan', True)],
          'japp': [('japp', False)],
          'japp-': [('japp', False)],
          'jappen': [('japp', False)],
          'jappens': [('japp', False)],
          'japps': [('japp', False)],
          'jar': [('jare', False)],
          'jar-': [('jare', False)],
          'jard': [('jard', False)],
          'jard-': [('jard', False)],
          'jarden': [('jard', False)],
          'jardens': [('jard', False)],
          'jarder': [('jard', False)],
          'jarderna': [('jard', False)],
          'jardernas': [('jard', False)],
          'jarders': [('jard', False)],
          'jards': [('jard', False)],
          'jards-': [('jard', False)],
          'jare': [('jare', False)],
          'jaren': [('jar', False)],
          'jarens': [('jare', False)],
          'jares': [('jare', False)],
          'jarna': [('jare', False)],
          'jars': [('jar', False)],
          'jas': [('ja', False)],
          'jas-': [('ja', True)],
          'jasar': [('jas', False)],
          'jasarna': [('jas', False)],
          'jasarnas': [('jas', False)],
          'jaserier': [('jaserier', False)],
          'jaseriernas': [('jaserier', False)],
          'jaseriers': [('jaserier', False)],
          'jaskar': [('jasker', False)],
          'jaskarna': [('jasker', False)],
          'jaskarnas': [('jasker', False)],
          'jaskars': [('jasker', False)],
          'jass': [('jass', True)],
          'jassen': [('jass', True)],
          'jassens': [('jass', True)],
          'jat': [('ja', True)],
          'jats': [('ja', False)],
          'jats-': [('jat', False)],
          'jatt': [('jatt', False)],
          'jatt-': [('jatt', False)],
          'jattar': [('jatt', False)],
          'jattars': [('jatt', False)],
          'jatten': [('jatt', False)],
          'jatts': [('jatt', False)],
          'jatts-': [('jatt', False)],
          'jauns': [('jau', False)],
          'javan': [('java', True), ('javan', True)],
          'javanden': [('javande', False)],
          'javandens': [('javande', False)],
          'javanens': [('javan', True)],
          'javanerna': [('javan', True)],
          'javans': [('javan', True), ('java', True)],
          'jazz': [('jazz', True)],
          'jazz-': [('jazz', True)],
          'jbagg': [('jbagge', False)],
          'jbagg-': [('jbagge', False)],
          'jbaggar': [('jbagge', False)],
          'jbaggarna': [('jbagge', False)],
          'jbaggarnas': [('jbagge', False)],
          'jbaggars': [('jbagge', False)],
          'jbaggen': [('jbagge', False)],
          'jbaggens': [('jbagge', False)],
          'jbaggs': [('jbagge', False)],
          'jbaggs-': [('jbagge', False)],
          'jblom': [('jblomma', False)],
          'jblom-': [('jblomma', False)],
          'jbloms': [('jblomma', False)],
          'jbloms-': [('jblomma', False)],
          'jborst': [('jborste', False)],
          'jborst-': [('jborste', False)],
          'jborsten': [('jborste', False)],
          'jborstens': [('jborste', False)],
          'jd': [('jd', False)],
          'jd-': [('jd', False)],
          'jdagar': [('jdag', False)],
          'jdagarnas': [('jdag', False)],
          'jdagars': [('jdag', False)],
          'jdagen': [('jdag', False)],
          'jdagens': [('jdag', False)],
          'jdags': [('jdag', False)],
          'jdan': [('jdag', False)],
          'jdanden': [('jdande', False)],
          'jdandens': [('jdande', False)],
          'jdans': [('jdag', False)],
          'jdaren': [('jdare', False)],
          'jdarna': [('jdare', False)],
          'jdarnas': [('jdare', False)],
          'jdars': [('jd', False)],
          'jde': [('jd', False)],
          'jde-': [('jd', False)],
          'jdeg': [('jdeg', False)],
          'jdel': [('jdel', False)],
          'jdels-': [('jdel', False)],
          'jden': [('jd', False)],
          'jdens': [('jd', False)],
          'jder': [('jd', False)],
          'jder-': [('jder', False)],
          'jdern': [('jder', False)],
          'jderna': [('jd', False)],
          'jdernas': [('jd', False)],
          'jderns': [('jder', False)],
          'jders': [('jd', False)],
          'jders-': [('jder', False)],
          'jdhopp': [('jdhopp', False)],
          'jdhopps': [('jdhopp', False)],
          'jdhopps-': [('jdhopp', False)],
          'jdlar': [('jdel', False)],
          'jdlarna': [('jdel', False)],
          'jdlarnas': [('jdel', False)],
          'jdlars': [('jdel', False)],
          'jdrar': [('jder', False)],
          'jdrarna': [('jder', False)],
          'jdrars': [('jder', False)],
          'jds': [('jd', False)],
          'jds-': [('jd', False)],
          'jeborgen': [('jeborg', False)],
          'jeck': [('jeck', False)],
          'jeck-': [('jeck', False)],
          'jecken': [('jeck', False)],
          'jeckens': [('jeck', False)],
          'jecks': [('jeck', False)],
          'jecks-': [('jeck', False)],
          'jed': [('jed', False)],
          'jed-': [('jed', False)],
          'jedan': [('jedag', False)],
          'jedans-': [('jedans', False)],
          'jedomar': [('jedomare', False)],
          'jedomarna': [('jedomare', False)],
          'jedomarnas': [('jedomare', False)],
          'jeds': [('jed', False)],
          'jeds-': [('jed', False)],
          'jedödarna': [('jedödare', False)],
          'jeer': [('je', False)],
          'jeerna': [('je', False)],
          'jeernas': [('je', False)],
          'jeers': [('je', False)],
          'jefader-': [('jefar', False)],
          'jefaderns': [('jefar', False)],
          'jefaders': [('jefar', False)],
          'jefäder': [('jefar', False)],
          'jefäderna': [('jefar', False)],
          'jefädernas': [('jefar', False)],
          'jefäders': [('jefar', False)],
          'jegångarnas': [('jegång', False)],
          'jekrets': [('jekrets', False)],
          'jekt': [('jekt', False)],
          'jekt-': [('jekt', False)],
          'jekten': [('jekt', False)],
          'jektens': [('jekt', False)],
          'jektet': [('jekt', False)],
          'jektets': [('jekt', False)],
          'jektiven': [('jektiv', False)],
          'jektivens': [('jektiv', False)],
          'jekts': [('jekt', False)],
          'jekts-': [('jekt', False)],
          'jelandens': [('jeland', False)],
          'jelandet': [('jeland', False)],
          'jemang': [('jemang', False)],
          'jemang-': [('jemang', False)],
          'jemangs': [('jemang', False)],
          'jemangs-': [('jemang', False)],
          'jen': [('je', False)],
          'jena': [('je', False)],
          'jenas': [('je', False)],
          'jenkor': [('jenka', True)],
          'jenkorna': [('jenka', True)],
          'jenkornas': [('jenka', True)],
          'jenkors': [('jenka', True)],
          'jens': [('je', False)],
          'jensk': [('jenska', False)],
          'jensk-': [('jenska', False)],
          'jeppar': [('jeppe', True)],
          'jepparna': [('jeppe', True)],
          'jeppars': [('jeppe', True)],
          'jer-': [('jer', False)],
          'jerare': [('jerare', False)],
          'jerares': [('jerare', False)],
          'jerarna': [('jerare', False)],
          'jerarnas': [('jerare', False)],
          'jeren': [('jeren', False)],
          'jerens': [('jeren', False)],
          'jerens-': [('jeren', False)],
          'jeri': [('jeri', False)],
          'jeri-': [('jeri', False)],
          'jerier': [('jeri', False)],
          'jerierna': [('jeri', False)],
          'jeriers': [('jeri', False)],
          'jeriet': [('jeri', False)],
          'jeris': [('jeri', False)],
          'jeris-': [('jeri', False)],
          'jerit': [('jeri', False)],
          'jerke': [('jerka', False)],
          'jerkors': [('jerka', False)],
          'jerks': [('jerka', False)],
          'jerks-': [('jerka', False)],
          'jers-': [('jer', False)],
          'jes': [('je', False)],
          'jes-': [('je', False)],
          'jeset': [('jeset', False)],
          'jess': [('jess', False)],
          'jessens': [('jess', False)],
          'jestan': [('jestad', False)],
          'jesten': [('jesten', False)],
          'jestens': [('jesten', False)],
          'jet': [('jet', True)],
          'jetarnas': [('jet', False)],
          'jeten': [('jet', False)],
          'jetens': [('jet', False)],
          'jeter': [('jet', False)],
          'jeters': [('jet', False)],
          'jeträden': [('jeträd', False)],
          'jeträdet': [('jeträd', False)],
          'jets': [('jet', True)],
          'jett': [('jett', False)],
          'jett-': [('jett', False)],
          'jetten': [('jett', False)],
          'jetter': [('jett', False)],
          'jetterna': [('jett', False)],
          'jetternas': [('jett', False)],
          'jetters': [('jett', False)],
          'jetts': [('jett', False)],
          'jetts-': [('jett', False)],
          'jeväxlarna': [('jeväxel', False)],
          'jf': [('jf', False)],
          'jf-': [('jf', False)],
          'jfar': [('jf', False)],
          'jfarna': [('jf', False)],
          'jfars': [('jf', False)],
          'jfen': [('jfena', False)],
          'jfens': [('jf', False)],
          'jfer': [('jf', False)],
          'jferna': [('jf', False)],
          'jfernas': [('jf', False)],
          'jfers': [('jf', False)],
          'jfiskar': [('jfisk', False)],
          'jfiskarna': [('jfisk', False)],
          'jfiskarnas': [('jfisk', False)],
          'jfs': [('jf', False)],
          'jfs-': [('jf', False)],
          'jgan': [('jga', False)],
          'jgans': [('jga', False)],
          'jgas': [('jga', False)],
          'jhandlar': [('jhandlare', False)],
          'jhandlarna': [('jhandlare', False)],
          'jhandlarnas': [('jhandlare', False)],
          'jhets': [('jhet', False)],
          'jhets-': [('jhet', False)],
          'jhål': [('jhål', False)],
          'jhåls': [('jhål', False)],
          'jhåls-': [('jhål', False)],
          'jian': [('jian', False)],
          'jian-': [('jian', False)],
          'jians': [('jian', False)],
          'jibbar': [('jib', False)],
          'jibbarna': [('jib', False)],
          'jibbars': [('jib', False)],
          'jibben': [('jib', False)],
          'jigg': [('jigg', True)],
          'jigg-': [('jigg', True)],
          'jiggarna': [('jigg', True)],
          'jiggarnas': [('jigg', True)],
          'jiggars': [('jigg', True)],
          'jiggen': [('jigg', False)],
          'jiggens': [('jigg', False)],
          'jiggs': [('jigg', True)],
          'jiggs-': [('jigg', False)],
          'jigheter': [('jighet', False)],
          'jigheterna': [('jighet', False)],
          'jigheternas': [('jighet', False)],
          'jigheters': [('jighet', False)],
          'jighets-': [('jighet', False)],
          'jingel': [('jingel', False)],
          'jingel-': [('jingel', False)],
          'jinglar': [('jingel', False)],
          'jinglarna': [('jingel', False)],
          'jinglarnas': [('jingel', False)],
          'jis': [('jis', False)],
          'jisarnas': [('jis', False)],
          'jiskan': [('jiska', False)],
          'jiskans': [('jiska', False)],
          'jiske': [('jiska', False)],
          'jiske-': [('jiska', False)],
          'jist-': [('jist', False)],
          'jisten': [('jist', False)],
          'jistens': [('jist', False)],
          'jister': [('jist', False)],
          'jisterna': [('jist', False)],
          'jisternas': [('jist', False)],
          'jisters': [('jist', False)],
          'jj': [('jja', False)],
          'jj-': [('jj', False)],
          'jjan': [('jja', False)],
          'jjans': [('jja', False)],
          'jjar': [('jje', False)],
          'jjarna': [('jje', False)],
          'jjarnas': [('jje', False)],
          'jjars': [('jje', False)],
          'jje': [('jja', False)],
          'jje-': [('jja', False)],
          'jjor': [('jja', False)],
          'jjorna': [('jja', False)],
          'jjornas': [('jja', False)],
          'jjors': [('jja', False)],
          'jjs': [('jj', False)],
          'jk': [('jk', False)],
          'jk-': [('jk', False)],
          'jkan': [('jka', False)],
          'jkanden': [('jkande', False)],
          'jkans': [('jka', False)],
          'jkar-': [('jkare', False)],
          'jkare': [('jkare', False)],
          'jkaren': [('jkare', False)],
          'jkarens': [('jkare', False)],
          'jkart': [('jkarta', False)],
          'jkart-': [('jkarta', False)],
          'jkarts': [('jkarta', False)],
          'jkarts-': [('jkarta', False)],
          'jkas': [('jka', False)],
          'jke': [('jka', False)],
          'jke-': [('jka', False)],
          'jken': [('jk', False)],
          'jkens': [('jk', False)],
          'jker': [('jk', False)],
          'jkerna': [('jk', False)],
          'jkernas': [('jk', False)],
          'jkers': [('jk', False)],
          'jkkasse-': [('jkkassa', False)],
          'jklagets': [('jklag', False)],
          'jkningar': [('jkning', False)],
          'jkningarna': [('jkning', False)],
          'jkningarnas': [('jkning', False)],
          'jkningars': [('jkning', False)],
          'jknings': [('jkning', False)],
          'jknings-': [('jkning', False)],
          'jkopp': [('jkopp', False)],
          'jkoppar': [('jkopp', False)],
          'jkoppars': [('jkopp', False)],
          'jkopps': [('jkopp', False)],
          'jkopps-': [('jkopp', False)],
          'jkor': [('jka', False)],
          'jkorna': [('jka', False)],
          'jkornas': [('jka', False)],
          'jkors': [('jka', False)],
          'jkott': [('jkott', False)],
          'jkott-': [('jkott', False)],
          'jkotten': [('jkott', False)],
          'jkottens': [('jkott', False)],
          'jkotts': [('jkott', False)],
          'jkotts-': [('jkott', False)],
          'jkrokarnas': [('jkrok', False)],
          'jks': [('jk', False)],
          'jkunskaper': [('jkunskap', False)],
          'jkunskaperna': [('jkunskap', False)],
          'jkunskapernas': [('jkunskap', False)],
          'jkunskapers': [('jkunskap', False)],
          'jkunskaps': [('jkunskap', False)],
          'jkår': [('jkår', False)],
          'jkåren': [('jkår', False)],
          'jkårens': [('jkår', False)],
          'jkårs': [('jkår', False)],
          'jkårs-': [('jkår', False)],
          'jl': [('jl', False)],
          'jl-': [('jl', False)],
          'jlack': [('jlack', False)],
          'jlanden': [('jlande', False)],
          'jlandena': [('jlande', False)],
          'jlandenas': [('jlande', False)],
          'jlandens': [('jlande', False)],
          'jlandet': [('jlande', False)],
          'jlandets': [('jlande', False)],
          'jlar': [('jlare', False)],
          'jlaren': [('jlare', False)],
          'jlarna': [('jlare', False)],
          'jlarnas': [('jlare', False)],
          'jlen': [('jl', False)],
          'jlens': [('jl', False)],
          'jlets': [('jl', False)],
          'jligans': [('jliga', False)],
          'jlighets': [('jlighet', False)],
          'jlik': [('jlika', False)],
          'jlik-': [('jlika', False)],
          'jlike': [('jlika', False)],
          'jlike-': [('jlika', False)],
          'jliks': [('jlika', False)],
          'jliks-': [('jlika', False)],
          'jlis': [('jlis', False)],
          'jlis-': [('jlis', False)],
          'jlisen': [('jlis', False)],
          'jlisens': [('jlis', False)],
          'jlock': [('jlock', False)],
          'jm-': [('jm', False)],
          'jmack': [('jmacka', False)],
          'jmack-': [('jmacka', False)],
          'jmacks': [('jmacka', False)],
          'jmacks-': [('jmacka', False)],
          'jman': [('jman', False)],
          'jmanden': [('jmande', False)],
          'jmaner': [('jman', False)],
          'jmanerna': [('jman', False)],
          'jmanernas': [('jman', False)],
          'jmaners': [('jman', False)],
          'jmans': [('jman', False)],
          'jmaster': [('jmast', False)],
          'jmasters': [('jmast', False)],
          'jmen': [('jm', False)],
          'jmens': [('jm', False)],
          'jms-': [('jm', False)],
          'jnanden': [('jnande', False)],
          'joar': [('jo', False)],
          'joars': [('jo', False)],
          'jobb': [('jobb', False)],
          'jobbens': [('jobb', False)],
          'jobbs': [('jobb', False)],
          'jobbs-': [('jobb', False)],
          'joden': [('jod', True)],
          'jodens': [('jod', True)],
          'jods': [('jod', True)],
          'joen': [('jo', False)],
          'joer': [('jo', False)],
          'joerna': [('jo', False)],
          'joernas': [('jo', False)],
          'joers': [('jo', False)],
          'joget': [('jog', False)],
          'jogets': [('jog', False)],
          'joggar': [('joggare', True)],
          'joggarna': [('joggare', True)],
          'joggarnas': [('joggare', True)],
          'jojk': [('jojk', True)],
          'jojk-': [('jojk', True)],
          'jojken': [('jojk', True)],
          'jojkens': [('jojk', True)],
          'jojks': [('jojk', True)],
          'jojor': [('jojo', True)],
          'jojorna': [('jojo', True)],
          'jojornas': [('jojo', True)],
          'jojors': [('jojo', True)],
          'joker': [('joker', True)],
          'jokers': [('joker', True)],
          'jokets': [('jok', False)],
          'joll': [('jolle', True)],
          'joll-': [('jolle', True)],
          'jollarna': [('jolle', True)],
          'jollarnas': [('jolle', True)],
          'jolle': [('jolle', True)],
          'jolle-': [('jolla', False)],
          'jollen': [('jolle', False)],
          'jollens': [('jolle', False)],
          'jolls': [('jolle', True)],
          'jolls-': [('jolle', True)],
          'jom': [('jomme', False)],
          'jom-': [('jomme', False)],
          'jomen': [('jom', False)],
          'jomens': [('jom', False)],
          'jommar': [('jomme', False)],
          'jommarnas': [('jomme', False)],
          'jommars': [('jomme', False)],
          'jommen': [('jomme', False)],
          'jommens': [('jomme', False)],
          'joms': [('jomme', False)],
          'joms-': [('jomme', False)],
          'jon': [('jon', True)],
          'jon-': [('jon', False)],
          'joner': [('joner', True), ('jon', True)],
          'jonerna': [('joner', True), ('jon', True)],
          'jonernas': [('joner', True), ('jon', True)],
          'joners': [('joner', True), ('jon', True)],
          'jong': [('jong', False)],
          'jong-': [('jong', False)],
          'jonger': [('jong', False)],
          'jongerna': [('jong', False)],
          'jongernas': [('jong', False)],
          'jongers': [('jong', False)],
          'jongs': [('jong', False)],
          'jongs-': [('jong', False)],
          'jonier': [('jonier', True)],
          'jonierna': [('jonier', True)],
          'joniernas': [('jonier', True)],
          'jonk': [('jonk', False)],
          'jonk-': [('jonk', False)],
          'jonken': [('jonk', False)],
          'jonkens': [('jonk', False)],
          'jonker': [('jonk', False)],
          'jonkerna': [('jonk', False)],
          'jonkernas': [('jonk', False)],
          'jonkers': [('jonk', False)],
          'jonks': [('jonk', False)],
          'jonks-': [('jonk', False)],
          'jons': [('jon', True)],
          'jons-': [('jon', False)],
          'jor': [('jo', False)],
          'jord': [('jord', True)],
          'jord-': [('jord', False)],
          'jordar': [('jord', False)],
          'jordarna': [('jord', False)],
          'jordbor': [('jordbo', True)],
          'jorden': [('jord', True)],
          'jordens': [('jord', False)],
          'jordgubb': [('jordgubb', True), ('jordgubbe', True)],
          'jordgubb-': [('jordgubbe', True), ('jordgubb', True)],
          'jordgubbs': [('jordgubbe', True), ('jordgubb', True)],
          'jordgubbs-': [('jordgubb', True), ('jordgubbe', True)],
          'jords': [('jord', False)],
          'jords-': [('jord', False)],
          'jorn': [('jor', False)],
          'jorna': [('jo', False)],
          'jorns': [('jor', False)],
          'jort': [('jort', False)],
          'jort-': [('jort', False)],
          'jortar': [('jort', False)],
          'jortarna': [('jort', False)],
          'jorte': [('jorta', False)],
          'jorte-': [('jorta', False)],
          'jorten': [('jort', False)],
          'jortens': [('jort', False)],
          'jorts': [('jorta', False)],
          'jorts-': [('jort', False)],
          'jos': [('jos', True)],
          'jos-': [('jos', True)],
          'josk': [('josk', False)],
          'josk-': [('josk', False)],
          'jota': [('jota', True)],
          'jotas': [('jota', True)],
          'jotin': [('jotin', False)],
          'jott': [('jott', False)],
          'jott-': [('jott', False)],
          'jotten': [('jott', False)],
          'jotter': [('jott', False)],
          'jotterna': [('jott', False)],
          'jotternas': [('jott', False)],
          'jotters': [('jott', False)],
          'jotts': [('jott', False)],
          'jotts-': [('jott', False)],
          'jours': [('jour', False)],
          'jours-': [('jour', False)],
          'jovis': [('jovis', False)],
          'jox': [('jox', True)],
          'jox-': [('jox', True)],
          'jp': [('jp', False)],
          'jp-': [('jp', False)],
          'jpande': [('jpande', False)],
          'jpande-': [('jpande', False)],
          'jpar': [('jp', False)],
          'jparna': [('jp', False)],
          'jpars': [('jp', False)],
          'jpen': [('jp', False)],
          'jpens': [('jp', False)],
          'jper': [('jp', False)],
          'jperna': [('jp', False)],
          'jpernas': [('jp', False)],
          'jpers': [('jp', False)],
          'jpet': [('jp', False)],
          'jpets': [('jp', False)],
          'jpkurs': [('jpkur', False)],
          'jps': [('jp', False)],
          'jps-': [('jp', False)],
          'jrams': [('jram', False)],
          'jrams-': [('jram', False)],
          'jroms': [('jrom', False)],
          'jröst': [('jröst', False)],
          'jröst-': [('jröst', False)],
          'jrösten': [('jröst', False)],
          'jröstens': [('jröst', False)],
          'js': [('ja', False)],
          'js-': [('ja', False)],
          'jsanden': [('jsande', False)],
          'jsandens': [('jsande', False)],
          'jsaren': [('jsare', False)],
          'jsarnas': [('jsare', False)],
          'jsars': [('js', False)],
          'jsel': [('jsel', False)],
          'jsel-': [('jsel', False)],
          'jsels': [('jsel', False)],
          'jsels-': [('jsel', False)],
          'jsen': [('js', False)],
          'jsenas': [('jsena', False)],
          'jsens': [('js', False)],
          'jser-': [('jser', False)],
          'jsern': [('jser', False)],
          'jserna': [('js', False)],
          'jsernas': [('js', False)],
          'jserns': [('jser', False)],
          'jsers-': [('jser', False)],
          'jset': [('js', False)],
          'jsets': [('js', False)],
          'jslag': [('jslag', False)],
          'jslags': [('jslag', False)],
          'jslags-': [('jslag', False)],
          'jslandets': [('jslande', False)],
          'jslar': [('jsel', False)],
          'jslarna': [('jsel', False)],
          'jslarnas': [('jsel', False)],
          'jsling': [('jsling', False)],
          'jslings': [('jsling', False)],
          'jslings-': [('jsling', False)],
          'jst': [('jst', False)],
          'jstar': [('jst', False)],
          'jstarnas': [('jst', False)],
          'jstars': [('jst', False)],
          'jsten': [('jsten', False)],
          'jstens': [('jst', False)],
          'jstudie': [('jstudium', False)],
          'jstudie-': [('jstudium', False)],
          'jstudier': [('jstudium', False)],
          'jstudierna': [('jstudium', False)],
          'jstudiernas': [('jstudium', False)],
          'jstudiers': [('jstudium', False)],
          'jstötarnas': [('jstöt', False)],
          'jsvärdet': [('jsvärd', False)],
          'jsvärmar': [('jsvärm', False)],
          'jsvärmarna': [('jsvärm', False)],
          'jsvärmarnas': [('jsvärm', False)],
          'jsås': [('jsås', False)],
          'jsås-': [('jsås', False)],
          'jt': [('jt', False)],
          'jt-': [('jt', False)],
          'jtalar': [('jtalare', False)],
          'jtalar-': [('jtalare', False)],
          'jtalaren': [('jtalare', False)],
          'jtalarens': [('jtalare', False)],
          'jtalens': [('jtal', False)],
          'jtalet': [('jtal', False)],
          'jtanden': [('jtande', False)],
          'jtandens': [('jtande', False)],
          'jtaren': [('jtare', False)],
          'jteln': [('jtel', False)],
          'jtelns': [('jtel', False)],
          'jtels': [('jtel', False)],
          'jtels-': [('jtel', False)],
          'jten': [('jt', False)],
          'jtens': [('jt', False)],
          'jter': [('jt', False)],
          'jter-': [('jter', False)],
          'jtern': [('jter', False)],
          'jterna': [('jt', False)],
          'jternas': [('jt', False)],
          'jterns': [('jter', False)],
          'jters': [('jt', False)],
          'jters-': [('jter', False)],
          'jtersen': [('jter', False)],
          'jtersens': [('jter', False)],
          'jtes': [('jte', False)],
          'jtes-': [('jte', False)],
          'jtet': [('jt', False)],
          'jtets': [('jt', False)],
          'jthet': [('jthet', False)],
          'jthets': [('jthet', False)],
          'jtis': [('jti', False)],
          'jtis-': [('jti', False)],
          'jtlar': [('jtel', False)],
          'jtlarna': [('jtel', False)],
          'jtlarnas': [('jtel', False)],
          'jträt': [('jträ', False)],
          'jträts': [('jträ', False)],
          'jts': [('jt', False)],
          'jts-': [('jt', False)],
          'jtton': [('jtton', False)],
          'jttons': [('jtton', False)],
          'jtåg': [('jtåg', False)],
          'jtågs': [('jtåg', False)],
          'jtågs-': [('jtåg', False)],
          'ju': [('ju', False)],
          'ju-': [('ju', False)],
          'juan': [('juan', False)],
          'juana': [('juana', False)],
          'juanas': [('juana', False)],
          'juans': [('juan', False)],
          'juarnas': [('juare', False)],
          'juas': [('jua', False)],
          'jubb': [('jubb', False)],
          'jubbarna': [('jubb', False)],
          'jubbarnas': [('jubb', False)],
          'jubbars': [('jubb', False)],
          'jubbens': [('jubb', False)],
          'jubbs': [('jubb', False)],
          'jubbs-': [('jubb', False)],
          'jubilars': [('jubilar', True)],
          'juck': [('juck', False)],
          'juck-': [('juck', False)],
          'jucks': [('juck', False)],
          'jucks-': [('juck', False)],
          'judar': [('jude', True)],
          'judarna': [('jude', True)],
          'judarnas': [('jude', True)],
          'judars': [('jude', True)],
          'jude': [('jude', True)],
          'jude-': [('jude', True)],
          'juden': [('jude', True)],
          'judens': [('jude', True)],
          'juder': [('juder', False)],
          'juderna': [('juder', False)],
          'judernas': [('juder', False)],
          'juders': [('juder', False)],
          'juer': [('ju', False)],
          'juerna': [('ju', False)],
          'juernas': [('ju', False)],
          'juers': [('ju', False)],
          'jug': [('juga', False)],
          'jug-': [('jug', False)],
          'jugar': [('jugare', False)],
          'jugarna': [('jugare', False)],
          'jugarnas': [('jugare', False)],
          'jugets': [('jug', False)],
          'jugg': [('jugg', False)],
          'jugg-': [('jugg', False)],
          'juggen': [('jugg', False)],
          'juggens': [('jugg', False)],
          'juggs': [('jugg', False)],
          'juggs-': [('jugg', False)],
          'jugs': [('juga', False)],
          'jugs-': [('jug', False)],
          'juk': [('juka', False)],
          'juk-': [('juka', False)],
          'jukas': [('juka', False)],
          'jukis-': [('jukis', False)],
          'jukisarna': [('jukis', False)],
          'juks': [('juka', False)],
          'juks-': [('juka', False)],
          'jularna': [('jul', True)],
          'juli': [('juli', True)],
          'julis': [('juli', True)],
          'jull': [('julle', True)],
          'jull-': [('julle', True)],
          'jullarnas': [('julle', True)],
          'jullen': [('julle', True)],
          'jullens': [('julle', True)],
          'julls': [('julle', True)],
          'julls-': [('julle', True)],
          'julott': [('julotta', True)],
          'julotte': [('julotta', True)],
          'julp': [('julp', True)],
          'julp-': [('julp', True)],
          'julps-': [('julp', True)],
          'jumbors': [('jumbo', True)],
          'jun': [('ju', False)],
          'juna': [('ju', False)],
          'junas': [('ju', False)],
          'jung': [('jung', False)],
          'jung-': [('jung', False)],
          'jungen': [('jung', False)],
          'jungens': [('jung', False)],
          'jungs': [('jung', False)],
          'jungs-': [('jung', False)],
          'juni': [('juni', True)],
          'juni-': [('juni', True)],
          'junis': [('juni', True)],
          'junk': [('junk', False)],
          'junk-': [('junk', False)],
          'junkar': [('junkare', False)],
          'junkarna': [('junkare', False)],
          'junks': [('junk', False)],
          'junks-': [('junk', False)],
          'juns': [('ju', False)],
          'juns-': [('jun', False)],
          'junt-': [('junta', True)],
          'junte': [('junta', False)],
          'junte-': [('junta', False)],
          'junts': [('junta', False)],
          'juor': [('jua', False)],
          'juorna': [('jua', False)],
          'juornas': [('jua', False)],
          'juors': [('jua', False)],
          'jur': [('jure', False)],
          'jur-': [('jure', False)],
          'jurar': [('jure', False)],
          'jurarna': [('jure', False)],
          'jurarnas': [('jure', False)],
          'jurars': [('jure', False)],
          'jure': [('jure', False)],
          'jure-': [('jure', False)],
          'juren': [('jure', False)],
          'jurens': [('jure', False)],
          'jurie-': [('jurie', False)],
          'jurien': [('jurie', False)],
          'juriernas': [('jurie', False)],
          'juriers': [('jurie', False)],
          'jurs': [('jure', False)],
          'jurs-': [('jure', False)],
          'jursten': [('jursten', False)],
          'jurstens': [('jursten', False)],
          'jurt': [('jurt', True), ('jurta', True)],
          'jurt-': [('jurt', True), ('jurta', True)],
          'jurts': [('jurta', True), ('jurt', True)],
          'jurts-': [('jurt', True), ('jurta', True)],
          'jus': [('jus', True)],
          'jus-': [('jus', True)],
          'jusan': [('jusa', False)],
          'jusans': [('jusa', False)],
          'jusar': [('jusare', False)],
          'jusar-': [('jusare', False)],
          'jusarens': [('jusare', False)],
          'jusarna': [('jusare', False)],
          'jusarnas': [('jusare', False)],
          'jusars': [('juse', False)],
          'juse': [('juse', False)],
          'jusen': [('jus', True)],
          'jusens': [('jus', True)],
          'jusringarna': [('jusring', False)],
          'jusringarnas': [('jusring', False)],
          'jut': [('juta', False)],
          'jut-': [('juta', False)],
          'jutan': [('juta', False)],
          'jutar': [('jute', True)],
          'jutarna': [('jute', True)],
          'jutarnas': [('jute', True)],
          'jutars': [('jute', True)],
          'jute': [('jute', True)],
          'jute-': [('jute', True)],
          'juten': [('jute', True)],
          'jutens': [('jute', True)],
          'juteri': [('juteri', False)],
          'juteri-': [('juteri', False)],
          'juteriers': [('juteri', False)],
          'juteriet': [('juteri', False)],
          'jutet': [('jute', True)],
          'jutets': [('jute', True)],
          'jutiden': [('jutiden', False)],
          'jutin': [('jutin', False)],
          'jutsanden': [('jutsande', False)],
          'jutsandens': [('jutsande', False)],
          'jutsar': [('juts', False)],
          'jutsarna': [('juts', False)],
          'jutsen': [('juts', False)],
          'jutsens': [('juts', False)],
          'jutt': [('jutt', False)],
          'juttars': [('jutt', False)],
          'jutten': [('jutt', False)],
          'jutts': [('jutt', False)],
          'jutts-': [('jutt', False)],
          'juv-': [('juv', False)],
          'jven': [('jv', False)],
          'jvens': [('jv', False)],
          'jwan': [('jwan', False)],
          'jwans': [('jwan', False)],
          'jyck': [('jycke', True)],
          'jyck-': [('jycke', True)],
          'jyckar': [('jycke', True)],
          'jyckarna': [('jycke', True)],
          'jyckarnas': [('jycke', True)],
          'jycks-': [('jycke', True)],
          'jyvar': [('jyv', False)],
          'jäbb': [('jäbb', False)],
          'jäbbs': [('jäbb', False)],
          'jäbbs-': [('jäbb', False)],
          'jäder': [('jäder', False)],
          'jäders': [('jäder', False)],
          'jäfs': [('jäfs', False)],
          'jägar': [('jägare', False)],
          'jägarna': [('jägare', False)],
          'jägarnas': [('jägare', False)],
          'jäklarna': [('jäkel', True)],
          'jäknar': [('jäkne', False)],
          'jäknarnas': [('jäkne', False)],
          'jäknen': [('jäkne', False)],
          'jäkt': [('jäkt', False)],
          'jäkt-': [('jäkt', True)],
          'jäkten': [('jäkt', False)],
          'jäktens': [('jäkt', False)],
          'jäktet': [('jäkt', True)],
          'jäkts': [('jäkt', True)],
          'jäkts-': [('jäkt', True)],
          'jälar': [('jäle', False)],
          'jälarna': [('jäle', False)],
          'jälarnas': [('jäle', False)],
          'jälars': [('jäle', False)],
          'jäle': [('jäle', False)],
          'jäle-': [('jäle', False)],
          'jälen': [('jäle', False)],
          'jälens': [('jäle', False)],
          'jälk': [('jälk', False)],
          'jälk-': [('jälk', False)],
          'jälkar': [('jälk', False)],
          'jälkarna': [('jälk', False)],
          'jälkarnas': [('jälke', False)],
          'jälkars': [('jälk', False)],
          'jälken': [('jälk', False)],
          'jälkens': [('jälk', False)],
          'jälks': [('jälk', False)],
          'jälks-': [('jälk', False)],
          'jäll': [('jäll', False)],
          'jäll-': [('jäll', False)],
          'jällan': [('jälla', False)],
          'jällanden': [('jällande', False)],
          'jällandena': [('jällande', False)],
          'jällandenas': [('jällande', False)],
          'jällandens': [('jällande', False)],
          'jälle': [('jälla', False)],
          'jälle-': [('jälla', False)],
          'jällen': [('jäll', False)],
          'jället': [('jäll', False)],
          'jällets': [('jäll', False)],
          'jällningar': [('jällning', False)],
          'jällningarna': [('jällning', False)],
          'jällningarnas': [('jällning', False)],
          'jällningars': [('jällning', False)],
          'jällnings': [('jällning', False)],
          'jällnings-': [('jällning', False)],
          'jälls': [('jäll', False)],
          'jälls-': [('jäll', False)],
          'jäls': [('jäl', False)],
          'jält': [('jälte', False)],
          'jält-': [('jälte', False)],
          'jältarna': [('jälte', False)],
          'jälts': [('jälte', False)],
          'jälts-': [('jälte', False)],
          'jälv': [('jälv', False)],
          'jämtar': [('jämte', True)],
          'jämtarna': [('jämte', True)],
          'jämtarnas': [('jämte', True)],
          'jäng-': [('jäng', False)],
          'jänger': [('jäng', False)],
          'jängerna': [('jäng', False)],
          'jängernas': [('jäng', False)],
          'jängers': [('jäng', False)],
          'jänkar': [('jänkare', True)],
          'jänkarna': [('jänkare', True)],
          'jänkarnas': [('jänkare', True)],
          'jänt': [('jänta', True)],
          'jänt-': [('jänta', False)],
          'jäntans': [('jänta', True)],
          'jänte': [('jänta', True)],
          'jänts': [('jänta', False)],
          'jänts-': [('jänta', True)],
          'jär': [('jära', False)],
          'jär-': [('jära', False)],
          'järan': [('jära', False)],
          'järans': [('jära', False)],
          'järd': [('järd', False)],
          'järd-': [('järd', False)],
          'järdar': [('järd', False)],
          'järdarna': [('järd', False)],
          'järdarnas': [('järde', False)],
          'järdars': [('järd', False)],
          'järden': [('järd', False)],
          'järdens': [('järd', False)],
          'järds': [('järd', False)],
          'järds-': [('järd', False)],
          'järn': [('järn', False)],
          'järn-': [('järn', False)],
          'järnar': [('järn', False)],
          'järnarna': [('järn', False)],
          'järnorna': [('järna', False)],
          'järnornas': [('järna', False)],
          'järns': [('järn', False)],
          'järns-': [('järn', False)],
          'järnvägar': [('järnvägare', True), ('järnväg', True)],
          'järnvägarna': [('järnvägare', True), ('järnväg', True)],
          'järnvägarnas': [('järnvägare', True), ('järnväg', True)],
          'järp': [('järpe', False)],
          'järparna': [('järpe', False)],
          'järpars': [('järpe', True)],
          'järps': [('järpe', False)],
          'järr': [('järr', False)],
          'järrs-': [('järr', False)],
          'järs': [('jära', False)],
          'järs-': [('jära', False)],
          'järt': [('järt', False)],
          'järt-': [('järt', False)],
          'järtanden': [('järtande', False)],
          'järtandens': [('järtande', False)],
          'järter': [('järter', False)],
          'järterna': [('järter', False)],
          'järternas': [('järter', False)],
          'järters': [('järter', False)],
          'järts': [('järt', False)],
          'järts-': [('järt', False)],
          'järv': [('järv', True)],
          'järv-': [('järv', True)],
          'järvarna': [('järv', True)],
          'järvarnas': [('järv', True)],
          'järvars': [('järv', True)],
          'järven': [('järv', True)],
          'järvens': [('järv', True)],
          'järvs': [('järv', True)],
          'järvs-': [('järv', True)],
          'jäsk': [('jäsk', False)],
          'jäsk-': [('jäsk', False)],
          'jäskarnas': [('jäsker', False)],
          'jäss': [('jässa', False)],
          'jäss-': [('jässa', False)],
          'jässarna': [('jässe', False)],
          'jässarnas': [('jässe', False)],
          'jässe': [('jässa', False)],
          'jässe-': [('jässa', False)],
          'jässen': [('jässe', False)],
          'jässens': [('jässe', False)],
          'jäst-': [('jäst', False)],
          'jästen': [('jäst', False)],
          'jästens': [('jäst', True)],
          'jät-': [('jät', False)],
          'jätets': [('jät', False)],
          'jättar': [('jätte', False)],
          'jättarna': [('jätte', False)],
          'jätten': [('jätte', False)],
          'jättens': [('jätte', False)],
          'jättrar': [('jättrar', False)],
          'jäv': [('jäv', False)],
          'jäv-': [('jäv', True)],
          'jävets': [('jäv', True)],
          'jävlar': [('jävel', False)],
          'jävlarna': [('jävel', True)],
          'jävlarnas': [('jävel', True)],
          'jävlars': [('jävel', True)],
          'jäx': [('jäxa', False)],
          'jäx-': [('jäxa', False)],
          'jå': [('jå', False)],
          'jå-': [('jå', False)],
          'jåar': [('jåare', False)],
          'jåarna': [('jåare', False)],
          'jåarnas': [('jåare', False)],
          'jåparnas': [('jåp', False)],
          'jås': [('jå', False)],
          'jåt': [('jå', False)],
          'jåts': [('jå', False)],
          'jéerna': [('jé', False)],
          'jéernas': [('jé', False)],
          'jöar': [('jö', False)],
          'jöarna': [('jö', False)],
          'jödet': [('jöd', False)],
          'jödets': [('jöd', False)],
          'jögats': [('jöga', False)],
          'jögonens': [('jöga', False)],
          'jögons': [('jöga', False)],
          'jökorna': [('jöko', False)],
          'jökornas': [('jöko', False)],
          'jökors': [('jöko', False)],
          'jön': [('jö', False)],
          'jöna': [('jö', False)],
          'jönas': [('jö', False)],
          'jöns': [('jöns', True)],
          'jöns-': [('jöns', False)],
          'jöpenn': [('jöpenna', False)],
          'jöpenns': [('jöpenna', False)],
          'jören': [('jör', False)],
          'jörens': [('jör', False)],
          'jörn': [('jörn', False)],
          'jörn-': [('jörn', False)],
          'jörnar': [('jörn', False)],
          'jörnarna': [('jörn', False)],
          'jörnen': [('jörn', False)],
          'jörnens': [('jörn', False)],
          'jörns': [('jörn', False)],
          'jörns-': [('jörn', False)],
          'jös': [('jö', False)],
          'jös-': [('jö', False)],
          'jöss': [('jösse', True)],
          'jöss-': [('jösse', True)],
          'jössen': [('jösse', True)],
          'jössens': [('jösse', True)],
          'jöt': [('jö', False)],
          'jöts': [('jö', False)],
          'k': [('k', True)],
          'k-': [('k', True)],
          'ka': [('ka', False)],
          'ka-': [('ka', False)],
          'kabackens': [('kabacke', False)],
          'kabb': [('kabb', False)],
          'kabb-': [('kabb', False)],
          'kabbens': [('kabb', False)],
          'kabbs': [('kabb', False)],
          'kabbs-': [('kabb', False)],
          'kaber': [('kab', False)],
          'kabers': [('kab', False)],
          'kablandet': [('kablande', True)],
          'kablandets': [('kablande', True)],
          'kackel': [('kackel', True)],
          'kackel-': [('kackel', False)],
          'kacklandets': [('kacklande', True)],
          'kadags': [('kadags', False)],
          'kadags-': [('kadags', False)],
          'kadamen': [('kadam', False)],
          'kadans': [('kadans', False)],
          'kadens': [('kadens', True)],
          'kader': [('kader', True)],
          'kader-': [('kader', True)],
          'kaders': [('kader', False)],
          'kadier': [('kadi', True)],
          'kadierna': [('kadi', True)],
          'kadiers': [('kadi', True)],
          'kadin': [('kadi', True)],
          'kadins': [('kadi', True)],
          'kadis': [('kadi', True)],
          'kadon': [('kado', False)],
          'kadorna': [('kado', False)],
          'kadornas': [('kado', False)],
          'kados-': [('kado', False)],
          'kadus': [('kadus', False)],
          'kadus-': [('kadus', False)],
          'kaffarnas': [('kaffare', False)],
          'kaffens': [('kaffe', True)],
          'kaftan': [('kaftan', True)],
          'kafts': [('kaft', False)],
          'kafts-': [('kaft', False)],
          'kage': [('kage', False)],
          'kage-': [('kage', False)],
          'kagen': [('kage', False)],
          'kagens': [('kage', False)],
          'kaget': [('kage', False)],
          'kagg': [('kagge', True)],
          'kagg-': [('kagge', True)],
          'kaggar': [('kagge', True)],
          'kaggarna': [('kagge', True)],
          'kaggs': [('kagge', True)],
          'kaggs-': [('kagge', True)],
          'kahäst': [('kahäst', False)],
          'kahäst-': [('kahäst', False)],
          'kahästar': [('kahäst', False)],
          'kahästarna': [('kahäst', False)],
          'kaj': [('kaj', True), ('kaja', True)],
          'kaj-': [('kaja', True), ('kaj', True)],
          'kajans': [('kaja', False)],
          'kajas': [('kaja', False)],
          'kajer': [('kaj', True)],
          'kajers': [('kaj', True)],
          'kajor': [('kaja', True)],
          'kajs': [('kaj', True), ('kaja', True)],
          'kajs-': [('kaja', True), ('kaj', True)],
          'kak': [('kaka', False)],
          'kak-': [('kaka', False)],
          'kaka': [('kaka', False)],
          'kakan': [('kaka', False)],
          'kakans': [('kaka', False)],
          'kakar': [('kakare', False)],
          'kakarna': [('kakare', False)],
          'kakas': [('kaka', False)],
          'kakets': [('kak', False)],
          'kakins': [('kaki', True)],
          'kaklandet': [('kaklande', True)],
          'kakors': [('kaka', False)],
          'kaks': [('kaka', False)],
          'kaks-': [('kaka', False)],
          'kalan': [('kala', False)],
          'kalandets': [('kalande', False)],
          'kalans': [('kala', False)],
          'kalar': [('kalare', False)],
          'kalar-': [('kalare', False)],
          'kalarens': [('kalare', False)],
          'kalarna': [('kalare', False)],
          'kalarnas': [('kalare', False)],
          'kalas': [('kalas', True)],
          'kalder': [('kald', False)],
          'kalders': [('kald', False)],
          'kale': [('kala', False)],
          'kale-': [('kala', False)],
          'kalet': [('kal', False)],
          'kalets': [('kal', False)],
          'kalgen': [('kalg', False)],
          'kalgens': [('kalg', False)],
          'kalie-': [('kalier', False)],
          'kaliens': [('kalie', False)],
          'kalier': [('kali', False)],
          'kalierna': [('kali', False)],
          'kaliernas': [('kali', False)],
          'kalin': [('kalin', False)],
          'kalis': [('kali', True)],
          'kalis-': [('kali', True)],
          'kalit': [('kali', True)],
          'kalits': [('kali', True)],
          'kalk': [('kalk', False)],
          'kalk-': [('kalk', False)],
          'kalkar': [('kalk', False)],
          'kalkarna': [('kalk', False)],
          'kalker': [('kalk', True)],
          'kalkers': [('kalk', True)],
          'kalks': [('kalk', False)],
          'kalks-': [('kalk', False)],
          'kall': [('kalla', True), ('kall', True)],
          'kall-': [('kall', True), ('kalla', True)],
          'kallan': [('kalla', True)],
          'kallanden': [('kallande', False)],
          'kallandens': [('kallande', False)],
          'kallandet': [('kallande', False)],
          'kallans': [('kalla', True)],
          'kallar': [('kallare', False)],
          'kallarna': [('kalle', False)],
          'kallarnas': [('kalle', False)],
          'kalle': [('kalla', True)],
          'kalle-': [('kalla', True)],
          'kallen': [('kall', False)],
          'kallens': [('kall', True)],
          'kallor': [('kalla', True)],
          'kallorna': [('kalla', True)],
          'kallras': [('kallras', True)],
          'kalls': [('kalla', True), ('kall', True)],
          'kalls-': [('kalla', True), ('kall', True)],
          'kallskänk': [('kallskänka', True), ('kallskänk', True)],
          'kallskänk-': [('kallskänka', True), ('kallskänk', True)],
          'kallskänks': [('kallskänka', True), ('kallskänk', True)],
          'kallskänks-': [('kallskänk', True), ('kallskänka', True)],
          'kalmars': [('kalm', False)],
          'kalsong': [('kalsonger', False)],
          'kalsong-': [('kalsonger', False)],
          'kalsonger': [('kalsonger', False)],
          'kalsongerna': [('kalsonger', True)],
          'kalsongernas': [('kalsonger', False)],
          'kalsongers': [('kalsonger', False)],
          'kalsongs': [('kalsonger', False)],
          'kaltans': [('kaltan', False)],
          'kalv': [('kalv', False)],
          'kalv-': [('kalv', False)],
          'kalvar': [('kalv', False)],
          'kalvarna': [('kalv', False)],
          'kalvarnas': [('kalv', False)],
          'kalvars': [('kalv', False)],
          'kalvs': [('kalv', False)],
          'kalvs-': [('kalv', False)],
          'kam': [('kam', False)],
          'kam-': [('kam', False)],
          'kamen': [('kamen', False)],
          'kamens': [('kamen', False)],
          'kamenten': [('kament', False)],
          'kamentens': [('kament', False)],
          'kamentet': [('kament', False)],
          'kaments-': [('kament', False)],
          'kamin': [('kamin', False)],
          'kamins': [('kamin', False)],
          'kammar': [('kam', True), ('kammare', True)],
          'kammarna': [('kam', True)],
          'kammarnas': [('kam', False)],
          'kamp': [('kamp', False)],
          'kamp-': [('kamp', False)],
          'kampar': [('kampare', True), ('kamp', True)],
          'kamparna': [('kampare', True), ('kamp', True)],
          'kamparnas': [('kampare', True), ('kamp', True)],
          'kampen': [('kamp', False)],
          'kampens': [('kamp', False)],
          'kamps': [('kamp', False)],
          'kamps-': [('kamp', False)],
          'kamrarna': [('kammare', False)],
          'kamrarnas': [('kammare', False)],
          'kamrars': [('kammare', False)],
          'kams': [('kams', True), ('kam', True)],
          'kams-': [('kams', True), ('kam', True)],
          'kan': [('kana', True), ('kan', True)],
          'kan-': [('kana', True), ('kan', True)],
          'kana': [('kana', True)],
          'kanan': [('kana', False)],
          'kanans': [('kana', True)],
          'kanar': [('kanare', False)],
          'kanarna': [('kanare', False)],
          'kanas': [('kana', True)],
          'kand': [('kand', True)],
          'kand-': [('kand', False)],
          'kandar': [('kandar', True)],
          'kandar-': [('kandar', True)],
          'kandarens': [('kandar', True)],
          'kandars': [('kandar', True)],
          'kandens': [('kande', False)],
          'kander': [('kand', False)],
          'kanders': [('kand', False)],
          'kandets': [('kande', False)],
          'kandis-': [('kandi', True)],
          'kandit': [('kandi', True)],
          'kandits': [('kandi', True)],
          'kands': [('kand', False)],
          'kands-': [('kand', False)],
          'kanelbull': [('kanelbulle', True), ('kanelbulla', True)],
          'kanelbull-': [('kanelbulla', True), ('kanelbulle', True)],
          'kanelbulle': [('kanelbulle', True), ('kanelbulla', True)],
          'kanelbulle-': [('kanelbulle', True), ('kanelbulla', True)],
          'kanelbulls': [('kanelbulle', True), ('kanelbulla', True)],
          'kanelbulls-': [('kanelbulle', True), ('kanelbulla', True)],
          'kanens': [('kan', False)],
          'kanets': [('kan', False)],
          'kaniker': [('kanik', True)],
          'kanikerna': [('kanik', True)],
          'kanikernas': [('kanik', True)],
          'kanikers': [('kanik', True)],
          'kanits': [('kanit', False)],
          'kanjon': [('kanjon', True)],
          'kank': [('kank', False)],
          'kank-': [('kank', False)],
          'kankar': [('kankare', False)],
          'kankar-': [('kankare', False)],
          'kankarna': [('kank', False)],
          'kankarnas': [('kank', False)],
          'kankars': [('kank', False)],
          'kanken': [('kank', False)],
          'kankens': [('kank', False)],
          'kankor': [('kank', False)],
          'kankorna': [('kank', False)],
          'kankornas': [('kank', False)],
          'kankors': [('kank', False)],
          'kanks': [('kank', False)],
          'kanks-': [('kank', False)],
          'kanmälningar': [('kanmälan', False)],
          'kanmälningarna': [('kanmälan', False)],
          'kanmälningarnas': [('kanmälan', False)],
          'kanmälningars': [('kanmälan', False)],
          'kann': [('kanna', False)],
          'kanne': [('kanna', False)],
          'kanne-': [('kanna', False)],
          'kannor': [('kanna', False)],
          'kannorna': [('kanna', False)],
          'kannornas': [('kanna', False)],
          'kannors': [('kanna', True)],
          'kanor': [('kana', False)],
          'kanordnar': [('kanorden', False)],
          'kanordnarna': [('kanorden', False)],
          'kanordnarnas': [('kanorden', False)],
          'kanorna': [('kana', False)],
          'kanornas': [('kana', False)],
          'kanors': [('kana', True)],
          'kans': [('kana', True), ('kan', True)],
          'kans-': [('kana', False)],
          'kansar': [('kans', False)],
          'kansarna': [('kans', False)],
          'kansars': [('kans', False)],
          'kansen': [('kans', False)],
          'kansens': [('kans', False)],
          'kanser': [('kans', False)],
          'kanserna': [('kans', False)],
          'kansernas': [('kans', False)],
          'kansers': [('kans', False)],
          'kansk': [('kanska', False)],
          'kansk-': [('kanska', False)],
          'kant': [('kant', False)],
          'kanta': [('kant', False)],
          'kantas': [('kant', False)],
          'kanten': [('kant', False)],
          'kantens': [('kant', False)],
          'kanter': [('kant', False)],
          'kanterna': [('kant', False)],
          'kanternas': [('kant', False)],
          'kanters': [('kant', False)],
          'kants-': [('kant', False)],
          'kaos': [('kaos', False)],
          'kaos-': [('kaos', True)],
          'kap': [('kap', False)],
          'kap-': [('kap', False)],
          'kapar': [('kapare', False)],
          'kaparens': [('kapare', False)],
          'kaparna': [('kapare', True)],
          'kaparnas': [('kapare', True)],
          'kapars': [('kap', False)],
          'kapets': [('kap', False)],
          'kapis': [('kapi', False)],
          'kapp': [('kappa', True), ('kapp', True), ('kappe', True)],
          'kapp-': [('kappa', True), ('kappe', True), ('kapp', True)],
          'kappar': [('kapp', True), ('kappe', True)],
          'kapparna': [('kappe', True), ('kapp', True)],
          'kapparnas': [('kappe', True), ('kapp', True)],
          'kappars': [('kapp', True), ('kappe', True)],
          'kappe': [('kappe', True), ('kappa', True)],
          'kappen': [('kappe', True), ('kapp', True)],
          'kappens': [('kappe', True), ('kapp', True)],
          'kapperna': [('kapp', False)],
          'kappernas': [('kapp', False)],
          'kappers': [('kapp', False)],
          'kapps': [('kappe', True), ('kappa', True), ('kapp', True)],
          'kapps-': [('kapp', True), ('kappa', True), ('kappe', True)],
          'kaps': [('kap', True)],
          'kaps-': [('kap', False)],
          'kapslandet': [('kapslande', True)],
          'kapslandets': [('kapslande', True)],
          'kar': [('kar', True), ('kara', True)],
          'kar-': [('kar', True), ('kara', True)],
          'karakteristik': [('karakteristika', True), ('karakteristik', True)],
          'karakteristik-': [('karakteristika', True), ('karakteristik', True)],
          'karakteristiks': [('karakteristika', True), ('karakteristik', True)],
          'karakteristiks-': [('karakteristika', True), ('karakteristik', True)],
          'karaktäristik': [('karaktäristika', True), ('karaktäristik', True)],
          'karaktäristik-': [('karaktäristika', True), ('karaktäristik', True)],
          'karaktäristiks': [('karaktäristika', True), ('karaktäristik', True)],
          'karaktäristiks-': [('karaktäristika', True), ('karaktäristik', True)],
          'karan': [('kara', False)],
          'karans': [('kara', False)],
          'karaten': [('karate', True), ('karat', True)],
          'karatens': [('karate', True), ('karat', True)],
          'karbon': [('karbon', True)],
          'karbons': [('karbon', True)],
          'kard': [('karda', True)],
          'kard-': [('karda', True)],
          'kardan': [('karda', True), ('kardan', True)],
          'kardans': [('karda', True), ('kardan', True)],
          'karde': [('karda', True)],
          'karde-': [('karda', True)],
          'karden': [('kard', False)],
          'kardens': [('kard', False)],
          'karder': [('kard', False)],
          'karderna': [('kard', False)],
          'kardernas': [('kard', False)],
          'karders': [('kard', False)],
          'kards': [('karda', True)],
          'kards-': [('karda', True)],
          'kare': [('kara', True)],
          'kare-': [('kara', True)],
          'karen': [('kar', False)],
          'karens': [('karens', True), ('kar', True)],
          'kares': [('kare', False)],
          'karet': [('karet', True), ('kar', True)],
          'karets': [('karet', True), ('kar', True)],
          'karfar': [('karfar', False)],
          'karfars': [('karfar', False)],
          'kargen': [('karg', False)],
          'kargens': [('karg', False)],
          'karian': [('karian', False)],
          'karians': [('karian', False)],
          'karie': [('karie', False)],
          'karie-': [('karie', False)],
          'karier': [('karie', False)],
          'karierna': [('karie', False)],
          'kariernas': [('karie', False)],
          'kariers': [('karie', False)],
          'karies': [('karies', True)],
          'karies-': [('karies', True)],
          'karin': [('karin', False)],
          'karit': [('kariter', True)],
          'kariter': [('kariter', True)],
          'kariterna': [('kariter', True)],
          'karits': [('kariter', True)],
          'karkas': [('karkas', True)],
          'karmar': [('karm', False)],
          'karmarna': [('karm', False)],
          'karmarnas': [('karm', False)],
          'karn': [('karn', False)],
          'karna': [('kare', False)],
          'karnas': [('k', False)],
          'karns': [('karn', False)],
          'karon': [('karoner', False)],
          'karoner': [('karoner', False)],
          'karonerna': [('karoner', False)],
          'karonernas': [('karoner', False)],
          'karoners': [('karoner', False)],
          'karp': [('karp', True)],
          'karp-': [('karp', True)],
          'karpar': [('karp', True)],
          'karpars': [('karp', True)],
          'karps': [('karp', False)],
          'karrock': [('karrock', False)],
          'kars': [('kar', True), ('kara', True)],
          'kars-': [('kar', True), ('kara', True)],
          'karsten': [('karst', True)],
          'kart': [('karta', True), ('kart', True)],
          'kart-': [('kart', True), ('karta', True)],
          'kartan': [('karta', True)],
          'kartans': [('karta', False)],
          'kartar': [('kart', False)],
          'kartars': [('kart', False)],
          'karten': [('kart', False)],
          'kartens': [('kart', False)],
          'karter': [('kart', False)],
          'karterna': [('kart', False)],
          'karters': [('kart', False)],
          'karts': [('karta', True), ('kart', True)],
          'karts-': [('kart', True), ('karta', True)],
          'karv': [('karv', False)],
          'karv-': [('karv', False)],
          'karvar': [('karv', False)],
          'karvarna': [('karv', False)],
          'karvarnas': [('karv', False)],
          'karvars': [('karv', False)],
          'karven': [('karv', False)],
          'karvens': [('karv', False)],
          'karvs': [('karv', False)],
          'karvs-': [('karv', False)],
          'kas': [('kase', True)],
          'kas-': [('kase', True)],
          'kasar': [('kase', True)],
          'kasarna': [('kase', True)],
          'kasarnas': [('kase', True)],
          'kasars': [('kase', False)],
          'kase': [('kase', False)],
          'kasen': [('kase', True)],
          'kasens': [('kase', True)],
          'kasern': [('kasern', False)],
          'kaserns': [('kasern', False)],
          'kasier': [('kasier', False)],
          'kasiernas': [('kasier', False)],
          'kasiers': [('kasier', False)],
          'kasin': [('kasin', False)],
          'kask': [('kask', True)],
          'kask-': [('kask', True)],
          'kaskarna': [('kask', False)],
          'kasm': [('kasm', False)],
          'kasm-': [('kasm', False)],
          'kasmer': [('kasm', False)],
          'kasmerna': [('kasm', False)],
          'kasmernas': [('kasm', False)],
          'kasmers': [('kasm', False)],
          'kass': [('kasse', True)],
          'kass-': [('kasse', False)],
          'kassar': [('kasse', False)],
          'kassarna': [('kasse', False)],
          'kassarnas': [('kasse', False)],
          'kasse': [('kasse', True), ('kassa', True)],
          'kasse-': [('kassa', False)],
          'kassen': [('kasse', True)],
          'kassens': [('kasse', True)],
          'kassor': [('kassa', False)],
          'kassorna': [('kassa', False)],
          'kassornas': [('kassa', False)],
          'kassors': [('kassa', False)],
          'kast-': [('kast', False)],
          'kastanjen': [('kastanje', True), ('kastanj', True)],
          'kastanjens': [('kastanje', True), ('kastanj', True)],
          'kastanjer': [('kastanje', True), ('kastanj', True)],
          'kastanjerna': [('kastanje', True), ('kastanj', True)],
          'kastanjernas': [('kastanje', True), ('kastanj', True)],
          'kastanjers': [('kastanje', True), ('kastanj', True)],
          'kastarnas': [('kastare', False)],
          'kasten': [('kast', False)],
          'kaster': [('kast', False)],
          'kasterna': [('kast', False)],
          'kasternas': [('kast', True)],
          'kasters': [('kast', True)],
          'kastor': [('kastor', True)],
          'kat': [('kat', True)],
          'kat-': [('kat', True)],
          'kata': [('kata', False)],
          'katan': [('kata', False)],
          'katarna': [('kate', False)],
          'katars': [('kate', False)],
          'katas': [('kata', False)],
          'katell': [('katell', False)],
          'katell-': [('katell', False)],
          'katells': [('katell', False)],
          'katen': [('kat', True)],
          'katens': [('kat', True)],
          'kates': [('kate', False)],
          'kates-': [('kate', False)],
          'katet': [('katet', True), ('kat', True)],
          'kateter': [('katet', True), ('kateter', True)],
          'kateters': [('kateter', True), ('katet', True)],
          'katets': [('katet', True), ('kat', True)],
          'kation': [('kation', False)],
          'kationen': [('kation', False)],
          'kations': [('kation', False)],
          'kativets': [('kativ', False)],
          'kator': [('kator', False)],
          'kators': [('kator', False)],
          'katos': [('kato', False)],
          'kats': [('katsa', True), ('katse', True), ('kat', True)],
          'kats-': [('katsa', True), ('katse', True)],
          'katsar': [('katse', True)],
          'katsarna': [('katse', True)],
          'katsarnas': [('katse', True)],
          'katse': [('katsa', True), ('katse', True)],
          'katsen': [('katse', True)],
          'katt': [('katta', True), ('katt', True)],
          'katt-': [('katta', True), ('katt', True)],
          'kattan': [('katta', False)],
          'kattans': [('katta', False)],
          'katte': [('katta', False)],
          'katte-': [('katta', True)],
          'katten': [('katten', True), ('katt', True)],
          'kattens': [('katten', True), ('katt', True)],
          'katter': [('katt', False)],
          'katters': [('katt', False)],
          'katts': [('katta', True), ('katt', True)],
          'katts-': [('katta', True), ('katt', True)],
          'kauriernas': [('kauri', True)],
          'kauriers': [('kauri', True)],
          'kaus': [('kaus', True)],
          'kaus-': [('kaus', True)],
          'kauser': [('kaus', True)],
          'kauserna': [('kaus', True)],
          'kausernas': [('kaus', True)],
          'kausers': [('kaus', True)],
          'kavaller': [('kavall', True)],
          'kavallerna': [('kavall', True)],
          'kavallernas': [('kavall', True)],
          'kavallers': [('kavall', True)],
          'kavalls': [('kavall', True)],
          'kavalls-': [('kavall', True)],
          'kavanden': [('kavande', False)],
          'kavandens': [('kavande', True)],
          'kaven': [('kav', False)],
          'kavens': [('kav', False)],
          'kavern': [('kavern', True)],
          'kavern-': [('kavern', True)],
          'kaverns': [('kavern', True)],
          'kaverns-': [('kavern', True)],
          'kavet': [('kav', False)],
          'kavets': [('kav', False)],
          'kavlar': [('kavel', True), ('kavle', True)],
          'kavlarna': [('kavle', True), ('kavel', True)],
          'kavlarnas': [('kavle', True), ('kavel', True)],
          'kavlars': [('kavel', True), ('kavle', True)],
          'kavlingen': [('kavling', True)],
          'kavlingens': [('kavling', False)],
          'kax': [('kaxe', True)],
          'kax-': [('kaxe', True)],
          'kaxar': [('kaxe', True)],
          'kaxarna': [('kaxe', True)],
          'kaxarnas': [('kaxe', True)],
          'kaxars': [('kaxe', True)],
          'kaxe': [('kaxe', True)],
          'kaxen': [('kaxe', True)],
          'kaxens': [('kaxe', True)],
          'kb': [('kb', False)],
          'kback': [('kbacke', False)],
          'kback-': [('kbacke', False)],
          'kbackar': [('kbacke', False)],
          'kbackarna': [('kbacke', False)],
          'kbackarnas': [('kbacke', False)],
          'kbackars': [('kbacke', False)],
          'kbacke': [('kbacke', False)],
          'kbacke-': [('kbacke', False)],
          'kbacken': [('kbacke', False)],
          'kbackens': [('kbacke', False)],
          'kbacks': [('kbacke', False)],
          'kbacks-': [('kbacke', False)],
          'kbagg': [('kbagge', False)],
          'kbagg-': [('kbagge', False)],
          'kbaggar': [('kbagge', False)],
          'kbaggarna': [('kbagge', False)],
          'kbaggarnas': [('kbagge', False)],
          'kbaggars': [('kbagge', False)],
          'kbaggen': [('kbagge', False)],
          'kbaggens': [('kbagge', False)],
          'kbaggs': [('kbagge', False)],
          'kbaggs-': [('kbagge', False)],
          'kbanan': [('kbana', False)],
          'kbanans': [('kbana', False)],
          'kbandets': [('kband', False)],
          'kbane': [('kbana', False)],
          'kbane-': [('kbana', False)],
          'kbarens': [('kbar', False)],
          'kbars': [('kbar', False)],
          'kben': [('kben', False)],
          'kbens': [('kben', False)],
          'kbens-': [('kben', False)],
          'kbete': [('kbete', False)],
          'kbeten': [('kbete', False)],
          'kbetens': [('kbete', False)],
          'kbil': [('kbil', False)],
          'kbilars': [('kbil', False)],
          'kbils': [('kbil', False)],
          'kbils-': [('kbil', False)],
          'kbit': [('kbit', False)],
          'kbits': [('kbit', False)],
          'kbits-': [('kbit', False)],
          'kblom': [('kblomma', False)],
          'kblom-': [('kblomma', False)],
          'kbloms': [('kblomma', False)],
          'kbloms-': [('kblomma', False)],
          'kbläck': [('kbläck', False)],
          'kbläck-': [('kbläck', False)],
          'kbläcks': [('kbläck', False)],
          'kbläcks-': [('kbläck', False)],
          'kblåsarna': [('kblåsare', False)],
          'kboj': [('kboj', False)],
          'kboj-': [('kboj', False)],
          'kbojar': [('kboj', False)],
          'kbojars': [('kboj', False)],
          'kbojs': [('kboj', False)],
          'kbojs-': [('kboj', False)],
          'kbomb': [('kbomb', False)],
          'kbomber': [('kbomb', False)],
          'kbomberna': [('kbomb', False)],
          'kbombernas': [('kbomb', False)],
          'kbombers': [('kbomb', False)],
          'kbombs': [('kbomb', False)],
          'kbombs-': [('kbomb', False)],
          'kbond': [('kbonde', False)],
          'kbond-': [('kbonde', False)],
          'kbondens': [('kbonde', False)],
          'kbonds': [('kbonde', False)],
          'kborgar': [('kborgare', False)],
          'kborgarna': [('kborgare', False)],
          'kborgarnas': [('kborgare', False)],
          'kborr': [('kborre', False)],
          'kborr-': [('kborre', False)],
          'kborrar': [('kborre', False)],
          'kborrarna': [('kborre', False)],
          'kborrarnas': [('kborre', False)],
          'kborrars': [('kborre', False)],
          'kborren': [('kborre', False)],
          'kborrens': [('kborre', False)],
          'kborrs': [('kborre', False)],
          'kborrs-': [('kborre', False)],
          'kborst': [('kborste', False)],
          'kborst-': [('kborste', False)],
          'kborsten': [('kborste', False)],
          'kborstens': [('kborste', False)],
          'kbot': [('kbo', False)],
          'kbots': [('kbo', False)],
          'kboxar': [('kbox', False)],
          'kboxarna': [('kbox', False)],
          'kboxarnas': [('kbox', False)],
          'kbrandens': [('kbrand', False)],
          'kbrons': [('kbro', False)],
          'kbryt': [('kbryt', False)],
          'kbrytar': [('kbrytare', False)],
          'kbrytarna': [('kbrytare', False)],
          'kbrytarnas': [('kbrytare', False)],
          'kbryten': [('kbryt', False)],
          'kbrytens': [('kbryt', False)],
          'kbryts': [('kbryt', False)],
          'kbryts-': [('kbryt', False)],
          'kbräds': [('kbräda', False)],
          'kbräds-': [('kbräda', False)],
          'kbråk': [('kbråk', False)],
          'kbråks': [('kbråk', False)],
          'kbråks-': [('kbråk', False)],
          'kbröst': [('kbröst', False)],
          'kbröst-': [('kbröst', False)],
          'kbull': [('kbulle', False)],
          'kbull-': [('kbulle', False)],
          'kbulle': [('kbulle', False)],
          'kbulle-': [('kbulle', False)],
          'kbulls': [('kbulle', False)],
          'kbulls-': [('kbulle', False)],
          'kbyx': [('kbyxa', False)],
          'kbyx-': [('kbyxa', False)],
          'kbyxornas': [('kbyxa', False)],
          'kbärs': [('kbär', False)],
          'kbärs-': [('kbär', False)],
          'kbåg': [('kbåge', False)],
          'kbåg-': [('kbåge', False)],
          'kbågs': [('kbåge', False)],
          'kbågs-': [('kbåge', False)],
          'kcell': [('kcell', False)],
          'kdagar': [('kdag', False)],
          'kdagarna': [('kdag', False)],
          'kdagarnas': [('kdag', False)],
          'kdagen': [('kdag', False)],
          'kdagens': [('kdag', False)],
          'kdags': [('kdag', False)],
          'kdags-': [('kdag', False)],
          'kdans': [('kdans', False)],
          'kdel': [('kdel', False)],
          'kdelar': [('kdelare', False)],
          'kdelarna': [('kdelare', False)],
          'kdelarnas': [('kdelare', False)],
          'kdelars': [('kdel', False)],
          'kdels': [('kdel', False)],
          'kdels-': [('kdel', False)],
          'kdoken': [('kdoke', False)],
          'kdokens': [('kdoke', False)],
          'kdomar': [('kdom', False)],
          'kdomarna': [('kdom', False)],
          'kdomarnas': [('kdom', False)],
          'kdomen': [('kdom', False)],
          'kdon': [('kdon', False)],
          'kdon-': [('kdon', False)],
          'kdons': [('kdon', False)],
          'kdons-': [('kdon', False)],
          'kdos': [('kdos', False)],
          'kdos-': [('kdos', False)],
          'kdots': [('kdot', False)],
          'kdramer': [('kdrama', False)],
          'kdramerna': [('kdrama', False)],
          'kdramernas': [('kdrama', False)],
          'kdropp': [('kdropp', False)],
          'kdropps': [('kdropp', False)],
          'kdropps-': [('kdropp', False)],
          'kear': [('ke', False)],
          'kearna': [('ke', False)],
          'kebanans': [('kebana', False)],
          'ked': [('ked', False)],
          'ked-': [('ked', False)],
          'kedarnas': [('ked', False)],
          'kede': [('kede', False)],
          'keden': [('ked', True)],
          'kedens': [('ked', True)],
          'kedes': [('kede', False)],
          'kedes-': [('kede', False)],
          'keds': [('ked', False)],
          'keds-': [('ked', False)],
          'keen': [('ke', False)],
          'keens': [('kee', False)],
          'keer': [('kee', False)],
          'keerna': [('kee', False)],
          'keernas': [('kee', False)],
          'keffekterna': [('keffekt', False)],
          'kegångarnas': [('kegång', False)],
          'kejsar': [('kejsar', True), ('kejsare', True)],
          'kejsar-': [('kejsar', True), ('kejsare', True)],
          'kejsarnas': [('kejsare', True)],
          'kejt': [('kejt', False)],
          'kejt-': [('kejt', False)],
          'kejtarnas': [('kejtare', False)],
          'kejten': [('kejt', False)],
          'kejtens': [('kejt', False)],
          'kejts': [('kejt', False)],
          'kejts-': [('kejt', False)],
          'kek': [('keka', False)],
          'kek-': [('keka', False)],
          'keke': [('keka', False)],
          'keke-': [('keka', False)],
          'keks': [('kek', False)],
          'keks-': [('kek', False)],
          'kel': [('kel', True)],
          'kel-': [('kel', True)],
          'kelanden': [('kelande', False)],
          'kelandens': [('kelande', False)],
          'kelandets': [('kelande', True)],
          'keldar': [('keld', False)],
          'keldarna': [('keld', False)],
          'keldarnas': [('keld', False)],
          'kelhake-': [('kelhake', False)],
          'keline': [('kelina', False)],
          'keline-': [('kelina', False)],
          'kelis': [('kelis', False)],
          'kelknippe': [('kelknippa', False)],
          'kelknippe-': [('kelknippe', False)],
          'kelkrokarnas': [('kelkrok', False)],
          'kelkurs-': [('kelkur', False)],
          'kelroller': [('kelroller', False)],
          'kelrollers': [('kelroller', False)],
          'kels': [('kel', True)],
          'kels-': [('kel', True)],
          'kelset': [('kelse', False)],
          'kelsets': [('kelse', False)],
          'kelspol-': [('kelspole', False)],
          'kelspolens': [('kelspole', False)],
          'kelställen': [('kelställ', False)],
          'kelställens': [('kelställ', False)],
          'kelstället': [('kelställ', False)],
          'kelställets': [('kelställ', False)],
          'kem': [('kem', True)],
          'kem-': [('kem', False)],
          'kemang': [('kemang', False)],
          'kemang-': [('kemang', False)],
          'kemanger': [('kemang', False)],
          'kemangerna': [('kemang', False)],
          'kemangernas': [('kemang', False)],
          'kemangers': [('kemang', False)],
          'kemangs': [('kemang', False)],
          'kemangs-': [('kemang', False)],
          'kemien': [('kemi', False)],
          'kemiens': [('kemi', False)],
          'kemier': [('kemi', False)],
          'kemierna': [('kemi', False)],
          'kemiernas': [('kemi', False)],
          'kemiers': [('kemi', False)],
          'kemis': [('kemi', False)],
          'kems': [('kem', False)],
          'kems-': [('kem', False)],
          'kena': [('ke', False)],
          'kenans': [('kena', False)],
          'kenas': [('ke', False)],
          'kenden': [('kend', False)],
          'kendens': [('kend', False)],
          'kendos': [('kendo', True)],
          'kene': [('kena', False)],
          'kene-': [('kena', False)],
          'kenet': [('ken', False)],
          'kenets': [('ken', False)],
          'kenheter': [('kenhet', False)],
          'kenheterna': [('kenhet', False)],
          'kenheternas': [('kenhet', False)],
          'kenheters': [('kenhet', False)],
          'kenhets': [('kenhet', False)],
          'kenhets-': [('kenhet', False)],
          'kenn': [('ken', False)],
          'kensanden': [('kensand', False)],
          'kensandens': [('kensand', False)],
          'kenskaper': [('kenskaper', False)],
          'kenskaperna': [('kenskaper', False)],
          'kenskapernas': [('kenskaper', False)],
          'kenskapers': [('kenskaper', False)],
          'kenskaps-': [('kenskap', False)],
          'kensteinar': [('kenstein', False)],
          'kensteinarna': [('kenstein', False)],
          'kepp': [('kepp', False)],
          'kepp-': [('kepp', False)],
          'keppar': [('keppare', False)],
          'kepparnas': [('keppare', False)],
          'keppen': [('kepp', False)],
          'keppens': [('kepp', False)],
          'kepps': [('kepp', False)],
          'kepps-': [('kepp', False)],
          'keps': [('keps', True)],
          'keps-': [('keps', True)],
          'kepsis': [('kepsis', False)],
          'ker-': [('ker', False)],
          'kerare': [('kerare', False)],
          'kerares': [('kerare', False)],
          'kerarna': [('kerare', False)],
          'kerarnas': [('kerare', False)],
          'kerbets': [('kerbeta', False)],
          'kerbitar': [('kerbit', False)],
          'kerbitarna': [('kerbit', False)],
          'kergärden': [('kergärde', False)],
          'kergärdens': [('kergärde', False)],
          'keri': [('keri', False)],
          'keri-': [('keri', False)],
          'kerier': [('keri', False)],
          'kerierna': [('keri', False)],
          'keriers': [('keri', False)],
          'keriet': [('keri', False)],
          'keris': [('keri', False)],
          'keris-': [('keri', False)],
          'kerit': [('keri', False)],
          'kerkist': [('kerkist', False)],
          'kerlack-': [('kerlacka', False)],
          'kerlacks': [('kerlacka', False)],
          'kerlacks-': [('kerlacka', False)],
          'kerman': [('kerman', False)],
          'kermans': [('kerman', False)],
          'kerren': [('kerren', False)],
          'kerrens': [('kerren', False)],
          'kers-': [('ker', False)],
          'kersarnas': [('ker', False)],
          'kersen': [('ker', False)],
          'kertens': [('kert', False)],
          'kerts': [('kert', False)],
          'kerts-': [('kert', False)],
          'kerärter': [('kerärter', False)],
          'kerärterna': [('kerärt', False)],
          'kerärternas': [('kerärt', False)],
          'kerärters': [('kerärt', False)],
          'kerärts': [('kerärter', False)],
          'kerärts-': [('kerärter', False)],
          'kes': [('ke', False)],
          'kes-': [('ke', False)],
          'kesarna': [('ke', False)],
          'kesarnas': [('ke', False)],
          'kesen': [('ke', False)],
          'kesens': [('ke', False)],
          'keson': [('keso', True)],
          'kesons': [('keso', True)],
          'kess': [('kess', False)],
          'kessens': [('kess', False)],
          'kesser': [('kess', False)],
          'kesserna': [('kess', False)],
          'kessernas': [('kess', False)],
          'kessers': [('kess', False)],
          'kester': [('kester', False)],
          'kestern': [('kester', False)],
          'kesterns': [('kester', False)],
          'kesters': [('kester', False)],
          'kestrar': [('kester', False)],
          'ketarnas': [('ket', False)],
          'keten': [('ket', False)],
          'ketens': [('ket', False)],
          'keter': [('ket', False)],
          'keteri': [('keteri', False)],
          'keteri-': [('keteri', False)],
          'keteris': [('keteri', False)],
          'keteris-': [('keteri', False)],
          'keters': [('ket', False)],
          'ketets': [('ket', False)],
          'ketidens': [('ketid', False)],
          'kets': [('k', False)],
          'kett': [('kett', False)],
          'kett-': [('kett', False)],
          'ketten': [('kett', False)],
          'ketter': [('kett', False)],
          'ketterna': [('kett', False)],
          'ketternas': [('kett', False)],
          'ketters': [('kett', False)],
          'ketts': [('kett', False)],
          'ketts-': [('kett', False)],
          'kevill': [('kevilla', False)],
          'kevill-': [('kevilla', False)],
          'keville': [('kevilla', False)],
          'keville-': [('kevilla', False)],
          'kevlar': [('kevlar', True)],
          'kfakta': [('kfakta', False)],
          'kfaktas': [('kfakta', False)],
          'kfasen': [('kfas', False)],
          'kfasens': [('kfas', False)],
          'kfat': [('kfat', False)],
          'kfaun': [('kfauna', False)],
          'kfaun-': [('kfauna', False)],
          'kfauns': [('kfauna', False)],
          'kfauns-': [('kfauna', False)],
          'kfel': [('kfel', False)],
          'kfels': [('kfel', False)],
          'kfels-': [('kfel', False)],
          'kfis': [('kfis', False)],
          'kfis-': [('kfis', False)],
          'kfiskar': [('kfisk', False)],
          'kfiskarnas': [('kfisk', False)],
          'kfjäll': [('kfjäll', False)],
          'kfjälls': [('kfjäll', False)],
          'kfjälls-': [('kfjäll', False)],
          'kflyt': [('kfly', False)],
          'kflyts': [('kfly', False)],
          'kfläck': [('kfläck', False)],
          'kfläcks': [('kfläck', False)],
          'kflödet': [('kflöde', False)],
          'kfnaskarnas': [('kfnasker', False)],
          'kformar': [('kform', False)],
          'kformarna': [('kform', False)],
          'kformarnas': [('kform', False)],
          'kfots': [('kfot', False)],
          'kfots-': [('kfötter', False)],
          'kframställanden': [('kframställan', False)],
          'kframställandena': [('kframställan', False)],
          'kframställandenas': [('kframställan', False)],
          'kframställandens': [('kframställan', False)],
          'kframställningar': [('kframställning', False)],
          'kframställningarna': [('kframställning', False)],
          'kframställningarnas': [('kframställning', False)],
          'kframställningars': [('kframställning', False)],
          'kfyrar': [('kfyr', False)],
          'kfyrarna': [('kfyr', False)],
          'kfång': [('kfång', False)],
          'kfång-': [('kfång', False)],
          'kfången': [('kfång', False)],
          'kfångens': [('kfång', False)],
          'kfångs': [('kfång', False)],
          'kfångs-': [('kfång', False)],
          'kförar': [('kförare', False)],
          'kförarna': [('kförare', False)],
          'kförarnas': [('kförare', False)],
          'kförlag': [('kförlag', False)],
          'kförlags': [('kförlag', False)],
          'kförlags-': [('kförlag', False)],
          'kförsäkringar': [('kförsäkring', False)],
          'kförsäkringarna': [('kförsäkring', False)],
          'kförsäkringarnas': [('kförsäkring', False)],
          'kförsäkringars': [('kförsäkring', False)],
          'kfötter': [('kfötter', False)],
          'kfötterna': [('kfötter', False)],
          'kfötternas': [('kfötter', False)],
          'kfötters': [('kfötter', False)],
          'kg-': [('kg', True)],
          'kgaserna': [('kgas', False)],
          'kgasernas': [('kgas', False)],
          'kgate': [('kgata', False)],
          'kgate-': [('kgata', False)],
          'kgats': [('kgata', False)],
          'kgiftet': [('kgift', False)],
          'kgiftets': [('kgift', False)],
          'kgifts': [('kgift', False)],
          'kgods': [('kgods', False)],
          'kgods-': [('kgods', False)],
          'kgrann': [('kgranne', False)],
          'kgrann-': [('kgranne', False)],
          'kgranns': [('kgranne', False)],
          'kgranns-': [('kgranne', False)],
          'kgrevar': [('kgreve', False)],
          'kgrevarna': [('kgreve', False)],
          'kgrevarnas': [('kgreve', False)],
          'kgrevars': [('kgreve', False)],
          'kgrevens': [('kgreve', False)],
          'kgrevs': [('kgreve', False)],
          'kgryt': [('kgryta', False)],
          'kgryt-': [('kgryta', False)],
          'kgryts': [('kgryta', False)],
          'kgryts-': [('kgryta', False)],
          'kgräns': [('kgräns', False)],
          'kgräns-': [('kgräns', False)],
          'kgubb': [('kgubbe', False)],
          'kgubbs': [('kgubbe', False)],
          'kgångar': [('kgång', False)],
          'kgångarna': [('kgång', False)],
          'kgångarnas': [('kgång', False)],
          'kh-': [('kh', False)],
          'khack': [('khacka', False)],
          'khack-': [('khacka', False)],
          'khackor': [('khacka', False)],
          'khacks': [('khacka', False)],
          'khacks-': [('khacka', False)],
          'khake': [('khake', False)],
          'khake-': [('khake', False)],
          'khaken': [('khake', False)],
          'khakens': [('khake', False)],
          'khamrar': [('khammare', False)],
          'khan': [('khan', True)],
          'khan-': [('khan', True)],
          'khandlarna': [('khandlare', False)],
          'khandlarnas': [('khandlare', False)],
          'khands': [('khand', False)],
          'khands-': [('khand', False)],
          'khanen': [('khan', True)],
          'khanens': [('khan', True)],
          'khans': [('khan', True)],
          'khar': [('khare', False)],
          'khar-': [('khare', False)],
          'kharen': [('khare', False)],
          'khas': [('khas', False)],
          'khasens': [('khas', False)],
          'khen': [('kh', False)],
          'khens': [('kh', False)],
          'kher': [('kh', False)],
          'kherna': [('kh', False)],
          'khernas': [('kh', False)],
          'khers': [('kh', False)],
          'kheter': [('khet', False)],
          'kheterna': [('khet', False)],
          'kheternas': [('khet', False)],
          'kheters': [('khet', False)],
          'khets': [('khet', False)],
          'khets-': [('khet', False)],
          'khimlen': [('khimmel', False)],
          'khmer': [('khmer', True)],
          'kholmar': [('kholmare', False)],
          'kholmarna': [('kholmare', False)],
          'kholmarnas': [('kholmare', False)],
          'khon': [('kho', False)],
          'khons': [('kho', False)],
          'khoparna': [('khop', False)],
          'khor': [('kha', False)],
          'khorna': [('kha', False)],
          'khornas': [('kha', False)],
          'khors': [('kha', False)],
          'khost': [('khosta', False)],
          'khost-': [('khosta', False)],
          'khots': [('khot', False)],
          'khs-': [('kh', False)],
          'khundars': [('khund', False)],
          'khus': [('khus', False)],
          'khuv': [('khuv', False)],
          'khuven': [('khuv', False)],
          'khuvens': [('khuv', False)],
          'khuvs': [('khuv', False)],
          'khuvs-': [('khuv', False)],
          'khylle': [('khylla', False)],
          'khylle-': [('khylla', False)],
          'khyvlar': [('khyvel', False)],
          'khyvlarna': [('khyvel', False)],
          'khyvlarnas': [('khyvel', False)],
          'khäfte': [('khäfte', False)],
          'khäften': [('khäfte', False)],
          'khål': [('khål', False)],
          'khåls': [('khål', False)],
          'khåls-': [('khål', False)],
          'khögskolan': [('khögskola', False)],
          'khögskolans': [('khögskola', False)],
          'ki': [('ki', False)],
          'ki-': [('ki', False)],
          'kiasmernas': [('kiasm', True)],
          'kick': [('kicka', True), ('kick', True)],
          'kick-': [('kicka', True), ('kick', True)],
          'kickar': [('kick', True)],
          'kickarna': [('kick', False)],
          'kickelsen': [('kickelse', False)],
          'kicket': [('kick', False)],
          'kicks': [('kicka', True), ('kick', True)],
          'kicks-': [('kicka', True), ('kick', True)],
          'kid': [('kid', True)],
          'kid-': [('kid', True)],
          'kida': [('kida', False)],
          'kidas': [('kida', False)],
          'kide': [('kida', False)],
          'kiden': [('kid', False)],
          'kidens': [('kid', False)],
          'kidet': [('kid', True)],
          'kidets': [('kid', True)],
          'kidon': [('kido', False)],
          'kidons': [('kido', False)],
          'kidos': [('kido', False)],
          'kids': [('kid', True), ('kids', True)],
          'kids-': [('kid', True)],
          'kien': [('ki', False)],
          'kiens': [('ki', False)],
          'kier': [('ki', False)],
          'kierna': [('ki', False)],
          'kiernas': [('ki', False)],
          'kiers': [('ki', False)],
          'kiesarna': [('kie', False)],
          'kiesarnas': [('kie', False)],
          'kiffer-': [('kiffer', False)],
          'kift': [('kift', False)],
          'kift-': [('kift', False)],
          'kiftarnas': [('kiftare', False)],
          'kifts': [('kift', False)],
          'kifts-': [('kift', False)],
          'kigheter': [('kighet', False)],
          'kigheterna': [('kighet', False)],
          'kigheternas': [('kighet', False)],
          'kigheters': [('kighet', False)],
          'kighets-': [('kighet', False)],
          'kikandens': [('kikande', False)],
          'kikar': [('kikare', False)],
          'kikarna': [('kikare', False)],
          'kikarnas': [('kikare', True)],
          'kikten': [('kikt', False)],
          'kiktens': [('kikt', False)],
          'kiktet': [('kikt', False)],
          'kikts': [('kikt', False)],
          'kikts-': [('kikt', False)],
          'kilandets': [('kilande', True)],
          'kilje': [('kilje', False)],
          'kiljs-': [('kilje', False)],
          'kill': [('kille', False)],
          'kill-': [('kille', True)],
          'killar': [('kille', False)],
          'killarna': [('kille', False)],
          'killarnas': [('kille', False)],
          'killen': [('kille', True)],
          'killens': [('kille', True)],
          'killer': [('kill', False)],
          'killerna': [('kill', False)],
          'killernas': [('kill', False)],
          'killers': [('kill', False)],
          'kills': [('kille', True)],
          'kills-': [('kille', False)],
          'kilo': [('kilo', False)],
          'kilon': [('kilo', True)],
          'kilons': [('kilo', True)],
          'kilots': [('kilo', True)],
          'kilt-': [('kilt', True)],
          'kilts': [('kilt', True)],
          'kilts-': [('kilt', True)],
          'kimmers': [('kimmer', False)],
          'kimåns': [('kimå', False)],
          'kin': [('kin', False)],
          'kina': [('kina', True)],
          'kinandens': [('kinande', False)],
          'kinans': [('kina', True)],
          'kinas': [('kina', True)],
          'kind': [('kind', True)],
          'kind-': [('kind', True)],
          'kinder': [('kind', True)],
          'kinderna': [('kind', False)],
          'kindernas': [('kind', True)],
          'kinders': [('kind', True)],
          'kinds': [('kind', True)],
          'kinds-': [('kind', True)],
          'kinets': [('kin', False)],
          'king': [('king', False)],
          'king-': [('king', False)],
          'kingar': [('king', False)],
          'kingarna': [('king', False)],
          'kingarnas': [('king', False)],
          'kingars': [('king', False)],
          'kingen': [('king', False)],
          'kingens': [('king', False)],
          'kinges': [('kinges', False)],
          'kinges-': [('kinges', False)],
          'kinget': [('king', False)],
          'kingrarnas': [('kingrare', False)],
          'kings': [('king', False)],
          'kings-': [('king', False)],
          'kingskor': [('kingska', False)],
          'kingskorna': [('kingska', False)],
          'kingskornas': [('kingska', False)],
          'kingskors': [('kingska', False)],
          'kini': [('kini', False)],
          'kini-': [('kini', False)],
          'kinier': [('kinier', False)],
          'kinierna': [('kinier', False)],
          'kinin': [('kinin', True)],
          'kinins': [('kinin', True)],
          'kinis': [('kini', False)],
          'kinister': [('kinist', False)],
          'kinisters': [('kinist', False)],
          'kink': [('kink', True)],
          'kink-': [('kink', True)],
          'kinks': [('kink', True)],
          'kinks-': [('kink', True)],
          'kinn-': [('kinn', False)],
          'kinnar': [('kinnare', False)],
          'kinnarnas': [('kinnare', False)],
          'kinne': [('kinna', False)],
          'kinne-': [('kinna', False)],
          'kinnens': [('kinn', False)],
          'kinnet': [('kinn', False)],
          'kinns': [('kinn', False)],
          'kinns-': [('kinn', False)],
          'kinon': [('kinon', False)],
          'kinons': [('kino', False)],
          'kinos': [('kino', False)],
          'kinos-': [('kinos', False)],
          'kinosens': [('kinos', False)],
          'kins': [('ki', False)],
          'kiparnas': [('kip', True)],
          'kirer': [('kir', False)],
          'kirerna': [('kir', False)],
          'kirernas': [('kir', False)],
          'kirers': [('kir', False)],
          'kirins': [('kiri', False)],
          'kiris': [('kiri', False)],
          'kiris-': [('kiri', False)],
          'kis': [('kis', True)],
          'kis-': [('kis', True)],
          'kisarna': [('kis', True)],
          'kisarnas': [('kis', True)],
          'kisen': [('kis', True)],
          'kisens': [('kis', True)],
          'kiskan': [('kiska', False)],
          'kiskans': [('kiska', False)],
          'kiske': [('kiska', False)],
          'kiske-': [('kiska', False)],
          'kismernas': [('kism', False)],
          'kiss': [('kisse', True), ('kiss', True)],
          'kiss-': [('kisse', True), ('kiss', True)],
          'kissarna': [('kisse', True)],
          'kissarnas': [('kisse', True)],
          'kisse': [('kisse', True)],
          'kisse-': [('kissa', False)],
          'kissen': [('kisse', True)],
          'kissens': [('kisse', True)],
          'kisser': [('kiss', False)],
          'kisserna': [('kiss', False)],
          'kissernas': [('kiss', False)],
          'kissers': [('kiss', False)],
          'kist': [('kista', False)],
          'kist-': [('kista', True)],
          'kistan': [('kista', True)],
          'kistans': [('kista', True)],
          'kiste': [('kista', False)],
          'kisten': [('kist', False)],
          'kistens': [('kist', False)],
          'kister': [('kist', False)],
          'kisterna': [('kist', False)],
          'kisternas': [('kist', False)],
          'kisters': [('kist', False)],
          'kistor': [('kista', False)],
          'kistors': [('kista', False)],
          'kit': [('kit', False)],
          'kita': [('kita', False)],
          'kitan': [('kita', False)],
          'kitarnas': [('kit', False)],
          'kitas': [('kita', False)],
          'kiternas': [('kit', False)],
          'kitet': [('kit', False)],
          'kitets': [('kit', False)],
          'kitis': [('kitis', False)],
          'kits': [('kit', False)],
          'kitt': [('kitt', False)],
          'kitt-': [('kitt', True)],
          'kitten': [('kitt', False)],
          'kittlar': [('kittel', True), ('kittlare', True)],
          'kittlarna': [('kittel', True), ('kittlare', True)],
          'kittlarnas': [('kittel', True), ('kittlare', True)],
          'kitts': [('kitt', False)],
          'kitts-': [('kitt', False)],
          'kiv': [('kiv', True)],
          'kiv-': [('kiv', True)],
          'kivarierna': [('kivarie', False)],
          'kivets': [('kiv', False)],
          'kivier': [('kivi', True)],
          'kivierna': [('kivi', True)],
          'kiviernas': [('kivi', True)],
          'kiviers': [('kivi', True)],
          'kivin': [('kivi', True)],
          'kivins': [('kivi', True)],
          'kivis': [('kivi', True)],
          'kivs': [('kiv', True)],
          'kivs-': [('kiv', True)],
          'kjack': [('kjacka', False)],
          'kjack-': [('kjacka', False)],
          'kjacks': [('kjacka', False)],
          'kjacks-': [('kjacka', False)],
          'kjan': [('kja', False)],
          'kjans': [('kja', False)],
          'kje': [('kja', False)],
          'kje-': [('kja', False)],
          'kjom': [('kjom', False)],
          'kjom-': [('kjom', False)],
          'kjoms': [('kjom', False)],
          'kjoms-': [('kjom', False)],
          'kjon': [('kjon', False)],
          'kjoner': [('kjon', False)],
          'kjonerna': [('kjon', False)],
          'kjonernas': [('kjon', False)],
          'kjoners': [('kjon', False)],
          'kjor': [('kja', False)],
          'kjorna': [('kja', False)],
          'kjornas': [('kja', False)],
          'kjors': [('kja', False)],
          'kjort': [('kjorta', False)],
          'kjort-': [('kjorta', False)],
          'kjorts-': [('kjorta', False)],
          'kjus': [('kjusa', False)],
          'kjus-': [('kjusa', False)],
          'kjuse': [('kjusa', False)],
          'kjut': [('kjut', False)],
          'kjut-': [('kjut', False)],
          'kjuten': [('kjut', False)],
          'kjutens': [('kjut', False)],
          'kjutet': [('kjut', False)],
          'kjutets': [('kjut', False)],
          'kk-': [('kk', False)],
          'kkammar': [('kkammare', False)],
          'kkams': [('kkam', False)],
          'kkams-': [('kkam', False)],
          'kkan': [('kka', False)],
          'kkans': [('kka', False)],
          'kkapp': [('kkappa', False)],
          'kkapp-': [('kkappa', False)],
          'kkappe': [('kkappa', False)],
          'kkapps': [('kkappa', False)],
          'kkapps-': [('kkappa', False)],
          'kkar': [('kk', False)],
          'kkarna': [('kk', False)],
          'kkars': [('kk', False)],
          'kkas': [('kka', False)],
          'kkasse': [('kkassa', False)],
          'kkasse-': [('kkasse', False)],
          'kken': [('kk', False)],
          'kkens': [('kk', False)],
          'kkisen': [('kkis', False)],
          'kkisens': [('kkis', False)],
          'kkist-': [('kkista', False)],
          'kkistan': [('kkista', False)],
          'kkistans': [('kkista', False)],
          'kklinikerna': [('kklinik', False)],
          'kklock': [('kklocka', False)],
          'kklubb': [('kklubb', False)],
          'kklubb-': [('kklubba', False)],
          'kklubbs': [('kklubb', False)],
          'kklubbs-': [('kklubb', False)],
          'kklädes': [('kkläder', False)],
          'kklädes-': [('kkläder', False)],
          'kknall': [('kknall', False)],
          'kknallar': [('kknall', False)],
          'kknallarna': [('kknall', False)],
          'kknallarnas': [('kknall', False)],
          'kknallars': [('kknall', False)],
          'kknallen': [('kknall', False)],
          'kknallens': [('kknall', False)],
          'kknalls': [('kknall', False)],
          'kknalls-': [('kknall', False)],
          'kknut': [('kknut', False)],
          'kknuts': [('kknut', False)],
          'kknuts-': [('kknut', False)],
          'kknät': [('kknä', False)],
          'kknäts': [('kknä', False)],
          'kkon': [('kko', False)],
          'kkons': [('kko', False)],
          'kkonst-': [('kkonst', False)],
          'kkonsterna': [('kkonst', False)],
          'kkonsternas': [('kkonst', False)],
          'kkonsters': [('kkonst', False)],
          'kkopp': [('kkopp', False)],
          'kkopp-': [('kkopp', False)],
          'kkoppar': [('kkopp', False)],
          'kkoppars': [('kkopp', False)],
          'kkopps': [('kkopp', False)],
          'kkopps-': [('kkopp', False)],
          'kkor': [('kko', False)],
          'kkors': [('kko', False)],
          'kkors-': [('kkors', False)],
          'kkos': [('kko', False)],
          'kkos-': [('kko', False)],
          'kkrans': [('kkrans', False)],
          'kkrans-': [('kkran', False)],
          'kkris': [('kkris', False)],
          'kkris-': [('kkris', False)],
          'kkrokarnas': [('kkrok', False)],
          'kkronan': [('kkrona', False)],
          'kkronans': [('kkrona', False)],
          'kkrons-': [('kkrona', False)],
          'kks': [('kk', False)],
          'kks-': [('kk', False)],
          'kkunskaper': [('kkunskap', False)],
          'kkunskaperna': [('kkunskap', False)],
          'kkunskapernas': [('kkunskap', False)],
          'kkunskaps': [('kkunskap', False)],
          'kkurs': [('kkurs', False)],
          'kkurs-': [('kkurs', False)],
          'kkärr': [('kkärra', False)],
          'kkärr-': [('kkärra', False)],
          'kkärrs': [('kkärra', False)],
          'kkärrs-': [('kkärra', False)],
          'kkår': [('kkår', False)],
          'kkåren': [('kkår', False)],
          'kkårens': [('kkår', False)],
          'kkårs': [('kkår', False)],
          'kkårs-': [('kkår', False)],
          'kköks': [('kkök', False)],
          'kköks-': [('kkök', False)],
          'kkör': [('kkör', False)],
          'kkörs-': [('kkör', False)],
          'kl': [('kl', True)],
          'kl-': [('kl', True)],
          'klabb': [('klabb', True), ('klabbe', True)],
          'klabb-': [('klabb', True), ('klabbe', True)],
          'klabbar': [('klabb', True), ('klabbe', True)],
          'klabbarna': [('klabbe', True), ('klabb', True)],
          'klabbarnas': [('klabbe', True), ('klabb', True)],
          'klabbars': [('klabb', True), ('klabbe', True)],
          'klabben': [('klabb', True), ('klabbe', True)],
          'klabbens': [('klabbe', True), ('klabb', True)],
          'klabbs': [('klabbe', True), ('klabb', True)],
          'klabbs-': [('klabb', True), ('klabbe', True)],
          'klabbsköt': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbsköt-': [('klabbsköt', True), ('klabbsköte', True)],
          'klabbskötar': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbskötarna': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbskötarnas': [('klabbsköt', True), ('klabbsköte', True)],
          'klabbskötars': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbsköten': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbskötens': [('klabbsköt', True), ('klabbsköte', True)],
          'klabbsköts': [('klabbsköte', True), ('klabbsköt', True)],
          'klabbsköts-': [('klabbsköte', True), ('klabbsköt', True)],
          'klack': [('klack', False)],
          'klackarnas': [('klack', False)],
          'klad': [('klad', False)],
          'klad-': [('klad', False)],
          'kladdar': [('kladd', True)],
          'kladdarna': [('kladd', True)],
          'kladdarnas': [('kladd', True)],
          'klads': [('klad', False)],
          'klads-': [('klada', False)],
          'klag': [('klag', False)],
          'klagan': [('klagan', True)],
          'klagar': [('klagare', False)],
          'klagarnas': [('klagare', False)],
          'klagen': [('klag', False)],
          'klagens': [('klag', False)],
          'klagerna': [('klager', False)],
          'klaget': [('klag', False)],
          'klagets': [('klage', False)],
          'klags': [('klag', False)],
          'klags-': [('klag', False)],
          'klam': [('klam', False)],
          'klam-': [('klam', False)],
          'klamat': [('klamat', False)],
          'klamats': [('klamat', False)],
          'klamen': [('klam', False)],
          'klamens': [('klam', False)],
          'klamer': [('klam', False)],
          'klamerna': [('klam', False)],
          'klamernas': [('klam', False)],
          'klamers': [('klam', False)],
          'klammen': [('klam', True)],
          'klammens': [('klam', True)],
          'klamp': [('klamp', True)],
          'klamp-': [('klamp', True)],
          'klamps': [('klamp', True)],
          'klamps-': [('klamp', True)],
          'klams': [('klam', False)],
          'klams-': [('klam', False)],
          'klan': [('klan', True)],
          'klan-': [('klan', True)],
          'klanden': [('klande', False)],
          'klandena': [('klande', False)],
          'klandenas': [('klande', False)],
          'klandens': [('klande', False)],
          'klander': [('klander', True)],
          'klanders': [('klander', True)],
          'klandet': [('klande', False)],
          'klandets': [('kland', False)],
          'klandrar': [('klandrare', True)],
          'klandrarna': [('klandrare', True)],
          'klandrarnas': [('klandrare', True)],
          'klaner': [('klan', True)],
          'klanerna': [('klan', True)],
          'klanernas': [('klan', True)],
          'klaners': [('klan', True)],
          'klangarna': [('klangare', False)],
          'klangarnas': [('klangare', False)],
          'klank': [('klank', True)],
          'klank-': [('klank', True)],
          'klanks': [('klank', True)],
          'klanks-': [('klank', True)],
          'klans': [('klan', True)],
          'klans-': [('klan', False)],
          'klant-': [('klant', True)],
          'klantarnas': [('klant', True)],
          'klants': [('klant', True)],
          'klants-': [('klant', True)],
          'klapp': [('klappa', True), ('klapp', True)],
          'klapp-': [('klappa', True), ('klapp', True)],
          'klappbräde': [('klappbräde', True), ('klappbräda', True)],
          'klapps': [('klappa', True), ('klapp', True)],
          'klapps-': [('klappa', True), ('klapp', True)],
          'klaranden': [('klarande', False)],
          'klarandens': [('klarande', False)],
          'klaren': [('klare', False)],
          'klas': [('klase', True)],
          'klas-': [('klase', False)],
          'klasarna': [('klase', False)],
          'klasarnas': [('klase', False)],
          'klasen': [('klase', True)],
          'klasens': [('klase', False)],
          'klassar': [('klassare', False)],
          'klassarna': [('klassare', False)],
          'klassarnas': [('klassare', False)],
          'klassiker': [('klassik', True), ('klassiker', True)],
          'klassikerna': [('klassik', True), ('klassiker', True)],
          'klassikernas': [('klassik', True), ('klassiker', True)],
          'klassikers': [('klassik', True), ('klassiker', True)],
          'klav': [('klav', True), ('klave', True)],
          'klav-': [('klave', True), ('klav', True)],
          'klavar': [('klave', True), ('klav', True)],
          'klavarna': [('klave', True), ('klav', True)],
          'klavarnas': [('klav', True), ('klave', True)],
          'klavars': [('klav', True), ('klave', True)],
          'klave': [('klave', True)],
          'klaven': [('klave', True), ('klav', True)],
          'klavens': [('klave', True), ('klav', True)],
          'klaver': [('klaver', True)],
          'klavers': [('klaver', True)],
          'klavs': [('klave', True), ('klav', True)],
          'klavs-': [('klave', True), ('klav', True)],
          'kle': [('kla', False)],
          'kle-': [('kla', False)],
          'klek': [('klek', False)],
          'klekar': [('klek', False)],
          'klekarna': [('klek', False)],
          'klekarnas': [('klek', False)],
          'kleken': [('klek', False)],
          'kleks-': [('klek', False)],
          'kler': [('kel', False)],
          'kler-': [('kler', False)],
          'klerna': [('kel', False)],
          'kleros': [('kleros', False)],
          'kleros-': [('kleros', False)],
          'klers': [('kel', False)],
          'klers-': [('kler', False)],
          'klesen': [('kles', False)],
          'klesens': [('kles', False)],
          'klet': [('klet', True)],
          'kletarnas': [('kletare', False)],
          'kletet': [('klet', True)],
          'klets': [('klet', False)],
          'klets-': [('klet', True)],
          'kleven': [('klev', True)],
          'klevens': [('klev', True)],
          'klevet': [('klev', True)],
          'klevets': [('klev', True)],
          'klevs': [('klev', True)],
          'kli': [('kli', False)],
          'kli-': [('kli', False)],
          'klick': [('klick', False)],
          'klickarnas': [('klick', False)],
          'klid-': [('klid', False)],
          'klider': [('klid', False)],
          'kliderna': [('klid', False)],
          'klidernas': [('klid', False)],
          'kliders': [('klid', False)],
          'klids': [('klid', False)],
          'kliets': [('kli', False)],
          'klifs-': [('klifs', True)],
          'klighets': [('klighet', False)],
          'klik': [('klika', False)],
          'klik-': [('klika', False)],
          'klike': [('klika', False)],
          'klike-': [('klika', False)],
          'kliks': [('klika', False)],
          'kliks-': [('klika', False)],
          'klimp': [('klimp', True)],
          'klimp-': [('klimp', False)],
          'klimps': [('klimp', False)],
          'klimps-': [('klimp', True)],
          'klin': [('klin', False)],
          'klin-': [('klin', False)],
          'klina': [('klina', False)],
          'klinas': [('klina', False)],
          'kline': [('klina', False)],
          'kline-': [('klina', False)],
          'klinen': [('klin', False)],
          'klinens': [('klin', False)],
          'kliner': [('klin', False)],
          'klinerna': [('klin', False)],
          'klinernas': [('klin', False)],
          'kliners': [('klin', False)],
          'kling': [('kling', True), ('klinga', True)],
          'kling-': [('klinga', True), ('kling', True)],
          'klingets': [('kling', True)],
          'klings': [('kling', True), ('klinga', True)],
          'klings-': [('klinga', True), ('kling', True)],
          'kliniker': [('kliniker', True), ('klinik', True)],
          'klinikerna': [('kliniker', True), ('klinik', True)],
          'klinikernas': [('kliniker', True), ('klinik', True)],
          'klinikers': [('kliniker', True), ('klinik', True)],
          'klink': [('klink', True), ('klinka', True)],
          'klink-': [('klink', True), ('klinka', True)],
          'klinks': [('klink', True), ('klinka', True)],
          'klinks-': [('klink', True), ('klinka', True)],
          'klins': [('klina', False)],
          'klins-': [('klina', False)],
          'klint-': [('klint', True)],
          'klints': [('klint', False)],
          'klipp': [('klippa', True), ('klipp', True)],
          'klipp-': [('klippa', True), ('klipp', True)],
          'klippar': [('klippare', False)],
          'klipparna': [('klippare', True)],
          'klipps': [('klippa', True), ('klipp', True)],
          'klipps-': [('klippa', True), ('klipp', True)],
          'klips-': [('klips', False)],
          'klir': [('klir', False)],
          'klir-': [('klir', False)],
          'klirs': [('klir', False)],
          'klirs-': [('klir', False)],
          'klis': [('kli', False)],
          'klis-': [('klis', False)],
          'klisen': [('klis', False)],
          'klisens': [('klis', False)],
          'klist': [('klist', False)],
          'klist-': [('klist', False)],
          'klister': [('klister', False)],
          'klisters': [('klister', True)],
          'klitt': [('klitta', True), ('klitter', True)],
          'klitt-': [('klitta', True), ('klitter', True)],
          'klitter': [('klitter', True)],
          'klitters': [('klitter', True)],
          'klitts': [('klitta', True), ('klitter', True)],
          'klitts-': [('klitta', True), ('klitter', True)],
          'klivs': [('kliv', False)],
          'klivs-': [('kliv', False)],
          'klo-': [('klo', False)],
          'klock': [('klocka', True)],
          'klock-': [('klocka', False)],
          'klockar': [('klockare', True)],
          'klockarna': [('klockare', True)],
          'klockarnas': [('klockare', True)],
          'klocks': [('klocka', False)],
          'klocks-': [('klocka', False)],
          'klog': [('klog', False)],
          'klog-': [('klog', False)],
          'klogen': [('klog', False)],
          'klogens': [('klog', False)],
          'kloger': [('klog', False)],
          'klogerna': [('klog', False)],
          'klogernas': [('klog', False)],
          'klogers': [('klog', False)],
          'klogs': [('klog', False)],
          'klogs-': [('klog', False)],
          'klon': [('klo', True), ('klon', True)],
          'klonen': [('klon', True)],
          'klonens': [('klon', False)],
          'kloner': [('klon', True)],
          'klonerna': [('klon', False)],
          'klonernas': [('klon', True)],
          'kloners': [('klon', False)],
          'klons': [('klon', True), ('klo', True)],
          'klopp': [('kloppa', False)],
          'klopp-': [('kloppa', False)],
          'klopps': [('kloppa', False)],
          'klopps-': [('klopp', False)],
          'klops': [('klop', False)],
          'klor': [('klo', True), ('klor', True)],
          'klor-': [('klor', True)],
          'kloren': [('klor', True)],
          'klorens': [('klor', True)],
          'klorna': [('klo', True)],
          'klornas': [('klo', True)],
          'klors': [('klo', True), ('klor', True)],
          'klossar': [('kloss', False)],
          'klossarna': [('kloss', False)],
          'klot': [('klot', True)],
          'klots': [('klots', True), ('klot', True)],
          'klots-': [('klots', True), ('klot', True)],
          'klotter': [('klotter', False)],
          'klotters': [('klotter', False)],
          'klottrar': [('klottrare', True)],
          'klottrarna': [('klottrare', False)],
          'klov': [('klove', True)],
          'klov-': [('klove', False)],
          'klovar': [('klove', True)],
          'klovarna': [('klove', True)],
          'klovarnas': [('klove', True)],
          'klovars': [('klove', False)],
          'kloven': [('klove', False)],
          'klovens': [('klove', True)],
          'klovs': [('klove', True)],
          'klovs-': [('klove', True)],
          'kls': [('kla', False)],
          'klubb': [('klubba', True), ('klubb', True)],
          'klubb-': [('klubb', True), ('klubba', True)],
          'klubbs': [('klubb', True), ('klubba', True)],
          'klubbs-': [('klubb', True), ('klubba', True)],
          'kluck': [('kluck', True)],
          'kluck-': [('kluck', True)],
          'klucks': [('kluck', True)],
          'klucks-': [('kluck', True)],
          'kluddar': [('kluddare', True), ('kludd', True)],
          'kluddarna': [('kluddare', True), ('kludd', True)],
          'kluddarnas': [('kluddare', True), ('kludd', True)],
          'kluster': [('kluster', True)],
          'klusterna': [('kluster', True)],
          'klusternas': [('kluster', True)],
          'klusters': [('kluster', True)],
          'klut': [('klut', True)],
          'klut-': [('klut', True)],
          'kluten': [('klut', False)],
          'kluts': [('klut', False)],
          'kluts-': [('klut', False)],
          'klyft': [('klyft', True), ('klyfta', True)],
          'klyft-': [('klyft', True), ('klyfta', True)],
          'klyfts': [('klyft', True), ('klyfta', True)],
          'klyfts-': [('klyft', True), ('klyfta', True)],
          'klys': [('klys', False)],
          'klys-': [('klys', True)],
          'klysen': [('klys', False)],
          'klysens': [('klys', False)],
          'klyset': [('klys', False)],
          'klysets': [('klys', True)],
          'klyvar': [('klyvare', True), ('klyv', True)],
          'klyvarna': [('klyvare', True), ('klyv', True)],
          'klyvarnas': [('klyv', True), ('klyvare', True)],
          'kläd': [('kläder', True)],
          'klädar': [('klädare', False)],
          'klädarna': [('klädare', False)],
          'klädarnas': [('klädare', False)],
          'klädes': [('kläder', True), ('kläde', True)],
          'klädes-': [('kläde', True), ('kläder', True)],
          'kläds': [('kläder', False)],
          'kläds-': [('kläder', False)],
          'kläggar': [('kläggare', False)],
          'kläggarna': [('kläggare', False)],
          'kläggarnas': [('kläggare', False)],
          'klämmar': [('klämmare', True), ('kläm', True)],
          'klämmarna': [('klämmare', True), ('kläm', True)],
          'klämmarnas': [('klämmare', True), ('kläm', True)],
          'klän': [('klä', False)],
          'kländer': [('kland', False)],
          'kländerna': [('kland', False)],
          'kländernas': [('kland', False)],
          'kländers': [('kland', False)],
          'klänge': [('klänge', True)],
          'klängen': [('klänge', True)],
          'klängens': [('klänge', True)],
          'klänget': [('klänge', True)],
          'klängs': [('klänge', True)],
          'klängs-': [('klänge', True)],
          'kläns': [('klä', False)],
          'kläsanden': [('kläsande', False)],
          'kläsarna': [('kläsare', False)],
          'kläsarnas': [('kläsare', False)],
          'klät': [('klä', False)],
          'kläts': [('klä', False)],
          'klåns': [('klån', False)],
          'klåns-': [('klån', False)],
          'klöje': [('klöja', False)],
          'klöje-': [('klöja', False)],
          'klön': [('klön', False)],
          'klös-': [('klös', True)],
          'km-': [('km', True)],
          'kmack': [('kmacka', False)],
          'kmack-': [('kmacka', False)],
          'kmacks': [('kmacka', False)],
          'kmacks-': [('kmacka', False)],
          'kmakar': [('kmakare', False)],
          'kmakarna': [('kmakare', False)],
          'kmakarnas': [('kmakare', False)],
          'kman': [('kman', False)],
          'kman-': [('kman', False)],
          'kmanarna': [('kman', False)],
          'kmaniernas': [('kmani', False)],
          'kmannen': [('kman', False)],
          'kmannens': [('kman', False)],
          'kmans': [('kman', False)],
          'kmas': [('kma', False)],
          'kmask': [('kmask', False)],
          'kmask-': [('kmask', False)],
          'kmaster': [('kmast', False)],
          'kmasters': [('kmast', False)],
          'kmat': [('kmat', False)],
          'kmaten': [('kmat', False)],
          'kmats': [('kmat', False)],
          'kmatt': [('kmatta', False)],
          'kmatt-': [('kmatta', False)],
          'kmatte': [('kmatta', False)],
          'kmatte-': [('kmatta', False)],
          'kmatts': [('kmatta', False)],
          'kmatts-': [('kmatta', False)],
          'kmen': [('kmen', False)],
          'kmens': [('kmen', False)],
          'kmer': [('kma', False)],
          'kmers': [('kma', False)],
          'kmetoden': [('kmetod', False)],
          'kmetodens': [('kmetod', False)],
          'kminister': [('kminister', False)],
          'kministers': [('kminister', False)],
          'kmixer': [('kmix', False)],
          'kmixerna': [('kmix', False)],
          'kmixernas': [('kmix', False)],
          'kmixers': [('kmix', False)],
          'kmjölk': [('kmjölk', False)],
          'kmjölk-': [('kmjölk', False)],
          'kmjölken': [('kmjölk', False)],
          'kmjölkens': [('kmjölk', False)],
          'kmjölks': [('kmjölk', False)],
          'kmjölks-': [('kmjölk', False)],
          'kmopp': [('kmoppe', False)],
          'kmopp-': [('kmoppe', False)],
          'kmoppar': [('kmoppe', False)],
          'kmopparna': [('kmoppe', False)],
          'kmopparnas': [('kmoppe', False)],
          'kmoppars': [('kmoppe', False)],
          'kmoppen': [('kmoppe', False)],
          'kmoppens': [('kmoppe', False)],
          'kmopps': [('kmoppe', False)],
          'kmopps-': [('kmoppe', False)],
          'kmurar': [('kmur', False)],
          'kmurarna': [('kmur', False)],
          'kmurarnas': [('kmur', False)],
          'kmus': [('kmus', False)],
          'kmyr': [('kmyra', False)],
          'kmyr-': [('kmyra', False)],
          'kmyrs': [('kmyra', False)],
          'kmyrs-': [('kmyra', False)],
          'kmän': [('kman', False)],
          'kmäns': [('kman', False)],
          'kmåns': [('kmåns', False)],
          'kmåns-': [('kmåns', False)],
          'kmöss': [('kmössa', False)],
          'kn': [('kna', False)],
          'kn-': [('kna', False)],
          'kna': [('kna', False)],
          'knack': [('knack', False)],
          'knack-': [('knack', True)],
          'knackar': [('knackare', False)],
          'knackarna': [('knackare', False)],
          'knackarnas': [('knackare', False)],
          'knacken': [('knack', True)],
          'knackens': [('knack', True)],
          'knacks': [('knack', False)],
          'knacks-': [('knack', False)],
          'knader': [('knad', False)],
          'knaderna': [('knad', False)],
          'knadernas': [('knad', False)],
          'knaders': [('knad', False)],
          'knads': [('knad', False)],
          'knads-': [('knad', False)],
          'knagg': [('knagge', True)],
          'knagg-': [('knagge', True)],
          'knaggar': [('knagge', True)],
          'knaggarna': [('knagge', True)],
          'knaggarnas': [('knagge', True)],
          'knaggars': [('knagge', True)],
          'knaggen': [('knagge', True)],
          'knaggens': [('knagge', True)],
          'knaggs': [('knagge', True)],
          'knaggs-': [('knagge', True)],
          'knall': [('knalle', True), ('knall', True)],
          'knall-': [('knall', True), ('knalle', True)],
          'knallar': [('knalle', True), ('knall', True)],
          'knallarna': [('knalle', True), ('knall', True)],
          'knallarnas': [('knalle', True), ('knall', True)],
          'knallars': [('knalle', True), ('knall', True)],
          'knallen': [('knall', True), ('knalle', True)],
          'knallens': [('knall', True), ('knalle', True)],
          'knalls': [('knalle', True), ('knall', True)],
          'knalls-': [('knalle', True), ('knall', True)],
          'knamn': [('knamn', False)],
          'knamn-': [('knamn', False)],
          'knamnen': [('knamn', False)],
          'knamnens': [('knamn', False)],
          'knamns': [('knamn', False)],
          'knamns-': [('knamn', False)],
          'knanden': [('knande', False)],
          'knap': [('knape', True), ('knap', True)],
          'knap-': [('knape', True), ('knap', True)],
          'knapar': [('knape', True), ('knap', True)],
          'knaparna': [('knape', True), ('knap', True)],
          'knaparnas': [('knape', True), ('knap', True)],
          'knapars': [('knape', True), ('knap', True)],
          'knapen': [('knap', True), ('knape', True)],
          'knapens': [('knap', True), ('knape', True)],
          'knapparnas': [('knapp', False)],
          'knaps': [('knape', True), ('knap', True)],
          'knaps-': [('knape', True), ('knap', True)],
          'knar-': [('knare', False)],
          'knaren': [('knare', False)],
          'knarens': [('knare', False)],
          'knarna': [('ken', False)],
          'knarnas': [('ken', False)],
          'knars': [('ken', False)],
          'knas': [('kna', False)],
          'knaster': [('knaster', True)],
          'knasterna': [('knaster', True)],
          'knasternas': [('knaster', True)],
          'knasters': [('knaster', True)],
          'knatt': [('knatte', True)],
          'knatt-': [('knatte', True)],
          'knattarnas': [('knatte', True)],
          'knatten': [('knatte', True)],
          'knattens': [('knatte', True)],
          'knatts': [('knatte', True)],
          'knatts-': [('knatte', True)],
          'kne': [('kna', False)],
          'kne-': [('kne', False)],
          'knegen': [('kneg', True)],
          'knegens': [('kneg', True)],
          'knektar': [('knekt', False)],
          'knektars': [('knekt', False)],
          'knen': [('kne', False)],
          'knens': [('ken', False)],
          'kneorden': [('kneord', False)],
          'kneordens': [('kneord', False)],
          'knet': [('ken', False)],
          'knets': [('ken', False)],
          'knickarnas': [('knick', False)],
          'knickers': [('knickers', True)],
          'knik': [('knik', False)],
          'knik-': [('knik', False)],
          'kniks': [('knik', False)],
          'kniks-': [('knik', False)],
          'knin': [('knin', False)],
          'knin-': [('knin', False)],
          'kninen': [('knin', False)],
          'kninens': [('knin', False)],
          'kninet': [('knin', False)],
          'kninets': [('knin', False)],
          'knins': [('knin', False)],
          'knip': [('knip', True), ('knipa', True)],
          'knip-': [('knip', True), ('knipa', True)],
          'knipp': [('knippa', True), ('knippe', True)],
          'knipp-': [('knippe', True), ('knippa', True)],
          'knippe': [('knippa', True), ('knippe', True)],
          'knippe-': [('knippa', True)],
          'knipps': [('knippa', True), ('knippe', True)],
          'knipps-': [('knippe', True), ('knippa', True)],
          'knips': [('knipa', True), ('knip', True)],
          'knips-': [('knip', True), ('knipa', True)],
          'knisse': [('knisse', False)],
          'knisse-': [('knisse', False)],
          'knog': [('knog', True), ('knoge', True)],
          'knog-': [('knog', True), ('knoge', True)],
          'knogar': [('knoge', True), ('knogare', True)],
          'knogarna': [('knogare', True), ('knoge', True)],
          'knogarnas': [('knoge', True), ('knogare', True)],
          'knogen': [('knog', True), ('knoge', True)],
          'knogens': [('knoge', True), ('knog', True)],
          'knogs': [('knog', True), ('knoge', True)],
          'knogs-': [('knog', True), ('knoge', True)],
          'knopp': [('knopp', False)],
          'knopp-': [('knopp', False)],
          'knopparnas': [('knopp', False)],
          'knopps': [('knopp', False)],
          'knopps-': [('knopp', False)],
          'knops': [('knop', False)],
          'knops-': [('knop', False)],
          'knor': [('kna', False)],
          'knorna': [('kna', False)],
          'knornas': [('kna', False)],
          'knors': [('kna', False)],
          'knos': [('knos', False)],
          'knot': [('knot', True), ('knota', True)],
          'knot-': [('knot', True), ('knota', True)],
          'knots': [('knota', True), ('knot', True)],
          'knots-': [('knot', True), ('knota', True)],
          'knotter': [('knotter', True), ('knottra', True)],
          'knotter-': [('knottra', True), ('knotter', True)],
          'knotters': [('knotter', True)],
          'kns': [('kna', False)],
          'kns-': [('kna', False)],
          'knut': [('knuta', True), ('knut', True)],
          'knut-': [('knut', True), ('knuta', True)],
          'knuts': [('knuta', True), ('knut', True)],
          'knuts-': [('knuta', True), ('knut', True)],
          'knutt': [('knutte', True)],
          'knutt-': [('knutte', True)],
          'knuttars': [('knutte', True)],
          'knutten': [('knutte', False)],
          'knutts': [('knutte', False)],
          'knyckel': [('knycklar', False)],
          'knyckel-': [('knycklar', False)],
          'knyckels': [('knycklar', False)],
          'knyckels-': [('knycklar', False)],
          'knycklar': [('knycklar', False)],
          'knycklarna': [('knycklar', False)],
          'knycklarnas': [('knycklar', False)],
          'knycklars': [('knycklar', False)],
          'knyts': [('knyte', True)],
          'knytt': [('knytt', False)],
          'knytts': [('knytt', False)],
          'knytts-': [('knytt', False)],
          'knäckar': [('knäck', True)],
          'knäckarna': [('knäck', True)],
          'knäckarnas': [('knäck', True)],
          'knäppar': [('knäpp', True), ('knäppare', True)],
          'knäpparna': [('knäppare', True), ('knäpp', True)],
          'knäpparnas': [('knäppare', True), ('knäpp', True)],
          'knäppe': [('knäppe', False)],
          'knäppe-': [('knäppe', False)],
          'knäppen': [('knäpp', True), ('knäppe', True)],
          'knäppens': [('knäppe', True), ('knäpp', True)],
          'knäppet': [('knäppe', False)],
          'knäs': [('knä', False)],
          'knäs-': [('knä', False)],
          'knät': [('knä', True)],
          'knäts': [('knä', True)],
          'knös': [('knös', True)],
          'knös-': [('knös', True)],
          'ko': [('ko', False)],
          'ko-': [('ko', True)],
          'kobb-': [('kobbe', True)],
          'kobbar': [('kobbe', True)],
          'kobbarna': [('kobbe', True)],
          'kobbarnas': [('kobbe', True)],
          'kobben': [('kobbe', True)],
          'kobblar': [('kobbel', True)],
          'kobblarna': [('kobbel', True)],
          'kobblarnas': [('kobbel', True)],
          'kobbs': [('kobbe', True)],
          'kobbs-': [('kobbe', True)],
          'koben': [('koben', False)],
          'kobens': [('koben', False)],
          'kobin': [('kobin', False)],
          'kock': [('kock', True), ('kocka', True)],
          'kock-': [('kock', True), ('kocka', True)],
          'kockar': [('kock', False)],
          'kockarna': [('kock', False)],
          'kocken': [('kock', False)],
          'kockens': [('kock', False)],
          'kocker': [('kock', True)],
          'kockers': [('kock', True)],
          'kocks': [('kocka', True), ('kock', True)],
          'kocks-': [('kocka', True), ('kock', True)],
          'kodan': [('kodag', False)],
          'kodans': [('kodag', False)],
          'kodans-': [('kodans', False)],
          'kodar': [('kodag', False)],
          'kodarna': [('kodag', False)],
          'kodarnas': [('kodag', False)],
          'kodars': [('kodag', False)],
          'koden': [('kod', False)],
          'kodens': [('kod', False)],
          'koders': [('kod', False)],
          'kods': [('kod', False)],
          'kods-': [('kod', False)],
          'koff': [('koff', True)],
          'koff-': [('koff', True)],
          'koffar': [('koff', True)],
          'koffarna': [('koff', True)],
          'koffs': [('koff', True)],
          'koffs-': [('koff', True)],
          'kogen': [('kogen', False)],
          'kogens': [('kogen', False)],
          'koger': [('koger', False)],
          'kogerna': [('koger', True)],
          'kogernas': [('koger', True)],
          'kogers': [('koger', False)],
          'koggarna': [('kogg', True)],
          'koggarnas': [('kogg', True)],
          'kogrens': [('koger', True)],
          'kohag': [('kohage', True)],
          'kohag-': [('kohage', True)],
          'kohagen': [('kohage', True)],
          'kohagens': [('kohage', True)],
          'kohags': [('kohage', True)],
          'kohags-': [('kohage', True)],
          'koinets': [('koine', True)],
          'koj': [('koja', True), ('koj', True)],
          'koj-': [('koja', True), ('koj', True)],
          'kojan': [('koja', False)],
          'kojans': [('koja', False)],
          'kojar': [('kojare', False)],
          'kojar-': [('kojare', False)],
          'kojarens': [('kojare', False)],
          'kojarna': [('kojare', False)],
          'kojarnas': [('kojare', False)],
          'kojets': [('koj', False)],
          'kojs': [('koj', True), ('koja', True)],
          'kojs-': [('koja', True), ('koj', True)],
          'kok': [('koka', True), ('kok', True)],
          'kok-': [('koka', True), ('kok', True)],
          'kokan': [('koka', True)],
          'kokar': [('kokare', False)],
          'kokarens': [('kokare', False)],
          'kokarna': [('kokare', False)],
          'kokarnas': [('kokare', False)],
          'kokerit': [('kokeri', False)],
          'kokets': [('kok', False)],
          'kokos': [('kokos', True)],
          'koks': [('koks', True), ('koka', True), ('kok', True)],
          'koks-': [('koka', True), ('kok', True), ('koks', True)],
          'kol': [('kol', True)],
          'kol-': [('kol', True)],
          'kolan': [('kola', True)],
          'kolans': [('kola', True)],
          'kolar': [('kolare', True)],
          'kolar-': [('kolare', True)],
          'kolarens': [('kolare', True)],
          'kolarna': [('kolare', True)],
          'kolarnas': [('kolare', True)],
          'kolat': [('kola', True)],
          'kolats': [('kola', True)],
          'kolerans': [('kolera', True)],
          'kolets': [('kol', False)],
          'koli': [('koli', False)],
          'kolien': [('koli', False)],
          'koliens': [('koli', False)],
          'koliker': [('koliker', False)],
          'kolikerna': [('koliker', False)],
          'kolikernas': [('koliker', False)],
          'kolikers': [('koliker', False)],
          'kolins': [('koli', False)],
          'kolios': [('kolios', False)],
          'kolis': [('koli', False)],
          'kolk': [('kolk', False)],
          'kolk-': [('kolk', False)],
          'kolkarnas': [('kolkare', False)],
          'kolks': [('kolk', False)],
          'kolks-': [('kolk', False)],
          'koll': [('koll', False)],
          'koll-': [('koll', True)],
          'kollagen': [('kollage', True)],
          'kollagens': [('kollage', True)],
          'kollar': [('koll', True)],
          'kollarna': [('koll', False)],
          'kollarnas': [('koll', False)],
          'kollars': [('koll', True)],
          'kollen': [('koll', False)],
          'kollens': [('koll', False)],
          'kollon': [('kollo', True)],
          'kollons': [('kollo', True)],
          'kolls': [('koll', False)],
          'kolls-': [('koll', False)],
          'kolm': [('kolm', True)],
          'kolm-': [('kolm', True)],
          'kolmen': [('kolm', True)],
          'kolor': [('kola', True)],
          'kolors': [('kola', True)],
          'kols': [('kol', True)],
          'kols-': [('kol', True)],
          'kolt-': [('kolt', False)],
          'kolts': [('kolt', True)],
          'kolts-': [('kolt', True)],
          'kolv': [('kolv', False)],
          'kolv-': [('kolv', False)],
          'kolvs': [('kolv', False)],
          'kolvs-': [('kolv', False)],
          'kom': [('komma', False)],
          'kom-': [('komma', False)],
          'koman': [('koma', False)],
          'komanier': [('komani', False)],
          'komanierna': [('komani', False)],
          'komaniernas': [('komani', False)],
          'komaniers': [('komani', False)],
          'komans': [('koma', False)],
          'komans-': [('koman', False)],
          'komat': [('koma', True)],
          'komats': [('koma', True)],
          'komb': [('komb', False)],
          'komb-': [('komb', False)],
          'komben': [('komb', False)],
          'kombens': [('komb', False)],
          'komber': [('komb', False)],
          'komberna': [('komb', False)],
          'kombernas': [('komb', False)],
          'kombers': [('komb', False)],
          'kombin': [('kombi', True)],
          'kombs': [('komb', False)],
          'kombs-': [('komb', False)],
          'komen': [('kom', False)],
          'komens': [('kom', False)],
          'komet': [('komet', True)],
          'kometer': [('komet', True)],
          'kometers': [('komet', True)],
          'komets': [('komet', True)],
          'komiker': [('komiker', False)],
          'komikerna': [('komiker', True)],
          'komikernas': [('komiker', True)],
          'komikers': [('komiker', False)],
          'kommarna': [('kom', False)],
          'komme': [('komma', False)],
          'komme-': [('komma', False)],
          'kommunfullmäktige': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kommunfullmäktigen': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kommunfullmäktigena': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kommunfullmäktigenas': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kommunfullmäktigens': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kommunfullmäktiges': [('kommunfullmäktig', True), ('kommunfullmäktige', True)],
          'kompars': [('kompars', True)],
          'komponents': [('komponent', True)],
          'komponents-': [('komponent', False)],
          'kompositer': [('komposit', True), ('kompositum', True)],
          'kompositerna': [('komposit', True), ('kompositum', True)],
          'kompositernas': [('kompositum', True), ('komposit', True)],
          'kompositers': [('komposit', True), ('kompositum', True)],
          'kområdets': [('kområde', False)],
          'koms': [('komma', False)],
          'koms-': [('kom', False)],
          'komsen': [('kom', False)],
          'komsens': [('kom', False)],
          'komst': [('komst', False)],
          'kon': [('kona', True), ('kon', True), ('ko', True)],
          'kon-': [('kona', True), ('kon', True)],
          'kona': [('kona', True)],
          'konan': [('kona', False)],
          'konans': [('kona', True)],
          'konarna': [('konare', False)],
          'konarnas': [('konare', False)],
          'konas': [('kona', True)],
          'kond': [('kond', False)],
          'kond-': [('kond', False)],
          'konden': [('kond', False)],
          'kondens': [('kondens', True)],
          'konder': [('kond', False)],
          'konders': [('kond', False)],
          'kondor': [('kondor', True)],
          'kondors': [('kondor', True)],
          'konds': [('kond', False)],
          'kong': [('kong', False)],
          'kong-': [('kong', False)],
          'konger': [('kong', False)],
          'kongerna': [('kong', False)],
          'kongernas': [('kong', False)],
          'kongers': [('kong', False)],
          'kongs': [('kong', False)],
          'kongs-': [('kong', False)],
          'koni': [('koni', False)],
          'koni-': [('koni', False)],
          'konien': [('koni', False)],
          'koniens': [('koni', False)],
          'konin': [('koni', False)],
          'konins': [('koni', False)],
          'konis': [('koni', False)],
          'konomens': [('konom', False)],
          'kons': [('kon', True), ('ko', True), ('kona', True)],
          'kons-': [('kona', True), ('kon', True)],
          'konsort': [('konsorter', True)],
          'konsorter': [('konsorter', True)],
          'konsorterna': [('konsorter', True)],
          'konsorternas': [('konsorter', True)],
          'konsorters': [('konsorter', True)],
          'konsorts': [('konsorter', True)],
          'konsorts-': [('konsorter', True)],
          'konst': [('konst', False)],
          'konst-': [('konst', True)],
          'konster': [('konst', True)],
          'konsterna': [('konst', True)],
          'konsternas': [('konst', True)],
          'konsters': [('konst', True)],
          'konter': [('kont', True)],
          'konters': [('kont', False)],
          'konvaljen': [('konvalj', True), ('konvalje', True)],
          'konvaljens': [('konvalj', True), ('konvalje', True)],
          'konvaljer': [('konvalj', True), ('konvalje', True)],
          'konvaljerna': [('konvalje', True), ('konvalj', True)],
          'konvaljernas': [('konvalj', True), ('konvalje', True)],
          'konvaljers': [('konvalj', True), ('konvalje', True)],
          'kopan': [('kopa', False)],
          'kopans': [('kopa', False)],
          'koparnas': [('kop', False)],
          'kopas': [('kopa', False)],
          'kope': [('kope', False)],
          'kope-': [('kope', False)],
          'kopen': [('kope', False)],
          'kopens': [('kope', False)],
          'kopier': [('kopi', False)],
          'kopierna': [('kopi', False)],
          'kopiernas': [('kopi', False)],
          'kopiers': [('kopi', False)],
          'kopins': [('kopi', False)],
          'kopp': [('koppa', True), ('kopp', True)],
          'kopp-': [('koppa', True), ('kopp', True)],
          'koppar': [('koppar', True), ('kopp', True)],
          'koppar-': [('koppar', True)],
          'kopparna': [('kopp', False)],
          'koppars': [('koppar', True), ('kopp', True)],
          'koppe': [('koppa', False)],
          'koppe-': [('koppa', False)],
          'koppen': [('kopp', False)],
          'koppens': [('kopp', False)],
          'koppor': [('koppa', True)],
          'kopporna': [('koppa', True)],
          'koppornas': [('koppa', False)],
          'koppors': [('koppa', False)],
          'kopps': [('koppa', True), ('kopp', True)],
          'kopps-': [('koppa', True), ('kopp', True)],
          'kopras': [('kopra', True)],
          'kopter': [('kopt', True), ('kopter', True)],
          'kopterna': [('kopt', True), ('kopter', True)],
          'kopternas': [('kopt', True), ('kopter', True)],
          'kopters': [('kopt', True), ('kopter', True)],
          'kopulas': [('kopula', True)],
          'kopås': [('kopåse', False)],
          'kopås-': [('kopåse', False)],
          'kor': [('ko', True), ('kor', True)],
          'korans': [('koran', True)],
          'koras': [('koras', False)],
          'kord': [('korda', True), ('kord', True)],
          'kord-': [('korda', True), ('kord', True)],
          'kordans': [('korda', True)],
          'korden': [('kord', False)],
          'kordens': [('kord', True)],
          'korder': [('kord', False)],
          'korderna': [('kord', False)],
          'kordernas': [('kord', False)],
          'korders': [('kord', False)],
          'kordnar': [('korden', False)],
          'kordnarna': [('korden', False)],
          'kordnarnas': [('korden', False)],
          'kords': [('korda', True), ('kord', True)],
          'kords-': [('korda', True), ('kord', True)],
          'koret': [('kor', True)],
          'korets': [('kor', True)],
          'korgar': [('korg', False)],
          'korgarna': [('korg', False)],
          'korgarnas': [('korg', False)],
          'korgen': [('korg', False)],
          'korgens': [('korg', False)],
          'kori': [('kori', False)],
          'kori-': [('kori', False)],
          'koriens': [('kori', False)],
          'koriken': [('korike', False)],
          'korikens': [('korike', False)],
          'korins': [('kori', False)],
          'korinter': [('korint', True), ('korinter', True)],
          'korinterna': [('korint', True), ('korinter', True)],
          'korinternas': [('korint', True), ('korinter', True)],
          'korinters': [('korint', True), ('korinter', True)],
          'koris': [('kori', False)],
          'kork': [('kork', False)],
          'korkar': [('kork', False)],
          'korkarna': [('kork', False)],
          'korn': [('korn', False)],
          'korn-': [('korn', False)],
          'korna': [('ko', False)],
          'kornas': [('ko', False)],
          'kornen': [('korn', False)],
          'kornens': [('korn', False)],
          'korns': [('korn', False)],
          'korns-': [('korn', False)],
          'koron': [('korona', True)],
          'korons': [('korona', True)],
          'koros': [('koros', False)],
          'koros-': [('koros', False)],
          'korp': [('korp', True)],
          'korp-': [('korp', True)],
          'korpar': [('korp', False)],
          'korps': [('korp', False)],
          'korps-': [('korp', True)],
          'korr': [('korr', False)],
          'korr-': [('korr', False)],
          'korren': [('korr', True), ('korre', True)],
          'korrens': [('korr', True), ('korre', True)],
          'korrs': [('korr', True)],
          'korrs-': [('korr', False)],
          'kors': [('kors', True), ('kor', True), ('ko', True)],
          'kors-': [('kor', True), ('kors', True)],
          'korskot': [('korskota', True)],
          'korskots': [('korskota', True)],
          'korskots-': [('korskota', True)],
          'korstens': [('korsten', False)],
          'kort': [('kort', False)],
          'kort-': [('kort', True)],
          'korten': [('kort', False)],
          'kortens': [('kort', False)],
          'korter': [('kort', False)],
          'korternas': [('kort', False)],
          'korters': [('kort', False)],
          'kortet': [('kort', False)],
          'korts': [('kort', False)],
          'korts-': [('kort', False)],
          'kortände': [('kortände', True), ('kortända', True)],
          'kortände-': [('kortända', True), ('kortände', True)],
          'korv': [('korv', False)],
          'korv-': [('korv', False)],
          'korvs': [('korv', False)],
          'korvs-': [('korv', False)],
          'kos': [('kosa', True), ('kos', True), ('ko', True)],
          'kos-': [('kos', True), ('kosa', True), ('ko', True)],
          'kosa': [('kosa', True)],
          'kosan': [('kosa', True)],
          'kosans': [('kosa', True)],
          'kosas': [('kosa', True)],
          'kospermien': [('kospermie', False)],
          'kospermiens': [('kospermie', False)],
          'koss': [('kossa', True)],
          'kosse': [('kossa', False)],
          'kosse-': [('kossa', True)],
          'kost-': [('kost', False)],
          'koster': [('koster', True)],
          'kosterna': [('kost', False)],
          'kosternas': [('kost', False)],
          'kosters': [('koster', True)],
          'kostnader': [('kostnad', True)],
          'kostnaderna': [('kostnad', True)],
          'kostnadernas': [('kostnad', True)],
          'kostnaders': [('kostnad', True)],
          'kostnads': [('kostnad', True)],
          'kostnads-': [('kostnad', True)],
          'kostrar': [('koster', True)],
          'kostrarna': [('koster', True)],
          'kot': [('kota', True)],
          'kot-': [('kota', False)],
          'kota': [('kota', False)],
          'kotarnas': [('kot', False)],
          'kotas': [('kota', False)],
          'kotin': [('kotin', False)],
          'kotnötter': [('kotnöt', False)],
          'kotnötterna': [('kotnöt', False)],
          'kotnötternas': [('kotnöt', False)],
          'kotnötters': [('kotnöt', False)],
          'kotrippar': [('kotripp', False)],
          'kotripparnas': [('kotripp', False)],
          'kots': [('kota', True)],
          'kots-': [('kota', False)],
          'kott': [('kotte', True)],
          'kott-': [('kotte', True)],
          'kottar': [('kotte', False)],
          'kottarna': [('kotte', True)],
          'kottarnas': [('kotte', True)],
          'kottars': [('kotte', True)],
          'kotte': [('kotte', True)],
          'kotte-': [('kotte', False)],
          'kotten': [('kotte', True)],
          'kottens': [('kotte', True)],
          'kotter': [('kott', False)],
          'kotterier': [('kotteri', True)],
          'kotterierna': [('kotteri', True)],
          'kotteriernas': [('kotteri', True)],
          'kotterna': [('kott', False)],
          'kotternas': [('kott', False)],
          'kotters': [('kott', False)],
          'kottpengarna': [('kottpeng', False)],
          'kotts': [('kotte', True)],
          'kotts-': [('kotte', True)],
          'kouten': [('kout', False)],
          'koutens': [('kout', False)],
          'kouter': [('kout', False)],
          'kouterna': [('kout', False)],
          'kouternas': [('kout', False)],
          'kouters': [('kout', False)],
          'kovits': [('kovit', False)],
          'kovor': [('kovor', False)],
          'kovorna': [('kovor', False)],
          'kovornas': [('kovor', False)],
          'kovors': [('kovor', False)],
          'kox': [('kox', True)],
          'kox-': [('kox', True)],
          'koxar': [('koxe', False)],
          'koxarnas': [('koxe', False)],
          'koxars': [('koxe', False)],
          'koxen': [('kox', True)],
          'koxens': [('kox', True)],
          'kpelar': [('kpelare', False)],
          'kpelar-': [('kpelare', False)],
          'kpell': [('kpelle', False)],
          'kpell-': [('kpelle', False)],
          'kpellar': [('kpelle', False)],
          'kpellarna': [('kpelle', False)],
          'kpellars': [('kpelle', False)],
          'kpells': [('kpelle', False)],
          'kpells-': [('kpelle', False)],
          'kpengar': [('kpeng', False)],
          'kpengarna': [('kpeng', False)],
          'kpengarnas': [('kpeng', False)],
          'kpengars': [('kpeng', False)],
          'kpenning': [('kpenning', False)],
          'kpenningar': [('kpenning', False)],
          'kpenningarna': [('kpenning', False)],
          'kpenningarnas': [('kpenning', False)],
          'kpenningars': [('kpenning', False)],
          'kpennings': [('kpenning', False)],
          'kpennings-': [('kpenning', False)],
          'kpinnar': [('kpinne', False)],
          'kpinnarnas': [('kpinne', False)],
          'kpinnens': [('kpinne', False)],
          'kpinns': [('kpinne', False)],
          'kpit': [('kpit', False)],
          'kpits': [('kpit', False)],
          'kpits-': [('kpit', False)],
          'kplanet': [('kplan', False)],
          'kplanets': [('kplan', False)],
          'kpojk': [('kpojke', False)],
          'kpojk-': [('kpojke', False)],
          'kpojks': [('kpojke', False)],
          'kpojks-': [('kpojke', False)],
          'kportarnas': [('kport', False)],
          'kpotens': [('kpot', False)],
          'kpots': [('kpot', False)],
          'kpressar': [('kpress', False)],
          'kpressarna': [('kpress', False)],
          'kpressarnas': [('kpress', False)],
          'kprickar': [('kprick', False)],
          'kprickarna': [('kprick', False)],
          'kprickarnas': [('kprick', False)],
          'kpricks-': [('kprick', False)],
          'kproblemet': [('kproblem', False)],
          'kproblemets': [('kproblem', False)],
          'kpump': [('kpump', False)],
          'kpumps': [('kpump', False)],
          'kpumps-': [('kpump', False)],
          'kputs': [('kputs', False)],
          'kputs-': [('kputs', False)],
          'kr': [('kr', False)],
          'kr-': [('kr', False)],
          'krabb': [('krabba', False)],
          'krabb-': [('krabba', False)],
          'krabbs-': [('krabba', False)],
          'kraden': [('krad', False)],
          'kradens': [('krad', False)],
          'krafter': [('kraft', True)],
          'krafterna': [('kraft', True)],
          'krafternas': [('kraft', True)],
          'krafters': [('kraft', True)],
          'krafts': [('kraft', True)],
          'krafts-': [('kraft', True)],
          'krag': [('krage', False)],
          'krag-': [('krage', False)],
          'kragar': [('krage', False)],
          'krage': [('krage', False)],
          'krage-': [('krage', False)],
          'krags': [('krage', False)],
          'krags-': [('krage', False)],
          'krak': [('krake', False)],
          'krak-': [('krake', False)],
          'krakar': [('krake', True)],
          'krakarna': [('krake', True)],
          'krakarnas': [('krake', False)],
          'krakars': [('krake', True)],
          'krake': [('krake', True)],
          'kraken': [('krake', True)],
          'krakens': [('krake', True)],
          'kraks': [('krake', False)],
          'kraks-': [('krake', True)],
          'kramar': [('kram', True)],
          'kramarna': [('kram', True)],
          'kramarnas': [('kram', True)],
          'kramlandets': [('kramlande', False)],
          'kramp': [('krampa', True), ('kramp', True)],
          'kramp-': [('krampa', True), ('kramp', True)],
          'kramps': [('krampa', True), ('kramp', True)],
          'kramps-': [('krampa', True), ('kramp', True)],
          'krams': [('kram', True), ('krams', True)],
          'krams-': [('krams', True), ('kram', True)],
          'kran': [('kran', False)],
          'kran-': [('kran', False)],
          'krande': [('krande', False)],
          'krande-': [('krande', False)],
          'kranden': [('krande', False)],
          'krandens': [('krande', False)],
          'krandet': [('krande', False)],
          'kranier': [('kranium', True)],
          'kranierna': [('kranium', True)],
          'krank': [('krank', False)],
          'krankar': [('krank', False)],
          'krankarna': [('krank', False)],
          'kranks': [('krank', False)],
          'krans': [('krans', True), ('kran', True)],
          'krans-': [('krans', True), ('kran', True)],
          'krape': [('krapa', False)],
          'krape-': [('krapa', False)],
          'krapet': [('krap', False)],
          'krar': [('krare', False)],
          'krarna': [('krare', False)],
          'krarnas': [('ker', False)],
          'kras': [('kras', True)],
          'kras-': [('kras', False)],
          'krasens': [('kras', False)],
          'krasiernas': [('krasi', False)],
          'krasiers': [('krasi', False)],
          'krassens': [('krasse', False)],
          'krat': [('krat', False)],
          'kraten': [('krat', False)],
          'kratens': [('krat', False)],
          'krater': [('krater', True)],
          'kraterna': [('krat', False)],
          'kraternas': [('krat', False)],
          'kraters': [('krater', True)],
          'kratiers': [('krati', False)],
          'kratin': [('krati', False)],
          'krats': [('krats', True)],
          'krats-': [('krats', True)],
          'kratt': [('kratta', False)],
          'kratt-': [('kratta', True)],
          'krattar': [('krattare', False)],
          'krattarna': [('krattare', False)],
          'krattarnas': [('krattare', False)],
          'kratts': [('kratta', False)],
          'kratts-': [('kratta', True)],
          'krav': [('krav', False)],
          'krav-': [('krav', True)],
          'kravaller': [('kravall', True)],
          'kravallerna': [('kravall', True)],
          'kravallernas': [('kravall', True)],
          'kravallers': [('kravall', True)],
          'kravalls': [('kravall', True)],
          'kraven': [('krav', False)],
          'kravens': [('krav', False)],
          'kravs': [('krav', False)],
          'kravs-': [('krav', False)],
          'kraxen': [('krax', True)],
          'kraxens': [('krax', True)],
          'kre': [('kra', False)],
          'kre-': [('kra', False)],
          'kred': [('kred', False)],
          'kred-': [('kred', False)],
          'kreden': [('kred', False)],
          'kredens': [('kred', False)],
          'kredet': [('kred', False)],
          'kredets': [('kred', False)],
          'kreds': [('kred', False)],
          'kreds-': [('kred', False)],
          'kremmar': [('krem', False)],
          'kremmarna': [('krem', False)],
          'kremmarnas': [('krem', False)],
          'krems': [('krem', False)],
          'krems-': [('krem', False)],
          'kren': [('ker', False)],
          'krens': [('ker', False)],
          'krens-': [('krens', False)],
          'krepans': [('krepans', False)],
          'krers': [('ker', False)],
          'kres': [('kres', False)],
          'kres-': [('kres', False)],
          'krese': [('kresa', False)],
          'krese-': [('kresa', False)],
          'kresen': [('kres', False)],
          'kresens': [('kres', False)],
          'kret': [('ker', False)],
          'kretanden': [('kretande', True)],
          'kretandens': [('kretande', True)],
          'kreter': [('kreter', True)],
          'krets': [('krets', False)],
          'krets-': [('krets', True)],
          'kreve': [('kreva', False)],
          'krevens': [('krev', False)],
          'kri': [('kria', True)],
          'kri-': [('kria', True)],
          'krias': [('kria', True)],
          'krick-': [('kricka', True)],
          'kricket': [('kricket', True)],
          'kricks': [('kricka', True)],
          'kricks-': [('kricka', True)],
          'krien': [('kri', False)],
          'kriets': [('kri', False)],
          'krig': [('krig', False)],
          'krig-': [('krig', False)],
          'krighets': [('krighet', False)],
          'krigs': [('krig', False)],
          'krigs-': [('krig', False)],
          'krike': [('krika', False)],
          'krike-': [('krika', False)],
          'kriken': [('krik', False)],
          'krikens': [('krik', False)],
          'kriket': [('krik', False)],
          'krikets': [('krik', False)],
          'krill-': [('krill', False)],
          'krillarna': [('krill', False)],
          'krillarnas': [('krill', False)],
          'kriminalen': [('kriminalen', True)],
          'kriminalens': [('kriminalen', True)],
          'krin-': [('krin', False)],
          'krind': [('krinda', False)],
          'krind-': [('krinda', False)],
          'krinds': [('krinda', False)],
          'krinds-': [('krinda', False)],
          'kringarna': [('kring', False)],
          'kringarnas': [('kring', False)],
          'krins-': [('krin', False)],
          'krior': [('kria', True)],
          'kris': [('kria', True), ('kris', True)],
          'kris-': [('kria', True), ('kris', True)],
          'krisarna': [('kris', True)],
          'kriser': [('kris', False)],
          'kriserna': [('kris', False)],
          'krisernas': [('kris', False)],
          'krisers': [('kris', False)],
          'krisk': [('krisk', False)],
          'krisk-': [('krisk', False)],
          'kristarnas': [('krist', False)],
          'krit': [('krita', True)],
          'krit-': [('krita', False)],
          'kritans': [('krita', False)],
          'kriter': [('krit', False)],
          'kritiker': [('kritik', True), ('kritiker', True)],
          'kritikerna': [('kritik', True), ('kritiker', True)],
          'kritikernas': [('kritiker', True), ('kritik', True)],
          'kritikers': [('kritik', True), ('kritiker', True)],
          'krits': [('krita', True)],
          'krits-': [('krita', True)],
          'kritter': [('kritter', True)],
          'kritterna': [('kritter', True)],
          'kritternas': [('kritter', True)],
          'kritters': [('kritter', True)],
          'krivar': [('krivare', False)],
          'krivar-': [('krivare', False)],
          'kro-': [('kro', False)],
          'kroben': [('krob', False)],
          'krobens': [('krob', False)],
          'krober': [('krob', False)],
          'kroberna': [('krob', False)],
          'krobernas': [('krob', False)],
          'krobers': [('krob', False)],
          'krock': [('krock', False)],
          'krockar': [('krock', False)],
          'krockarna': [('krock', False)],
          'krockarnas': [('krock', False)],
          'krocket': [('krocket', True)],
          'krockets': [('krocket', True)],
          'krogen': [('krog', False)],
          'krogens': [('krog', False)],
          'krokar': [('krok', False)],
          'krokarna': [('krok', False)],
          'krokarnas': [('krok', True)],
          'krokars': [('krok', False)],
          'kroken': [('krok', False)],
          'krokens': [('krok', False)],
          'kroks': [('krok', False)],
          'kroks-': [('krok', False)],
          'kroller': [('kroller', False)],
          'krollerna': [('kroller', False)],
          'krollernas': [('kroller', False)],
          'krollers': [('kroller', False)],
          'kromans': [('kroman', False)],
          'kroms-': [('krom', False)],
          'kron': [('krona', False)],
          'kron-': [('krona', False)],
          'krona': [('krona', False)],
          'kronan': [('kronan', True), ('krona', True)],
          'kronans': [('kronan', True), ('krona', True)],
          'kronas': [('krona', False)],
          'krone': [('krona', False)],
          'krone-': [('krona', False)],
          'kronen': [('kron', False)],
          'kronens': [('kron', False)],
          'kroner': [('kron', False)],
          'kronerna': [('kron', False)],
          'kronernas': [('kron', False)],
          'kroners': [('kron', False)],
          'krons': [('krona', False)],
          'krons-': [('krona', True)],
          'kropen': [('krop', False)],
          'kropens': [('krop', False)],
          'kropparna': [('kropp', False)],
          'kropparnas': [('kropp', False)],
          'kropps': [('kropp', False)],
          'kropps-': [('kropp', False)],
          'krops': [('krop', False)],
          'kror': [('kra', False)],
          'krorna': [('kra', False)],
          'krornas': [('kra', False)],
          'krors': [('kra', False)],
          'kros': [('kros', False)],
          'kros-': [('kros', False)],
          'krossar': [('kross', True)],
          'krossarna': [('kross', False)],
          'krossarnas': [('kross', True)],
          'krot': [('krot', False)],
          'krotar': [('krot', False)],
          'krotarna': [('krot', False)],
          'krotarnas': [('krot', False)],
          'krotars': [('krot', False)],
          'kroten': [('krot', False)],
          'krotens': [('krot', False)],
          'krots': [('krot', False)],
          'krots-': [('krot', False)],
          'krottarna': [('krott', False)],
          'krov': [('krov', False)],
          'krov-': [('krov', False)],
          'krovs': [('krov', False)],
          'krovs-': [('krov', False)],
          'krs': [('kra', False)],
          'krs-': [('kra', False)],
          'krubb': [('krubb', True), ('krubba', True)],
          'krubb-': [('krubb', True), ('krubba', True)],
          'krubbet': [('krubb', True)],
          'krubbets': [('krubb', True)],
          'krubbor': [('krubba', True)],
          'krubborna': [('krubba', True)],
          'krubbornas': [('krubba', True)],
          'krubbors': [('krubba', True)],
          'krubbs': [('krubb', True), ('krubba', True)],
          'krubbs-': [('krubb', True), ('krubba', True)],
          'krud': [('krud', False)],
          'krud-': [('krud', False)],
          'krudanden': [('krudande', False)],
          'krudandens': [('krudande', False)],
          'krudens': [('krud', False)],
          'kruds': [('krud', False)],
          'kruds-': [('krud', False)],
          'krull': [('krull', True)],
          'krull-': [('krull', True)],
          'krullarna': [('krulle', False)],
          'krulle': [('krulla', False)],
          'krulle-': [('krulle', False)],
          'krulls': [('krull', True)],
          'krulls-': [('krull', True)],
          'krumbukt': [('krumbukt', True), ('krumbukter', True)],
          'krumbukt-': [('krumbukt', True), ('krumbukter', True)],
          'krumbukter': [('krumbukt', True), ('krumbukter', True)],
          'krumbukterna': [('krumbukt', True), ('krumbukter', True)],
          'krumbukternas': [('krumbukt', True), ('krumbukter', True)],
          'krumbukters': [('krumbukt', True), ('krumbukter', True)],
          'krumbukts': [('krumbukt', True), ('krumbukter', True)],
          'krumbukts-': [('krumbukt', True), ('krumbukter', True)],
          'krums-': [('krum', False)],
          'krus': [('krus', False)],
          'krus-': [('krus', False)],
          'krusarna': [('krusare', False)],
          'krusarnas': [('krusare', False)],
          'krusidull': [('krusidull', True), ('krusiduller', True)],
          'krusidull-': [('krusiduller', True), ('krusidull', True)],
          'krusiduller': [('krusiduller', True), ('krusidull', True)],
          'krusidullerna': [('krusiduller', True), ('krusidull', True)],
          'krusidullernas': [('krusiduller', True), ('krusidull', True)],
          'krusidullers': [('krusiduller', True), ('krusidull', True)],
          'krusidulls': [('krusidull', True), ('krusiduller', True)],
          'krusidulls-': [('krusiduller', True), ('krusidull', True)],
          'krut': [('krut', False)],
          'krut-': [('krut', True)],
          'kruts': [('krut', True)],
          'kruts-': [('krut', False)],
          'kruv': [('kruv', False)],
          'kruv-': [('kruv', False)],
          'kruvs': [('kruv', False)],
          'kruvs-': [('kruv', False)],
          'kry': [('kry', False)],
          'kry-': [('kry', False)],
          'kryck': [('krycka', False)],
          'kryck-': [('krycka', False)],
          'krycks': [('krycka', True)],
          'krycks-': [('krycka', True)],
          'kryggar': [('krygg', False)],
          'krylen': [('kryl', False)],
          'krylens': [('kryl', False)],
          'kryps': [('kryp', False)],
          'kryps-': [('kryp', True)],
          'krypton': [('krypton', True), ('krypto', True)],
          'kryptons': [('krypton', True), ('krypto', True)],
          'krys': [('kry', False)],
          'kryssar': [('kryssare', False)],
          'kryssarna': [('kryssare', True)],
          'kryssarnas': [('kryssare', False)],
          'kryt-': [('kryt', False)],
          'krytarnas': [('krytare', False)],
          'kryten': [('kryt', False)],
          'krytens': [('kryt', False)],
          'kryts-': [('kryt', False)],
          'kräck': [('kräck', False)],
          'kräck-': [('kräck', False)],
          'kräckarnas': [('kräck', False)],
          'kräcke': [('kräcke', False)],
          'kräcken': [('kräck', False)],
          'kräcks': [('kräck', False)],
          'kräcks-': [('kräck', False)],
          'kräden': [('kräde', False)],
          'krädens': [('kräde', False)],
          'krädets': [('kräde', False)],
          'kräk': [('kräk', False)],
          'kräk-': [('kräk', True)],
          'kräks': [('kräks', True), ('kräk', True)],
          'kräks-': [('kräks', True), ('kräk', True)],
          'krällarna': [('kräll', False)],
          'krällarnas': [('kräll', False)],
          'kräm': [('kräm', True)],
          'kräm-': [('kräm', False)],
          'kräms': [('kräm', False)],
          'kräms-': [('kräm', False)],
          'krän': [('krän', False)],
          'kränn': [('kränna', False)],
          'kränn-': [('kränna', False)],
          'kränns': [('kränna', False)],
          'kränns-': [('kränna', False)],
          'kräns': [('krän', False)],
          'kräns-': [('krän', False)],
          'kräpp': [('kräpp', True)],
          'kräpp-': [('kräpp', True)],
          'kräpps': [('kräpp', True)],
          'kräpps-': [('kräpp', True)],
          'krättens': [('krätt', False)],
          'kräv': [('kräva', True)],
          'kräv-': [('kräva', True)],
          'krävar': [('krävare', False)],
          'krävarna': [('krävare', False)],
          'krävarnas': [('krävare', False)],
          'krävs': [('kräva', True)],
          'krävs-': [('kräva', True)],
          'kråden': [('kråd', False)],
          'krådens': [('kråd', False)],
          'kråk': [('kråka', True)],
          'kråk-': [('kråka', True)],
          'kråke': [('kråka', False)],
          'kråks': [('kråka', False)],
          'kråks-': [('kråka', False)],
          'krål': [('krål', False)],
          'krål-': [('krål', False)],
          'krålens': [('krål', False)],
          'kråls': [('krål', False)],
          'kråls-': [('krål', False)],
          'kråm': [('kråm', False)],
          'kråms': [('kråm', False)],
          'kråms-': [('kråm', False)],
          'krån': [('krå', False)],
          'kråns': [('krå', False)],
          'krås': [('krås', False)],
          'krås-': [('krås', False)],
          'kråsen': [('krås', True)],
          'kråsens': [('krås', True)],
          'krökar': [('krök', False)],
          'krökarna': [('krök', False)],
          'krökarnas': [('krök', False)],
          'kröken': [('krök', True), ('kröken', True)],
          'krökens': [('krök', True)],
          'krön': [('krön', False)],
          'krön-': [('krön', True)],
          'kröna': [('kröna', False)],
          'krönas': [('kröna', False)],
          'kröns': [('krön', False)],
          'kröns-': [('krön', True)],
          'kröst': [('kröst', False)],
          'kröstar': [('kröstare', False)],
          'kröstarna': [('kröstare', False)],
          'kröstens': [('kröst', False)],
          'krötter': [('krot', False)],
          'krötterna': [('krot', False)],
          'krötternas': [('krot', False)],
          'krötters': [('krot', False)],
          'ksage': [('ksaga', False)],
          'ksage-': [('ksaga', False)],
          'ksago': [('ksaga', False)],
          'ksago-': [('ksaga', False)],
          'ksaker': [('ksak', False)],
          'ksakerna': [('ksak', False)],
          'ksakernas': [('ksak', False)],
          'ksakers': [('ksak', False)],
          'ksaks': [('ksaker', False)],
          'ksaks-': [('ksaker', False)],
          'ksalen': [('ksal', False)],
          'ksalens': [('ksal', False)],
          'ksanden': [('ksande', False)],
          'ksandens': [('ksande', False)],
          'ksans': [('ksa', False)],
          'ksarnas': [('k', False)],
          'ksats': [('ksats', False)],
          'ksats-': [('ksats', False)],
          'ksaxar': [('ksax', False)],
          'ksaxarna': [('ksax', False)],
          'ksaxarnas': [('ksax', False)],
          'ksbytet': [('ksbyte', False)],
          'ksdammen': [('ksdamm', False)],
          'kse': [('ksa', False)],
          'kse-': [('ksa', False)],
          'kseffekt': [('kseffekt', False)],
          'kseffekter': [('kseffekt', False)],
          'kseffekternas': [('kseffekt', False)],
          'kseffekters': [('kseffekt', False)],
          'kseffekts': [('kseffekt', False)],
          'kseffekts-': [('kseffekt', False)],
          'ksen': [('ks', False)],
          'kset': [('ks', False)],
          'ksets': [('ks', False)],
          'ksgatan': [('ksgata', False)],
          'ksh': [('ksha', False)],
          'ksh-': [('ksha', False)],
          'kshandlar': [('kshandlare', False)],
          'kshans': [('ksha', False)],
          'kshas': [('ksha', False)],
          'kshors': [('ksha', False)],
          'kshögskolan': [('kshögskolan', False)],
          'kshögskolans': [('kshögskolan', False)],
          'ksidan': [('ksida', False)],
          'ksidans': [('ksida', False)],
          'kside-': [('ksida', False)],
          'ksides': [('ksida', False)],
          'ksin-': [('ksin', False)],
          'ksinen': [('ksin', False)],
          'ksinens': [('ksin', False)],
          'ksins': [('ksin', False)],
          'ksins-': [('ksin', False)],
          'ksis': [('ksis', False)],
          'ksjukan': [('ksjuka', False)],
          'ksk': [('kska', False)],
          'ksk-': [('kska', False)],
          'kskal': [('kskal', False)],
          'kskallen': [('kskalle', False)],
          'kskallens': [('kskalle', False)],
          'kskals': [('kskal', False)],
          'kskals-': [('kskal', False)],
          'kskan': [('kska', False)],
          'kskans': [('kska', False)],
          'kskiften': [('kskifte', False)],
          'kskiftens': [('kskifte', False)],
          'kskiftet': [('kskifte', False)],
          'kskiftets': [('kskifte', False)],
          'ksko': [('ksko', False)],
          'kskock': [('kskock', False)],
          'kskocks': [('kskock', False)],
          'kskocks-': [('kskock', False)],
          'kskons': [('ksko', False)],
          'kskonst': [('kskonst', False)],
          'kskor': [('ksko', False)],
          'kskorna': [('ksko', False)],
          'kskornas': [('ksko', False)],
          'kskorp': [('kskorp', False)],
          'kskorps': [('kskorp', False)],
          'kskorps-': [('kskorp', False)],
          'kskors': [('ksko', False)],
          'kskott': [('kskott', False)],
          'kskottar': [('kskottare', False)],
          'kskottarna': [('kskottare', False)],
          'kskottarnas': [('kskottare', False)],
          'kskotten': [('kskott', False)],
          'kskottens': [('kskott', False)],
          'kskotts-': [('kskott', False)],
          'kskrap': [('kskrap', False)],
          'kskraps': [('kskrap', False)],
          'kskraps-': [('kskrap', False)],
          'kskrin': [('kskrin', False)],
          'kskrins': [('kskrin', False)],
          'kskris': [('kskris', False)],
          'kskrällen': [('kskräll', False)],
          'kskrällens': [('kskräll', False)],
          'kskvätt': [('kskvätta', False)],
          'kskvätt-': [('kskvätta', False)],
          'kskvätts': [('kskvätta', False)],
          'kskvätts-': [('kskvätta', False)],
          'kskytten': [('kskytt', False)],
          'kskyttens': [('kskytt', False)],
          'kskärmarna': [('kskärm', False)],
          'kskärmarnas': [('kskärm', False)],
          'kskärv': [('kskärva', False)],
          'kskärv-': [('kskärva', False)],
          'kskärvs': [('kskärva', False)],
          'kskärvs-': [('kskärva', False)],
          'kskön': [('kskö', False)],
          'ksköns': [('kskö', False)],
          'kskötar': [('kskötare', False)],
          'kskötarna': [('kskötare', False)],
          'kskötarnas': [('kskötare', False)],
          'kslag': [('kslag', False)],
          'kslagar': [('kslagare', False)],
          'kslagarna': [('kslagare', False)],
          'kslagarnas': [('kslagare', False)],
          'kslags': [('kslag', False)],
          'kslags-': [('kslag', False)],
          'kslotts': [('kslott', False)],
          'kslyn': [('ksly', False)],
          'kslyna': [('ksly', False)],
          'kslynas': [('ksly', False)],
          'kslyns': [('ksly', False)],
          'ksläng': [('kslänga', False)],
          'ksläng-': [('ksläng', False)],
          'kslängs': [('ksläng', False)],
          'kslängs-': [('kslänga', False)],
          'kslån': [('kslån', False)],
          'kslåns': [('kslån', False)],
          'kslås': [('kslås', False)],
          'kslås-': [('kslås', False)],
          'ksmäll': [('ksmäll', False)],
          'ksmäll-': [('ksmäll', False)],
          'ksmällar': [('ksmäll', False)],
          'ksmällarna': [('ksmäll', False)],
          'ksmällarnas': [('ksmäll', False)],
          'ksmälls': [('ksmälla', False)],
          'ksmälls-': [('ksmälla', False)],
          'ksnacks': [('ksnack', False)],
          'ksnyckel': [('ksnyckel', False)],
          'ksnyckel-': [('ksnyckel', False)],
          'ksnyckels': [('ksnyckel', False)],
          'ksnyckels-': [('ksnyckel', False)],
          'ksnycklar': [('ksnyckel', False)],
          'ksnycklarna': [('ksnyckel', False)],
          'ksnycklarnas': [('ksnyckel', False)],
          'ksnycklars': [('ksnyckel', False)],
          'ksnärt': [('ksnärta', False)],
          'ksnärt-': [('ksnärt', False)],
          'ksnärts': [('ksnärta', False)],
          'ksnärts-': [('ksnärt', False)],
          'ksområdet': [('ksområde', False)],
          'ksopp': [('ksoppa', False)],
          'ksopp-': [('ksoppa', False)],
          'ksopps': [('ksopp', False)],
          'ksopps-': [('ksoppa', False)],
          'ksor': [('ksa', False)],
          'ksorna': [('ksa', False)],
          'ksornas': [('ksa', False)],
          'ksors': [('ksa', False)],
          'kspad': [('kspade', False)],
          'kspad-': [('kspade', False)],
          'kspads': [('kspade', False)],
          'kspads-': [('kspade', False)],
          'kspar': [('kspar', False)],
          'kspars': [('kspar', False)],
          'kspat': [('kspat', False)],
          'kspats': [('kspat', False)],
          'kspeng': [('kspeng', False)],
          'kspeng-': [('kspeng', False)],
          'kspengar': [('kspeng', False)],
          'kspengarna': [('kspeng', False)],
          'kspengarnas': [('kspeng', False)],
          'kspengars': [('kspeng', False)],
          'kspengs': [('kspeng', False)],
          'kspengs-': [('kspeng', False)],
          'kspets': [('kspets', False)],
          'kspets-': [('kspets', False)],
          'kspiller': [('kspillra', False)],
          'kspire': [('kspira', False)],
          'kspire-': [('kspira', False)],
          'kspisar': [('kspis', False)],
          'kspisarna': [('kspis', False)],
          'kspisarnas': [('kspis', False)],
          'ksportar': [('ksport', False)],
          'ksportarna': [('ksport', False)],
          'ksportarnas': [('ksportare', False)],
          'kspott-': [('kspott', False)],
          'kspotts': [('kspott', False)],
          'kspris': [('kspris', False)],
          'ksprit': [('ksprit', False)],
          'ksprits': [('ksprit', False)],
          'ksprits-': [('ksprit', False)],
          'ksprut': [('kspruta', False)],
          'ksprut-': [('kspruta', False)],
          'kspruts': [('kspruta', False)],
          'kspruts-': [('kspruta', False)],
          'kspån': [('kspån', False)],
          'kspåns': [('kspån', False)],
          'kspåns-': [('kspån', False)],
          'ksrån': [('ksrån', False)],
          'kstak': [('kstak', False)],
          'kstaken': [('kstake', False)],
          'kstakens': [('kstak', False)],
          'kstaket': [('kstak', False)],
          'kstakets': [('kstak', False)],
          'kstaks': [('kstak', False)],
          'kstaks-': [('kstak', False)],
          'kstalets': [('kstal', False)],
          'kstammar': [('kstam', False)],
          'kstammarna': [('kstam', False)],
          'kstammarnas': [('kstam', False)],
          'kstans': [('kstad', False)],
          'kstarter': [('kstart', False)],
          'kstarterna': [('kstart', False)],
          'kstarternas': [('kstart', False)],
          'kstarters': [('kstart', False)],
          'kstavarna': [('kstav', False)],
          'ksteg': [('ksteg', False)],
          'kstegen': [('ksteg', False)],
          'kstegens': [('ksteg', False)],
          'kstegs': [('ksteg', False)],
          'kstegs-': [('ksteg', False)],
          'kstekar': [('kstek', False)],
          'kstekarna': [('kstek', False)],
          'kstekarnas': [('kstek', False)],
          'ksten': [('ksten', False)],
          'kstick': [('ksticka', False)],
          'kstick-': [('ksticka', False)],
          'ksticks': [('ksticka', False)],
          'ksticks-': [('ksticka', False)],
          'kstol': [('kstol', False)],
          'kstol-': [('kstol', False)],
          'kstoll': [('kstolle', False)],
          'kstoll-': [('kstolle', False)],
          'kstollar': [('kstolle', False)],
          'kstollarna': [('kstolle', False)],
          'kstollarnas': [('kstolle', False)],
          'kstollars': [('kstolle', False)],
          'kstolle': [('kstolle', False)],
          'kstollen': [('kstolle', False)],
          'kstollens': [('kstolle', False)],
          'kstolls': [('kstolle', False)],
          'kstolls-': [('kstolle', False)],
          'kstols': [('kstol', False)],
          'kstols-': [('kstol', False)],
          'kstomten': [('kstomt', False)],
          'kstormarna': [('kstorm', False)],
          'kstormarnas': [('kstorm', False)],
          'kstorn': [('kstorn', False)],
          'kstorns': [('kstorn', False)],
          'ksträck': [('ksträcka', False)],
          'ksträck-': [('ksträcka', False)],
          'ksträcks': [('ksträcka', False)],
          'ksträcks-': [('ksträcka', False)],
          'kstudie': [('kstudium', False)],
          'kstudie-': [('kstudium', False)],
          'kstudier': [('kstudium', False)],
          'kstudierna': [('kstudium', False)],
          'kstudiernas': [('kstudium', False)],
          'kstudiers': [('kstudium', False)],
          'kstycken': [('kstycke', False)],
          'kstyckena': [('kstycke', False)],
          'kstyckenas': [('kstycke', False)],
          'kstyckens': [('kstycke', False)],
          'kstycket': [('kstycke', False)],
          'kstyckets': [('kstycke', False)],
          'kstycks': [('kstycke', False)],
          'kstyren': [('kstyre', False)],
          'kstyrens': [('kstyre', False)],
          'kstyrkan': [('kstyrka', False)],
          'kstyrke': [('kstyrka', False)],
          'kställanden': [('kställande', False)],
          'kställandena': [('kställande', False)],
          'kställandenas': [('kställande', False)],
          'kställandens': [('kställande', False)],
          'kställen': [('kställ', False)],
          'kställens': [('kställ', False)],
          'kstället': [('kställ', False)],
          'kställets': [('kställ', False)],
          'kställningar': [('kställning', False)],
          'kställningarna': [('kställning', False)],
          'kställningarnas': [('kställning', False)],
          'kställningars': [('kställning', False)],
          'kställnings': [('kställning', False)],
          'kställnings-': [('kställning', False)],
          'kstötarnas': [('kstöt', False)],
          'kstövlars': [('kstövel', False)],
          'ksuddar': [('ksuddare', False)],
          'ksuddarna': [('ksuddare', False)],
          'ksuddarnas': [('ksuddare', False)],
          'ksval': [('ksval', False)],
          'ksvale': [('ksvala', False)],
          'ksvalen': [('ksval', False)],
          'ksvalens': [('ksval', False)],
          'ksvals': [('ksval', False)],
          'ksvals-': [('ksval', False)],
          'ksvar': [('ksvara', False)],
          'ksving': [('ksving', False)],
          'ksvingen': [('ksving', False)],
          'ksvägen': [('ksvägen', False)],
          'ksvägens': [('ksväg', False)],
          'ksvärden': [('ksvärde', False)],
          'ksvärdens': [('ksvärde', False)],
          'ksvärdet': [('ksvärd', False)],
          'ksvärdets': [('ksvärde', False)],
          'ksyns': [('ksyn', False)],
          'ksyre': [('ksyra', False)],
          'ksyre-': [('ksyra', False)],
          'ksås': [('ksås', False)],
          'ksås-': [('ksås', False)],
          'ksömmar': [('ksöm', False)],
          'ksömmarna': [('ksöm', False)],
          'ksömmarnas': [('ksöm', False)],
          'ksön': [('ksö', False)],
          'ksös': [('ksö', False)],
          'kt': [('kt', False)],
          'kt-': [('kt', False)],
          'ktak': [('ktak', False)],
          'ktaken': [('ktak', False)],
          'ktaket': [('ktak', False)],
          'ktalandena': [('ktalande', False)],
          'ktalandenas': [('ktalande', False)],
          'ktalandens': [('ktalande', False)],
          'ktalar': [('ktalare', False)],
          'ktalar-': [('ktalare', False)],
          'ktalaren': [('ktalare', False)],
          'ktalarens': [('ktalare', False)],
          'ktalen': [('ktal', False)],
          'ktalens': [('ktal', False)],
          'ktalet': [('ktal', False)],
          'ktamenten': [('ktamente', False)],
          'ktamentens': [('ktamente', False)],
          'ktamentet': [('ktamente', False)],
          'ktaments-': [('ktamente', False)],
          'ktan': [('ktan', False)],
          'ktan-': [('ktan', False)],
          'ktanden': [('ktande', False)],
          'ktandens': [('ktande', False)],
          'ktank': [('ktanke', False)],
          'ktank-': [('ktanke', False)],
          'ktankar': [('ktank', False)],
          'ktankarna': [('ktank', False)],
          'ktankarnas': [('ktank', False)],
          'ktankars': [('ktank', False)],
          'ktanke-': [('ktanke', False)],
          'ktanken': [('ktank', False)],
          'ktankens': [('ktank', False)],
          'ktanks': [('ktanke', False)],
          'ktanks-': [('ktanke', False)],
          'ktans': [('ktan', False)],
          'ktans-': [('ktan', False)],
          'ktants': [('ktant', False)],
          'ktar-': [('ktar', False)],
          'ktaren': [('ktare', False)],
          'ktarens': [('ktar', False)],
          'ktaret': [('ktar', False)],
          'ktarets': [('ktar', False)],
          'ktarierna': [('ktarium', False)],
          'ktariers': [('ktarium', False)],
          'ktarna': [('kt', False)],
          'ktarnas': [('ktare', False)],
          'ktars': [('kt', False)],
          'ktars-': [('ktar', False)],
          'ktas-': [('ktas', False)],
          'ktasen': [('ktas', False)],
          'ktasens': [('ktas', False)],
          'ktat': [('ktat', False)],
          'ktats': [('ktat', False)],
          'ktaverna': [('ktav', False)],
          'ktavernas': [('ktav', False)],
          'ktbit': [('ktbit', False)],
          'ktbitar': [('ktbit', False)],
          'ktbitarna': [('ktbit', False)],
          'ktbitarnas': [('ktbit', False)],
          'kte-': [('kta', False)],
          'kteater': [('kteat', False)],
          'kteaters': [('kteat', False)],
          'ktekniker': [('kteknik', False)],
          'kteknikerna': [('kteknik', False)],
          'kteknikernas': [('kteknik', False)],
          'kteknikers': [('kteknik', False)],
          'kteln': [('ktel', False)],
          'ktelns': [('ktel', False)],
          'ktels': [('ktel', False)],
          'ktels-': [('ktel', False)],
          'kten': [('kt', False)],
          'ktens': [('kt', False)],
          'kter': [('kt', False)],
          'kter-': [('kter', False)],
          'kteranden': [('kterande', False)],
          'kterandens': [('kterande', False)],
          'kterie': [('kterie', False)],
          'kterie-': [('kterie', False)],
          'kterien': [('kterie', False)],
          'kteriens': [('kterie', False)],
          'kterier': [('kteri', False)],
          'kteriets': [('kteri', False)],
          'kterits': [('kteri', False)],
          'ktermer': [('kterm', False)],
          'ktermerna': [('kterm', False)],
          'ktermernas': [('kterm', False)],
          'ktermers': [('kterm', False)],
          'ktern': [('kter', False)],
          'kterna': [('kt', False)],
          'kternas': [('kt', False)],
          'kterns': [('kter', False)],
          'kters': [('kt', False)],
          'kters-': [('kter', False)],
          'ktes': [('kte', False)],
          'ktes-': [('kte', False)],
          'ktet': [('kt', False)],
          'ktets': [('kte', False)],
          'kthandlarnas': [('kthandlare', False)],
          'kthet': [('kthet', False)],
          'kthets': [('kthet', False)],
          'ktick': [('kticka', False)],
          'ktick-': [('kticka', False)],
          'kticks': [('kticka', False)],
          'kticks-': [('kticka', False)],
          'ktiden': [('ktid', False)],
          'ktider': [('ktid', False)],
          'ktiders': [('ktid', False)],
          'ktie': [('ktie', False)],
          'ktie-': [('ktie', False)],
          'ktien': [('ktie', False)],
          'ktiens': [('ktie', False)],
          'ktier': [('ktie', False)],
          'ktierna': [('ktie', False)],
          'ktiernas': [('ktie', False)],
          'ktiers': [('ktie', False)],
          'kties': [('ktie', False)],
          'ktighets': [('ktighet', False)],
          'ktik': [('ktik', False)],
          'ktik-': [('ktik', False)],
          'ktiks': [('ktik', False)],
          'ktilen': [('ktil', False)],
          'ktilens': [('ktil', False)],
          'ktim': [('ktimme', False)],
          'ktim-': [('ktimme', False)],
          'ktimmarna': [('ktimme', False)],
          'ktin-': [('ktin', False)],
          'ktinens': [('ktin', False)],
          'ktiner': [('ktin', False)],
          'ktinerna': [('ktin', False)],
          'ktinernas': [('ktin', False)],
          'ktiners': [('ktin', False)],
          'ktins': [('ktin', False)],
          'ktins-': [('ktin', False)],
          'ktions-': [('ktion', False)],
          'ktippar': [('ktipp', False)],
          'ktipparna': [('ktipp', False)],
          'ktipparnas': [('ktipp', False)],
          'ktis': [('kti', False)],
          'ktit': [('ktit', False)],
          'ktit-': [('ktit', False)],
          'ktits': [('ktit', False)],
          'ktiv': [('ktiv', False)],
          'ktiv-': [('ktiv', False)],
          'ktiven': [('ktiv', False)],
          'ktivens': [('ktiv', False)],
          'ktiver': [('ktiv', False)],
          'ktiverna': [('ktiv', False)],
          'ktivernas': [('ktiv', False)],
          'ktivers': [('ktiv', False)],
          'ktivet': [('ktiv', False)],
          'ktivets': [('ktivum', False)],
          'ktivs': [('ktiv', False)],
          'ktivs-': [('ktiv', False)],
          'ktlar': [('ktel', False)],
          'ktlarna': [('ktel', False)],
          'ktlarnas': [('ktel', False)],
          'ktlins': [('ktlins', False)],
          'ktlins-': [('ktlins', False)],
          'ktmans': [('ktman', False)],
          'ktmask': [('ktmask', False)],
          'ktmask-': [('ktmask', False)],
          'kto-': [('kto', False)],
          'ktoden': [('ktod', False)],
          'ktodens': [('ktod', False)],
          'ktoffer': [('ktoffer', False)],
          'ktoffers': [('ktoffer', False)],
          'ktomten': [('ktomte', False)],
          'ktomtens': [('ktomte', False)],
          'kton': [('kton', False)],
          'ktonerna': [('kton', False)],
          'ktonernas': [('kton', False)],
          'ktoners': [('kton', False)],
          'ktonik': [('ktonik', False)],
          'ktonik-': [('ktonik', False)],
          'ktoniker': [('ktonik', False)],
          'ktonikerna': [('ktonik', False)],
          'ktonikernas': [('ktonik', False)],
          'ktonikers': [('ktonik', False)],
          'ktoniks': [('ktonik', False)],
          'ktoniks-': [('ktonik', False)],
          'ktons': [('kto', False)],
          'ktor': [('kta', False)],
          'ktoren': [('ktor', False)],
          'ktorens': [('ktor', False)],
          'ktorer': [('ktor', False)],
          'ktorerna': [('ktor', False)],
          'ktorernas': [('ktor', False)],
          'ktorers': [('ktor', False)],
          'ktori': [('ktoria', False)],
          'ktori-': [('ktoria', False)],
          'ktorian': [('ktoria', False)],
          'ktorians': [('ktoria', False)],
          'ktorier': [('ktorium', False)],
          'ktorierna': [('ktori', False)],
          'ktoriernas': [('ktori', False)],
          'ktoriers': [('ktori', False)],
          'ktoriet': [('ktori', False)],
          'ktoriets': [('ktori', False)],
          'ktoris': [('ktoria', False)],
          'ktoris-': [('ktori', False)],
          'ktorn': [('ktor', False)],
          'ktorna': [('kta', False)],
          'ktornas': [('kta', False)],
          'ktorns': [('ktor', False)],
          'ktors': [('kta', False)],
          'ktorv': [('ktorv', False)],
          'ktorvs': [('ktorv', False)],
          'ktorvs-': [('ktorv', False)],
          'ktos': [('ktos', False)],
          'ktos-': [('ktos', False)],
          'ktpengarnas': [('ktpengar', False)],
          'ktrams': [('ktram', False)],
          'ktrams-': [('ktram', False)],
          'ktrana': [('ktrum', False)],
          'ktranas': [('ktrum', False)],
          'ktrapp': [('ktrappa', False)],
          'ktrapp-': [('ktrappa', False)],
          'ktrapps': [('ktrappa', False)],
          'ktrapps-': [('ktrappa', False)],
          'ktrar': [('kter', False)],
          'ktrarna': [('kter', False)],
          'ktrars': [('kter', False)],
          'ktras': [('ktrum', False)],
          'ktratt': [('ktratt', False)],
          'ktratts': [('ktratt', False)],
          'ktratts-': [('ktratt', False)],
          'ktrav': [('ktrave', False)],
          'ktrav-': [('ktrave', False)],
          'ktravar': [('ktrave', False)],
          'ktravarna': [('ktrave', False)],
          'ktravarnas': [('ktrave', False)],
          'ktraven': [('ktrave', False)],
          'ktravens': [('ktrave', False)],
          'ktravs': [('ktrave', False)],
          'ktravs-': [('ktrave', False)],
          'ktren': [('kter', False)],
          'ktrers': [('ktrum', False)],
          'ktrin': [('ktrin', False)],
          'ktringar': [('ktring', False)],
          'ktringars': [('ktring', False)],
          'ktringens': [('ktring', False)],
          'ktrins': [('ktrin', False)],
          'ktris': [('ktris', False)],
          'ktriss': [('ktrissa', False)],
          'ktriss-': [('ktrissa', False)],
          'ktron': [('ktro', False)],
          'ktron-': [('ktron', False)],
          'ktrons': [('ktron', False)],
          'ktros': [('ktro', False)],
          'ktros-': [('ktro', False)],
          'ktrum': [('ktrum', False)],
          'ktrum-': [('ktrum', False)],
          'ktrums': [('ktrum', False)],
          'ktrums-': [('ktrum', False)],
          'ktrycket': [('ktryck', False)],
          'ktryckets': [('ktryck', False)],
          'ktrycks': [('ktryck', False)],
          'ktrycks-': [('ktryck', False)],
          'kträd': [('kträd', False)],
          'kträd-': [('kträd', False)],
          'kträden': [('kträd', False)],
          'kträdens': [('kträd', False)],
          'kträdet': [('kträd', False)],
          'kträdets': [('kträd', False)],
          'kträds': [('kträd', False)],
          'kträn': [('kträd', False)],
          'kträna': [('kträd', False)],
          'ktränas': [('kträd', False)],
          'kträns': [('kträd', False)],
          'kträt': [('kträ', False)],
          'kträts': [('kträ', False)],
          'kts': [('kt', False)],
          'kts-': [('kt', False)],
          'ktsikten': [('ktsikte', False)],
          'ktskatt': [('ktskatt', False)],
          'ktskatt-': [('ktskatt', False)],
          'ktskatte': [('ktskatt', False)],
          'ktskatte-': [('ktskatt', False)],
          'ktskatts': [('ktskatt', False)],
          'ktskiftens': [('ktskifte', False)],
          'ktskår': [('ktskåra', False)],
          'ktskåre': [('ktskåra', False)],
          'ktskårs': [('ktskåra', False)],
          'ktskårs-': [('ktskåra', False)],
          'ktslagar': [('ktslag', False)],
          'ktslagarna': [('ktslag', False)],
          'ktslagarnas': [('ktslag', False)],
          'ktstudie': [('ktstudium', False)],
          'ktstudier': [('ktstudium', False)],
          'kttidens': [('kttid', False)],
          'ktträden': [('ktträd', False)],
          'ktträdens': [('ktträd', False)],
          'ktträdet': [('ktträd', False)],
          'ktträn': [('ktträ', False)],
          'ktträna': [('ktträ', False)],
          'kttränas': [('ktträd', False)],
          'ktträns': [('ktträ', False)],
          'ktuarie': [('ktuarie', False)],
          'ktuarie-': [('ktuarium', False)],
          'ktuarier': [('ktuarium', False)],
          'ktuarierna': [('ktuarie', False)],
          'ktuariernas': [('ktuarium', False)],
          'ktuariers': [('ktuarie', False)],
          'ktum': [('ktum', False)],
          'ktum-': [('ktum', False)],
          'ktumen': [('ktum', False)],
          'ktumens': [('ktum', False)],
          'ktummen': [('ktum', False)],
          'ktummens': [('ktum', False)],
          'ktums': [('ktum', False)],
          'ktums-': [('ktum', False)],
          'ktur': [('ktur', False)],
          'ktur-': [('ktur', False)],
          'kture': [('ktura', False)],
          'kturer': [('ktur', False)],
          'kturerna': [('ktur', False)],
          'kturernas': [('ktur', False)],
          'kturers': [('ktur', False)],
          'kturs': [('ktur', False)],
          'ktus': [('ktus', False)],
          'ktus-': [('ktus', False)],
          'ktvägen': [('ktväg', False)],
          'ktvägens': [('ktväg', False)],
          'ktycket': [('ktycke', False)],
          'ktylen': [('ktyl', False)],
          'ktylens': [('ktyl', False)],
          'ktyper': [('ktyp', False)],
          'ktypernas': [('ktyp', False)],
          'ktyren': [('ktyr', False)],
          'ktyrens': [('ktyr', False)],
          'ktyt': [('ktyta', False)],
          'ktyts': [('ktyta', False)],
          'ktändernas': [('ktand', False)],
          'ktänger': [('ktång', False)],
          'ktängernas': [('ktång', False)],
          'ktängers': [('ktång', False)],
          'ktärter': [('ktärt', False)],
          'ktärters': [('ktärt', False)],
          'ktärts': [('ktärt', False)],
          'ktärts-': [('ktärt', False)],
          'ktång': [('ktång', False)],
          'ktång-': [('ktång', False)],
          'ktången': [('ktång', False)],
          'ktångens': [('ktång', False)],
          'ktångs': [('ktång', False)],
          'ktår': [('ktå', False)],
          'ktårs': [('ktå', False)],
          'ktörn': [('ktör', False)],
          'ktörns': [('ktör', False)],
          'ku': [('ku', False)],
          'kuar': [('ku', False)],
          'kuarna': [('ku', False)],
          'kuars': [('ku', False)],
          'kubb': [('kubb', True), ('kubbe', True)],
          'kubb-': [('kubbe', True), ('kubb', True)],
          'kubbar': [('kubbe', True), ('kubb', True)],
          'kubbarna': [('kubbe', True), ('kubb', True)],
          'kubbarnas': [('kubb', True), ('kubbe', True)],
          'kubbars': [('kubbe', True), ('kubb', True)],
          'kubben': [('kubbe', True), ('kubb', True)],
          'kubbens': [('kubbe', True), ('kubb', True)],
          'kubbet': [('kubb', False)],
          'kubbets': [('kubb', False)],
          'kubbs': [('kubbe', True), ('kubb', True)],
          'kubbs-': [('kubb', True), ('kubbe', True)],
          'kuckel': [('kuckel', True)],
          'kuckel-': [('kuckel', True)],
          'kucklet': [('kuckel', True)],
          'kucklets': [('kuckel', True)],
          'kudd': [('kudde', True)],
          'kudd-': [('kudde', True)],
          'kuddar': [('kudde', False)],
          'kuddarna': [('kudde', False)],
          'kuddarnas': [('kudde', False)],
          'kuddars': [('kudde', False)],
          'kudden': [('kudde', False)],
          'kuddens': [('kudde', False)],
          'kudds': [('kudde', True)],
          'kudds-': [('kudde', True)],
          'kuer': [('ku', False)],
          'kuerna': [('ku', False)],
          'kuernas': [('ku', False)],
          'kuers': [('ku', False)],
          'kuet': [('ku', False)],
          'kuff': [('kuff', False)],
          'kuff-': [('kuff', False)],
          'kuffar': [('kuff', False)],
          'kuffarna': [('kuff', False)],
          'kuffs': [('kuff', False)],
          'kuffs-': [('kuff', False)],
          'kufs-': [('kuf', True)],
          'kugg': [('kugge', True)],
          'kugg-': [('kugge', True)],
          'kuggar': [('kugge', True)],
          'kuggarna': [('kugge', True)],
          'kuggarnas': [('kugge', True)],
          'kugge': [('kugge', True)],
          'kuggens': [('kugge', True)],
          'kuggs': [('kugge', True)],
          'kuggs-': [('kugge', True)],
          'kukarnas': [('kuk', True)],
          'kul': [('kula', False)],
          'kul-': [('kula', False)],
          'kula': [('kula', False)],
          'kulan': [('kula', False)],
          'kulans': [('kula', False)],
          'kular': [('kular', False)],
          'kulars': [('kular', False)],
          'kulas': [('kula', False)],
          'kulden': [('kuld', False)],
          'kuldens': [('kuld', False)],
          'kuli': [('kuli', True)],
          'kulin': [('kuli', True)],
          'kulin-': [('kulinum', False)],
          'kulinen': [('kulinum', False)],
          'kulinens': [('kulinum', False)],
          'kuliner': [('kulinum', False)],
          'kulinerna': [('kulinum', False)],
          'kulinernas': [('kulinum', False)],
          'kuliners': [('kulinum', False)],
          'kulinet': [('kulinum', False)],
          'kulinets': [('kulin', False)],
          'kulins': [('kuli', True)],
          'kulis': [('kuli', True)],
          'kull': [('kulle', True), ('kull', True), ('kulla', True)],
          'kull-': [('kulle', True), ('kull', True), ('kulla', True)],
          'kullar': [('kulle', True), ('kull', True)],
          'kullarna': [('kull', True), ('kulle', True)],
          'kullarnas': [('kull', True), ('kulle', True)],
          'kullars': [('kull', True), ('kulle', True)],
          'kulle': [('kulle', True), ('kulla', True)],
          'kulle-': [('kulla', False)],
          'kullen': [('kull', True), ('kulle', True)],
          'kullens': [('kull', True), ('kulle', True)],
          'kulls': [('kulla', True), ('kull', True), ('kulle', True)],
          'kulls-': [('kulle', True), ('kulla', True), ('kull', True)],
          'kulor': [('kula', True)],
          'kulorna': [('kula', True)],
          'kulornas': [('kula', True)],
          'kulors': [('kula', True)],
          'kulott-': [('kulott', False)],
          'kulotten': [('kulott', False)],
          'kulotter': [('kulott', False)],
          'kulotterna': [('kulott', False)],
          'kulotternas': [('kulott', False)],
          'kulotters': [('kulott', False)],
          'kulotts': [('kulott', False)],
          'kuls': [('kula', False)],
          'kuls-': [('kula', False)],
          'kult-': [('kult', False)],
          'kultar': [('kult', True)],
          'kultarna': [('kult', True)],
          'kultarnas': [('kult', True)],
          'kultars': [('kult', True)],
          'kulten': [('kult', False)],
          'kultens': [('kult', False)],
          'kulter': [('kult', False)],
          'kultets': [('kultet', False)],
          'kults': [('kult', False)],
          'kults-': [('kult', False)],
          'kumlar': [('kummel', True)],
          'kumlarna': [('kummel', True)],
          'kumlen': [('kummel', False)],
          'kumlens': [('kummel', False)],
          'kumlet': [('kummel', False)],
          'kumlets': [('kummel', True)],
          'kummis': [('kummis', False)],
          'kummis-': [('kummis', False)],
          'kumpan': [('kumpan', True)],
          'kumpans': [('kumpan', True)],
          'kumpor': [('kumpa', False)],
          'kumporna': [('kumpa', False)],
          'kumpornas': [('kumpa', False)],
          'kumpors': [('kumpa', False)],
          'kun': [('ku', False)],
          'kuna': [('ku', False)],
          'kunas': [('ku', False)],
          'kund': [('kund', False)],
          'kund-': [('kund', False)],
          'kunder': [('kund', False)],
          'kunderna': [('kund', False)],
          'kunders': [('kund', False)],
          'kunds': [('kund', False)],
          'kunds-': [('kund', False)],
          'kung': [('kung', False)],
          'kung-': [('kung', False)],
          'kungar': [('kung', True)],
          'kungarna': [('kung', False)],
          'kungarnas': [('kung', False)],
          'kungars': [('kung', False)],
          'kungen': [('kung', False)],
          'kungens': [('kung', False)],
          'kungs': [('kung', False)],
          'kungs-': [('kung', False)],
          'kuniversitetet': [('kuniversitet', False)],
          'kunk': [('kunk', False)],
          'kunk-': [('kunk', False)],
          'kunkarnas': [('kunk', False)],
          'kunkars': [('kunk', False)],
          'kunken': [('kunk', False)],
          'kunkens': [('kunk', False)],
          'kunks': [('kunk', False)],
          'kunks-': [('kunk', False)],
          'kunnar': [('kunnare', False)],
          'kunnarnas': [('kunnare', False)],
          'kuns': [('ku', False)],
          'kuns-': [('kun', False)],
          'kunskaper': [('kunskap', True)],
          'kunskaperna': [('kunskap', True)],
          'kunskapernas': [('kunskap', True)],
          'kunskapers': [('kunskap', True)],
          'kunskaps': [('kunskap', True)],
          'kunskaps-': [('kunskap', False)],
          'kup': [('kupa', False)],
          'kup-': [('kupa', False)],
          'kupp': [('kupp', False)],
          'kupp-': [('kupp', False)],
          'kupps': [('kupp', False)],
          'kupps-': [('kupp', False)],
          'kups': [('kupa', False)],
          'kups-': [('kupa', True)],
          'kur': [('kur', True)],
          'kur-': [('kur', True)],
          'kuran': [('kura', False)],
          'kurans': [('kura', False)],
          'kurder': [('kurd', True), ('kurder', True)],
          'kurderna': [('kurd', True), ('kurder', True)],
          'kurdernas': [('kurd', True), ('kurder', True)],
          'kurders': [('kurd', True), ('kurder', True)],
          'kuret': [('kuret', False)],
          'kurets': [('kuret', False)],
          'kurie': [('kuria', True)],
          'kuriosa': [('kuriosum', True)],
          'kuriosas': [('kuriosum', True)],
          'kuris': [('kuria', True)],
          'kurk': [('kurk', False)],
          'kurk-': [('kurk', False)],
          'kurks': [('kurk', False)],
          'kurks-': [('kurk', False)],
          'kurna': [('ku', False)],
          'kurnas': [('kurna', False)],
          'kurne': [('kurna', False)],
          'kurr': [('kurr', True), ('kurre', True)],
          'kurr-': [('kurre', True), ('kurr', True)],
          'kurren': [('kurre', True), ('kurr', True)],
          'kurrens': [('kurre', True), ('kurr', True)],
          'kurrs': [('kurre', True), ('kurr', True)],
          'kurrs-': [('kurre', True), ('kurr', True)],
          'kurs': [('kur', True), ('kurs', True)],
          'kurs-': [('kur', True), ('kurs', True)],
          'kursarna': [('kursare', True)],
          'kursarnas': [('kursare', True)],
          'kurser': [('kurs', False)],
          'kurserna': [('kurs', False)],
          'kursernas': [('kurs', False)],
          'kursers': [('kurs', False)],
          'kurtagen': [('kurtage', True)],
          'kurtagens': [('kurtage', True)],
          'kurtaget': [('kurtage', True)],
          'kurtagets': [('kurtage', True)],
          'kurv': [('kurvor', True), ('kurva', True)],
          'kurv-': [('kurvor', True), ('kurva', True)],
          'kurvor': [('kurvor', True), ('kurva', True)],
          'kurvorna': [('kurvor', True), ('kurva', True)],
          'kurvornas': [('kurvor', True), ('kurva', True)],
          'kurvors': [('kurvor', True), ('kurva', True)],
          'kurvs': [('kurvor', True), ('kurva', True)],
          'kurvs-': [('kurvor', True), ('kurva', True)],
          'kus': [('kuse', True)],
          'kus-': [('kuse', True)],
          'kusan': [('kusa', False)],
          'kusans': [('kusa', False)],
          'kusar': [('kuse', True)],
          'kusarna': [('kuse', True)],
          'kusarnas': [('kuse', True)],
          'kusars': [('kuse', True)],
          'kuse': [('kuse', True)],
          'kusen': [('kuse', True)],
          'kusens': [('kuse', True)],
          'kusin': [('kusin', True)],
          'kusiner': [('kusin', False)],
          'kusinerna': [('kusin', True)],
          'kusinernas': [('kusin', True)],
          'kusiners': [('kusin', True)],
          'kusins': [('kusin', True)],
          'kusk': [('kusk', True)],
          'kusk-': [('kusk', False)],
          'kuskar': [('kusk', True)],
          'kuskarna': [('kusk', False)],
          'kuskarnas': [('kusk', False)],
          'kuskars': [('kusk', False)],
          'kusken': [('kusk', True)],
          'kuskens': [('kusk', False)],
          'kust-': [('kust', False)],
          'kuster': [('kust', False)],
          'kusterna': [('kust', True)],
          'kusternas': [('kust', False)],
          'kusters': [('kust', False)],
          'kut': [('kut', True)],
          'kut-': [('kut', True)],
          'kutan': [('kuta', False)],
          'kutarnas': [('kut', True)],
          'kuteri': [('kuteri', False)],
          'kuteri-': [('kuteri', False)],
          'kuteriers': [('kuteri', False)],
          'kuteriet': [('kuteri', False)],
          'kutor': [('kutor', False)],
          'kutors': [('kutor', False)],
          'kuts': [('kuts', True), ('kut', True)],
          'kuts-': [('kut', True), ('kuts', True)],
          'kutsar': [('kuts', False)],
          'kutsarna': [('kuts', True)],
          'kutsen': [('kuts', False)],
          'kutsens': [('kuts', True)],
          'kutt': [('kutt', False)],
          'kutt-': [('kutt', False)],
          'kutten': [('kutt', False)],
          'kutts': [('kutt', False)],
          'kutts-': [('kutt', False)],
          'kvack': [('kvack', True)],
          'kvack-': [('kvack', True)],
          'kvacks': [('kvack', True)],
          'kvader': [('kvader', False)],
          'kvaders': [('kvader', False)],
          'kvak': [('kvaka', False)],
          'kvak-': [('kvaka', False)],
          'kvakans': [('kvaka', False)],
          'kvaks': [('kvaka', False)],
          'kvaks-': [('kvaka', False)],
          'kval': [('kval', False)],
          'kval-': [('kval', False)],
          'kvalen': [('kval', False)],
          'kvalens': [('kval', False)],
          'kvaller': [('kvaller', False)],
          'kvallers': [('kvaller', False)],
          'kvals': [('kval', True)],
          'kvals-': [('kval', False)],
          'kvan': [('kva', False)],
          'kvanne': [('kvanne', True)],
          'kvanne-': [('kvanne', True)],
          'kvans': [('kva', False)],
          'kvar': [('kvara', False)],
          'kvar-': [('kvara', False)],
          'kvaran': [('kvara', False)],
          'kvarans': [('kvara', False)],
          'kvarie': [('kvarium', False)],
          'kvarie-': [('kvarium', False)],
          'kvarier': [('kvarie', False)],
          'kvarierna': [('kvarium', False)],
          'kvariernas': [('kvarie', False)],
          'kvariers': [('kvarium', False)],
          'kvarnarnas': [('kvarn', False)],
          'kvarter': [('kvart', True), ('kvarter', True)],
          'kvarters': [('kvart', True), ('kvarter', True)],
          'kvarts': [('kvart', True), ('kvarts', True)],
          'kvarts-': [('kvarts', True), ('kvart', True)],
          'kvas': [('kva', False)],
          'kvasar': [('kvasar', True)],
          'kvasars': [('kvasar', True)],
          'kvaskar': [('kvasker', False)],
          'kvaskarna': [('kvasker', False)],
          'kvaskarnas': [('kvasker', False)],
          'kvaskars': [('kvasker', False)],
          'kvatten': [('kvatten', False)],
          'kveck': [('kvecka', False)],
          'kveck-': [('kvecka', False)],
          'kvecks': [('kvecka', False)],
          'kvecks-': [('kvecka', False)],
          'kvens': [('kvens', False)],
          'kvens-': [('kvens', False)],
          'kverande': [('kverande', False)],
          'kverande-': [('kverande', False)],
          'kverkets': [('kverk', False)],
          'kvers': [('kvers', False)],
          'kversen': [('kvers', False)],
          'kvett': [('kvett', False)],
          'kvetts': [('kvett', False)],
          'kvetts-': [('kvett', False)],
          'kvidan': [('kvidan', True)],
          'kvidans': [('kvidan', True)],
          'kvide': [('kvida', False)],
          'kvide-': [('kvida', False)],
          'kviden': [('kvid', False)],
          'kvidens': [('kvid', False)],
          'kvider': [('kvid', False)],
          'kviders': [('kvid', False)],
          'kvids-': [('kvida', False)],
          'kvier': [('kviem', False)],
          'kvierna': [('kvium', False)],
          'kviernas': [('kviem', False)],
          'kviers': [('kviem', False)],
          'kviet': [('kviem', False)],
          'kviets': [('kviem', False)],
          'kvigg': [('kvigg', False)],
          'kviggar': [('kvigg', False)],
          'kviggarna': [('kvigg', False)],
          'kviggarnas': [('kvigg', False)],
          'kviggars': [('kvigg', False)],
          'kviggen': [('kvigg', False)],
          'kviggens': [('kvigg', False)],
          'kviggs': [('kvigg', False)],
          'kviggs-': [('kvigg', False)],
          'kvill': [('kvill', False)],
          'kvill-': [('kvill', False)],
          'kvillens': [('kvill', False)],
          'kvills': [('kvill', False)],
          'kvin': [('kvin', False)],
          'kving': [('kvinge', False)],
          'kving-': [('kvinge', False)],
          'kvingar': [('kvinge', False)],
          'kvingarna': [('kvinge', False)],
          'kvingarnas': [('kvinge', False)],
          'kvingars': [('kvinge', False)],
          'kvingen': [('kvinge', False)],
          'kvingens': [('kvinge', False)],
          'kvings': [('kvinge', False)],
          'kvings-': [('kvinge', False)],
          'kvinn-': [('kvinna', True)],
          'kvinns': [('kvinna', True), ('kvinns', True)],
          'kvinns-': [('kvinna', True), ('kvinns', True)],
          'kvins': [('kvin', False)],
          'kvins-': [('kvin', False)],
          'kvinter': [('kvint', False)],
          'kvinters': [('kvint', True)],
          'kviol': [('kviol', False)],
          'kviol-': [('kviol', False)],
          'kviols': [('kviol', False)],
          'kviols-': [('kviol', False)],
          'kvis': [('kvisa', False)],
          'kvis-': [('kvis', False)],
          'kvisa': [('kvisa', False)],
          'kvisar': [('kvis', False)],
          'kvisarna': [('kvis', False)],
          'kvisarnas': [('kvis', False)],
          'kvisars': [('kvis', False)],
          'kvisas': [('kvisa', False)],
          'kvise': [('kvisa', False)],
          'kvisen': [('kvis', False)],
          'kvisens': [('kvis', False)],
          'kvisitor': [('kvisita', False)],
          'kvisitors': [('kvisita', False)],
          'kvisor': [('kvisa', False)],
          'kvist': [('kvist', False)],
          'kvist-': [('kvist', False)],
          'kvisten': [('kvist', False)],
          'kvistens': [('kvist', False)],
          'kvitet': [('kvitet', False)],
          'kvitets': [('kvitet', False)],
          'kvittens': [('kvitten', True), ('kvittens', True)],
          'kvittens-': [('kvittens', True), ('kvitten', True)],
          'kvots': [('kvot', False)],
          'kvägar': [('kväg', False)],
          'kvägarna': [('kväg', False)],
          'kvägarnas': [('kväg', False)],
          'kvägen': [('kväg', False)],
          'kvägs': [('kväg', False)],
          'kvägs-': [('kväg', False)],
          'kvälden': [('kvälde', False)],
          'kväldens': [('kvälde', False)],
          'kvältar': [('kvältare', False)],
          'kvältarna': [('kvältare', False)],
          'kvältarnas': [('kvältare', False)],
          'kvärden': [('kvärde', False)],
          'kvärdens': [('kvärde', False)],
          'kvärdet': [('kvärde', False)],
          'kväsendet': [('kväsen', False)],
          'kväsendets': [('kväsen', False)],
          'kvättar': [('kvätt', False)],
          'kvättarna': [('kvätt', False)],
          'kvättarnas': [('kvätt', False)],
          'kvättars': [('kvätt', False)],
          'kvätte': [('kvätta', False)],
          'kvätten': [('kvätt', False)],
          'kvättens': [('kvätt', False)],
          'kväxlar': [('kväxel', False)],
          'kväxlarna': [('kväxel', False)],
          'kväxlarnas': [('kväxel', False)],
          'kvågarna': [('kvåg', False)],
          'kvårdar': [('kvårdare', False)],
          'kvårdarna': [('kvårdare', False)],
          'kvårdarnas': [('kvårdare', False)],
          'ky': [('ky', False)],
          'ky-': [('ky', False)],
          'kyar': [('ky', False)],
          'kyarna': [('ky', False)],
          'kydd': [('kydd', False)],
          'kydds': [('kydd', False)],
          'kydds-': [('kydd', False)],
          'kyer': [('ky', False)],
          'kyerna': [('ky', False)],
          'kyernas': [('ky', False)],
          'kyers': [('ky', False)],
          'kyggets': [('kygge', False)],
          'kyggs': [('kygge', False)],
          'kyggs-': [('kygge', False)],
          'kyl': [('kyl', True), ('kyla', True)],
          'kyl-': [('kyl', True), ('kyla', True)],
          'kylar': [('kylare', True), ('kyl', True)],
          'kylarna': [('kylare', True), ('kyl', True)],
          'kylarnas': [('kylare', True), ('kyl', True)],
          'kylas': [('kyla', False)],
          'kyllandet': [('kyllande', False)],
          'kyllans': [('kyllan', False)],
          'kyllernas': [('kyller', True)],
          'kyls': [('kyl', True)],
          'kyls-': [('kyl', True)],
          'kylt-': [('kylt', False)],
          'kyltar': [('kylt', False)],
          'kyltarna': [('kylt', False)],
          'kylten': [('kylt', False)],
          'kyltens': [('kylt', False)],
          'kylts': [('kylt', False)],
          'kylts-': [('kylt', False)],
          'kymtarna': [('kymt', False)],
          'kymtarnas': [('kymt', False)],
          'kyn': [('ky', False)],
          'kyndans': [('kyndan', False)],
          'kynken': [('kynke', False)],
          'kynkens': [('kynke', False)],
          'kynket': [('kynke', False)],
          'kynkets': [('kynke', False)],
          'kynks': [('kynke', False)],
          'kynks-': [('kynke', False)],
          'kynns-': [('kynne', True)],
          'kyns': [('ky', False)],
          'kypar': [('kyp', True), ('kypare', True)],
          'kyparna': [('kypare', True), ('kyp', True)],
          'kyparnas': [('kyp', True), ('kypare', True)],
          'kyrers': [('kyr', False)],
          'kyrie-': [('kyria', False)],
          'kyrkan': [('kyrka', False)],
          'kyrkans': [('kyrka', False)],
          'kyrke': [('kyrka', False)],
          'kys': [('ky', False)],
          'kys-': [('ky', False)],
          'kyssar': [('kyss', False)],
          'kyssarna': [('kyss', False)],
          'kyt': [('kyt', False)],
          'kyt-': [('kyt', False)],
          'kyts': [('kyt', False)],
          'kyts-': [('kyt', False)],
          'kytt': [('kytt', False)],
          'kytt-': [('kytt', False)],
          'kyttar': [('kytt', False)],
          'kytte-': [('kytte', False)],
          'kytten': [('kytt', False)],
          'kyttens': [('kytt', False)],
          'kyttet': [('kytt', True)],
          'kyttets': [('kytt', True)],
          'kytts': [('kytt', False)],
          'kytts-': [('kytt', False)],
          'kyx': [('kyxa', False)],
          'kyx-': [('kyxa', False)],
          'kzon': [('kzon', False)],
          'kzonen': [('kzon', False)],
          'käck': [('käck', False)],
          'käck-': [('käck', False)],
          'käckar': [('käck', False)],
          'käckarna': [('käck', False)],
          'käcken': [('käck', False)],
          'käckens': [('käck', False)],
          'käcks': [('käck', False)],
          'käcks-': [('käck', False)],
          'kädd-': [('kädda', False)],
          'kädde': [('kädda', False)],
          'kädde-': [('kädda', False)],
          'käft': [('käft', True)],
          'käft-': [('käft', True)],
          'käften': [('käft', True)],
          'käftens': [('käft', True)],
          'käfts': [('käft', True)],
          'käfts-': [('käft', True)],
          'kägar': [('kägare', False)],
          'kägarnas': [('kägare', False)],
          'kägel': [('kägel', True), ('kägla', True)],
          'kägel-': [('kägel', True), ('kägla', True)],
          'kägg': [('kägg', False)],
          'kägg-': [('kägg', False)],
          'käggs': [('kägg', False)],
          'käggs-': [('kägg', False)],
          'käk': [('käk', True), ('käke', True)],
          'käk-': [('käk', True), ('käke', True)],
          'käkar': [('käke', False)],
          'käkarnas': [('käke', False)],
          'käke': [('käke', False)],
          'käken': [('käke', False)],
          'käkens': [('käke', True)],
          'käkets': [('käk', True)],
          'käks': [('käk', True), ('käke', True)],
          'käks-': [('käk', True), ('käke', True)],
          'käkte': [('käkta', False)],
          'käkts-': [('käkta', False)],
          'kälkarnas': [('kälke', True)],
          'käll': [('källa', True)],
          'käll-': [('källa', True)],
          'källan': [('källa', False)],
          'källanden': [('källande', False)],
          'källandena': [('källande', False)],
          'källandenas': [('källande', False)],
          'källandens': [('källande', False)],
          'källarna': [('källare', False)],
          'källarnas': [('källare', True)],
          'källe': [('källa', False)],
          'källe-': [('källa', False)],
          'kället': [('käll', False)],
          'källets': [('käll', False)],
          'källningar': [('källning', False)],
          'källningarna': [('källning', False)],
          'källningarnas': [('källning', False)],
          'källningars': [('källning', False)],
          'källnings': [('källning', False)],
          'källnings-': [('källning', False)],
          'källs': [('källa', False)],
          'källs-': [('källa', False)],
          'käls': [('käl', False)],
          'kält-': [('kält', True)],
          'kältet': [('kält', True)],
          'kälts': [('kält', True)],
          'kälts-': [('kält', True)],
          'kämpar': [('kämpe', True)],
          'kämparna': [('kämpe', False)],
          'kämparnas': [('kämpe', True)],
          'kämt': [('kämt', False)],
          'kämt-': [('kämt', False)],
          'kämten': [('kämt', False)],
          'kämtens': [('kämt', False)],
          'kämts': [('kämt', False)],
          'kämts-': [('kämt', False)],
          'känd': [('kända', False)],
          'känd-': [('kända', False)],
          'kändar': [('kände', False)],
          'kändarna': [('kände', False)],
          'känds': [('kända', False)],
          'känds-': [('kända', False)],
          'käng': [('käng', True), ('känga', True)],
          'käng-': [('käng', True), ('känga', True)],
          'känge': [('känga', True)],
          'kängen': [('käng', True)],
          'kängens': [('käng', False)],
          'känger': [('käng', True)],
          'kängerna': [('käng', True)],
          'kängernas': [('käng', False)],
          'kängers': [('käng', True)],
          'kängs': [('käng', True), ('känga', True)],
          'kängs-': [('käng', True), ('känga', True)],
          'känke': [('känka', False)],
          'känken': [('känk', False)],
          'känkens': [('känk', False)],
          'känker': [('känk', False)],
          'känkerna': [('känk', False)],
          'känkernas': [('känk', False)],
          'känkers': [('känk', False)],
          'käpp': [('käpp', False)],
          'käpp-': [('käpp', False)],
          'käppar': [('käpp', False)],
          'käpparna': [('käpp', False)],
          'käppe': [('käppa', False)],
          'käppe-': [('käppa', False)],
          'käppen': [('käpp', False)],
          'käppens': [('käpp', False)],
          'käpps': [('käpp', False)],
          'käpps-': [('käpp', False)],
          'käran': [('kära', False)],
          'kärans': [('kära', False)],
          'kärarnas': [('kärare', False)],
          'kärl': [('kärl', False)],
          'kärl-': [('kärl', False)],
          'kärls': [('kärl', False)],
          'kärls-': [('kärl', False)],
          'kärmar': [('kärm', False)],
          'kärmarna': [('kärm', False)],
          'kärmarnas': [('kärm', False)],
          'kärmens': [('kärm', False)],
          'kärmet': [('kärm', False)],
          'kärn': [('kärna', True)],
          'kärnarnas': [('kärnare', False)],
          'kärnorna': [('kärna', False)],
          'kärnornas': [('kärna', False)],
          'kärns': [('kärna', True)],
          'kärp': [('kärp', False)],
          'kärp-': [('kärp', False)],
          'kärpen': [('kärp', False)],
          'kärpens': [('kärp', False)],
          'kärps': [('kärp', False)],
          'kärps-': [('kärp', False)],
          'kärr': [('kärr', True), ('kärra', True)],
          'kärr-': [('kärr', True), ('kärra', True)],
          'kärrs': [('kärr', True), ('kärra', True)],
          'kärrs-': [('kärr', True), ('kärra', True)],
          'kärt': [('kärt', False)],
          'kärt-': [('kärt', False)],
          'kärter': [('kärt', False)],
          'kärterna': [('kärt', False)],
          'kärternas': [('kärt', False)],
          'kärters': [('kärt', False)],
          'kärts-': [('kärt', False)],
          'kärv': [('kärve', True)],
          'kärv-': [('kärve', False)],
          'kärvar': [('kärve', True)],
          'kärvarna': [('kärve', True)],
          'kärvarnas': [('kärve', True)],
          'kärvars': [('kärve', True)],
          'kärve': [('kärve', True)],
          'kärven': [('kärve', True)],
          'kärvens': [('kärve', True)],
          'kärvs': [('kärve', True)],
          'kärvs-': [('kärve', True)],
          'kät-': [('kät', False)],
          'kätt': [('kätte', False)],
          'kätt-': [('kätte', False)],
          'kättar': [('kättare', True), ('kätte', True)],
          'kättarna': [('kätte', True), ('kättare', True)],
          'kättarnas': [('kättare', True), ('kätte', True)],
          'kätten': [('kätte', False)],
          'kättens': [('kätte', False)],
          'kätts': [('kätte', True)],
          'kätts-': [('kätte', True)],
          'kävor': [('kävor', False)],
          'kävorna': [('kävor', False)],
          'kävornas': [('kävor', False)],
          'kävors': [('kävor', False)],
          'kå': [('kå', False)],
          'kå-': [('kå', False)],
          'kåd': [('kåda', True)],
          'kåd-': [('kåda', True)],
          'kådan': [('kåda', True)],
          'kådans': [('kåda', True)],
          'kådar': [('kådare', False)],
          'kådarna': [('kådare', False)],
          'kåder': [('kådra', False)],
          'kåder-': [('kådra', False)],
          'kåders': [('kåder', False)],
          'kådra': [('kåder', False)],
          'kådran': [('kådra', False)],
          'kådrans': [('kåder', False)],
          'kådras': [('kådra', False)],
          'kådre': [('kådra', False)],
          'kådre-': [('kåder', False)],
          'kådror': [('kåder', False)],
          'kådrorna': [('kåder', False)],
          'kådrornas': [('kådra', False)],
          'kådrors': [('kådra', False)],
          'kåds-': [('kåda', True)],
          'kåkar': [('kåk', False)],
          'kåkarna': [('kåk', False)],
          'kåkarnas': [('kåk', True)],
          'kålarnas': [('kål', False)],
          'kålars': [('kål', False)],
          'kåldolmar': [('kåldolme', True), ('kåldolma', True)],
          'kåldolmarna': [('kåldolme', True), ('kåldolma', True)],
          'kåldolmarnas': [('kåldolme', True), ('kåldolma', True)],
          'kåldolmars': [('kåldolme', True), ('kåldolma', True)],
          'kålen': [('kål', True)],
          'kålighets-': [('kålighet', False)],
          'kållandenas': [('kållande', False)],
          'kång-': [('kånga', False)],
          'kånge-': [('kånga', False)],
          'kångs': [('kånga', False)],
          'kångs-': [('kånga', False)],
          'kånk': [('kånk', False)],
          'kånk-': [('kånk', False)],
          'kånks': [('kånk', False)],
          'kånks-': [('kånk', False)],
          'kåns': [('kå', False)],
          'kåp': [('kåpa', False)],
          'kåp-': [('kåpa', True)],
          'kåps': [('kåpa', False)],
          'kåps-': [('kåpa', False)],
          'kår': [('kåre', True), ('kår', True)],
          'kår-': [('kår', True), ('kåre', True)],
          'kårande': [('kåranda', True), ('kårande', True)],
          'kårande-': [('kåranda', True), ('kårande', True)],
          'kårar': [('kåre', True)],
          'kårars': [('kåre', False)],
          'kåre': [('kåre', False)],
          'kåre-': [('kåre', False)],
          'kåren': [('kår', True), ('kåre', True)],
          'kårens': [('kår', True), ('kåre', True)],
          'kårs': [('kåre', True), ('kår', True)],
          'kårs-': [('kår', True), ('kåre', True)],
          'kås': [('kåsa', True)],
          'kås-': [('kåsa', True)],
          'kåsar': [('kås', False)],
          'kåt': [('kåta', True)],
          'kåt-': [('kåta', True)],
          'kåts': [('kåta', True)],
          'kåts-': [('kåta', True)],
          'kåvar': [('kåvara', False)],
          'kéerna': [('ké', False)],
          'kéernas': [('ké', False)],
          'kögat': [('köga', False)],
          'kögats': [('köga', False)],
          'kögonens': [('köga', False)],
          'kögons': [('köga', False)],
          'kök': [('kök', True)],
          'kökan': [('köka', False)],
          'kökans': [('köka', False)],
          'köken': [('kök', False)],
          'kökens': [('kök', False)],
          'kökets': [('kök', False)],
          'kökor': [('köka', False)],
          'köks': [('köksa', True), ('kök', True)],
          'köks-': [('köksa', True), ('kök', True)],
          'kön': [('kön', True), ('kö', True)],
          'köns': [('kön', True), ('kö', True)],
          'köns-': [('kön', True)],
          'kör': [('kör', True)],
          'kör-': [('kör', True)],
          'körarna': [('körare', False)],
          'körarnas': [('körare', False)],
          'kördar': [('körd', False)],
          'kördarna': [('körd', False)],
          'kören': [('kör', False)],
          'körens': [('kör', False)],
          'köret': [('köre', False)],
          'körn': [('kör', False)],
          'körnar': [('körnare', True)],
          'körnarna': [('körnare', True)],
          'körnarnas': [('körnare', True)],
          'körns': [('kör', False)],
          'körs': [('kör', True)],
          'körs-': [('kör', True)],
          'körten': [('kört', False)],
          'körtens': [('kört', False)],
          'körtet': [('kört', False)],
          'kös': [('kö', False)],
          'kös-': [('kös', False)],
          'köte': [('köte', False)],
          'köte-': [('köte', False)],
          'köter': [('köt', False)],
          'köterna': [('köt', False)],
          'köternas': [('köt', False)],
          'köters': [('köt', False)],
          'kötes': [('köte', False)],
          'kötes-': [('köte', False)],
          'kötet': [('köte', False)],
          'kött': [('kött', False)],
          'kött-': [('kött', False)],
          'kötts': [('kött', False)],
          'kötts-': [('kött', False)],
          'l': [('l', True)],
          'l-': [('l', True)],
          'la': [('la', False)],
          'la-': [('la', False)],
          'labb': [('labbe', True), ('labb', True)],
          'labb-': [('labb', True), ('labbe', True)],
          'labbar': [('labbe', True), ('labb', True)],
          'labbarna': [('labbe', True), ('labb', True)],
          'labbarnas': [('labb', True), ('labbe', True)],
          'labbars': [('labb', True), ('labbe', True)],
          'labben': [('labb', True), ('labbe', True)],
          'labbens': [('labbe', True), ('labb', True)],
          'labbs': [('labbe', True), ('labb', True)],
          'labbs-': [('labbe', True), ('labb', True)],
          'laber': [('laber', False)],
          'labers': [('laber', False)],
          'labon': [('labo', False)],
          'labons': [('labo', False)],
          'lacen': [('lac', False)],
          'lacens': [('lace', False)],
          'lacins': [('laci', False)],
          'lack': [('lack', True)],
          'lack-': [('lack', False)],
          'lackar': [('lack', False)],
          'lackarna': [('lack', False)],
          'lackarnas': [('lackare', False)],
          'lackars': [('lack', False)],
          'lacke': [('lacka', False)],
          'lacke-': [('lacka', False)],
          'lacken': [('lack', False)],
          'lackens': [('lack', False)],
          'lacker': [('lack', False)],
          'lackers': [('lack', False)],
          'lacket': [('lack', False)],
          'lackets': [('lack', False)],
          'lacklanden': [('lackland', False)],
          'lacklandens': [('lackland', False)],
          'lacklandet': [('lackland', False)],
          'lackor': [('lacka', False)],
          'lackorna': [('lacka', False)],
          'lackornas': [('lacka', False)],
          'lackors': [('lacka', False)],
          'lacks': [('lack', False)],
          'lacks-': [('lack', False)],
          'lad': [('lad', True), ('lada', True)],
          'lad-': [('lad', True), ('lada', True)],
          'ladd': [('ladd', False)],
          'laddar': [('laddare', True)],
          'laddarna': [('laddare', False)],
          'laddarnas': [('laddare', False)],
          'laddrarnas': [('laddrare', False)],
          'ladds': [('ladd', False)],
          'ladds-': [('ladd', False)],
          'ladets': [('lad', False)],
          'ladies': [('lady', True)],
          'ladiet': [('ladium', False)],
          'ladiets': [('ladium', False)],
          'ladium': [('ladium', False)],
          'ladiums': [('ladium', False)],
          'lads': [('lad', True), ('lada', True)],
          'lads-': [('lad', True), ('lada', True)],
          'lafader': [('lafader', False)],
          'lafaders-': [('lafader', False)],
          'lafar': [('laf', False)],
          'laff': [('laff', False)],
          'laff-': [('laff', False)],
          'laffar': [('laff', False)],
          'laffarna': [('laff', False)],
          'laffe': [('laffa', False)],
          'laffe-': [('laffa', False)],
          'laffen': [('laff', False)],
          'laffer': [('laff', False)],
          'laffers': [('laff', False)],
          'laffs': [('laff', False)],
          'laffs-': [('laff', False)],
          'lafs': [('lafs', False)],
          'lafs-': [('lafs', False)],
          'lafsar': [('lafs', False)],
          'lafsarna': [('lafs', False)],
          'lag': [('lag', True)],
          'lag-': [('lag', True)],
          'lagan': [('laga', False)],
          'lagans': [('lagan', False)],
          'lagar': [('lag', True)],
          'lagar-': [('lagare', False)],
          'lagarna': [('lag', True)],
          'lagarnas': [('lag', True)],
          'lagars': [('lag', False)],
          'lage': [('lage', False)],
          'lage-': [('lage', False)],
          'lagen': [('lag', True)],
          'lagens': [('lag', True)],
          'lager': [('lager', False)],
          'lagerna': [('lager', True)],
          'lagernas': [('lager', True)],
          'lagers': [('lager', False)],
          'laget': [('lag', True)],
          'lagets': [('lag', False)],
          'lagg': [('lagg', False)],
          'lagg-': [('lagg', False)],
          'laggarna': [('lagg', False)],
          'laggarnas': [('lagg', False)],
          'laggars': [('lagg', True)],
          'lagge': [('lagga', False)],
          'lagge-': [('lagga', False)],
          'laggen': [('lagg', False)],
          'laggens': [('lagg', False)],
          'laggs': [('lagg', False)],
          'laggs-': [('lagg', False)],
          'lagman': [('lagman', True)],
          'lagmans': [('lagman', True)],
          'lagn': [('lagn', True)],
          'lagn-': [('lagn', True)],
          'lagns': [('lagn', True)],
          'lagns-': [('lagn', True)],
          'lago-': [('lago', False)],
          'lagrar': [('lager', False)],
          'lagrars': [('lager', False)],
          'lags': [('lag', True)],
          'lags-': [('lag', True)],
          'lagsverken': [('lagsverk', False)],
          'lagsverkens': [('lagsverk', False)],
          'lagsverket': [('lagsverk', False)],
          'lagsverks': [('lagsverk', False)],
          'lagsverks-': [('lagsverk', False)],
          'lagsvärdens': [('lagsvärd', False)],
          'lagsvärdet': [('lagsvärd', False)],
          'lahäst': [('lahäst', False)],
          'lahäst-': [('lahäst', False)],
          'lahästar': [('lahäst', False)],
          'lahästarna': [('lahäst', False)],
          'lahästarnas': [('lahästar', False)],
          'lahästars': [('lahästar', False)],
          'lak': [('lake', True)],
          'lak-': [('lake', True)],
          'lakar': [('lake', False)],
          'lakarna': [('lake', True)],
          'lakarnas': [('lake', False)],
          'lakars': [('lake', False)],
          'lakat': [('lakat', False)],
          'lakats': [('lakat', False)],
          'lake': [('lake', True)],
          'lake-': [('lake', False)],
          'laken': [('lake', False)],
          'lakens': [('lake', False)],
          'lakes': [('lake', False)],
          'lakets': [('lak', False)],
          'lakrits-': [('lakrits', True)],
          'laks': [('lake', True)],
          'laks-': [('lake', True)],
          'lakter': [('lakt', False)],
          'lakterier': [('lakteri', False)],
          'lakteriets': [('lakteri', False)],
          'lakters': [('lakt', False)],
          'laktins': [('laktin', False)],
          'lakören': [('lakör', False)],
          'lakörens': [('lakör', False)],
          'lalien': [('lali', False)],
          'lalier': [('lali', False)],
          'lalierna': [('lali', False)],
          'laliernas': [('lali', False)],
          'laliers': [('lali', False)],
          'lalins': [('lali', False)],
          'lallanden': [('lallande', True)],
          'lallandens': [('lallande', True)],
          'lallandet': [('lallande', True)],
          'lals': [('lal', False)],
          'lam': [('lama', True)],
          'lam-': [('lama', True)],
          'laman': [('lama', True)],
          'lamans': [('lama', True)],
          'lamar': [('lamare', False)],
          'lamarna': [('lamare', False)],
          'lamas-': [('lama', True)],
          'lamat': [('lama', True)],
          'lamatens': [('lamat', False)],
          'lamats': [('lama', True)],
          'lamenten': [('lament', False)],
          'lamentens': [('lament', False)],
          'lamentet': [('lament', False)],
          'laments-': [('lament', False)],
          'lamet': [('lam', False)],
          'lamets': [('lam', False)],
          'lamin': [('lamin', False)],
          'lamins': [('lamin', False)],
          'lammar': [('lam', False)],
          'lammarnas': [('lam', False)],
          'lammen': [('lamm', True)],
          'lammens': [('lamm', False)],
          'lammerna': [('lammer', False)],
          'lammers': [('lammer', False)],
          'lammet': [('lamm', False)],
          'lammets': [('lamm', False)],
          'lamp': [('lampa', True)],
          'lamp-': [('lampa', True)],
          'lampar': [('lamp', False)],
          'lamparna': [('lamp', False)],
          'lampen': [('lamp', False)],
          'lampens': [('lamp', False)],
          'lamps': [('lampa', True)],
          'lamps-': [('lampa', True)],
          'lamrar': [('lammer', False)],
          'lams': [('lama', True)],
          'lams-': [('lama', True)],
          'lan': [('lan', True), ('lana', True)],
          'lan-': [('lan', True), ('lana', True)],
          'lana': [('lana', True)],
          'lanan': [('lana', False)],
          'lanans': [('lana', True)],
          'lanas': [('lana', True)],
          'land': [('land', False)],
          'land-': [('land', False)],
          'landagen': [('landag', False)],
          'landagens': [('landag', False)],
          'landar': [('landare', False)],
          'landaren': [('landare', False)],
          'landarna': [('landare', False)],
          'landarnas': [('landare', False)],
          'landen': [('land', False)],
          'landens': [('land', False)],
          'lander': [('land', False)],
          'landers': [('land', False)],
          'landet': [('land', False)],
          'landets': [('land', True)],
          'landis': [('landis', True)],
          'landrar': [('lander', False)],
          'landrarna': [('lander', False)],
          'landrarnas': [('lander', False)],
          'landrars': [('lander', False)],
          'lands': [('land', False)],
          'lands-': [('land', False)],
          'landserfarenheter': [('landserfarenheter', False)],
          'landserfarenheterna': [('landserfarenheter', False)],
          'landserfarenheternas': [('landserfarenheter', False)],
          'landserfarenheters': [('landserfarenheter', False)],
          'landserfarenhets': [('landserfarenheter', False)],
          'landserfarenhets-': [('landserfarenheter', False)],
          'landsträck': [('landsträcka', True)],
          'landsträck-': [('landsträcka', True)],
          'landsträcks': [('landsträcka', True)],
          'landsträcks-': [('landsträcka', True)],
          'landsände': [('landsände', True), ('landsända', True)],
          'landsände-': [('landsända', True), ('landsände', True)],
          'lane': [('lana', True)],
          'lane-': [('lana', True)],
          'lanens': [('lan', False)],
          'laner': [('laner', True), ('lan', True)],
          'lanerna': [('laner', True), ('lan', True)],
          'lanernas': [('laner', True), ('lan', True)],
          'laners': [('laner', True), ('lan', True)],
          'lang': [('lang', False)],
          'lang-': [('lang', False)],
          'langar': [('langare', True)],
          'langaren': [('langare', False)],
          'langarna': [('langare', True)],
          'langarnas': [('langare', True)],
          'langars': [('lang', False)],
          'langen': [('lang', False)],
          'langens': [('lang', False)],
          'langer': [('lang', False)],
          'langerna': [('lang', False)],
          'langernas': [('lang', False)],
          'langers': [('lang', False)],
          'langos': [('langos', True)],
          'langos-': [('langos', True)],
          'langosarna': [('langos', True)],
          'langs': [('lang', False)],
          'langs-': [('lang', False)],
          'lank': [('lanka', True), ('lank', True)],
          'lank-': [('lanka', True), ('lank', True)],
          'lankar': [('lankare', False)],
          'lankar-': [('lankare', False)],
          'lanke': [('lanka', False)],
          'lanke-': [('lanka', True)],
          'lanken': [('lank', False)],
          'lankens': [('lank', True)],
          'lanker': [('lank', False)],
          'lankerna': [('lank', False)],
          'lankernas': [('lank', False)],
          'lankers': [('lank', False)],
          'lankes': [('lankes', True)],
          'lankes-': [('lankes', True)],
          'lankor': [('lanka', False)],
          'lankorna': [('lanka', False)],
          'lankornas': [('lanka', False)],
          'lanks': [('lank', True), ('lanka', True)],
          'lanks-': [('lanka', True), ('lank', True)],
          'lann-': [('lann', True)],
          'lanns': [('lann', True)],
          'lanns-': [('lann', True)],
          'lanor': [('lana', True)],
          'lanorna': [('lana', False)],
          'lanornas': [('lana', True)],
          'lanors': [('lana', False)],
          'lans': [('lan', True), ('lans', True), ('lana', True)],
          'lans-': [('lana', True), ('lans', True)],
          'lansar': [('lans', False)],
          'lansaren': [('lansare', False)],
          'lansarna': [('lans', False)],
          'lansarnas': [('lans', True)],
          'lansars': [('lans', True)],
          'lansen': [('lans', False)],
          'lansens': [('lans', False)],
          'lanser': [('lans', False)],
          'lanserna': [('lans', False)],
          'lansernas': [('lans', False)],
          'lansers': [('lans', False)],
          'lansk': [('lanska', False)],
          'lansk-': [('lanska', False)],
          'lanstalter': [('lanstalt', False)],
          'lanstalterna': [('lanstalt', False)],
          'lanstalternas': [('lanstalt', False)],
          'lanstalters': [('lanstalt', False)],
          'lanstalts': [('lanstalt', False)],
          'lanstalts-': [('lanstalt', False)],
          'lant': [('lant', False)],
          'lant-': [('lanta', False)],
          'lanta': [('lanta', False)],
          'lantan': [('lantan', True)],
          'lantans': [('lantan', True)],
          'lantar': [('lant', False)],
          'lantarna': [('lant', False)],
          'lantars': [('lant', False)],
          'lante': [('lanta', False)],
          'lante-': [('lanta', False)],
          'lanten': [('lant', False)],
          'lantens': [('lant', False)],
          'lanter': [('lant', False)],
          'lanterna': [('lanterna', True)],
          'lanternas': [('lanterna', True)],
          'lanters': [('lant', False)],
          'lantor': [('lanta', False)],
          'lantors': [('lanta', False)],
          'lantras': [('lantras', True)],
          'laområdet': [('laområde', False)],
          'lap': [('lapa', False)],
          'lap-': [('lapa', False)],
          'lapan': [('lapa', False)],
          'lapans': [('lapa', False)],
          'lapas': [('lapa', False)],
          'lapp': [('lapp', False)],
          'lapp-': [('lapp', False)],
          'lappar': [('lapp', False)],
          'lappars': [('lapp', False)],
          'lappe': [('lappa', False)],
          'lappen': [('lapp', False)],
          'lappens': [('lapp', False)],
          'lapper': [('lapper', False)],
          'lapps': [('lapp', False)],
          'lapps-': [('lapp', False)],
          'laps': [('laps', False)],
          'laps-': [('laps', False)],
          'lar': [('el', False)],
          'lar-': [('lare', False)],
          'laranden': [('larand', False)],
          'larandens': [('larand', False)],
          'lard': [('lard', False)],
          'lard-': [('lard', False)],
          'lardagen': [('lardag', False)],
          'lardagens': [('lardag', False)],
          'larden': [('lard', False)],
          'lardens': [('lard', False)],
          'larder': [('lard', False)],
          'larderna': [('lard', False)],
          'lardernas': [('lard', False)],
          'larders': [('lard', False)],
          'lards': [('lard', False)],
          'lare': [('lare', False)],
          'lare-': [('larea', False)],
          'laren': [('lar', False)],
          'larens': [('lare', False)],
          'lares': [('lare', False)],
          'lares-': [('larea', False)],
          'largon': [('largo', True)],
          'largons': [('largo', True)],
          'largot': [('largo', True)],
          'largots': [('largo', True)],
          'larian': [('laria', False)],
          'larians': [('laria', False)],
          'larie': [('larium', False)],
          'larier': [('larium', False)],
          'lariernas': [('larium', False)],
          'lariers': [('larium', False)],
          'larisarnas': [('laris', False)],
          'larisen': [('laris', False)],
          'larismer': [('larism', False)],
          'larismerna': [('larism', False)],
          'larismernas': [('larism', False)],
          'larismers': [('larism', False)],
          'larkar': [('lark', False)],
          'larkarna': [('lark', False)],
          'larmar': [('larm', False)],
          'larmarna': [('larm', False)],
          'larmarnas': [('larm', False)],
          'larn': [('larn', False)],
          'larna': [('el', False)],
          'larnas': [('el', False)],
          'larns': [('larn', False)],
          'larområdet': [('larområd', False)],
          'larren': [('larre', False)],
          'larrens': [('larre', False)],
          'larrock': [('larrock', False)],
          'lars': [('el', False)],
          'lars-': [('larer', False)],
          'larsen': [('lar', False)],
          'larskens': [('larsken', False)],
          'lart': [('lart', False)],
          'lartens': [('lart', False)],
          'larter': [('lart', False)],
          'larterna': [('lart', False)],
          'larternas': [('lart', False)],
          'larters': [('lart', False)],
          'lartron': [('lartro', False)],
          'lartros': [('lartro', False)],
          'lartros-': [('lartro', False)],
          'larts-': [('lart', False)],
          'larv': [('larv', True), ('larva', True)],
          'larv-': [('larva', True), ('larv', True)],
          'larvar': [('larver', True)],
          'larvarna': [('larver', True)],
          'larvarnas': [('larver', True)],
          'larvars': [('larver', True)],
          'larve': [('larva', True)],
          'larven': [('larv', False)],
          'larvens': [('larv', False)],
          'larver': [('larver', True), ('larv', True)],
          'larvers': [('larver', True), ('larv', True)],
          'larvs': [('larva', True), ('larv', True)],
          'larvs-': [('larv', True), ('larva', True)],
          'las': [('la', False)],
          'las-': [('las', False)],
          'lasar': [('lase', False)],
          'lasarna': [('la', False)],
          'lasarnas': [('la', False)],
          'lasars': [('lase', False)],
          'lase': [('lase', False)],
          'lase-': [('lase', False)],
          'lasen': [('lase', False)],
          'lasens': [('la', False)],
          'laser': [('laser', False)],
          'lasers': [('laser', True)],
          'lasier': [('lasi', False)],
          'lasierna': [('lasi', False)],
          'lasiernas': [('lasi', False)],
          'lasins': [('lasi', False)],
          'lasis': [('lasi', False)],
          'lask': [('lask', False)],
          'lask-': [('lask', True)],
          'laskarna': [('lask', True)],
          'laske': [('laska', False)],
          'laske-': [('laska', False)],
          'lasket': [('lask', False)],
          'laskets': [('lask', False)],
          'lasklock': [('lasklocka', False)],
          'lasklocks': [('lasklock', False)],
          'lasklocks-': [('lasklock', False)],
          'laskorna': [('laska', False)],
          'laskornas': [('laska', False)],
          'laskors': [('laska', False)],
          'lasmat': [('lasmat', False)],
          'lasmats': [('lasmat', False)],
          'lasmerna': [('lasma', False)],
          'lasmers': [('lasma', False)],
          'lass': [('lass', False)],
          'lassar': [('lass', False)],
          'lassarna': [('lass', False)],
          'lassarnas': [('lasse', False)],
          'lassars': [('lass', False)],
          'lassen': [('lass', False)],
          'lassens': [('lass', False)],
          'lasset': [('lass', False)],
          'lasspinnar': [('lasspinne', False)],
          'lasspinnarna': [('lasspinne', False)],
          'lasspinnarnas': [('lasspinne', False)],
          'last-': [('last', False)],
          'lastan': [('lastad', False)],
          'lastans': [('lastad', False)],
          'lastarnas': [('lastare', False)],
          'lasten': [('last', False)],
          'laster': [('last', False)],
          'lasterna': [('last', False)],
          'lasternas': [('last', False)],
          'lasters': [('last', False)],
          'lastrum': [('lastrum', True)],
          'lastrums-': [('lastrum', True)],
          'lasvar': [('lasvar', False)],
          'lat': [('later', True)],
          'lat-': [('later', True)],
          'lata': [('lata', False)],
          'latan': [('lata', False)],
          'latans': [('latan', False)],
          'latarna': [('late', False)],
          'latars': [('late', False)],
          'latas': [('lata', False)],
          'laten': [('late', False)],
          'latens': [('latens', True)],
          'latens-': [('latens', True)],
          'later': [('later', False)],
          'laterna': [('later', False)],
          'laternas': [('later', True)],
          'laters': [('later', True)],
          'lates': [('late', False)],
          'lates-': [('late', False)],
          'latin': [('latin', False)],
          'lation': [('lation', False)],
          'lationen': [('lation', False)],
          'lations': [('lation', False)],
          'lativets': [('lativ', False)],
          'latonin': [('latonin', False)],
          'latonins': [('latonin', False)],
          'lator': [('lator', False)],
          'lators': [('lator', False)],
          'latrins': [('latrin', True)],
          'lats': [('later', True)],
          'lats-': [('later', True)],
          'latsen': [('lats', False)],
          'latsens': [('lats', False)],
          'latt': [('latta', True)],
          'latt-': [('latta', True)],
          'lattan': [('latta', False)],
          'lattans': [('latta', False)],
          'lattar': [('latte', True)],
          'lattarna': [('latte', False)],
          'lattarnas': [('latte', False)],
          'lattars': [('latte', True)],
          'latte': [('latta', True), ('latte', True)],
          'latte-': [('latte', True), ('latta', True)],
          'latten': [('latte', True)],
          'lattens': [('latte', True)],
          'latter': [('latt', False)],
          'latteranden': [('latterande', False)],
          'latterandens': [('latterande', False)],
          'latters': [('latt', False)],
          'latts': [('latta', True)],
          'latts-': [('latta', True)],
          'lav': [('lava', True), ('lave', True), ('lav', True)],
          'lav-': [('lave', True), ('lava', True), ('lav', True)],
          'lavan': [('lava', False)],
          'lavanden': [('lavande', False)],
          'lavandens': [('lavande', False)],
          'lavans': [('lava', False)],
          'lavar': [('lave', True), ('lav', True)],
          'lavarna': [('lave', True), ('lav', True)],
          'lavarnas': [('lave', True), ('lav', True)],
          'lavars': [('lav', True), ('lave', True)],
          'lave': [('lava', True), ('lave', True)],
          'lave-': [('lava', True)],
          'laven': [('lav', True), ('lave', True)],
          'lavens': [('lav', True), ('lave', True)],
          'laver': [('laver', False)],
          'lavernas': [('lav', False)],
          'laverns': [('laver', False)],
          'lavers': [('lav', False)],
          'lavers-': [('laver', False)],
          'lavin': [('lavin', False)],
          'lavins': [('lavin', True)],
          'lavs': [('lava', True), ('lave', True), ('lav', True)],
          'lavs-': [('lava', True), ('lave', True), ('lav', True)],
          'laxis': [('laxi', False)],
          'lays': [('lay', False)],
          'lays-': [('lay', False)],
          'lazer': [('lazer', False)],
          'lazers': [('lazer', False)],
          'lb': [('lb', False)],
          'lb-': [('lb', False)],
          'lback': [('lbacke', False)],
          'lback-': [('lbacke', False)],
          'lbackar': [('lbacke', False)],
          'lbackarna': [('lbacke', False)],
          'lbackarnas': [('lback', False)],
          'lbackars': [('lback', False)],
          'lbacke': [('lbacke', False)],
          'lbacke-': [('lbacke', False)],
          'lbacken': [('lback', False)],
          'lbackens': [('lback', False)],
          'lbacks': [('lback', False)],
          'lbacks-': [('lbacke', False)],
          'lbagg': [('lbagge', False)],
          'lbagg-': [('lbagge', False)],
          'lbaggar': [('lbagge', False)],
          'lbaggarna': [('lbagge', False)],
          'lbaggarnas': [('lbagge', False)],
          'lbaggars': [('lbagge', False)],
          'lbaggen': [('lbagge', False)],
          'lbaggens': [('lbagge', False)],
          'lbaggs': [('lbagge', False)],
          'lbaggs-': [('lbagge', False)],
          'lban-': [('lban', False)],
          'lbanan': [('lbana', False)],
          'lbanans': [('lbana', False)],
          'lbandets': [('lband', False)],
          'lbane': [('lbana', False)],
          'lbane-': [('lbana', False)],
          'lbaner': [('lban', False)],
          'lbaners': [('lban', False)],
          'lbarren': [('lbarr', False)],
          'lbarrens': [('lbarr', False)],
          'lbars': [('lbar', False)],
          'lbas': [('lbas', False)],
          'lben': [('lb', False)],
          'lbens': [('lben', False)],
          'lbens-': [('lben', False)],
          'lber': [('lb', False)],
          'lberna': [('lb', False)],
          'lbernas': [('lb', False)],
          'lbers': [('lb', False)],
          'lbete': [('lbete', False)],
          'lbeten': [('lbete', False)],
          'lbetens': [('lbete', False)],
          'lbevis': [('lbevis', False)],
          'lbevis-': [('lbevis', False)],
          'lbil': [('lbil', False)],
          'lbil-': [('lbil', False)],
          'lbilar': [('lbil', False)],
          'lbilars': [('lbil', False)],
          'lbils': [('lbil', False)],
          'lbils-': [('lbil', False)],
          'lbind': [('lbinda', False)],
          'lbind-': [('lbinda', False)],
          'lbinds': [('lbinda', False)],
          'lbinds-': [('lbinda', False)],
          'lbit': [('lbit', False)],
          'lbitar': [('lbit', False)],
          'lbitars': [('lbit', False)],
          'lbits': [('lbit', False)],
          'lbits-': [('lbit', False)],
          'lblom': [('lblomma', False)],
          'lblom-': [('lblomma', False)],
          'lbloms': [('lblomma', False)],
          'lbloms-': [('lblomma', False)],
          'lblåsarna': [('lblåsare', False)],
          'lbolaget': [('lbolag', False)],
          'lbond': [('lbonde', False)],
          'lbondens': [('lbonde', False)],
          'lbonds': [('lbonde', False)],
          'lbonds-': [('lbonde', False)],
          'lborgen': [('lborgen', False)],
          'lborgens': [('lborgen', False)],
          'lborst': [('lborste', False)],
          'lborst-': [('lborste', False)],
          'lborsten': [('lborste', False)],
          'lborstens': [('lborste', False)],
          'lbot': [('lbo', False)],
          'lbots': [('lbo', False)],
          'lboxar': [('lbox', False)],
          'lboxarna': [('lbox', False)],
          'lboxarnas': [('lbox', False)],
          'lbroder': [('lbroder', False)],
          'lbrodern': [('lbror', False)],
          'lbroderns': [('lbroder', False)],
          'lbroders': [('lbror', False)],
          'lbroms': [('lbroms', False)],
          'lbromsar': [('lbroms', False)],
          'lbromsarna': [('lbroms', False)],
          'lbromsarnas': [('lbroms', False)],
          'lbrons': [('lbro', False)],
          'lbrors': [('lbrorsa', False)],
          'lbrors-': [('lbrorsa', False)],
          'lbrynen': [('lbryn', False)],
          'lbrynens': [('lbryn', False)],
          'lbrynet': [('lbryn', False)],
          'lbrynets': [('lbryn', False)],
          'lbryns': [('lbryn', False)],
          'lbryns-': [('lbryn', False)],
          'lbräds': [('lbräda', False)],
          'lbräds-': [('lbräda', False)],
          'lbråk': [('lbråk', False)],
          'lbråks': [('lbråk', False)],
          'lbråks-': [('lbråk', False)],
          'lbröder': [('lbror', False)],
          'lbröderna': [('lbroder', False)],
          'lbrödernas': [('lbror', False)],
          'lbröders': [('lbroder', False)],
          'lbs': [('lb', False)],
          'lbs-': [('lb', False)],
          'lbull': [('lbulle', False)],
          'lbulle': [('lbulle', False)],
          'lbulle-': [('lbulle', False)],
          'lbulls': [('lbulle', False)],
          'lbulls-': [('lbulle', False)],
          'lburs-': [('lbur', False)],
          'lbygget': [('lbygge', False)],
          'lbyx': [('lbyxa', False)],
          'lbyx-': [('lbyxa', False)],
          'lbyxorna': [('lbyxa', False)],
          'lbäcken': [('lbäck', False)],
          'lbäckens': [('lbäck', False)],
          'lbälte': [('lbälte', False)],
          'lbärs': [('lbär', False)],
          'lbärs-': [('lbär', False)],
          'lbåg': [('lbåge', False)],
          'lbåg-': [('lbåge', False)],
          'lbågs': [('lbåge', False)],
          'lbågs-': [('lbåge', False)],
          'lbön': [('lbön', False)],
          'lböns': [('lbön', False)],
          'lböns-': [('lbön', False)],
          'lcell': [('lcell', False)],
          'lcellens': [('lcell', False)],
          'lcentret': [('lcenter', False)],
          'lcentrets': [('lcenter', False)],
          'lcers': [('lcer', False)],
          'lchoser': [('lchos', False)],
          'lchoserna': [('lchos', False)],
          'lchosernas': [('lchos', False)],
          'lchosers': [('lchos', False)],
          'ld': [('ld', False)],
          'ld-': [('ld', False)],
          'lda': [('ld', False)],
          'ldagar': [('ldag', False)],
          'ldagarna': [('ldag', False)],
          'ldagarnas': [('ldag', False)],
          'ldagars': [('ldag', False)],
          'ldagen': [('ldag', False)],
          'ldagens': [('ldag', False)],
          'ldags': [('ldag', False)],
          'ldags-': [('ldag', False)],
          'ldamen': [('ldam', False)],
          'ldamens': [('ldam', False)],
          'ldamer': [('ldam', False)],
          'ldamerna': [('ldam', False)],
          'ldan': [('ldan', False)],
          'ldanden': [('ldande', False)],
          'ldandens': [('ldande', False)],
          'ldans': [('ldan', False)],
          'ldans-': [('ldan', False)],
          'ldar': [('ld', False)],
          'ldaren': [('ldare', False)],
          'ldarna': [('ld', False)],
          'ldarnas': [('ld', False)],
          'ldars': [('ld', False)],
          'ldas': [('ld', False)],
          'ldat': [('ldat', False)],
          'ldaten': [('ldat', False)],
          'ldatens': [('ldat', False)],
          'ldater': [('ldat', False)],
          'ldaterna': [('ldat', False)],
          'ldaternas': [('ldat', False)],
          'ldaters': [('ldat', False)],
          'ldats': [('ldat', False)],
          'ldborgarna': [('ldborg', False)],
          'ldborgarnas': [('ldborg', False)],
          'lde': [('ld', False)],
          'lde-': [('ld', False)],
          'ldegs-': [('ldeg', False)],
          'ldel': [('ldel', False)],
          'ldelandet': [('ldelande', False)],
          'ldelar': [('ldelare', False)],
          'ldelarna': [('ldelare', False)],
          'ldelarnas': [('ldelare', False)],
          'ldels': [('ldel', False)],
          'ldels-': [('ldel', False)],
          'lden': [('ld', False)],
          'ldens': [('ld', False)],
          'lder': [('ld', False)],
          'lder-': [('lder', False)],
          'ldern': [('lder', False)],
          'lderna': [('ld', False)],
          'ldernas': [('ld', False)],
          'lderns': [('lder', False)],
          'lders': [('ld', False)],
          'lders-': [('lder', False)],
          'ldet': [('ld', False)],
          'ldets': [('lde', False)],
          'ldfälle': [('ldfälla', False)],
          'ldiken': [('ldik', False)],
          'ldikens': [('ldik', False)],
          'ldillen': [('ldille', False)],
          'ldillens': [('ldille', False)],
          'lding': [('lding', False)],
          'lding-': [('lding', False)],
          'ldingar': [('lding', False)],
          'ldingarna': [('lding', False)],
          'ldingarnas': [('lding', False)],
          'ldingars': [('lding', False)],
          'ldingen': [('lding', False)],
          'ldingens': [('lding', False)],
          'ldings': [('lding', False)],
          'ldings-': [('lding', False)],
          'ldis': [('ldis', False)],
          'ldis-': [('ldis', False)],
          'ldiskar': [('ldisk', False)],
          'ldiskarna': [('ldisk', False)],
          'ldiskarnas': [('ldisk', False)],
          'ldkrans': [('ldkran', False)],
          'ldkrans-': [('ldkran', False)],
          'ldningsvägar': [('ldningsväg', False)],
          'ldningsvägarna': [('ldningsväg', False)],
          'ldningsvägarnas': [('ldningsväg', False)],
          'ldningsvägars': [('ldningsväg', False)],
          'ldningsvägs': [('ldningsväg', False)],
          'ldningsvägs-': [('ldningsväg', False)],
          'ldo-': [('ldo', False)],
          'ldomar': [('ldomare', False)],
          'ldomarna': [('ldomare', False)],
          'ldomarnas': [('ldom', False)],
          'ldomen': [('ldom', False)],
          'ldon': [('ldon', False)],
          'ldon-': [('ldon', False)],
          'ldona': [('ldo', False)],
          'ldonas': [('ldo', False)],
          'ldons': [('ldo', False)],
          'ldons-': [('ldon', False)],
          'ldos': [('ldosa', False)],
          'ldos-': [('ldos', False)],
          'ldosen': [('ldos', False)],
          'ldot': [('ldo', False)],
          'ldpengar': [('ldpeng', False)],
          'ldplants-': [('ldplants', False)],
          'ldra': [('ldra', False)],
          'ldramer': [('ldrama', False)],
          'ldramerna': [('ldrama', False)],
          'ldramernas': [('ldrama', False)],
          'ldran': [('ldra', False)],
          'ldrans': [('ldra', False)],
          'ldrar': [('lder', False)],
          'ldrarna': [('lder', False)],
          'ldrarnas': [('ldrare', False)],
          'ldrars': [('lder', False)],
          'ldras': [('ldra', False)],
          'ldren': [('ldren', False)],
          'ldrens': [('ldren', False)],
          'ldringar': [('ldring', False)],
          'ldringarnas': [('ldring', False)],
          'ldringars': [('ldring', False)],
          'ldrinkar': [('ldrink', False)],
          'ldrinkarna': [('ldrink', False)],
          'ldrinkarnas': [('ldrink', False)],
          'ldrorna': [('ldra', False)],
          'lds': [('ld', False)],
          'lds-': [('ld', False)],
          'ldsanden': [('ldsand', False)],
          'ldsandens': [('ldsand', False)],
          'ldside': [('ldside', False)],
          'ldskartan': [('ldskarta', False)],
          'ldsken': [('ldsken', False)],
          'ldskens': [('ldsken', False)],
          'ldskotts': [('ldskott', False)],
          'ldskurs-': [('ldskur', False)],
          'ldsten': [('ldste', False)],
          'ldstens': [('ldste', False)],
          'ldstormar': [('ldstorm', False)],
          'ldstormarna': [('ldstormare', False)],
          'ldstormarnas': [('ldstormare', False)],
          'lduns': [('ldun', False)],
          'lduns-': [('ldun', False)],
          'ldus': [('ldus', False)],
          'ldus-': [('ldus', False)],
          'ldyn': [('ldyna', False)],
          'ldyn-': [('ldyna', False)],
          'ldyns': [('ldyna', False)],
          'ldyns-': [('ldyna', False)],
          'ldyrkar': [('ldyrkare', False)],
          'ldyrkarna': [('ldyrkare', False)],
          'ldyrkarnas': [('ldyrkare', False)],
          'ldår': [('ldåre', False)],
          'le': [('le', False)],
          'le-': [('le', False)],
          'leans': [('lea', False)],
          'leasen': [('leas', False)],
          'leasens': [('leas', False)],
          'leaser': [('leas', False)],
          'leaserna': [('leas', False)],
          'leasernas': [('leas', False)],
          'leasers': [('leas', False)],
          'leater': [('leat', False)],
          'leaters': [('leat', False)],
          'lebens': [('leben', False)],
          'lebror': [('lebror', False)],
          'lebs': [('lebs', False)],
          'leck': [('leck', False)],
          'leck-': [('leck', False)],
          'lecken': [('leck', False)],
          'leckens': [('leck', False)],
          'lecks': [('leck', False)],
          'lecks-': [('leck', False)],
          'led': [('led', False)],
          'led-': [('led', False)],
          'ledags': [('ledags', False)],
          'ledags-': [('ledags', False)],
          'ledan': [('leda', False)],
          'ledar': [('ledare', False)],
          'ledar-': [('ledare', False)],
          'ledarens': [('ledare', False)],
          'ledarna': [('ledare', False)],
          'ledd': [('ledd', True)],
          'ledd-': [('ledd', True)],
          'ledds': [('ledd', True)],
          'ledds-': [('ledd', True)],
          'ledets': [('led', False)],
          'leds': [('led', False)],
          'leds-': [('led', False)],
          'leen': [('leen', False)],
          'leers': [('leum', False)],
          'leets': [('leum', False)],
          'leffekterna': [('leffekt', False)],
          'leg': [('leg', True), ('lega', True)],
          'leg-': [('leg', True), ('lega', True)],
          'legans': [('lega', True)],
          'legas': [('lega', True)],
          'legas-': [('legas', False)],
          'lege': [('lega', True)],
          'lege-': [('lega', True)],
          'legen': [('leg', True)],
          'legens': [('leg', True)],
          'leger': [('lega', False)],
          'legers': [('lega', False)],
          'leges': [('lege', False)],
          'leget': [('leg', True)],
          'legets': [('leg', True)],
          'legiernas': [('legium', False)],
          'legionen': [('legion', False)],
          'legionens': [('legion', False)],
          'legis': [('legi', False)],
          'legs': [('leg', True), ('lega', True)],
          'legs-': [('leg', True), ('lega', True)],
          'leiner': [('lein', False)],
          'leinerna': [('lein', False)],
          'leinernas': [('lein', False)],
          'leiners': [('lein', False)],
          'lejdar': [('lejd', True), ('lejdare', True)],
          'lejdarna': [('lejdare', True), ('lejd', True)],
          'lejdarnas': [('lejdare', True), ('lejd', True)],
          'lejden': [('lejd', True)],
          'lejdens': [('lejd', True)],
          'lejkarna': [('lejk', False)],
          'lejs': [('lejs', False)],
          'lejs-': [('leja', False)],
          'lejsar': [('lejs', False)],
          'lejsarna': [('lejs', False)],
          'lejsars': [('lejs', False)],
          'lek': [('lek', True)],
          'lek-': [('lek', False)],
          'lekar': [('lekare', True), ('lek', True)],
          'lekarens': [('lekare', True)],
          'lekarna': [('lekare', True), ('lek', True)],
          'lekarnas': [('lekare', True), ('lek', True)],
          'leke': [('leka', False)],
          'leken': [('lek', True)],
          'lekens': [('lek', True)],
          'lekes': [('leke', False)],
          'leket': [('leke', False)],
          'leks': [('lek', False)],
          'leks-': [('lek', True)],
          'lekt': [('lekt', False)],
          'lekt-': [('lekt', False)],
          'lektans': [('lekta', False)],
          'lektas': [('lektas', False)],
          'lekten': [('lekt', False)],
          'lektens': [('lekt', False)],
          'lekter': [('lekt', False)],
          'lekterna': [('lekt', False)],
          'lekternas': [('lekter', False)],
          'lekters': [('lekt', False)],
          'lektet': [('lekt', False)],
          'lektets': [('lekt', False)],
          'lektiven': [('lektiv', False)],
          'lektivens': [('lektiv', False)],
          'lekts': [('lekt', False)],
          'lekts-': [('lekt', False)],
          'lektyr': [('lektyr', True)],
          'lektyr-': [('lektyr', True)],
          'lektyrs': [('lektyr', False)],
          'leldar': [('leld', False)],
          'leldarna': [('leld', False)],
          'leldarnas': [('leld', False)],
          'lele': [('lele', False)],
          'lele-': [('lele', False)],
          'lelen': [('lele', False)],
          'lelens': [('lele', False)],
          'leler': [('lele', False)],
          'lelerna': [('lele', False)],
          'lelernas': [('lele', False)],
          'lelers': [('lel', False)],
          'lell': [('lell', False)],
          'lell-': [('lell', False)],
          'lellen': [('lell', False)],
          'leller': [('lell', False)],
          'lellerna': [('lell', False)],
          'lellernas': [('lell', False)],
          'lellers': [('lell', False)],
          'lells': [('lell', False)],
          'lem': [('lem', True)],
          'lem-': [('lem', True)],
          'lemang': [('lemang', False)],
          'lemang-': [('lemang', False)],
          'lemanger': [('lemang', False)],
          'lemangerna': [('lemang', False)],
          'lemangernas': [('lemang', False)],
          'lemangers': [('lemang', False)],
          'lemangs': [('lemang', False)],
          'lemangs-': [('lemang', False)],
          'lemannen': [('lemann', False)],
          'lemannens': [('lemann', False)],
          'lematis': [('lematis', False)],
          'lementen': [('lement', False)],
          'lementens': [('lement', False)],
          'lementet': [('lement', False)],
          'lementets': [('lemente', False)],
          'lements': [('lemente', False)],
          'lements-': [('lement', False)],
          'lemien': [('lemi', False)],
          'lemiens': [('lemi', False)],
          'lemiker': [('lemiker', False)],
          'lemikerna': [('lemiker', False)],
          'lemikernas': [('lemiker', False)],
          'lemikers': [('lemiker', False)],
          'lemis': [('lemi', False)],
          'lemmans': [('lemma', False)],
          'lemon': [('lemo', False)],
          'lemons': [('lemo', False)],
          'lemor': [('lemor', False)],
          'lemors': [('lemor', False)],
          'lemos': [('lemos', False)],
          'lemosen': [('lemos', False)],
          'lemosens': [('lemos', False)],
          'lems': [('lem', False)],
          'lems-': [('lem', True)],
          'len': [('l', True)],
          'lena': [('le', False)],
          'lenans': [('lena', False)],
          'lenar': [('lenare', False)],
          'lenar-': [('lenare', False)],
          'lenarens': [('lenare', False)],
          'lenarna': [('lenare', False)],
          'lenarnas': [('lenare', False)],
          'lenas': [('le', False)],
          'lene': [('lena', False)],
          'lene-': [('lena', False)],
          'lenet': [('len', False)],
          'lenets': [('len', False)],
          'lenheter': [('lenhet', False)],
          'lenheterna': [('lenhet', False)],
          'lenheternas': [('lenhet', False)],
          'lenheters': [('lenhet', False)],
          'lenhets': [('lenhet', False)],
          'lenhets-': [('lenhet', False)],
          'lenklädes': [('lenkläde', False)],
          'lens': [('l', True)],
          'lens-': [('lens', False)],
          'lensen': [('lens', False)],
          'lensens': [('lens', False)],
          'lenser': [('lens', False)],
          'lenserna': [('lens', False)],
          'lensernas': [('lens', False)],
          'lensers': [('lens', False)],
          'lenskaps-': [('lenskap', False)],
          'lent': [('lent', False)],
          'lenten': [('lent', False)],
          'lentens': [('lent', False)],
          'lenter': [('lent', False)],
          'lenterna': [('lent', False)],
          'lenternas': [('lent', False)],
          'lenters': [('lent', False)],
          'lents-': [('lent', False)],
          'leons': [('leon', False)],
          'leor': [('lea', False)],
          'leorna': [('lea', False)],
          'leornas': [('lea', False)],
          'leors': [('lea', False)],
          'lepens': [('lep', False)],
          'lepsin': [('lepsi', False)],
          'ler': [('lera', True)],
          'ler-': [('lera', True)],
          'lera': [('lera', False)],
          'leran': [('lera', False)],
          'lerans': [('lera', False)],
          'lerare': [('lerare', False)],
          'lerares': [('lerare', False)],
          'lerarna': [('lerare', False)],
          'lerarnas': [('lerare', False)],
          'leren': [('leren', False)],
          'lerens': [('leren', False)],
          'lerfötter': [('lerfötter', True)],
          'lerfötterna': [('lerfötter', True)],
          'lerfötternas': [('lerfötter', True)],
          'lerfötters': [('lerfötter', True)],
          'lergens': [('lergen', False)],
          'lergens-': [('lergen', False)],
          'lergin': [('lergi', False)],
          'lergins': [('lergi', False)],
          'leri': [('leri', False)],
          'leri-': [('leri', False)],
          'lerier': [('leri', False)],
          'lerierna': [('leri', False)],
          'leriers': [('leri', False)],
          'leriet': [('leri', False)],
          'lerin': [('lerin', False)],
          'lerins': [('leri', False)],
          'leris': [('leri', False)],
          'leris-': [('leri', False)],
          'lerit': [('leri', False)],
          'lerk': [('lerk', False)],
          'lerk-': [('lerk', False)],
          'lerken': [('lerk', False)],
          'lerkens': [('lerk', False)],
          'lerks': [('lerk', False)],
          'lerks-': [('lerk', False)],
          'lerkurs': [('lerkur', False)],
          'lerkurs-': [('lerkur', False)],
          'lernas': [('el', False)],
          'leron': [('lero', False)],
          'lerons': [('lero', False)],
          'leror': [('lera', True)],
          'lerorna': [('lera', True)],
          'lerornas': [('lera', True)],
          'lerors': [('lera', True)],
          'leros': [('lero', False)],
          'leros-': [('lero', False)],
          'lers': [('lera', True)],
          'lers-': [('lera', True)],
          'lersarnas': [('ler', False)],
          'lersen': [('ler', False)],
          'lerstens': [('lersten', True)],
          'les': [('le', False)],
          'les-': [('le', False)],
          'lesar': [('lesare', False)],
          'lesarna': [('le', False)],
          'lesarnas': [('les', False)],
          'lese': [('lese', False)],
          'lese-': [('lese', False)],
          'lesen': [('le', False)],
          'lesens': [('lese', False)],
          'leses': [('lese', False)],
          'less': [('less', False)],
          'lessen': [('less', False)],
          'lessenas': [('lessena', False)],
          'lestans': [('lesta', False)],
          'leston': [('leston', False)],
          'lestors': [('lesta', False)],
          'let': [('l', True)],
          'letagen': [('letage', False)],
          'letagens': [('letage', False)],
          'letar': [('letare', False)],
          'letarna': [('letare', False)],
          'lete': [('lete', False)],
          'lete-': [('lete', False)],
          'leten': [('lete', False)],
          'letens': [('lete', False)],
          'leter': [('let', False)],
          'leters': [('let', False)],
          'letes': [('lete', False)],
          'letes-': [('lete', False)],
          'letet': [('lete', False)],
          'letets': [('let', False)],
          'letidens': [('letid', False)],
          'letin': [('letin', False)],
          'letklubb': [('letklubb', False)],
          'letklubbs': [('letklubb', False)],
          'letklubbs-': [('letklubb', False)],
          'leträden': [('leträd', False)],
          'leträdet': [('leträd', False)],
          'lets': [('l', True)],
          'lets-': [('lete', False)],
          'letsarna': [('let', False)],
          'letsarnas': [('let', False)],
          'lett': [('lett', False)],
          'lett-': [('lett', False)],
          'lette-': [('lette', False)],
          'letten': [('lett', False)],
          'lettens': [('lett', True)],
          'letter': [('lett', False)],
          'letterna': [('lett', False)],
          'letternas': [('lett', False)],
          'letters': [('lett', False)],
          'letts': [('lett', False)],
          'letts-': [('lett', False)],
          'lev': [('lev', False)],
          'lev-': [('lev', False)],
          'levans': [('leva', True)],
          'levarnas': [('lev', False)],
          'levars': [('lev', False)],
          'leve': [('leve', True)],
          'leve-': [('leve', True)],
          'leven': [('leve', True), ('lev', True)],
          'levens': [('leve', True), ('lev', True)],
          'lever': [('lever', False)],
          'leverket': [('leverk', False)],
          'levers': [('lever', True)],
          'levet': [('leve', True)],
          'levets': [('leve', True)],
          'levs': [('lev', True)],
          'levs-': [('lev', False)],
          'lexin': [('lexi', False)],
          'lexins': [('lexi', False)],
          'lextiden': [('lextid', False)],
          'lf': [('lf', False)],
          'lf-': [('lf', False)],
          'lfader': [('lfader', False)],
          'lfadern': [('lfader', False)],
          'lfaderns': [('lfader', False)],
          'lfaders': [('lfader', False)],
          'lfaders-': [('lfader', False)],
          'lfan': [('lfa', False)],
          'lfana': [('lfa', False)],
          'lfanas': [('lfa', False)],
          'lfans': [('lfa', False)],
          'lfar': [('lf', False)],
          'lfar-': [('lfare', False)],
          'lfare': [('lfare', False)],
          'lfarna': [('lf', False)],
          'lfarnas': [('lfare', False)],
          'lfars': [('lf', False)],
          'lfas': [('lfa', False)],
          'lfas-': [('lfa', False)],
          'lfasan': [('lfasan', False)],
          'lfasans': [('lfasan', False)],
          'lfat': [('lfat', False)],
          'lfats': [('lfat', False)],
          'lfel': [('lfel', False)],
          'lfel-': [('lfel', False)],
          'lfels': [('lfel', False)],
          'lfels-': [('lfel', False)],
          'lfen': [('lf', False)],
          'lfena': [('lfena', False)],
          'lfens': [('lf', False)],
          'lfer': [('lf', False)],
          'lfer-': [('lfer', False)],
          'lferna': [('lf', False)],
          'lfernas': [('lf', False)],
          'lfers': [('lf', False)],
          'lfie': [('lfie', False)],
          'lfie-': [('lfie', False)],
          'lfien': [('lfie', False)],
          'lfiens': [('lfie', False)],
          'lfier': [('lfie', False)],
          'lfierna': [('lfie', False)],
          'lfiernas': [('lfie', False)],
          'lfiers': [('lfie', False)],
          'lfilar': [('lfil', False)],
          'lfilarna': [('lfil', False)],
          'lfilarnas': [('lfil', False)],
          'lfilen': [('lfil', False)],
          'lfilens': [('lfil', False)],
          'lfin': [('lfin', False)],
          'lfink': [('lfink', False)],
          'lfink-': [('lfink', False)],
          'lfinks': [('lfink', False)],
          'lfinks-': [('lfink', False)],
          'lfinnar': [('lfinnare', False)],
          'lfinnarna': [('lfinnare', False)],
          'lfinnarnas': [('lfinnare', False)],
          'lfins': [('lfin', False)],
          'lfis': [('lfis', False)],
          'lfis-': [('lfis', False)],
          'lfiskar': [('lfiskare', False)],
          'lfiskarna': [('lfiskare', False)],
          'lfiskarnas': [('lfisk', False)],
          'lfit': [('lfit', False)],
          'lfits': [('lfit', False)],
          'lfjäll': [('lfjäll', False)],
          'lfjäll-': [('lfjäll', False)],
          'lfjälls': [('lfjäll', False)],
          'lfjälls-': [('lfjäll', False)],
          'lfkors': [('lfkors', False)],
          'lflagg': [('lflagga', False)],
          'lflagg-': [('lflagga', False)],
          'lflaggs': [('lflagga', False)],
          'lflaggs-': [('lflagga', False)],
          'lfläck': [('lfläck', False)],
          'lfläcks': [('lfläck', False)],
          'lflödet': [('lflöde', False)],
          'lflöts': [('lflöts', False)],
          'lflöts-': [('lflöts', False)],
          'lfons': [('lfons', False)],
          'lfons-': [('lfons', False)],
          'lfordringar': [('lfordran', False)],
          'lfordringarna': [('lfordran', False)],
          'lfordringarnas': [('lfordran', False)],
          'lfordringars': [('lfordran', False)],
          'lfoton': [('lfoto', False)],
          'lfotons': [('lfoto', False)],
          'lfots': [('lfot', False)],
          'lfots-': [('lfot', False)],
          'lframställningar': [('lframställning', False)],
          'lframställningarna': [('lframställning', False)],
          'lframställningarnas': [('lframställning', False)],
          'lframställningars': [('lframställning', False)],
          'lfs': [('lf', False)],
          'lfs-': [('lf', False)],
          'lfälle': [('lfälle', False)],
          'lfällen': [('lfälle', False)],
          'lfällens': [('lfälle', False)],
          'lfåll': [('lfåll', False)],
          'lfålls': [('lfåll', False)],
          'lfålls-': [('lfåll', False)],
          'lfång': [('lfång', False)],
          'lfång-': [('lfång', False)],
          'lfångar': [('lfångare', False)],
          'lfångarna': [('lfångare', False)],
          'lfångarnas': [('lfångare', False)],
          'lfången': [('lfång', False)],
          'lfångens': [('lfång', False)],
          'lfångs': [('lfång', False)],
          'lfångs-': [('lfång', False)],
          'lförar': [('lförare', False)],
          'lförarna': [('lförare', False)],
          'lförarnas': [('lförare', False)],
          'lförlust-': [('lförlust', False)],
          'lförluster': [('lförlust', False)],
          'lförlusterna': [('lförlust', False)],
          'lförlusternas': [('lförlust', False)],
          'lförsäkringar': [('lförsäkring', False)],
          'lförsäkringarna': [('lförsäkring', False)],
          'lförsäkringarnas': [('lförsäkring', False)],
          'lförsäkringars': [('lförsäkring', False)],
          'lg': [('lg', False)],
          'lg-': [('lg', False)],
          'lgamen': [('lgam', False)],
          'lgamens': [('lgam', False)],
          'lgamet': [('lgam', False)],
          'lgamets': [('lgam', False)],
          'lgandens': [('lgande', False)],
          'lgar': [('lge', False)],
          'lgar-': [('lgar', False)],
          'lgarden': [('lgarde', False)],
          'lgardens': [('lgarde', False)],
          'lgaren': [('lgare', False)],
          'lgarens': [('lgar', False)],
          'lgarna': [('lge', False)],
          'lgarnas': [('lg', False)],
          'lgars': [('lg', False)],
          'lgaserna': [('lgas', False)],
          'lgasernas': [('lgas', False)],
          'lgasers': [('lgas', False)],
          'lgate': [('lgata', False)],
          'lgate-': [('lgata', False)],
          'lgators': [('lgata', False)],
          'lgats': [('lgata', False)],
          'lgback': [('lgbacke', False)],
          'lgback-': [('lgbacke', False)],
          'lgbackar': [('lgbacke', False)],
          'lgbackarnas': [('lgbacke', False)],
          'lgbackars': [('lgbacke', False)],
          'lgbacken': [('lgbacke', False)],
          'lgbackens': [('lgbacke', False)],
          'lgbacks': [('lgbacke', False)],
          'lgborstar': [('lgborste', False)],
          'lgborstarna': [('lgborste', False)],
          'lgborstarnas': [('lgborste', False)],
          'lgdags': [('lgdag', False)],
          'lgelsen': [('lgelse', False)],
          'lgelsens': [('lgelse', False)],
          'lgen': [('lg', False)],
          'lgenier': [('lgeni', False)],
          'lgenierna': [('lgeni', False)],
          'lgeniernas': [('lgeni', False)],
          'lgeniers': [('lgeni', False)],
          'lgens': [('lg', False)],
          'lgenus': [('lgenus', False)],
          'lgenus-': [('lgenus', False)],
          'lger': [('lg', False)],
          'lgerier': [('lgerier', False)],
          'lgerierna': [('lgerier', False)],
          'lgeriers': [('lgerier', False)],
          'lgerna': [('lg', False)],
          'lgernas': [('lg', False)],
          'lgers': [('lg', False)],
          'lget': [('lg', False)],
          'lgets': [('lg', False)],
          'lgian': [('lgia', False)],
          'lgians': [('lgia', False)],
          'lgier': [('lgier', False)],
          'lgierna': [('lgier', False)],
          'lgiernas': [('lgi', False)],
          'lgiers': [('lgier', False)],
          'lgiften': [('lgift', False)],
          'lgiftens': [('lgift', False)],
          'lgiftet': [('lgift', False)],
          'lgiftets': [('lgift', False)],
          'lgifts': [('lgift', False)],
          'lgifts-': [('lgift', False)],
          'lgin': [('lgi', False)],
          'lgins': [('lgi', False)],
          'lgivar': [('lgivare', False)],
          'lgivarna': [('lgivare', False)],
          'lgivarnas': [('lgivare', False)],
          'lglasögon': [('lglasögon', False)],
          'lglasögonen': [('lglasögon', False)],
          'lglasögonens': [('lglasögon', False)],
          'lglasögons': [('lglasögon', False)],
          'lgods': [('lgods', False)],
          'lgods-': [('lgods', False)],
          'lgon': [('lgon', False)],
          'lgonen': [('lgon', False)],
          'lgonens': [('lgon', False)],
          'lgons': [('lgon', False)],
          'lgrammatik': [('lgrammatik', False)],
          'lgrammatik-': [('lgrammatik', False)],
          'lgrammatiker': [('lgrammatik', False)],
          'lgrammatikerna': [('lgrammatik', False)],
          'lgrammatikernas': [('lgrammatik', False)],
          'lgrammatikers': [('lgrammatik', False)],
          'lgrammatiks': [('lgrammatik', False)],
          'lgrammatiks-': [('lgrammatik', False)],
          'lgrann': [('lgranne', False)],
          'lgrann-': [('lgranne', False)],
          'lgranns': [('lgranne', False)],
          'lgranns-': [('lgranne', False)],
          'lgrep': [('lgrep', False)],
          'lgrepen': [('lgrep', False)],
          'lgrepens': [('lgrep', False)],
          'lgreps': [('lgrep', False)],
          'lgreps-': [('lgrep', False)],
          'lgrill': [('lgrill', False)],
          'lgrills': [('lgrill', False)],
          'lgrills-': [('lgrill', False)],
          'lgrim': [('lgrim', False)],
          'lgrim-': [('lgrim', False)],
          'lgrims': [('lgrim', False)],
          'lgrims-': [('lgrim', False)],
          'lgrynet': [('lgryn', False)],
          'lgrynets': [('lgryn', False)],
          'lgryt': [('lgryta', False)],
          'lgryt-': [('lgryta', False)],
          'lgryts': [('lgryta', False)],
          'lgryts-': [('lgryta', False)],
          'lgräns': [('lgräns', False)],
          'lgräns-': [('lgräns', False)],
          'lgs': [('lg', False)],
          'lgs-': [('lg', False)],
          'lgubb': [('lgubbe', False)],
          'lgubbs': [('lgubbe', False)],
          'lguinean': [('lguinean', False)],
          'lguineans': [('lguinean', False)],
          'lgum': [('lgum', False)],
          'lgums': [('lgum', False)],
          'lgums-': [('lgum', False)],
          'lgångar': [('lgångare', False)],
          'lgåve-': [('lgåva', False)],
          'lgåvor': [('lgåva', False)],
          'lgåvors': [('lgåva', False)],
          'lhak': [('lhaka', False)],
          'lhak-': [('lhaka', False)],
          'lhake-': [('lhake', False)],
          'lhaken': [('lhake', False)],
          'lhakens': [('lhake', False)],
          'lhaks': [('lhaka', False)],
          'lhaks-': [('lhaka', False)],
          'lhandlar': [('lhandel', False)],
          'lhandlarna': [('lhandel', False)],
          'lhandlarnas': [('lhandel', False)],
          'lhans-': [('lhane', False)],
          'lhar': [('lhare', False)],
          'lhar-': [('lhare', False)],
          'lharen': [('lhare', False)],
          'lharmonier': [('lharmoni', False)],
          'lharmonierna': [('lharmonium', False)],
          'lharmoniernas': [('lharmonium', False)],
          'lharmoniers': [('lharmonium', False)],
          'lhavsområdet': [('lhavsområdet', False)],
          'lhavsområdets': [('lhavsområdet', False)],
          'lheter': [('lhet', False)],
          'lheterna': [('lhet', False)],
          'lheternas': [('lhet', False)],
          'lheters': [('lhet', False)],
          'lhets': [('lhet', False)],
          'lhets-': [('lhet', False)],
          'lhone': [('lhona', False)],
          'lhopar': [('lhop', False)],
          'lhoparna': [('lhop', False)],
          'lhopp': [('lhoppa', False)],
          'lhopp-': [('lhoppa', False)],
          'lhopps': [('lhoppa', False)],
          'lhopps-': [('lhoppa', False)],
          'lhost': [('lhosta', False)],
          'lhost-': [('lhosta', False)],
          'lhundars': [('lhund', False)],
          'lhus': [('lhus', False)],
          'lhuve': [('lhuva', False)],
          'lhylle': [('lhylla', False)],
          'lhylle-': [('lhylla', False)],
          'lhytt': [('lhytt', False)],
          'lhytt-': [('lhytt', False)],
          'lhytts': [('lhytt', False)],
          'lhytts-': [('lhytt', False)],
          'lhyvlar': [('lhyvel', False)],
          'lhyvlarna': [('lhyvel', False)],
          'lhyvlarnas': [('lhyvel', False)],
          'lhälar': [('lhäl', False)],
          'lhälarna': [('lhäl', False)],
          'lhälarnas': [('lhäl', False)],
          'lhäll': [('lhäll', False)],
          'lhälls': [('lhäll', False)],
          'lhälls-': [('lhäll', False)],
          'lhärskare': [('lhärskare', False)],
          'lhästar': [('lhäst', False)],
          'lhästarnas': [('lhäst', False)],
          'lhål': [('lhål', False)],
          'lhåls': [('lhål', False)],
          'lhåls-': [('lhål', False)],
          'lhögskolans': [('lhögskola', False)],
          'lhölje': [('lhölje', False)],
          'lhörn': [('lhörn', False)],
          'lhörns': [('lhörn', False)],
          'lhörns-': [('lhörn', False)],
          'lhös': [('lhö', False)],
          'li': [('lie', True)],
          'li-': [('lie', True)],
          'lialen': [('lial', False)],
          'lialens': [('lial', False)],
          'lian': [('lian', False)],
          'lian-': [('lian', False)],
          'liana': [('lia', False)],
          'lianden': [('liande', False)],
          'lians': [('lian', False)],
          'lians-': [('lians', False)],
          'liar': [('lie', True)],
          'liarna': [('lie', True)],
          'liarnas': [('lie', True)],
          'lias': [('lias', True)],
          'lias-': [('lias', True)],
          'libb': [('libb', False)],
          'libbs': [('libb', False)],
          'libbs-': [('libb', False)],
          'liber': [('liber', False)],
          'libers': [('liber', False)],
          'libis': [('libi', False)],
          'libits': [('libi', False)],
          'librier': [('librium', False)],
          'librierna': [('librium', False)],
          'libriernas': [('libri', False)],
          'libriers': [('librium', False)],
          'librin': [('libri', False)],
          'libris': [('libris', False)],
          'lic': [('lic', True)],
          'lic-': [('lic', True)],
          'licen': [('lice', False)],
          'licens': [('licens', True)],
          'licier': [('licy', False)],
          'liciernas': [('licy', False)],
          'liciers': [('licy', False)],
          'lick': [('licka', False)],
          'lick-': [('lick', False)],
          'lickar': [('lick', False)],
          'lickarna': [('lick', False)],
          'lickarnas': [('lickare', False)],
          'licket': [('lick', False)],
          'licks': [('lick', False)],
          'licks-': [('lick', False)],
          'lics': [('lice', False)],
          'lid': [('lid', True)],
          'lid-': [('lid', True)],
          'lida': [('lida', False)],
          'lidas': [('lida', False)],
          'lide': [('lida', False)],
          'liden': [('lid', True)],
          'lidens': [('lid', False)],
          'lider': [('lider', True), ('lid', True)],
          'liderna': [('lider', True), ('lid', True)],
          'lidernas': [('lider', True), ('lid', True)],
          'liders': [('lid', True), ('lider', True)],
          'lidet': [('lid', False)],
          'lidets': [('lid', False)],
          'lids': [('lid', True)],
          'lids-': [('lid', True)],
          'lie': [('lie', True)],
          'lien': [('lie', True)],
          'lienden': [('liende', False)],
          'liendens': [('liende', False)],
          'liens': [('lie', True)],
          'lier': [('li', False)],
          'liernas': [('li', False)],
          'liers': [('li', False)],
          'liet': [('li', False)],
          'lietiden': [('lietid', False)],
          'liets': [('lium', False)],
          'lifs': [('lifs', False)],
          'lifs-': [('lif', False)],
          'lift': [('lift', False)],
          'lift-': [('lift', False)],
          'liftar': [('lift', True), ('liftare', True)],
          'liftarna': [('liftare', True), ('lift', True)],
          'liftarnas': [('liftare', True), ('lift', True)],
          'liften': [('lift', False)],
          'liftens': [('lift', False)],
          'lifts': [('lift', False)],
          'lifts-': [('lift', False)],
          'ligan': [('liga', False)],
          'ligans': [('liga', True)],
          'ligats': [('ligat', False)],
          'ligens': [('ligens', False)],
          'ligens-': [('ligens', False)],
          'ligenser': [('ligens', False)],
          'ligenserna': [('ligens', False)],
          'ligensernas': [('ligens', False)],
          'ligensers': [('ligens', False)],
          'ligets': [('lig', False)],
          'ligg': [('ligg', False)],
          'ligg-': [('ligg', True)],
          'liggar': [('liggare', False)],
          'liggarna': [('liggare', True)],
          'liggarnas': [('liggare', True)],
          'liggars': [('ligg', False)],
          'liggen': [('ligg', True)],
          'liggens': [('ligg', True)],
          'liggs': [('ligg', False)],
          'liggs-': [('ligg', True)],
          'ligheter': [('lighet', False)],
          'ligheterna': [('lighet', False)],
          'ligheternas': [('lighet', False)],
          'ligheters': [('lighet', False)],
          'lighets-': [('lighet', False)],
          'lik': [('lik', True), ('like', True)],
          'lik-': [('lik', True), ('like', True)],
          'lika': [('lika', False)],
          'likan': [('lika', False)],
          'likanden': [('likande', True)],
          'likandens': [('likande', False)],
          'likans': [('lika', False)],
          'likar': [('like', True), ('likare', True)],
          'likarna': [('like', True), ('likare', True)],
          'likarnas': [('likare', True), ('like', True)],
          'likars': [('like', True)],
          'likas': [('lika', False)],
          'likator': [('likator', False)],
          'likators': [('likator', False)],
          'like': [('like', False)],
          'like-': [('like', False)],
          'liken': [('lik', True), ('like', True)],
          'likens': [('lik', True), ('like', True)],
          'liker': [('liker', False)],
          'likerna': [('liker', False)],
          'likernas': [('liker', False)],
          'likers': [('liker', False)],
          'liket': [('lik', False)],
          'likets': [('lik', False)],
          'liks': [('like', True), ('lik', True)],
          'liks-': [('like', True), ('lik', True)],
          'likten': [('likt', False)],
          'liktens': [('likt', False)],
          'liktet': [('likt', False)],
          'liktorn': [('liktor', True), ('liktorn', True)],
          'liktorns': [('liktor', True), ('liktorn', True)],
          'likts': [('likt', False)],
          'likts-': [('likt', False)],
          'likus': [('liku', False)],
          'likvid': [('likvid', True), ('likvida', True)],
          'likvid-': [('likvid', True), ('likvida', True)],
          'likvids': [('likvida', True), ('likvid', True)],
          'lilje': [('lilja', False)],
          'lilje-': [('lilja', True)],
          'liljekonvaljen': [('liljekonvalje', True), ('liljekonvalj', True)],
          'liljekonvaljens': [('liljekonvalj', True), ('liljekonvalje', True)],
          'liljekonvaljer': [('liljekonvalje', True), ('liljekonvalj', True)],
          'liljekonvaljerna': [('liljekonvalj', True), ('liljekonvalje', True)],
          'liljekonvaljernas': [('liljekonvalj', True), ('liljekonvalje', True)],
          'liljekonvaljers': [('liljekonvalj', True), ('liljekonvalje', True)],
          'lillans': [('lillan', True)],
          'lillebrors': [('lillebror', True), ('lillebrorsa', True)],
          'lillen': [('lillen', True)],
          'lillens': [('lillen', True)],
          'lima': [('lima', False)],
          'limans': [('lima', False)],
          'limas': [('lima', False)],
          'lime': [('lime', True)],
          'lime-': [('lime', True)],
          'limen': [('lime', True)],
          'limens': [('lime', True)],
          'limer': [('lime', True)],
          'limerna': [('lime', True)],
          'limernas': [('lime', True)],
          'limers': [('lime', True)],
          'limes': [('limes', True), ('lime', True)],
          'limes-': [('lime', True), ('limes', True)],
          'limmer': [('lim', True)],
          'limmernas': [('lim', False)],
          'limmers': [('lim', True)],
          'limousinen': [('limousin', True), ('limousine', True)],
          'limousinens': [('limousin', True), ('limousine', True)],
          'limousiner': [('limousine', True), ('limousin', True)],
          'limousinerna': [('limousin', True), ('limousine', True)],
          'limousinernas': [('limousin', True), ('limousine', True)],
          'limousiners': [('limousin', True), ('limousine', True)],
          'limp': [('limpa', True)],
          'limp-': [('limpa', True)],
          'limps': [('limpa', True)],
          'limps-': [('limpa', True)],
          'lin': [('lin', True), ('lina', True)],
          'lin-': [('lin', True), ('lina', True)],
          'lina': [('lina', True)],
          'linandens': [('linande', False)],
          'linans': [('lina', False)],
          'linar': [('linare', False)],
          'linar-': [('linare', False)],
          'linarens': [('linare', False)],
          'linarna': [('linare', False)],
          'linas': [('lina', True)],
          'lind': [('lind', True)],
          'lind-': [('lind', True)],
          'lindans': [('lindans', True), ('linda', True)],
          'lindar': [('lind', True), ('lindare', True)],
          'lindarna': [('lind', True), ('lindare', True)],
          'lindarnas': [('lindare', True), ('lind', True)],
          'lindblom': [('lindblom', True), ('lindblomma', True)],
          'lindblom-': [('lindblom', True), ('lindblomma', True)],
          'lindbloms': [('lindblom', True), ('lindblomma', True)],
          'lindbloms-': [('lindblomma', True), ('lindblom', True)],
          'linds': [('lind', True)],
          'linds-': [('lind', True)],
          'line': [('lina', True)],
          'line-': [('lina', True)],
          'linen': [('line', False)],
          'linens': [('line', False)],
          'liners': [('liner', False)],
          'lines': [('line', False)],
          'lines-': [('line', False)],
          'linesen': [('line', False)],
          'linesens': [('line', False)],
          'linet': [('lin', True)],
          'linets': [('lin', False)],
          'ling': [('ling', False)],
          'ling-': [('ling', False)],
          'lingar': [('ling', False)],
          'lingarna': [('ling', False)],
          'lingarnas': [('ling', False)],
          'lingars': [('ling', False)],
          'linge': [('linga', False)],
          'linge-': [('linga', False)],
          'lingen': [('ling', False)],
          'lingens': [('ling', False)],
          'linger': [('ling', False)],
          'lingers': [('ling', False)],
          'linget': [('ling', False)],
          'lingets': [('linge', False)],
          'lingon': [('lingon', True)],
          'lingons': [('lingon', False)],
          'lingor': [('linga', False)],
          'lingorna': [('linga', False)],
          'lings': [('ling', False)],
          'lings-': [('ling', False)],
          'lingscentrer': [('lingscentrum', False)],
          'lingscentrerna': [('lingscentrum', False)],
          'lingscentrernas': [('lingscentrum', False)],
          'lingsdags': [('lingsdag', False)],
          'lingsdags-': [('lingsdag', False)],
          'lingskasse-': [('lingskasse', False)],
          'lingstanken': [('lingstank', False)],
          'lingsvägar': [('lingsväg', False)],
          'lingsvägarna': [('lingsväg', False)],
          'lingsvägarnas': [('lingsväg', False)],
          'lingsvägars': [('lingsväg', False)],
          'lingsvägs': [('lingsväg', False)],
          'lingsvägs-': [('lingsväg', False)],
          'lini': [('lini', False)],
          'lini-': [('lini', False)],
          'linier': [('lini', False)],
          'liniernas': [('lini', False)],
          'liniers': [('lini', False)],
          'linin': [('lini', False)],
          'linins': [('lini', False)],
          'linis': [('lini', False)],
          'linister': [('linist', False)],
          'linisters': [('linist', False)],
          'link': [('link', False)],
          'link-': [('linka', False)],
          'linkomst-': [('linkomst', False)],
          'linkomster': [('linkomst', False)],
          'linkomsterna': [('linkomst', False)],
          'linkomsternas': [('linkomst', False)],
          'linkomsters': [('linkomst', False)],
          'links': [('linka', False)],
          'links-': [('linka', False)],
          'linne': [('linnea', True), ('linne', True)],
          'linne-': [('linne', True), ('linnea', True)],
          'linnen': [('linne', False)],
          'linnes': [('linnea', True), ('linne', True)],
          'linnes-': [('linnea', True), ('linne', True)],
          'linnets': [('linne', False)],
          'linns-': [('linne', False)],
          'lins': [('lins', True), ('lina', True), ('lin', True)],
          'lins-': [('lins', True), ('lina', True), ('lin', True)],
          'lint': [('lint', False)],
          'linter': [('lint', False)],
          'linterna': [('lint', False)],
          'linternas': [('lint', False)],
          'linters': [('lint', False)],
          'lints-': [('lint', False)],
          'lion': [('lion', False)],
          'lionen': [('lion', False)],
          'lionens': [('lion', False)],
          'lioner': [('lion', False)],
          'lionerna': [('lion', False)],
          'lionernas': [('lion', False)],
          'lioners': [('lion', False)],
          'lions': [('lion', False)],
          'lior': [('lia', False)],
          'liorna': [('lia', False)],
          'liornas': [('lia', False)],
          'liors': [('lia', False)],
          'lios-': [('lios', False)],
          'liosen': [('lios', False)],
          'liosens': [('lios', False)],
          'lip': [('lipa', False)],
          'lip-': [('lipa', False)],
          'lipan': [('lipa', False)],
          'lipans': [('lipa', False)],
          'liparnas': [('lip', False)],
          'lipas': [('lipas', True)],
          'liper': [('liper', False)],
          'lipers': [('liper', False)],
          'lipp': [('lipp', False)],
          'lipp-': [('lipp', False)],
          'lippar': [('lipp', False)],
          'lipparna': [('lipp', False)],
          'lipparnas': [('lippare', False)],
          'lippe': [('lippa', False)],
          'lippe-': [('lippa', False)],
          'lippen': [('lipp', False)],
          'lippens': [('lipp', False)],
          'lipper': [('lipper', False)],
          'lippet': [('lipp', False)],
          'lippets': [('lipp', False)],
          'lipps': [('lipp', False)],
          'lipps-': [('lipp', False)],
          'lips': [('lips', False)],
          'lips-': [('lipa', False)],
          'lir': [('lir', True), ('lira', True)],
          'lir-': [('lir', True), ('lira', True)],
          'lirarnas': [('lirare', True)],
          'lire': [('lire', True), ('lira', True)],
          'lire-': [('lire', True), ('lira', True)],
          'liren': [('lire', True)],
          'lirens': [('lire', True)],
          'lires': [('lire', True)],
          'lires-': [('lire', True)],
          'lirr': [('lirr', False)],
          'lirr-': [('lirr', False)],
          'lirrs-': [('lirr', False)],
          'lirs': [('lira', True), ('lir', True)],
          'lirs-': [('lir', True), ('lira', True)],
          'lis': [('lie', True)],
          'lis-': [('lie', True)],
          'lisa': [('lisa', True)],
          'lisan': [('lisa', False)],
          'lisans': [('lisa', False)],
          'lisarnas': [('lis', False)],
          'lisas': [('lisa', False)],
          'lisationen': [('lisation', False)],
          'lisen': [('lisen', True)],
          'lisens': [('lisen', True)],
          'lish': [('lish', False)],
          'lish-': [('lish', False)],
          'lisk': [('lisk', False)],
          'lisk-': [('lisk', False)],
          'liskan': [('liska', False)],
          'liskans': [('liska', False)],
          'liske': [('liska', False)],
          'liske-': [('liska', False)],
          'lisket': [('lisk', False)],
          'lisman': [('lisman', False)],
          'lismans': [('lisman', False)],
          'lismer': [('lism', False)],
          'lismerna': [('lism', False)],
          'lismernas': [('lism', False)],
          'lismers': [('lism', False)],
          'liss': [('liss', False)],
          'liss-': [('lissa', False)],
          'lissar': [('liss', False)],
          'lissars': [('liss', False)],
          'lisse': [('lissa', False)],
          'lisse-': [('lissa', False)],
          'lissen': [('liss', False)],
          'lissens': [('liss', False)],
          'lisser': [('liss', False)],
          'lisserierna': [('lisserie', False)],
          'lisserna': [('liss', False)],
          'lissernas': [('liss', False)],
          'lissers': [('liss', False)],
          'list': [('lista', True), ('list', True)],
          'list-': [('lista', True), ('list', True)],
          'liste': [('lista', False)],
          'listen': [('list', False)],
          'listens': [('list', False)],
          'lister': [('list', False)],
          'listern': [('lister', False)],
          'listerna': [('list', False)],
          'listernas': [('list', False)],
          'listerns': [('lister', False)],
          'listers': [('list', False)],
          'listik': [('listik', False)],
          'listik-': [('listik', False)],
          'listiker': [('listik', False)],
          'listikerna': [('listik', False)],
          'listikernas': [('listik', False)],
          'listikers': [('listik', False)],
          'listiks': [('listik', False)],
          'listiks-': [('listik', False)],
          'listor': [('lista', False)],
          'listors': [('lista', False)],
          'lit': [('li', False)],
          'lita': [('lita', False)],
          'litan': [('lita', False)],
          'litans': [('litan', False)],
          'litans-': [('litan', False)],
          'litarnas': [('lit', False)],
          'litas': [('lita', False)],
          'liter': [('liter', False)],
          'literna': [('liter', False)],
          'liternas': [('liter', True)],
          'liters': [('liter', False)],
          'litet': [('lit', False)],
          'litets': [('lit', False)],
          'litiker': [('litiker', False)],
          'litikernas': [('litiker', False)],
          'litikers': [('litiker', False)],
          'litoris-': [('litoris', False)],
          'lits': [('li', False)],
          'litsar': [('lits', False)],
          'litsarna': [('lits', False)],
          'litsen': [('lits', False)],
          'litsens': [('lits', False)],
          'litte': [('litta', False)],
          'litter': [('littera', True)],
          'litter-': [('littera', True)],
          'litters': [('littera', True)],
          'litters-': [('littera', True)],
          'littrarnas': [('littrare', False)],
          'lium': [('lium', False)],
          'liums': [('lium', False)],
          'liver': [('liv', False)],
          'livers': [('liv', False)],
          'livets': [('liv', False)],
          'livlins': [('livlina', True)],
          'livs': [('livs', True), ('liv', True)],
          'livs-': [('livs', True), ('liv', True)],
          'livsanden': [('livsande', True)],
          'livsandens': [('livsande', True)],
          'lj': [('lj', False)],
          'lj-': [('lj', False)],
          'ljan': [('lja', False)],
          'ljans-': [('ljans', False)],
          'ljaren': [('ljare', False)],
          'ljarnas': [('ljare', False)],
          'lje': [('lja', False)],
          'lje-': [('lja', False)],
          'ljen': [('lj', False)],
          'ljens': [('lj', False)],
          'ljer': [('lj', False)],
          'ljeren': [('ljer', False)],
          'ljerens': [('ljer', False)],
          'ljerna': [('lj', False)],
          'ljernas': [('lj', False)],
          'ljers': [('lj', False)],
          'ljet': [('lje', False)],
          'ljets': [('lje', False)],
          'ljoll': [('ljolle', False)],
          'ljolls-': [('ljolle', False)],
          'ljon': [('ljon', False)],
          'ljoner': [('ljon', False)],
          'ljonerna': [('ljon', False)],
          'ljonernas': [('ljon', False)],
          'ljoners': [('ljon', False)],
          'ljons': [('ljon', False)],
          'ljor': [('lja', False)],
          'ljorna': [('lja', False)],
          'ljornas': [('lja', False)],
          'ljors': [('lja', False)],
          'ljos': [('ljo', False)],
          'ljs': [('lj', False)],
          'ljs-': [('lj', False)],
          'ljstens': [('ljsten', False)],
          'ljuden': [('ljud', False)],
          'ljudens': [('ljud', False)],
          'ljug': [('ljug', True)],
          'ljugs': [('ljug', False)],
          'ljus': [('ljus', False)],
          'ljus-': [('ljus', False)],
          'ljusen': [('ljus', False)],
          'ljusens': [('ljus', False)],
          'ljär': [('ljär', False)],
          'ljär-': [('ljär', False)],
          'ljärnvägar': [('ljärnväg', False)],
          'ljärnvägarna': [('ljärnväg', False)],
          'ljärnvägarnas': [('ljärnväg', False)],
          'ljärs': [('ljär', False)],
          'ljärs-': [('ljär', False)],
          'ljöns': [('ljö', False)],
          'lk': [('lk', False)],
          'lk-': [('lk', False)],
          'lkad': [('lkad', False)],
          'lkad-': [('lkad', False)],
          'lkadens': [('lkad', False)],
          'lkader': [('lkad', False)],
          'lkaders': [('lkad', False)],
          'lkads': [('lkad', False)],
          'lkads-': [('lkad', False)],
          'lkaj': [('lkaja', False)],
          'lkaj-': [('lkaja', False)],
          'lkajs': [('lkaja', False)],
          'lkajs-': [('lkaja', False)],
          'lkaliers': [('lkali', False)],
          'lkall': [('lkalle', False)],
          'lkall-': [('lkalle', False)],
          'lkallar': [('lkalle', False)],
          'lkalle': [('lkalle', False)],
          'lkallen': [('lkalle', False)],
          'lkallens': [('lkalle', False)],
          'lkalls': [('lkalle', False)],
          'lkalls-': [('lkalle', False)],
          'lkammar': [('lkammare', False)],
          'lkams': [('lkam', False)],
          'lkams-': [('lkam', False)],
          'lkan': [('lka', False)],
          'lkan-': [('lkan', False)],
          'lkana': [('lkana', False)],
          'lkanas': [('lkana', False)],
          'lkanden': [('lkande', False)],
          'lkans-': [('lkan', False)],
          'lkar': [('lk', False)],
          'lkar-': [('lkare', False)],
          'lkare': [('lkare', False)],
          'lkaren': [('lkare', False)],
          'lkarens': [('lkare', False)],
          'lkarna': [('lk', False)],
          'lkars': [('lk', False)],
          'lkart': [('lkarta', False)],
          'lkart-': [('lkarta', False)],
          'lkartan': [('lkarta', False)],
          'lkarts': [('lkarta', False)],
          'lkarts-': [('lkarta', False)],
          'lkas': [('lka', False)],
          'lkasse': [('lkassa', False)],
          'lkasse-': [('lkasse', False)],
          'lkassen': [('lkasse', False)],
          'lkatt': [('lkatt', False)],
          'lkatt-': [('lkatt', False)],
          'lkatten': [('lkatt', False)],
          'lkattens': [('lkatt', False)],
          'lkatts': [('lkatt', False)],
          'lkatts-': [('lkatt', False)],
          'lke': [('lka', False)],
          'lke-': [('lka', False)],
          'lken': [('lk', False)],
          'lkens': [('lk', False)],
          'lkerits': [('lkeri', False)],
          'lkerna': [('lk', False)],
          'lkernas': [('lk', False)],
          'lkersens': [('lker', False)],
          'lket': [('lk', False)],
          'lkets': [('lke', False)],
          'lkien': [('lkie', False)],
          'lkiens': [('lkie', False)],
          'lkikarnas': [('lkikare', False)],
          'lkis': [('lkis', False)],
          'lkis-': [('lkis', False)],
          'lkisarnas': [('lkis', False)],
          'lkisen': [('lkis', False)],
          'lkisens': [('lkis', False)],
          'lkist-': [('lkista', False)],
          'lkistans': [('lkista', False)],
          'lklagets': [('lklag', False)],
          'lklamp-': [('lklamp', False)],
          'lklamps-': [('lklamp', False)],
          'lklandet': [('lkland', False)],
          'lklapp': [('lklapp', False)],
          'lklapp-': [('lklapp', False)],
          'lklapps': [('lklapp', False)],
          'lklapps-': [('lklapp', False)],
          'lklin': [('lklina', False)],
          'lklin-': [('lklina', False)],
          'lkling': [('lklinga', False)],
          'lkling-': [('lklinga', False)],
          'lklings': [('lklinga', False)],
          'lklings-': [('lklinga', False)],
          'lkliniker': [('lklinik', False)],
          'lklinikerna': [('lklinik', False)],
          'lklinikernas': [('lklinik', False)],
          'lklinikers': [('lklinik', False)],
          'lklipp': [('lklipp', False)],
          'lklipps': [('lklipp', False)],
          'lklipps-': [('lklipp', False)],
          'lklock': [('lklocka', False)],
          'lklon': [('lklo', False)],
          'lklons': [('lklo', False)],
          'lklops': [('lklops', False)],
          'lklor': [('lklo', False)],
          'lkloren': [('lklore', False)],
          'lklorens': [('lklore', False)],
          'lklornas': [('lklo', False)],
          'lklors': [('lklo', False)],
          'lkningar': [('lkning', False)],
          'lkningarna': [('lkning', False)],
          'lkningarnas': [('lkning', False)],
          'lkningars': [('lkning', False)],
          'lknings': [('lkning', False)],
          'lknings-': [('lkning', False)],
          'lknipp': [('lknippa', False)],
          'lknipp-': [('lknippa', False)],
          'lknippe-': [('lknippe', False)],
          'lknipps': [('lknippa', False)],
          'lknipps-': [('lknippa', False)],
          'lknut': [('lknut', False)],
          'lknuts': [('lknut', False)],
          'lknuts-': [('lknut', False)],
          'lknät': [('lknä', False)],
          'lknäts': [('lknä', False)],
          'lko-': [('lko', False)],
          'lkols': [('lkol', False)],
          'lkols-': [('lkol', False)],
          'lkomst-': [('lkomst', False)],
          'lkon': [('lkon', False)],
          'lkon-': [('lkon', False)],
          'lkons': [('lkon', False)],
          'lkonst-': [('lkonst', False)],
          'lkonster': [('lkonst', False)],
          'lkonsterna': [('lkonst', False)],
          'lkonsternas': [('lkonst', False)],
          'lkonsters': [('lkonst', False)],
          'lkopp': [('lkopp', False)],
          'lkopp-': [('lkopp', False)],
          'lkoppar': [('lkopp', False)],
          'lkoppars': [('lkopp', False)],
          'lkopps': [('lkopp', False)],
          'lkopps-': [('lkopp', False)],
          'lkoret': [('lkor', False)],
          'lkorets': [('lkor', False)],
          'lkorna': [('lka', False)],
          'lkornas': [('lka', False)],
          'lkors': [('lka', False)],
          'lkors-': [('lkor', False)],
          'lkos': [('lko', False)],
          'lkos-': [('lko', False)],
          'lkostnaderna': [('lkostnad', False)],
          'lkostnadernas': [('lkostnad', False)],
          'lkostnads-': [('lkostnad', False)],
          'lkott': [('lkotte', False)],
          'lkott-': [('lkott', False)],
          'lkottar': [('lkott', False)],
          'lkottarna': [('lkott', False)],
          'lkottarnas': [('lkott', False)],
          'lkottars': [('lkott', False)],
          'lkotten': [('lkotte', False)],
          'lkottens': [('lkott', False)],
          'lkotts': [('lkott', False)],
          'lkotts-': [('lkotte', False)],
          'lkrafter': [('lkraft', False)],
          'lkrafts': [('lkraft', False)],
          'lkrafts-': [('lkraft', False)],
          'lkramp': [('lkramp', False)],
          'lkramps': [('lkramp', False)],
          'lkramps-': [('lkramp', False)],
          'lkrans': [('lkrans', False)],
          'lkrans-': [('lkrans', False)],
          'lkrar': [('lker', False)],
          'lkrarna': [('lker', False)],
          'lkrets-': [('lkrets', False)],
          'lkronan': [('lkrona', False)],
          'lkronans': [('lkrona', False)],
          'lkrons-': [('lkrona', False)],
          'lkrossar': [('lkross', False)],
          'lkrossarnas': [('lkross', False)],
          'lkrubb': [('lkrubba', False)],
          'lkrubb-': [('lkrubba', False)],
          'lkrubborna': [('lkrubba', False)],
          'lkrubbors': [('lkrubba', False)],
          'lkrubbs': [('lkrubba', False)],
          'lkrubbs-': [('lkrubba', False)],
          'lktanden': [('lktand', False)],
          'lktandens': [('lktand', False)],
          'lkteater': [('lkteater', False)],
          'lkteaters': [('lkteater', False)],
          'lktons': [('lkton', False)],
          'lktrons': [('lktro', False)],
          'lkubb': [('lkubb', False)],
          'lkubb-': [('lkubb', False)],
          'lkubbar': [('lkubb', False)],
          'lkubbarna': [('lkubb', False)],
          'lkubbarnas': [('lkubb', False)],
          'lkubbars': [('lkubb', False)],
          'lkubben': [('lkubb', False)],
          'lkubbens': [('lkubb', False)],
          'lkubbs': [('lkubb', False)],
          'lkubbs-': [('lkubb', False)],
          'lkull': [('lkulla', False)],
          'lkull-': [('lkulla', False)],
          'lkulle': [('lkulla', False)],
          'lkulls': [('lkulla', False)],
          'lkulls-': [('lkulla', False)],
          'lkulor': [('lkula', False)],
          'lkulorna': [('lkula', False)],
          'lkulornas': [('lkula', False)],
          'lkulors': [('lkula', False)],
          'lkunskaper': [('lkunskap', False)],
          'lkunskaps': [('lkunskap', False)],
          'lkurs': [('lkurs', False)],
          'lkurv': [('lkurva', False)],
          'lkurv-': [('lkurva', False)],
          'lkurvor': [('lkurva', False)],
          'lkurvorna': [('lkurva', False)],
          'lkurvornas': [('lkurva', False)],
          'lkurvors': [('lkurva', False)],
          'lkurvs': [('lkurva', False)],
          'lkurvs-': [('lkurva', False)],
          'lkus': [('lkusa', False)],
          'lkus-': [('lkusa', False)],
          'lkuse': [('lkusa', False)],
          'lkut-': [('lkut', False)],
          'lkuts': [('lkut', False)],
          'lkuts-': [('lkut', False)],
          'lkvis-': [('lkvisa', False)],
          'lkvägar': [('lkvägare', False)],
          'lkvägarna': [('lkvägare', False)],
          'lkvägarnas': [('lkvägare', False)],
          'lkyl': [('lkyl', False)],
          'lkyl-': [('lkyl', False)],
          'lkyls': [('lkyl', False)],
          'lkyls-': [('lkyl', False)],
          'lkyn': [('lkyn', False)],
          'lkyns': [('lkyn', False)],
          'lkäll': [('lkälla', False)],
          'lkäll-': [('lkälla', False)],
          'lkärv': [('lkärve', False)],
          'lkärvarna': [('lkärve', False)],
          'lkärvarnas': [('lkärve', False)],
          'lkärve': [('lkärve', False)],
          'lkärven': [('lkärve', False)],
          'lkärvens': [('lkärve', False)],
          'lkärvs-': [('lkärve', False)],
          'lkåder': [('lkåder', False)],
          'lkåder-': [('lkåder', False)],
          'lkådran': [('lkåder', False)],
          'lkådras': [('lkåder', False)],
          'lkådre': [('lkåder', False)],
          'lkådrornas': [('lkåder', False)],
          'lkådrors': [('lkåder', False)],
          'lkår': [('lkår', False)],
          'lkåren': [('lkår', False)],
          'lkårens': [('lkår', False)],
          'lkårs': [('lkår', False)],
          'lkårs-': [('lkår', False)],
          'lkök-': [('lkök', False)],
          'lköks': [('lkök', False)],
          'lköks-': [('lkök', False)],
          'lkön': [('lkö', False)],
          'lköns': [('lkö', False)],
          'lkör': [('lkör', False)],
          'lkörs': [('lkör', False)],
          'lkörs-': [('lkör', False)],
          'llacens': [('llac', False)],
          'llack': [('llack', False)],
          'llad': [('llad', False)],
          'llad-': [('llad', False)],
          'lladdar': [('lladdare', False)],
          'llads': [('llad', False)],
          'llads-': [('llad', False)],
          'llag': [('llag', False)],
          'llagarna': [('llag', False)],
          'llagarnas': [('llag', False)],
          'llagen': [('llag', False)],
          'llagens': [('llage', False)],
          'llagerna': [('llager', False)],
          'llaget': [('llage', False)],
          'llagets': [('llage', False)],
          'llags': [('llag', False)],
          'llags-': [('llag', False)],
          'llamps': [('llampa', False)],
          'llamps-': [('llampa', False)],
          'llan': [('lla', False)],
          'llan-': [('llan', False)],
          'llanden': [('llande', False)],
          'llandena': [('llande', False)],
          'llandenas': [('llande', False)],
          'llandens': [('llande', False)],
          'llandet': [('llande', False)],
          'llandets': [('lland', False)],
          'llaner': [('llan', False)],
          'llanerna': [('llan', False)],
          'llanernas': [('llan', False)],
          'llaners': [('llan', False)],
          'llans-': [('llan', False)],
          'llant-': [('llant', False)],
          'llanterna': [('llant', False)],
          'llanternas': [('llant', False)],
          'llants': [('llant', False)],
          'llants-': [('llant', False)],
          'llaps': [('llapa', False)],
          'llaps-': [('llapa', False)],
          'llarden': [('llarde', False)],
          'llardens': [('llarde', False)],
          'llarder': [('llarde', False)],
          'llarderna': [('llarde', False)],
          'llardernas': [('llarde', False)],
          'llarders': [('llarde', False)],
          'llaren': [('llare', False)],
          'llarie-': [('llarium', False)],
          'llarierna': [('llarium', False)],
          'llarn': [('llar', False)],
          'llarns': [('llar', False)],
          'llars': [('ll', False)],
          'llars-': [('llar', False)],
          'llasen': [('lla', False)],
          'llat': [('llat', False)],
          'llat-': [('llat', False)],
          'llaten': [('llat', False)],
          'llatens': [('llat', False)],
          'llater': [('llat', False)],
          'llaterna': [('llat', False)],
          'llaternas': [('llat', False)],
          'llaters': [('llat', False)],
          'llats': [('llat', False)],
          'llats-': [('llat', False)],
          'llbackarnas': [('llbacke', False)],
          'llbackars': [('llbacke', False)],
          'llbacken': [('llbacke', False)],
          'llbackens': [('llbacke', False)],
          'llbacks': [('llbacke', False)],
          'llben': [('llben', False)],
          'llbil': [('llbila', False)],
          'llbil-': [('llbila', False)],
          'llbils': [('llbila', False)],
          'llbils-': [('llbila', False)],
          'llborr': [('llborr', False)],
          'llborr-': [('llborr', False)],
          'llborrar': [('llborr', False)],
          'llborrarna': [('llborr', False)],
          'llborrarnas': [('llborr', False)],
          'llborrars': [('llborr', False)],
          'llborren': [('llborr', False)],
          'llborrens': [('llborr', False)],
          'llborrs': [('llborr', False)],
          'llborrs-': [('llborr', False)],
          'llbrodern': [('llbroder', False)],
          'llbroders': [('llbroder', False)],
          'llbröder': [('llbroder', False)],
          'llbrödernas': [('llbroder', False)],
          'llbull-': [('llbulle', False)],
          'lldelar': [('lldel', False)],
          'lldelarna': [('lldel', False)],
          'lldelarnas': [('lldel', False)],
          'lldomar': [('lldom', False)],
          'lldomarna': [('lldom', False)],
          'lldos-': [('lldosa', False)],
          'lle': [('lla', False)],
          'lle-': [('lla', False)],
          'llegans': [('llega', False)],
          'llegas': [('llega', False)],
          'llege': [('llege', False)],
          'llege-': [('llege', False)],
          'llegen': [('llege', False)],
          'llegens': [('llege', False)],
          'lleget': [('llege', False)],
          'llegets': [('llege', False)],
          'llegie': [('llegium', False)],
          'llegie-': [('llegium', False)],
          'llegier': [('llegium', False)],
          'llegierna': [('llegium', False)],
          'llegiers': [('llegium', False)],
          'llekar': [('llek', False)],
          'llektas': [('llekta', False)],
          'llekternas': [('llekt', False)],
          'llelen': [('llel', False)],
          'llelens': [('llel', False)],
          'lleler': [('llel', False)],
          'llelerna': [('llel', False)],
          'llelernas': [('llel', False)],
          'llen-': [('llen', False)],
          'llens-': [('llen', False)],
          'ller-': [('ller', False)],
          'llerin': [('lleri', False)],
          'llerna': [('ll', False)],
          'llernas': [('ll', False)],
          'llers': [('ll', False)],
          'llers-': [('ller', False)],
          'llet': [('ll', False)],
          'lletar': [('llet', False)],
          'lletarna': [('llet', False)],
          'lletarnas': [('lletare', False)],
          'lleten': [('llet', False)],
          'lletens': [('llet', False)],
          'llets': [('ll', False)],
          'llets-': [('llet', False)],
          'lletten': [('llette', False)],
          'llettens': [('llett', False)],
          'lletter': [('llette', False)],
          'lletterna': [('llette', False)],
          'lletternas': [('llette', False)],
          'lletters': [('llette', False)],
          'llfare': [('llfara', False)],
          'llfen': [('llfena', False)],
          'llfens': [('llfena', False)],
          'llgångar': [('llgång', False)],
          'llgångarna': [('llgång', False)],
          'llgångarnas': [('llgång', False)],
          'llgångars': [('llgång', False)],
          'llgångs': [('llgång', False)],
          'llgångs-': [('llgång', False)],
          'llhake': [('llhake', False)],
          'lli': [('llo', False)],
          'lli-': [('lli', False)],
          'llians': [('llians', False)],
          'llick': [('llick', False)],
          'llickarnas': [('llick', False)],
          'llie-': [('llie', False)],
          'llien': [('llie', False)],
          'llier': [('llier', False)],
          'llierna': [('llie', False)],
          'lliernas': [('llie', False)],
          'lliers': [('llier', False)],
          'lliet': [('llium', False)],
          'llighets': [('llighet', False)],
          'llikvid': [('llikvid', False)],
          'llikvid-': [('llikvid', False)],
          'llikvids': [('llikvid', False)],
          'llin': [('llin', False)],
          'llin-': [('llin', False)],
          'llina': [('llina', False)],
          'llinas': [('llina', False)],
          'llinen': [('llin', False)],
          'llinens': [('llin', False)],
          'lliner': [('llin', False)],
          'llinerna': [('llin', False)],
          'llinernas': [('llin', False)],
          'lliners': [('llin', False)],
          'llinet': [('llin', False)],
          'llins': [('llin', False)],
          'llins-': [('llins', False)],
          'llips-': [('llips', False)],
          'llis': [('lli', False)],
          'llis-': [('llis', False)],
          'llisen': [('llis', False)],
          'llisens': [('llis', False)],
          'llist': [('llist', False)],
          'llist-': [('llist', False)],
          'llit': [('llit', False)],
          'llit-': [('llit', False)],
          'lliten': [('llit', False)],
          'llitens': [('llit', False)],
          'lliter': [('llit', False)],
          'lliterna': [('llit', False)],
          'lliternas': [('llit', False)],
          'lliters': [('llit', False)],
          'llitet': [('llitet', False)],
          'llitets': [('llitet', False)],
          'llits': [('llit', False)],
          'llits-': [('llit', False)],
          'llivs': [('lliv', False)],
          'llivs-': [('lliv', False)],
          'llkon': [('llko', False)],
          'llkons': [('llko', False)],
          'llkor': [('llkor', False)],
          'llkorna': [('llko', False)],
          'llkornas': [('llko', False)],
          'llkors': [('llkor', False)],
          'llmjölk': [('llmjölke', False)],
          'llmjölk-': [('llmjölke', False)],
          'llmjölken': [('llmjölke', False)],
          'llmjölkens': [('llmjölke', False)],
          'llmjölks': [('llmjölke', False)],
          'llmjölks-': [('llmjölke', False)],
          'llmorna': [('llmo', False)],
          'llmornas': [('llmo', False)],
          'llmos': [('llmo', False)],
          'llmos-': [('llmo', False)],
          'llmåns': [('llmåne', False)],
          'llmåns-': [('llmåns', False)],
          'llningar': [('llning', False)],
          'llningarna': [('llning', False)],
          'llningarnas': [('llning', False)],
          'llningars': [('llning', False)],
          'llnings': [('llning', False)],
          'llnings-': [('llning', False)],
          'llo-': [('llo', False)],
          'llodiers': [('llodium', False)],
          'llok': [('llok', False)],
          'llok-': [('llok', False)],
          'lloks': [('llok', False)],
          'lloks-': [('llok', False)],
          'llom-': [('llom', False)],
          'lloms': [('llom', False)],
          'llon': [('llon', False)],
          'llonen': [('llon', False)],
          'llonens': [('llon', False)],
          'lloner': [('llon', False)],
          'llonerna': [('llon', False)],
          'llonernas': [('llon', False)],
          'lloners': [('llon', False)],
          'llons': [('llon', False)],
          'llopp': [('llopp', False)],
          'llopps': [('llopp', False)],
          'llopps-': [('llopp', False)],
          'llops': [('llop', False)],
          'llops-': [('llop', False)],
          'llor': [('lla', False)],
          'llorna': [('lla', False)],
          'llornas': [('lla', False)],
          'llors': [('lla', False)],
          'llos': [('llos', False)],
          'llos-': [('llos', False)],
          'llosarna': [('llos', False)],
          'llosen': [('llos', False)],
          'llosens': [('llos', False)],
          'llot': [('llo', False)],
          'llots': [('llo', False)],
          'llov': [('llov', False)],
          'llov-': [('llov', False)],
          'lloven': [('llov', False)],
          'llovens': [('llov', False)],
          'llovs': [('llov', False)],
          'llovs-': [('llov', False)],
          'llrar': [('ller', False)],
          'llrarna': [('llrare', False)],
          'llrarnas': [('llrare', False)],
          'llrars': [('ller', False)],
          'llras': [('llra', False)],
          'llsarnas': [('lls', False)],
          'llspinnar': [('llspinnare', False)],
          'llspinnarna': [('llspinnare', False)],
          'llspinnarnas': [('llspinnare', False)],
          'llstudie': [('llstudium', False)],
          'llstudie-': [('llstudie', False)],
          'llstudier': [('llstudium', False)],
          'llstudierna': [('llstudie', False)],
          'llstudiernas': [('llstudie', False)],
          'llstudiers': [('llstudie', False)],
          'llstyrkan': [('llstyrkan', False)],
          'llställen': [('llställe', False)],
          'llställens': [('llställe', False)],
          'llstället': [('llställe', False)],
          'llställets': [('llställe', False)],
          'llstötar': [('llstöt', False)],
          'llstötarna': [('llstöt', False)],
          'llt': [('llt', False)],
          'llte': [('llte', False)],
          'llte-': [('llte', False)],
          'lltes': [('llte', False)],
          'lltet': [('llte', False)],
          'lltets': [('llt', False)],
          'lltros': [('lltro', False)],
          'llträdets': [('llträde', False)],
          'llträn': [('llträ', False)],
          'llträna': [('llträ', False)],
          'llträns': [('llträ', False)],
          'lltårs': [('lltå', False)],
          'lluck': [('llucka', False)],
          'lluck-': [('llucka', False)],
          'llucks': [('llucka', False)],
          'lluffar': [('lluff', False)],
          'lluffarna': [('lluff', False)],
          'lluffarnas': [('lluff', False)],
          'llumen': [('llum', False)],
          'llumens': [('llum', False)],
          'llums': [('llum', False)],
          'llums-': [('llum', False)],
          'llunge': [('llunge', False)],
          'llunge-': [('llunge', False)],
          'llvar': [('llvar', False)],
          'llvind': [('llvind', False)],
          'llvärden': [('llvärd', False)],
          'llvärdens': [('llvärd', False)],
          'llväsendet': [('llväsen', False)],
          'llyftarnas': [('llyft', False)],
          'llyfts': [('llyft', False)],
          'llykt': [('llykta', False)],
          'llykt-': [('llykta', False)],
          'llykts': [('llykta', False)],
          'llyr': [('llyr', False)],
          'llyr-': [('llyr', False)],
          'llyrs': [('llyr', False)],
          'llys': [('lly', False)],
          'llysen': [('lly', False)],
          'llysens': [('lly', False)],
          'lländar': [('lländare', False)],
          'lländarna': [('lländare', False)],
          'lländarnas': [('llände', False)],
          'llände': [('llände', False)],
          'lländen': [('llände', False)],
          'lländens': [('llände', False)],
          'lländer': [('lland', False)],
          'lländerna': [('lland', False)],
          'lländernas': [('lland', False)],
          'lländers': [('lland', False)],
          'llär': [('llär', False)],
          'llär-': [('llär', False)],
          'llärs': [('llär', False)],
          'llärs-': [('llär', False)],
          'llåder': [('llåder', False)],
          'llås-': [('llåa', False)],
          'llåt': [('llåt', False)],
          'llåtarna': [('llåt', False)],
          'llös': [('llö', False)],
          'llös-': [('llö', False)],
          'llöss': [('llus', False)],
          'llössen': [('llus', False)],
          'llössens': [('llus', False)],
          'lm': [('lm', False)],
          'lm-': [('lm', False)],
          'lmack': [('lmack', False)],
          'lmacks': [('lmack', False)],
          'lmacks-': [('lmack', False)],
          'lmakar': [('lmakare', False)],
          'lmakarna': [('lmakare', False)],
          'lmakarnas': [('lmakare', False)],
          'lman': [('lman', False)],
          'lman-': [('lman', False)],
          'lmanden': [('lmande', False)],
          'lmaner': [('lman', False)],
          'lmanerna': [('lman', False)],
          'lmanernas': [('lman', False)],
          'lmaners': [('lman', False)],
          'lmannen': [('lman', False)],
          'lmannens': [('lman', False)],
          'lmans': [('lman', False)],
          'lmar': [('lm', False)],
          'lmar-': [('lmare', False)],
          'lmare': [('lmare', False)],
          'lmaren': [('lmare', False)],
          'lmarens': [('lmar', False)],
          'lmarginaler': [('lmarginal', False)],
          'lmarginalerna': [('lmarginal', False)],
          'lmarginalernas': [('lmarginal', False)],
          'lmarginalers': [('lmarginal', False)],
          'lmarna': [('lm', False)],
          'lmarnas': [('lmare', False)],
          'lmars': [('lm', False)],
          'lmars-': [('lmar', False)],
          'lmas': [('lma', False)],
          'lmas-': [('lma', False)],
          'lmasen': [('lmas', False)],
          'lmask': [('lmask', False)],
          'lmask-': [('lmask', False)],
          'lmaster': [('lmast', False)],
          'lmasters': [('lmast', False)],
          'lmat': [('lmat', False)],
          'lmaten': [('lmat', False)],
          'lmatens': [('lmat', False)],
          'lmaterier': [('lmateria', False)],
          'lmaterierna': [('lmateria', False)],
          'lmateriernas': [('lmateria', False)],
          'lmateriers': [('lmateria', False)],
          'lmats': [('lmat', False)],
          'lmatt': [('lmatta', False)],
          'lmatt-': [('lmatta', False)],
          'lmatte': [('lmatta', False)],
          'lmatte-': [('lmatta', False)],
          'lmatten': [('lmatt', False)],
          'lmatts': [('lmatta', False)],
          'lmatts-': [('lmatta', False)],
          'lmbolagets': [('lmbolag', False)],
          'lmediers': [('lmedium', False)],
          'lmen': [('lm', False)],
          'lmens': [('lm', False)],
          'lmens-': [('lmen', False)],
          'lmer': [('lm', False)],
          'lmerna': [('lm', False)],
          'lmernas': [('lm', False)],
          'lmers': [('lm', False)],
          'lmes': [('lme', False)],
          'lmes-': [('lme', False)],
          'lmfars': [('lmfars', False)],
          'lmfars-': [('lmfars', False)],
          'lmil': [('lmila', False)],
          'lmil-': [('lmila', False)],
          'lmile': [('lmila', False)],
          'lmile-': [('lmila', False)],
          'lmils': [('lmila', False)],
          'lmin': [('lmi', False)],
          'lminister': [('lminister', False)],
          'lministers': [('lminister', False)],
          'lmins': [('lmi', False)],
          'lmiss': [('lmiss', False)],
          'lmiss-': [('lmiss', False)],
          'lmissar': [('lmiss', False)],
          'lmissarna': [('lmiss', False)],
          'lmissarnas': [('lmiss', False)],
          'lmissars': [('lmiss', False)],
          'lmissen': [('lmiss', False)],
          'lmissens': [('lmiss', False)],
          'lmister': [('lmist', False)],
          'lmisters': [('lmist', False)],
          'lmits': [('lmi', False)],
          'lmjölk': [('lmjölk', False)],
          'lmjölk-': [('lmjölk', False)],
          'lmjölkar': [('lmjölke', False)],
          'lmjölkarna': [('lmjölke', False)],
          'lmjölkarnas': [('lmjölke', False)],
          'lmjölken': [('lmjölk', False)],
          'lmjölkens': [('lmjölk', False)],
          'lmjölks': [('lmjölk', False)],
          'lmjölks-': [('lmjölk', False)],
          'lmo': [('lmo', False)],
          'lmodet': [('lmod', False)],
          'lmodets': [('lmod', False)],
          'lmods': [('lmod', False)],
          'lmods-': [('lmod', False)],
          'lmor': [('lmo', False)],
          'lmorna': [('lma', False)],
          'lmornas': [('lma', False)],
          'lmors': [('lmo', False)],
          'lmos': [('lmos', False)],
          'lmos-': [('lmos', False)],
          'lmosen': [('lmos', False)],
          'lmosens': [('lmos', False)],
          'lmotet': [('lmote', False)],
          'lmotets': [('lmote', False)],
          'lms-': [('lm', False)],
          'lmsk': [('lmska', False)],
          'lmsk-': [('lmska', False)],
          'lmske': [('lmska', False)],
          'lmskor': [('lmska', False)],
          'lmskorna': [('lmska', False)],
          'lmskornas': [('lmska', False)],
          'lmskors': [('lmska', False)],
          'lmurar': [('lmur', False)],
          'lmurarna': [('lmur', False)],
          'lmurarnas': [('lmur', False)],
          'lmus': [('lmus', False)],
          'lmussel': [('lmussla', False)],
          'lmussel-': [('lmussla', False)],
          'lmygg': [('lmygga', False)],
          'lmygg-': [('lmygga', False)],
          'lmyggs': [('lmygga', False)],
          'lmyggs-': [('lmygga', False)],
          'lmynt': [('lmynt', False)],
          'lmynts': [('lmynt', False)],
          'lmynts-': [('lmynt', False)],
          'lmys': [('lmys', False)],
          'lmys-': [('lmys', False)],
          'lmän': [('lman', False)],
          'lmäns': [('lman', False)],
          'lmån': [('lmåne', False)],
          'lmån-': [('lmåne', False)],
          'lmåns': [('lmåns', False)],
          'lmöbor': [('lmöbo', False)],
          'lmöborna': [('lmöbo', False)],
          'lmöbors': [('lmöbo', False)],
          'lmöss': [('lmössa', False)],
          'ln': [('ln', False)],
          'ln-': [('ln', False)],
          'lna': [('lna', False)],
          'lnader': [('lnad', False)],
          'lnaderna': [('lnad', False)],
          'lnadernas': [('lnad', False)],
          'lnaders': [('lnad', False)],
          'lnads': [('lnad', False)],
          'lnads-': [('lnad', False)],
          'lnamn': [('lnamn', False)],
          'lnamn-': [('lnamn', False)],
          'lnamnen': [('lnamn', False)],
          'lnamnens': [('lnamn', False)],
          'lnamns': [('lnamn', False)],
          'lnamns-': [('lnamn', False)],
          'lnanden': [('lnande', False)],
          'lnar': [('lnare', False)],
          'lnar-': [('lnare', False)],
          'lnaren': [('lnare', False)],
          'lnarens': [('lnare', False)],
          'lnarna': [('ln', False)],
          'lnarnas': [('lnare', False)],
          'lnars': [('ln', False)],
          'lnas': [('lna', False)],
          'lne': [('lna', False)],
          'lne-': [('lna', False)],
          'lnen': [('ln', False)],
          'lnens': [('ln', False)],
          'lness-': [('lness', False)],
          'lnet': [('ln', False)],
          'lningarna': [('lan', False)],
          'lningarnas': [('lan', False)],
          'lningars': [('lan', False)],
          'lningsdos': [('lningsdos', False)],
          'lningsdos-': [('lningsdos', False)],
          'lnor': [('lna', False)],
          'lnorna': [('lna', False)],
          'lnornas': [('lna', False)],
          'lnors': [('lna', False)],
          'lnot': [('lnot', False)],
          'lnot-': [('lnot', False)],
          'lnots': [('lnot', False)],
          'lnots-': [('lnot', False)],
          'lns': [('ln', False)],
          'lns-': [('ln', False)],
          'lnär': [('lnär', False)],
          'lnär-': [('lnär', False)],
          'lnärer': [('lnär', False)],
          'lnärerna': [('lnär', False)],
          'lnärernas': [('lnär', False)],
          'lnärers': [('lnär', False)],
          'lnärs': [('lnär', False)],
          'lnärs-': [('lnär', False)],
          'lnäs': [('lnäsa', False)],
          'lnäs-': [('lnäsa', False)],
          'lnäts': [('lnät', False)],
          'lnötter': [('lnöt', False)],
          'lnötterna': [('lnöt', False)],
          'lnötternas': [('lnöt', False)],
          'lo': [('lo', False)],
          'lo-': [('lo', True)],
          'loafers': [('loafer', True), ('loafers', True)],
          'loafersen': [('loafers', True), ('loafer', True)],
          'loafersens': [('loafer', True), ('loafers', True)],
          'loar': [('lo', False)],
          'loars': [('lo', False)],
          'lobb': [('lobb', True)],
          'lobbar': [('lobb', True)],
          'lobbarna': [('lobb', True)],
          'lobbarnas': [('lobb', True)],
          'lobbars': [('lobb', True)],
          'lobbens': [('lobb', True)],
          'lobbs': [('lobb', True)],
          'lobbs-': [('lobb', True)],
          'lobin': [('lobin', False)],
          'lock': [('lock', True)],
          'lock-': [('lock', True)],
          'lockar': [('lock', False)],
          'lockarna': [('lock', False)],
          'lockarnas': [('lock', True)],
          'locken': [('lock', False)],
          'lockens': [('lock', False)],
          'locker': [('lock', False)],
          'lockers': [('lock', False)],
          'locket': [('lock', False)],
          'locks': [('lock', False)],
          'locks-': [('lock', False)],
          'lodar': [('lodare', True)],
          'lodarna': [('lodare', True)],
          'lodarnas': [('lodare', True)],
          'loden': [('loden', True), ('lod', True)],
          'lodens': [('loden', True), ('lod', True)],
          'loders': [('lod', False)],
          'lodet': [('lod', False)],
          'lodets': [('lod', False)],
          'lodier': [('lodium', False)],
          'lodierna': [('lodium', False)],
          'lodiernas': [('lodium', False)],
          'lodiers': [('lodi', False)],
          'lodis': [('lodis', True)],
          'lods': [('lod', False)],
          'lods-': [('lod', False)],
          'loen': [('loe', False)],
          'loens': [('loe', False)],
          'loer': [('lo', False)],
          'loerna': [('lo', False)],
          'loernas': [('lo', False)],
          'loers': [('lo', False)],
          'loft': [('loft', True)],
          'loft-': [('loft', True)],
          'lofts': [('loft', True)],
          'lofts-': [('loft', True)],
          'log': [('loge', True)],
          'log-': [('loge', True)],
          'logan': [('logan', False)],
          'logans-': [('logan', False)],
          'logar': [('loge', True)],
          'logarna': [('loge', True)],
          'logarnas': [('loge', True)],
          'logars': [('loge', True)],
          'loge': [('loge', False)],
          'loge-': [('loge', True)],
          'logen': [('loge', True)],
          'logenerna': [('logen', False)],
          'logens': [('loge', False)],
          'loger': [('loge', True)],
          'logerna': [('loge', False)],
          'logernas': [('loge', True)],
          'logers': [('loge', True)],
          'loget': [('log', False)],
          'logets': [('log', False)],
          'loggar': [('logg', True)],
          'loggarna': [('logg', False)],
          'loggarnas': [('logg', False)],
          'loggi': [('loggia', True)],
          'loggi-': [('loggia', True)],
          'loggis': [('loggia', True)],
          'logier': [('logi', False)],
          'logierna': [('logi', False)],
          'logiernas': [('logi', True)],
          'logiers': [('logi', False)],
          'logiet': [('logi', True)],
          'logiets': [('logi', True)],
          'logrammet': [('logram', False)],
          'logrammets': [('logram', False)],
          'logs': [('loge', True)],
          'logs-': [('loge', True)],
          'lok': [('lok', True), ('loka', True)],
          'lok-': [('lok', True), ('loka', True)],
          'lokan': [('loka', False)],
          'lokarnas': [('lok', False)],
          'lokets': [('lok', False)],
          'loks': [('lok', True), ('loka', True)],
          'loks-': [('loka', True), ('lok', True)],
          'loll': [('lolla', False)],
          'loll-': [('lolla', False)],
          'lolle': [('lolla', True)],
          'lolls': [('lolla', True)],
          'lolls-': [('lolla', False)],
          'lologier': [('lologi', False)],
          'lologierna': [('lologi', False)],
          'lologiers': [('lologi', False)],
          'lom': [('lom', True)],
          'lom-': [('lom', True)],
          'lomans-': [('loman', False)],
          'lomb': [('lomb', False)],
          'lomb-': [('lomb', False)],
          'lomben': [('lomb', False)],
          'lombens': [('lomb', False)],
          'lomber': [('lomb', False)],
          'lomberna': [('lomb', False)],
          'lombernas': [('lomb', False)],
          'lombers': [('lomb', False)],
          'lombs': [('lomb', False)],
          'lombs-': [('lomb', False)],
          'lomen': [('lom', False)],
          'lomens': [('lom', False)],
          'lometer': [('lometer', False)],
          'lometerna': [('lometer', False)],
          'lometernas': [('lometer', False)],
          'lometers': [('lometer', False)],
          'lommarna': [('lom', False)],
          'lomme': [('lomme', True)],
          'lomme-': [('lomme', True)],
          'lommen': [('lomme', True), ('lom', True)],
          'lommens': [('lomme', True), ('lom', True)],
          'loms': [('lom', True)],
          'loms-': [('lom', True)],
          'lomst': [('lomst', False)],
          'lomster': [('lomster', False)],
          'lomsterna': [('lomster', False)],
          'lomsternas': [('lomster', False)],
          'lomsters': [('lomster', False)],
          'lon': [('lo', False)],
          'lon-': [('lon', False)],
          'lona': [('lo', False)],
          'lonas': [('lo', False)],
          'lond': [('lond', False)],
          'lond-': [('lond', False)],
          'londen': [('lond', False)],
          'londens': [('lond', False)],
          'londer': [('lond', False)],
          'londers': [('lond', False)],
          'londs': [('lond', False)],
          'londs-': [('lond', False)],
          'lone': [('lone', False)],
          'lone-': [('lone', False)],
          'lones': [('lone', False)],
          'lones-': [('lone', False)],
          'long': [('long', False)],
          'long-': [('long', False)],
          'longer': [('long', False)],
          'longerna': [('long', False)],
          'longernas': [('long', False)],
          'longers': [('long', False)],
          'longs': [('long', False)],
          'longs-': [('long', False)],
          'loni': [('loni', False)],
          'loni-': [('loni', False)],
          'lonien': [('loni', False)],
          'loniens': [('loni', False)],
          'lonier': [('lonier', False)],
          'lonierna': [('loni', False)],
          'loniernas': [('lonier', False)],
          'loniers': [('loni', False)],
          'lonin': [('loni', False)],
          'lonins': [('loni', False)],
          'lonis': [('loni', False)],
          'lonnens': [('lonn', False)],
          'lonns': [('lonn', False)],
          'lonns-': [('lonn', False)],
          'lons': [('lo', True)],
          'lons-': [('lon', False)],
          'loon': [('loon', False)],
          'loons': [('loon', False)],
          'loor': [('loo', False)],
          'loors': [('loo', False)],
          'loparnas': [('lop', False)],
          'lopp': [('loppa', True), ('lopp', True)],
          'lopp-': [('loppa', True), ('lopp', True)],
          'loppar': [('lopp', False)],
          'lopparna': [('lopp', False)],
          'loppars': [('lopp', False)],
          'loppe': [('loppa', False)],
          'loppe-': [('loppa', False)],
          'loppen': [('lopp', False)],
          'loppens': [('lopp', False)],
          'loppers': [('lopp', False)],
          'loppor': [('loppa', False)],
          'lopporna': [('loppa', False)],
          'loppornas': [('loppa', False)],
          'loppors': [('loppa', False)],
          'lopps': [('loppa', True), ('lopp', True)],
          'lopps-': [('loppa', True), ('lopp', True)],
          'lops': [('lops', False)],
          'lops-': [('lops', False)],
          'lopsen': [('lops', False)],
          'lopuls': [('lopuls', False)],
          'lopuls-': [('lopuls', False)],
          'lora': [('lora', False)],
          'loran': [('loran', True)],
          'lorans': [('loran', True)],
          'lorar-': [('lorare', False)],
          'loraren': [('lorare', False)],
          'lorarens': [('lorare', False)],
          'loras': [('lora', False)],
          'lord': [('lord', False)],
          'lord-': [('lord', False)],
          'lorden': [('lord', True)],
          'lordens': [('lord', False)],
          'lorder': [('lord', True)],
          'lorderna': [('lord', True)],
          'lordernas': [('lord', True)],
          'lorders': [('lord', True)],
          'lordrarna': [('lorder', False)],
          'lords': [('lord', False)],
          'lords-': [('lord', True)],
          'lore': [('lore', False)],
          'lore-': [('lore', False)],
          'lores': [('lore', False)],
          'lori': [('lori', False)],
          'lori-': [('lori', False)],
          'loriens': [('lori', False)],
          'lorier': [('lori', False)],
          'lorierna': [('lori', False)],
          'loriers': [('lori', False)],
          'lorin': [('lorin', False)],
          'lorins': [('lori', False)],
          'loris': [('lori', False)],
          'lormar': [('lorm', False)],
          'lormarnas': [('lorm', False)],
          'lorn': [('lor', False)],
          'lorns': [('lor', False)],
          'loror': [('lora', False)],
          'lororna': [('lora', False)],
          'lorornas': [('lora', False)],
          'lorors': [('lora', False)],
          'lort': [('lort', False)],
          'lort-': [('lort', True)],
          'lortar': [('lort', True)],
          'lorten': [('lort', False)],
          'lortens': [('lort', True)],
          'lorts': [('lort', False)],
          'lorts-': [('lort', False)],
          'los': [('lo', True)],
          'los-': [('lo', False)],
          'losa': [('losa', False)],
          'losan': [('losa', False)],
          'losans': [('losa', False)],
          'losar': [('los', False)],
          'losarna': [('lo', False)],
          'losarnas': [('los', False)],
          'losars': [('los', False)],
          'losas': [('losa', False)],
          'losen': [('lo', False)],
          'losens': [('lo', False)],
          'loser': [('loser', True)],
          'losers': [('loser', True)],
          'loss': [('loss', False)],
          'loss-': [('loss', False)],
          'lossar': [('lossare', False)],
          'lossar-': [('lossar', False)],
          'lossaren': [('lossare', False)],
          'lossarens': [('lossar', False)],
          'lossarna': [('lossare', False)],
          'lossarnas': [('loss', False)],
          'lossars': [('loss', False)],
          'losse': [('lossa', False)],
          'losse-': [('lossa', False)],
          'lossen': [('loss', False)],
          'lossens': [('loss', False)],
          'lost': [('losta', True)],
          'lost-': [('losta', True)],
          'lostan': [('losta', True)],
          'lostans': [('losta', True)],
          'loste': [('losta', True)],
          'losterbrodern': [('losterbroder', False)],
          'losterbroderns': [('losterbroder', False)],
          'losterbroders': [('losterbroder', False)],
          'losterbröder': [('losterbroder', False)],
          'losterbrödernas': [('losterbroder', False)],
          'lot': [('lot', False)],
          'lota': [('lota', False)],
          'lotarnas': [('lot', False)],
          'lotas': [('lota', False)],
          'lotidens': [('lotid', False)],
          'lotron': [('lotron', False)],
          'lotrons': [('lotron', False)],
          'lots': [('lots', True)],
          'lots-': [('lots', False)],
          'lotsen': [('lots', True)],
          'lotsens': [('lots', False)],
          'lott': [('lott', True), ('lotta', True)],
          'lott-': [('lotta', True), ('lott', True)],
          'lottar': [('lott', False)],
          'lottarnas': [('lottare', False)],
          'lottars': [('lott', False)],
          'lotte': [('lotta', True)],
          'lotte-': [('lotta', True)],
          'lotten': [('lott', False)],
          'lottens': [('lott', True)],
          'lotter': [('lott', True)],
          'lotter-': [('lotter', False)],
          'lotterier': [('lotteri', True)],
          'lotterierna': [('lotteri', True)],
          'lotteriernas': [('lotteri', True)],
          'lotterna': [('lott', True)],
          'lotternas': [('lott', False)],
          'lotters': [('lott', False)],
          'lottis': [('lottis', False)],
          'lottis-': [('lottis', False)],
          'lottrar': [('lotter', False)],
          'lottrarna': [('lotter', False)],
          'lottrarnas': [('lottrare', False)],
          'lotts': [('lotta', True), ('lott', True)],
          'lotts-': [('lotta', True), ('lott', True)],
          'lours': [('lour', False)],
          'lov': [('love', True), ('lov', True)],
          'lov-': [('lov', True), ('love', True)],
          'lovar': [('lov', True), ('love', True)],
          'lovarna': [('love', True), ('lov', True)],
          'lovarnas': [('lov', True), ('love', True)],
          'lovars': [('lov', True), ('love', True)],
          'love': [('love', False)],
          'loven': [('lov', True), ('love', True)],
          'lovens': [('love', True), ('lov', True)],
          'lover': [('lover', False)],
          'lovers': [('lover', False)],
          'lovs': [('lov', True), ('love', True)],
          'lovs-': [('lov', True), ('love', True)],
          'lox': [('loxe', False)],
          'lox-': [('lox', False)],
          'loxar': [('loxe', False)],
          'loxarna': [('lox', False)],
          'loxarnas': [('loxe', False)],
          'loxars': [('loxe', False)],
          'loxen': [('loxe', False)],
          'loxens': [('loxe', False)],
          'lp': [('lpe', False)],
          'lp-': [('lp', False)],
          'lpack': [('lpacka', False)],
          'lpack-': [('lpacka', False)],
          'lpacke': [('lpacka', False)],
          'lpacks': [('lpacka', False)],
          'lpacks-': [('lpacka', False)],
          'lpadar': [('lpadare', False)],
          'lpande': [('lpande', False)],
          'lpande-': [('lpande', False)],
          'lpar': [('lp', False)],
          'lpar-': [('lpar', False)],
          'lparen': [('lpare', False)],
          'lparens': [('lpare', False)],
          'lpares': [('lpare', False)],
          'lparna': [('lp', False)],
          'lparnas': [('lpe', False)],
          'lpars': [('lp', False)],
          'lpars-': [('lpar', False)],
          'lpation': [('lpation', False)],
          'lpations': [('lpation', False)],
          'lpe': [('lpa', False)],
          'lpe-': [('lpa', False)],
          'lpell': [('lpelle', False)],
          'lpell-': [('lpelle', False)],
          'lpellar': [('lpelle', False)],
          'lpellarna': [('lpelle', False)],
          'lpellars': [('lpelle', False)],
          'lpellen': [('lpell', False)],
          'lpellens': [('lpell', False)],
          'lpells': [('lpelle', False)],
          'lpells-': [('lpelle', False)],
          'lpen': [('lp', False)],
          'lpengar': [('lpeng', False)],
          'lpengarna': [('lpengar', False)],
          'lpengarnas': [('lpeng', False)],
          'lpengars': [('lpeng', False)],
          'lpenn': [('lpenna', False)],
          'lpenning': [('lpenningar', False)],
          'lpenning-': [('lpenningar', False)],
          'lpenningar': [('lpenningar', False)],
          'lpenningarna': [('lpenningar', False)],
          'lpenningarnas': [('lpenningar', False)],
          'lpenningars': [('lpenningar', False)],
          'lpennings': [('lpenningar', False)],
          'lpennings-': [('lpenningar', False)],
          'lpens': [('lp', False)],
          'lper': [('lp', False)],
          'lperna': [('lp', False)],
          'lpernas': [('lp', False)],
          'lpers': [('lp', False)],
          'lpet': [('lpet', False)],
          'lpet-': [('lpet', False)],
          'lpetarnas': [('lpetare', False)],
          'lpetens': [('lpet', False)],
          'lpeter': [('lpet', False)],
          'lpeters': [('lpet', False)],
          'lpets': [('lpet', False)],
          'lpets-': [('lpet', False)],
          'lpiller': [('lpiller', False)],
          'lpillerna': [('lpiller', False)],
          'lpillers': [('lpiller', False)],
          'lpin': [('lpi', False)],
          'lpins': [('lpi', False)],
          'lpipar': [('lpipare', False)],
          'lpiparna': [('lpipare', False)],
          'lpiparnas': [('lpipare', False)],
          'lpit': [('lpit', False)],
          'lpits': [('lpit', False)],
          'lpits-': [('lpit', False)],
          'lplandet': [('lpland', False)],
          'lplanet': [('lplan', False)],
          'lplanets': [('lplan', False)],
          'lplank': [('lplank', False)],
          'lplanks': [('lplank', False)],
          'lplanks-': [('lplank', False)],
          'lplants': [('lplanta', False)],
          'lplants-': [('lplanta', False)],
          'lpojk': [('lpojke', False)],
          'lpojk-': [('lpojke', False)],
          'lpojks': [('lpojke', False)],
          'lpojks-': [('lpojke', False)],
          'lpor': [('lpa', False)],
          'lporna': [('lpa', False)],
          'lpornas': [('lpa', False)],
          'lpors': [('lpa', False)],
          'lportarnas': [('lport', False)],
          'lpressar': [('lpress', False)],
          'lpressarna': [('lpress', False)],
          'lpressarnas': [('lpress', False)],
          'lproblemet': [('lproblem', False)],
          'lproblemets': [('lproblem', False)],
          'lprocessen': [('lprocess', False)],
          'lprocessens': [('lprocess', False)],
          'lprogrammet': [('lprogram', False)],
          'lprosor': [('lpros', False)],
          'lprosorna': [('lpros', False)],
          'lprosornas': [('lpros', False)],
          'lprosors': [('lpros', False)],
          'lps': [('lpe', False)],
          'lps-': [('lp', False)],
          'lpskor': [('lpsko', False)],
          'lpskors': [('lpsko', False)],
          'lptris': [('lptris', False)],
          'lpump': [('lpump', False)],
          'lpumps': [('lpump', False)],
          'lpumps-': [('lpump', False)],
          'lputs': [('lputa', False)],
          'lputs-': [('lputa', False)],
          'lputt': [('lputt', False)],
          'lputt-': [('lputt', False)],
          'lputtar': [('lputt', False)],
          'lputtarna': [('lputt', False)],
          'lputtarnas': [('lputt', False)],
          'lputtars': [('lputt', False)],
          'lputten': [('lputt', False)],
          'lputtens': [('lputt', False)],
          'lputts': [('lputt', False)],
          'lputts-': [('lputt', False)],
          'lpåsar': [('lpåse', False)],
          'lrabbin': [('lrabbi', False)],
          'lrabbins': [('lrabbi', False)],
          'lrabbis': [('lrabbi', False)],
          'lraden': [('lrad', False)],
          'lradens': [('lrad', False)],
          'lramar': [('lram', False)],
          'lramarna': [('lram', False)],
          'lrams': [('lram', False)],
          'lrams-': [('lram', False)],
          'lran': [('lra', False)],
          'lrande': [('lrande', False)],
          'lrande-': [('lrande', False)],
          'lranden': [('lrande', False)],
          'lrandens': [('lrande', False)],
          'lrandet': [('lrande', False)],
          'lrans': [('lra', False)],
          'lrarnas': [('ler', False)],
          'lras': [('lras', False)],
          'lras-': [('lras', False)],
          'lrav': [('lrav', False)],
          'lraven': [('lrav', False)],
          'lravens': [('lrav', False)],
          'lravs': [('lrav', False)],
          'lravs-': [('lrav', False)],
          'lre': [('lra', False)],
          'lre-': [('lra', False)],
          'lremmar': [('lrem', False)],
          'lremmarna': [('lrem', False)],
          'lremmarnas': [('lrem', False)],
          'lrems': [('lremsa', False)],
          'lrems-': [('lremsa', False)],
          'lren': [('ler', False)],
          'lrens': [('ler', False)],
          'lrep': [('lrep', False)],
          'lrep-': [('lrep', False)],
          'lrepet': [('lrep', False)],
          'lrepets': [('lrep', False)],
          'lreps': [('lrep', False)],
          'lreps-': [('lrep', False)],
          'lrese': [('lresa', False)],
          'lrese-': [('lresa', False)],
          'lret': [('ler', False)],
          'lrets': [('ler', False)],
          'lrev': [('lrev', False)],
          'lrev-': [('lrev', False)],
          'lrevens': [('lrev', False)],
          'lrevs': [('lrev', False)],
          'lrevs-': [('lrev', False)],
          'lriggar': [('lriggare', False)],
          'lriggarna': [('lriggare', False)],
          'lriggarnas': [('lriggare', False)],
          'lrighets': [('lrighet', False)],
          'lrik': [('lrik', False)],
          'lrikar': [('lrik', False)],
          'lrikarna': [('lrik', False)],
          'lrikars': [('lrik', False)],
          'lriken': [('lrik', False)],
          'lrikens': [('lrik', False)],
          'lriket': [('lrike', False)],
          'lrikets': [('lrike', False)],
          'lriks': [('lrik', False)],
          'lriks-': [('lrik', False)],
          'lrim': [('lrim', False)],
          'lrims': [('lrim', False)],
          'lrims-': [('lrim', False)],
          'lringar': [('lring', False)],
          'lringarna': [('lring', False)],
          'lringarnas': [('lring', False)],
          'lrips': [('lripa', False)],
          'lrips-': [('lripa', False)],
          'lris': [('lris', False)],
          'lris-': [('lris', False)],
          'lrisk': [('lrisk', False)],
          'lrisk-': [('lrisk', False)],
          'lrits': [('lritsa', False)],
          'lrits-': [('lritsa', False)],
          'lrockar': [('lrock', False)],
          'lrockarna': [('lrock', False)],
          'lrockarnas': [('lrock', False)],
          'lrollerna': [('lroll', False)],
          'lrollernas': [('lroll', False)],
          'lrolls': [('lroll', False)],
          'lrolls-': [('lroll', False)],
          'lromans': [('lroman', False)],
          'lropen': [('lrop', False)],
          'lropens': [('lrop', False)],
          'lrops': [('lrop', False)],
          'lror': [('lra', False)],
          'lrorna': [('lra', False)],
          'lrornas': [('lra', False)],
          'lrors': [('lra', False)],
          'lros': [('lros', False)],
          'lros-': [('lros', False)],
          'lrossarna': [('lross', False)],
          'lrot': [('lrot', False)],
          'lroten': [('lrot', False)],
          'lrotens': [('lrot', False)],
          'lrots': [('lrot', False)],
          'lrots-': [('lrot', False)],
          'lrum': [('lrum', False)],
          'lrum-': [('lrum', False)],
          'lrums': [('lrum', False)],
          'lrums-': [('lrum', False)],
          'lryggar': [('lrygg', False)],
          'lryssarnas': [('lryss', False)],
          'lränn': [('lränna', False)],
          'lränn-': [('lränna', False)],
          'lränns': [('lränna', False)],
          'lränns-': [('lränna', False)],
          'lrättens': [('lrätt', False)],
          'lrättigheterna': [('lrättighet', False)],
          'lrättigheternas': [('lrättighet', False)],
          'lrättighets-': [('lrättighet', False)],
          'lråden': [('lråd', False)],
          'lrådens': [('lråd', False)],
          'lrådet': [('lråd', False)],
          'lrån': [('lrån', False)],
          'lråns': [('lrån', False)],
          'lrökar': [('lrök', False)],
          'lrökarna': [('lrök', False)],
          'lrökarnas': [('lrök', False)],
          'lrökens': [('lrök', False)],
          'lröst': [('lröst', False)],
          'lröst-': [('lröst', False)],
          'lrötter': [('lrot', False)],
          'lrötterna': [('lrot', False)],
          'lrötternas': [('lrot', False)],
          'lrötters': [('lrot', False)],
          'ls': [('l', True)],
          'ls-': [('la', False)],
          'lsalen': [('lsal', False)],
          'lsalens': [('lsal', False)],
          'lsamen': [('lsam', False)],
          'lsamens': [('lsam', False)],
          'lsamer': [('lsam', False)],
          'lsamerna': [('lsam', False)],
          'lsamernas': [('lsam', False)],
          'lsamers': [('lsam', False)],
          'lsamhällena': [('lsamhälle', False)],
          'lsanden': [('lsande', False)],
          'lsandens': [('lsande', False)],
          'lsanmälningarnas': [('lsanmälning', False)],
          'lsans': [('lsa', False)],
          'lsar': [('ls', False)],
          'lsar-': [('lsar', False)],
          'lsaren': [('lsare', False)],
          'lsarens': [('lsar', False)],
          'lsarie-': [('lsarium', False)],
          'lsarier': [('lsarium', False)],
          'lsarierna': [('lsarium', False)],
          'lsariernas': [('lsarium', False)],
          'lsariers': [('lsarium', False)],
          'lsarna': [('ls', False)],
          'lsarnas': [('l', False)],
          'lsars': [('ls', False)],
          'lsats': [('lsats', False)],
          'lsats-': [('lsats', False)],
          'lsaxar': [('lsax', False)],
          'lsaxarna': [('lsax', False)],
          'lsaxarnas': [('lsax', False)],
          'lsbit': [('lsbit', False)],
          'lsdomar': [('lsdomare', False)],
          'lsdomarna': [('lsdomare', False)],
          'lsdomarnas': [('lsdomare', False)],
          'lse': [('lsa', False)],
          'lse-': [('lsa', False)],
          'lsed': [('lsed', False)],
          'lsedan': [('lsedag', False)],
          'lsedans': [('lsedag', False)],
          'lseers': [('lse', False)],
          'lseffekt': [('lseffekt', False)],
          'lseffekts': [('lseffekt', False)],
          'lseffekts-': [('lseffekt', False)],
          'lsegrar': [('lseger', False)],
          'lsegrarna': [('lseger', False)],
          'lsegrarnas': [('lseger', False)],
          'lsemestrar': [('lsemester', False)],
          'lsemestrarna': [('lsemester', False)],
          'lsemestrarnas': [('lsemester', False)],
          'lsen': [('ls', False)],
          'lsenas': [('lsena', False)],
          'lsens': [('ls', False)],
          'lser': [('ls', False)],
          'lserierna': [('lserie', False)],
          'lseriernas': [('lserie', False)],
          'lserna': [('ls', False)],
          'lsernas': [('ls', False)],
          'lsers': [('ls', False)],
          'lset': [('lse', False)],
          'lsets': [('lse', False)],
          'lsex': [('lsex', False)],
          'lsfaktorer': [('lsfaktor', False)],
          'lsfaktorers': [('lsfaktor', False)],
          'lsfar': [('lsfara', False)],
          'lsfar-': [('lsfara', False)],
          'lsflagg': [('lsflagga', False)],
          'lsflaggs': [('lsflagga', False)],
          'lsförsäkringars': [('lsförsäkring', False)],
          'lsidan': [('lsida', False)],
          'lsidans': [('lsida', False)],
          'lside': [('lsida', False)],
          'lside-': [('lsida', False)],
          'lsides': [('lsida', False)],
          'lsiken': [('lsike', False)],
          'lsikens': [('lsike', False)],
          'lsiks': [('lsike', False)],
          'lsiks-': [('lsike', False)],
          'lsims': [('lsim', False)],
          'lsims-': [('lsim', False)],
          'lsin-': [('lsin', False)],
          'lsinen': [('lsin', False)],
          'lsinens': [('lsin', False)],
          'lsiner': [('lsin', False)],
          'lsinerna': [('lsin', False)],
          'lsinernas': [('lsin', False)],
          'lsiners': [('lsin', False)],
          'lsing': [('lsingar', False)],
          'lsing-': [('lsingar', False)],
          'lsingar': [('lsingar', False)],
          'lsingarna': [('lsingar', False)],
          'lsingarnas': [('lsingar', False)],
          'lsingars': [('lsingar', False)],
          'lsings': [('lsingar', False)],
          'lsings-': [('lsingar', False)],
          'lsins': [('lsin', False)],
          'lsinters': [('lsinter', False)],
          'lsjukan': [('lsjuka', False)],
          'lsk': [('lska', False)],
          'lsk-': [('lska', False)],
          'lskal': [('lskal', False)],
          'lskals': [('lskal', False)],
          'lskals-': [('lskal', False)],
          'lskan': [('lska', False)],
          'lskans': [('lska', False)],
          'lskans-': [('lskan', False)],
          'lskaps-': [('lskap', False)],
          'lskar': [('lskare', False)],
          'lskar-': [('lskare', False)],
          'lskare': [('lskare', False)],
          'lskarens': [('lskare', False)],
          'lskarna': [('lskare', False)],
          'lskasse-': [('lskassa', False)],
          'lskatts-': [('lskatt', False)],
          'lsken': [('lskena', False)],
          'lsken-': [('lskena', False)],
          'lskens': [('lsken', False)],
          'lskens-': [('lskena', False)],
          'lskiften': [('lskifte', False)],
          'lskiftens': [('lskifte', False)],
          'lskiftet': [('lskifte', False)],
          'lskiftets': [('lskifte', False)],
          'lskjuts': [('lskjuts', False)],
          'lskjuts-': [('lskjuts', False)],
          'lsklings': [('lskling', False)],
          'lsklocks': [('lsklocka', False)],
          'lsklocks-': [('lsklocka', False)],
          'lsko': [('lsko', False)],
          'lskon': [('lsko', False)],
          'lskonst': [('lskonst', False)],
          'lskot': [('lskota', False)],
          'lskot-': [('lskota', False)],
          'lskots': [('lskota', False)],
          'lskots-': [('lskota', False)],
          'lskott': [('lskott', False)],
          'lskotten': [('lskott', False)],
          'lskottens': [('lskott', False)],
          'lskotts-': [('lskott', False)],
          'lskrak': [('lskrake', False)],
          'lskrak-': [('lskrake', False)],
          'lskrakar': [('lskrake', False)],
          'lskrakarna': [('lskrake', False)],
          'lskrakarnas': [('lskrake', False)],
          'lskraken': [('lskrake', False)],
          'lskraks': [('lskrake', False)],
          'lskrik': [('lskrik', False)],
          'lskrik-': [('lskrik', False)],
          'lskriks': [('lskrik', False)],
          'lskriks-': [('lskrik', False)],
          'lskräm': [('lskrämma', False)],
          'lskrås': [('lskrås', False)],
          'lskulder': [('lskuld', False)],
          'lskullarnas': [('lskulle', False)],
          'lskullen': [('lskulle', False)],
          'lskur-': [('lskura', False)],
          'lskurs': [('lskurs', False)],
          'lskurs-': [('lskurs', False)],
          'lskytten': [('lskytt', False)],
          'lskyttens': [('lskytt', False)],
          'lskärmar': [('lskärm', False)],
          'lskärmarnas': [('lskärm', False)],
          'lskärv': [('lskärva', False)],
          'lskärv-': [('lskärva', False)],
          'lskärve': [('lskärva', False)],
          'lskärvs': [('lskärva', False)],
          'lskärvs-': [('lskärva', False)],
          'lslag': [('lslag', False)],
          'lslager': [('lslager', False)],
          'lslagernas': [('lslager', False)],
          'lslagers': [('lslager', False)],
          'lslags': [('lslag', False)],
          'lslags-': [('lslag', False)],
          'lslams': [('lslam', False)],
          'lslams-': [('lslam', False)],
          'lslarv': [('lslarv', False)],
          'lslarv-': [('lslarv', False)],
          'lslarver': [('lslarv', False)],
          'lslarvers': [('lslarv', False)],
          'lslarvs': [('lslarv', False)],
          'lslarvs-': [('lslarv', False)],
          'lsliparnas': [('lslip', False)],
          'lslips': [('lslip', False)],
          'lslips-': [('lslip', False)],
          'lsnickar': [('lsnick', False)],
          'lsnickarna': [('lsnick', False)],
          'lsnickarnas': [('lsnick', False)],
          'lsnyckel': [('lsnyckel', False)],
          'lsnyckel-': [('lsnyckel', False)],
          'lsnyckels': [('lsnyckel', False)],
          'lsnyckels-': [('lsnyckel', False)],
          'lsnycklar': [('lsnyckel', False)],
          'lsnycklarna': [('lsnyckel', False)],
          'lsnycklarnas': [('lsnyckel', False)],
          'lsnycklars': [('lsnyckel', False)],
          'lsnäpp': [('lsnäppa', False)],
          'lsnäpp-': [('lsnäppa', False)],
          'lsnäpps': [('lsnäppa', False)],
          'lsnäpps-': [('lsnäppa', False)],
          'lso': [('lsa', False)],
          'lso-': [('lsa', False)],
          'lsområdet': [('lsområde', False)],
          'lson': [('lson', False)],
          'lsongs-': [('lsonger', False)],
          'lsons': [('lson', False)],
          'lsopp': [('lsoppa', False)],
          'lsopp-': [('lsoppa', False)],
          'lsopps': [('lsoppa', False)],
          'lsopps-': [('lsoppa', False)],
          'lsor': [('lsa', False)],
          'lsorna': [('lsa', False)],
          'lsornas': [('lsa', False)],
          'lsors': [('lsa', False)],
          'lspad': [('lspade', False)],
          'lspad-': [('lspade', False)],
          'lspads': [('lspade', False)],
          'lspads-': [('lspade', False)],
          'lspets': [('lspets', False)],
          'lspets-': [('lspets', False)],
          'lspinn': [('lspinne', False)],
          'lspinn-': [('lspinne', False)],
          'lspinnen': [('lspinne', False)],
          'lspinnens': [('lspinne', False)],
          'lspinns': [('lspinne', False)],
          'lspisar': [('lspis', False)],
          'lspisarna': [('lspis', False)],
          'lspisarnas': [('lspis', False)],
          'lsportar': [('lsport', False)],
          'lsportarna': [('lsport', False)],
          'lspottar': [('lspottare', False)],
          'lspottarna': [('lspottare', False)],
          'lspottarnas': [('lspottare', False)],
          'lspring': [('lspringa', False)],
          'lspring-': [('lspringa', False)],
          'lsprings': [('lspringa', False)],
          'lsprings-': [('lspringa', False)],
          'lsprit': [('lsprit', False)],
          'lsprits': [('lsprit', False)],
          'lsprits-': [('lsprit', False)],
          'lsprivilegie': [('lsprivilegium', False)],
          'lsprivilegie-': [('lsprivilegium', False)],
          'lsprivilegier': [('lsprivilegium', False)],
          'lsprivilegierna': [('lsprivilegium', False)],
          'lsprivilegiers': [('lsprivilegium', False)],
          'lspån': [('lspån', False)],
          'lspåns': [('lspån', False)],
          'lspåns-': [('lspån', False)],
          'lsrems': [('lsrem', False)],
          'lsrems-': [('lsrem', False)],
          'lsringar': [('lsring', False)],
          'lsros': [('lsro', False)],
          'lss': [('ls', False)],
          'lsset': [('lsset', False)],
          'lssets': [('lsset', False)],
          'lsskiftet': [('lsskift', False)],
          'lsskiftets': [('lsskift', False)],
          'lssteg': [('lssteg', False)],
          'lsstegens': [('lssteg', False)],
          'lsstegs-': [('lssteg', False)],
          'lssträck': [('lssträck', False)],
          'lssträcks': [('lssträck', False)],
          'lssträcks-': [('lssträck', False)],
          'lst': [('lst', False)],
          'lstackar': [('lstack', False)],
          'lstackarna': [('lstack', False)],
          'lstackarnas': [('lstack', False)],
          'lstadge': [('lstadga', False)],
          'lstadge-': [('lstadga', False)],
          'lstadie': [('lstadium', False)],
          'lstadie-': [('lstadium', False)],
          'lstadier': [('lstadium', False)],
          'lstadierna': [('lstadium', False)],
          'lstadiernas': [('lstadium', False)],
          'lstadiers': [('lstadium', False)],
          'lstadiet': [('lstadium', False)],
          'lstadiets': [('lstadium', False)],
          'lstadium': [('lstadium', False)],
          'lstadiums': [('lstadium', False)],
          'lstak': [('lstak', False)],
          'lstaken': [('lstak', False)],
          'lstakens': [('lstak', False)],
          'lstaks': [('lstak', False)],
          'lstaks-': [('lstak', False)],
          'lstalets': [('lstal', False)],
          'lstammar': [('lstam', False)],
          'lstammarna': [('lstam', False)],
          'lstammarnas': [('lstam', False)],
          'lstampen': [('lstamp', False)],
          'lstampens': [('lstamp', False)],
          'lstans': [('lstad', False)],
          'lstarter': [('lstart', False)],
          'lstarterna': [('lstart', False)],
          'lstarternas': [('lstart', False)],
          'lstarters': [('lstart', False)],
          'lstavarna': [('lstav', False)],
          'lsteg': [('lsteg', False)],
          'lsteg-': [('lsteg', False)],
          'lstegen': [('lsteg', False)],
          'lstegens': [('lsteg', False)],
          'lstegs': [('lsteg', False)],
          'lstegs-': [('lsteg', False)],
          'lsten': [('lsten', False)],
          'lstens': [('lsten', False)],
          'lster': [('lster', False)],
          'lsterna': [('lster', False)],
          'lsternas': [('lster', False)],
          'lsters': [('lster', False)],
          'lstick': [('lsticka', False)],
          'lstick-': [('lsticka', False)],
          'lsticks': [('lstick', False)],
          'lsticks-': [('lsticka', False)],
          'lstol': [('lstol', False)],
          'lstol-': [('lstol', False)],
          'lstols': [('lstol', False)],
          'lstols-': [('lstol', False)],
          'lston': [('lsto', False)],
          'lstons': [('lston', False)],
          'lstons-': [('lston', False)],
          'lstops': [('lstops', False)],
          'lstops-': [('lstops', False)],
          'lstormarna': [('lstorm', False)],
          'lstormarnas': [('lstorm', False)],
          'lstranden': [('lstrande', False)],
          'lstrandens': [('lstrande', False)],
          'lstrar': [('lstrare', False)],
          'lstrarna': [('lstrare', False)],
          'lstrarnas': [('lster', False)],
          'lstringens': [('lstring', False)],
          'lsträn': [('lsträ', False)],
          'lsträns': [('lsträ', False)],
          'lstråk': [('lstråke', False)],
          'lstråk-': [('lstråke', False)],
          'lstråken': [('lstråke', False)],
          'lstråkens': [('lstråke', False)],
          'lstråks': [('lstråke', False)],
          'lstråks-': [('lstråke', False)],
          'lstudie-': [('lstudium', False)],
          'lstudierna': [('lstudium', False)],
          'lstudiernas': [('lstudium', False)],
          'lstudiers': [('lstudium', False)],
          'lstycken': [('lstycke', False)],
          'lstyckena': [('lstycke', False)],
          'lstyckenas': [('lstycke', False)],
          'lstyckens': [('lstycke', False)],
          'lstycket': [('lstycke', False)],
          'lstyckets': [('lstycke', False)],
          'lstycks': [('lstycke', False)],
          'lstyren': [('lstyre', False)],
          'lstyrens': [('lstyre', False)],
          'lstyret': [('lstyre', False)],
          'lstyrkan': [('lstyrka', False)],
          'lstyrkans': [('lstyrkan', False)],
          'lstyrke': [('lstyrka', False)],
          'lställanden': [('lställande', False)],
          'lställandena': [('lställande', False)],
          'lställandens': [('lställande', False)],
          'lställen': [('lställ', False)],
          'lställens': [('lställ', False)],
          'lstället': [('lställ', False)],
          'lställets': [('lställ', False)],
          'lställningar': [('lställning', False)],
          'lställningarna': [('lställning', False)],
          'lställningarnas': [('lställning', False)],
          'lställningars': [('lställning', False)],
          'lställnings': [('lställning', False)],
          'lställnings-': [('lställning', False)],
          'lstötar': [('lstötare', False)],
          'lstötarna': [('lstötare', False)],
          'lstötarnas': [('lstöt', False)],
          'lsuddarnas': [('lsudd', False)],
          'lsupar': [('lsup', False)],
          'lsuparna': [('lsup', False)],
          'lsuparnas': [('lsup', False)],
          'lsval': [('lsval', False)],
          'lsvalen': [('lsval', False)],
          'lsvalens': [('lsval', False)],
          'lsvals': [('lsval', False)],
          'lsvals-': [('lsval', False)],
          'lsvanor': [('lsvana', False)],
          'lsvanorna': [('lsvana', False)],
          'lsvanornas': [('lsvana', False)],
          'lsvanors': [('lsvana', False)],
          'lsvans': [('lsvan', False)],
          'lsvans-': [('lsvan', False)],
          'lsvarvar': [('lsvarv', False)],
          'lsvarvarna': [('lsvarv', False)],
          'lsvarvarnas': [('lsvarv', False)],
          'lsverken': [('lsverk', False)],
          'lsverkens': [('lsverk', False)],
          'lsverket': [('lsverk', False)],
          'lsverks': [('lsverk', False)],
          'lsverks-': [('lsverk', False)],
          'lsving': [('lsvinge', False)],
          'lsving-': [('lsvinge', False)],
          'lsvingar': [('lsvinge', False)],
          'lsvingarna': [('lsvinge', False)],
          'lsvingarnas': [('lsvinge', False)],
          'lsvingars': [('lsvinge', False)],
          'lsvingen': [('lsvinge', False)],
          'lsvingens': [('lsvinge', False)],
          'lsvings': [('lsvinge', False)],
          'lsvings-': [('lsvinge', False)],
          'lsvärmar': [('lsvärm', False)],
          'lsvärmarna': [('lsvärm', False)],
          'lsvärmarnas': [('lsvärm', False)],
          'lsvävar': [('lsväv', False)],
          'lsvävarna': [('lsväv', False)],
          'lsvävarnas': [('lsväv', False)],
          'lsyn': [('lsyn', False)],
          'lsyns': [('lsyn', False)],
          'lsyre': [('lsyra', False)],
          'lsyre-': [('lsyra', False)],
          'lsäkringar': [('lsäkring', False)],
          'lsäkringars': [('lsäkring', False)],
          'lsänger': [('lsänger', False)],
          'lsängers': [('lsänger', False)],
          'lsänke': [('lsänka', False)],
          'lsänks': [('lsänka', False)],
          'lsänks-': [('lsänka', False)],
          'lsådran': [('lsåder', False)],
          'lsådre': [('lsåder', False)],
          'lsådrornas': [('lsåder', False)],
          'lsådrors': [('lsåder', False)],
          'lsång-': [('lsång', False)],
          'lsås': [('lsås', False)],
          'lsås-': [('lsås', False)],
          'lsögon': [('lsöga', False)],
          'lsören': [('lsör', False)],
          'lsörens': [('lsör', False)],
          'lt-': [('lt', False)],
          'ltagen': [('ltag', False)],
          'ltagens': [('ltag', False)],
          'ltaget': [('ltag', False)],
          'ltaken': [('ltak', False)],
          'ltaket': [('ltak', False)],
          'ltalanden': [('ltalande', False)],
          'ltalandenas': [('ltalande', False)],
          'ltalandens': [('ltalande', False)],
          'ltalar': [('ltalare', False)],
          'ltalar-': [('ltalare', False)],
          'ltalaren': [('ltalare', False)],
          'ltalarens': [('ltalare', False)],
          'ltalen': [('ltal', False)],
          'ltalens': [('ltal', False)],
          'ltalet': [('ltal', False)],
          'ltan-': [('ltan', False)],
          'ltana': [('lta', False)],
          'ltanas': [('lta', False)],
          'ltanden': [('ltande', False)],
          'ltandens': [('ltande', False)],
          'ltans-': [('ltan', False)],
          'ltant-': [('ltant', False)],
          'ltar': [('lt', False)],
          'ltaren': [('ltare', False)],
          'ltarna': [('lt', False)],
          'ltars': [('lt', False)],
          'ltat': [('ltat', False)],
          'ltats': [('ltat', False)],
          'ltax': [('ltaxa', False)],
          'ltax-': [('ltaxa', False)],
          'ltbits': [('ltbi', False)],
          'lte': [('lta', False)],
          'lte-': [('lta', False)],
          'lten': [('lt', False)],
          'ltens': [('lt', False)],
          'lteor': [('ltea', False)],
          'lteors': [('ltea', False)],
          'lter': [('lt', False)],
          'lter-': [('lter', False)],
          'lteranden': [('lterande', False)],
          'lterandens': [('lterande', False)],
          'lterier': [('lteri', False)],
          'lterierna': [('lteri', False)],
          'lteriernas': [('lteri', False)],
          'lteriets': [('lteri', False)],
          'lterits': [('lteri', False)],
          'lterna': [('lt', False)],
          'lternas': [('lt', False)],
          'lters': [('lt', False)],
          'ltes': [('ltes', False)],
          'ltes-': [('lte', False)],
          'ltesarnas': [('ltesare', False)],
          'ltestens': [('ltest', False)],
          'ltet': [('lt', False)],
          'lteters': [('ltet', False)],
          'ltets': [('lte', False)],
          'lthandlarnas': [('lthandlare', False)],
          'lthet': [('lthet', False)],
          'lthets': [('lthet', False)],
          'ltick': [('lticka', False)],
          'ltick-': [('lticka', False)],
          'lticks': [('lticka', False)],
          'lticks-': [('lticka', False)],
          'ltidarna': [('ltidare', False)],
          'ltidarnas': [('ltidare', False)],
          'ltiden': [('ltid', False)],
          'ltider': [('ltid', False)],
          'ltiderna': [('ltid', False)],
          'ltiders': [('ltid', False)],
          'ltige': [('ltige', False)],
          'ltigens': [('ltige', False)],
          'ltiger': [('ltige', False)],
          'ltigers': [('ltige', False)],
          'ltighets': [('ltighet', False)],
          'ltik': [('ltik', False)],
          'ltillgångar': [('ltillgångar', False)],
          'ltillgångarna': [('ltillgångar', False)],
          'ltillgångarnas': [('ltillgångar', False)],
          'ltillgångars': [('ltillgångar', False)],
          'ltillgångs': [('ltillgångar', False)],
          'ltillgångs-': [('ltillgångar', False)],
          'ltim': [('ltimme', False)],
          'ltim-': [('ltimme', False)],
          'ltiman': [('ltima', False)],
          'ltimmarna': [('ltimme', False)],
          'ltinne': [('ltinna', False)],
          'ltit': [('ltita', False)],
          'ltitan': [('ltita', False)],
          'ltitans': [('ltita', False)],
          'ltits': [('ltita', False)],
          'ltje': [('ltje', False)],
          'ltje-': [('ltje', False)],
          'ltjen': [('ltje', False)],
          'ltjens': [('ltje', False)],
          'ltkikar': [('ltkikare', False)],
          'ltkikarna': [('ltkikare', False)],
          'lto': [('ltoa', False)],
          'lto-': [('ltoa', False)],
          'ltoffer': [('ltoffer', False)],
          'ltoffers': [('ltoffer', False)],
          'ltomten': [('ltomte', False)],
          'ltomtens': [('ltomte', False)],
          'lton': [('lton', False)],
          'ltoner': [('lton', False)],
          'ltonerna': [('lton', False)],
          'ltonernas': [('lton', False)],
          'ltoners': [('lton', False)],
          'ltons': [('lton', False)],
          'ltor': [('lta', False)],
          'ltork': [('ltork', False)],
          'ltornas': [('lta', False)],
          'ltors': [('lta', False)],
          'ltos': [('ltoa', False)],
          'ltos-': [('ltoa', False)],
          'ltra': [('ltra', False)],
          'ltramp': [('ltramp', False)],
          'ltramps': [('ltramp', False)],
          'ltramps-': [('ltramp', False)],
          'ltran': [('ltra', False)],
          'ltrans': [('ltran', False)],
          'ltrans-': [('ltran', False)],
          'ltrapp': [('ltrappa', False)],
          'ltrapp-': [('ltrappa', False)],
          'ltrapps': [('ltrappa', False)],
          'ltrapps-': [('ltrappa', False)],
          'ltras': [('ltra', False)],
          'ltrasen': [('ltra', False)],
          'ltrasens': [('ltra', False)],
          'ltratt': [('ltratt', False)],
          'ltratts': [('ltratt', False)],
          'ltratts-': [('ltratt', False)],
          'ltrav': [('ltrav', False)],
          'ltrav-': [('ltrav', False)],
          'ltraven': [('ltrav', False)],
          'ltravens': [('ltrav', False)],
          'ltravs': [('ltrav', False)],
          'ltravs-': [('ltrav', False)],
          'ltren': [('lter', False)],
          'ltrets': [('lter', False)],
          'ltringens': [('ltring', False)],
          'ltriss': [('ltrissa', False)],
          'ltriss-': [('ltrissa', False)],
          'ltron': [('ltro', False)],
          'ltrons': [('ltro', False)],
          'ltror': [('ltra', False)],
          'ltros': [('ltros', False)],
          'ltros-': [('ltro', False)],
          'ltrots': [('ltrot', False)],
          'ltrots-': [('ltrot', False)],
          'ltrycken': [('ltryck', False)],
          'ltryckens': [('ltryck', False)],
          'ltrycket': [('ltryck', False)],
          'ltryckets': [('ltryck', False)],
          'ltrycks': [('ltryck', False)],
          'ltrycks-': [('ltryck', False)],
          'lträcken': [('lträck', False)],
          'lträd': [('lträd', False)],
          'lträd-': [('lträd', False)],
          'lträde': [('lträde', False)],
          'lträden': [('lträde', False)],
          'lträdens': [('lträde', False)],
          'lträdet': [('lträde', False)],
          'lträdets': [('lträd', False)],
          'lträds': [('lträd', False)],
          'lträds-': [('lträd', False)],
          'lträn': [('lträd', False)],
          'lträna': [('lträd', False)],
          'ltränas': [('lträ', False)],
          'lträns': [('lträd', False)],
          'lträt': [('lträ', False)],
          'lträts': [('lträ', False)],
          'lts': [('lt', False)],
          'lts-': [('lt', False)],
          'ltspad': [('ltspad', False)],
          'ltspads': [('ltspad', False)],
          'ltspat': [('ltspat', False)],
          'ltstudie': [('ltstudium', False)],
          'ltstudier': [('ltstudium', False)],
          'ltub': [('ltub', False)],
          'ltub-': [('ltub', False)],
          'ltubs': [('ltub', False)],
          'ltubs-': [('ltub', False)],
          'ltugg': [('ltugg', False)],
          'ltuggs': [('ltugg', False)],
          'ltuggs-': [('ltugg', False)],
          'ltullar': [('ltull', False)],
          'ltullarna': [('ltull', False)],
          'ltullarnas': [('ltull', False)],
          'ltum': [('ltum', False)],
          'ltum-': [('ltum', False)],
          'ltums': [('ltum', False)],
          'ltums-': [('ltum', False)],
          'ltur': [('ltur', False)],
          'ltur-': [('ltur', False)],
          'lturer': [('ltur', False)],
          'lturerna': [('ltur', False)],
          'lturernas': [('ltur', False)],
          'lturers': [('ltur', False)],
          'lturs': [('ltur', False)],
          'lturs-': [('ltur', False)],
          'ltypen': [('ltyp', False)],
          'ltyper': [('ltyp', False)],
          'ltypernas': [('ltyp', False)],
          'ltypers': [('ltyp', False)],
          'ltänders': [('ltand', False)],
          'ltängarna': [('ltäng', False)],
          'ltängarnas': [('ltäng', False)],
          'ltängens': [('ltäng', False)],
          'ltåg': [('ltåg', False)],
          'ltågs': [('ltåg', False)],
          'ltågs-': [('ltåg', False)],
          'ltår': [('ltå', False)],
          'ltårar': [('ltårar', False)],
          'ltårarna': [('ltårar', False)],
          'ltårarnas': [('ltårar', False)],
          'ltårars': [('ltårar', False)],
          'ltårs': [('ltårar', False)],
          'ltårs-': [('ltårar', False)],
          'lu': [('lu', False)],
          'luan': [('luan', False)],
          'luans': [('luan', False)],
          'lubb': [('lubb', False)],
          'lubb-': [('lubb', True)],
          'lubbarna': [('lubb', False)],
          'lubbarnas': [('lubb', False)],
          'lubbars': [('lubb', False)],
          'lubbe': [('lubba', False)],
          'lubbe-': [('lubba', False)],
          'lubbens': [('lubb', False)],
          'lubbor': [('lubba', False)],
          'lubborna': [('lubba', False)],
          'lubbornas': [('lubba', False)],
          'lubbors': [('lubba', False)],
          'lubbs': [('lubb', False)],
          'lubbs-': [('lubb', False)],
          'lubon': [('lubo', False)],
          'lubons': [('lubo', False)],
          'lubor': [('lubo', False)],
          'luborna': [('lubo', False)],
          'lubornas': [('lubo', False)],
          'lubors': [('lubo', False)],
          'luck': [('lucka', True)],
          'luck-': [('lucka', True)],
          'lucks': [('lucka', True)],
          'lucks-': [('lucka', True)],
          'ludd': [('ludd', False)],
          'ludd-': [('ludd', False)],
          'luddars': [('ludd', False)],
          'ludden': [('ludd', False)],
          'luddens': [('ludd', False)],
          'ludds': [('ludd', False)],
          'ludds-': [('ludd', False)],
          'luder': [('luder', True)],
          'luderna': [('luder', True)],
          'ludernas': [('luder', True)],
          'luders': [('luder', True)],
          'ludie': [('ludium', False)],
          'ludie-': [('ludium', False)],
          'ludierna': [('ludium', False)],
          'ludiers': [('ludium', False)],
          'luens': [('luen', False)],
          'luer': [('lu', False)],
          'luerna': [('lu', False)],
          'luernas': [('lu', False)],
          'luers': [('lu', False)],
          'lues': [('lues', True)],
          'lues-': [('lues', False)],
          'luet': [('lu', False)],
          'luettens': [('luett', False)],
          'luetters': [('luett', False)],
          'luff': [('luff', False)],
          'luff-': [('luff', True)],
          'luffar': [('luffare', True)],
          'luffarna': [('luffare', True)],
          'luffarnas': [('luffare', False)],
          'luffs': [('luff', False)],
          'luffs-': [('luff', False)],
          'lufs': [('lufs', False)],
          'lug': [('luga', False)],
          'lugg': [('lugg', False)],
          'lugg-': [('lugg', False)],
          'luggar': [('lugg', False)],
          'luggarna': [('lugg', False)],
          'luggarnas': [('lugg', False)],
          'luggars': [('lugg', False)],
          'luggen': [('lugg', False)],
          'luggens': [('lugg', False)],
          'luggs': [('lugg', True)],
          'luggs-': [('lugg', False)],
          'lugs': [('luga', False)],
          'luide': [('luidum', False)],
          'luiden': [('luid', False)],
          'luidens': [('luid', False)],
          'lukar': [('lukare', False)],
          'lukarna': [('lukare', False)],
          'lukt': [('lukt', False)],
          'lukt-': [('lukt', True)],
          'luktar': [('lukt', False)],
          'luktarna': [('lukt', False)],
          'lukter': [('lukt', True)],
          'lukterna': [('lukt', True)],
          'lukternas': [('lukt', True)],
          'lukters': [('lukt', True)],
          'lukts': [('lukt', False)],
          'lukts-': [('lukt', False)],
          'lull': [('lull', False)],
          'lull-': [('lull', False)],
          'lulls': [('lull', False)],
          'lulls-': [('lull', False)],
          'lulosan': [('lulosa', False)],
          'lulosans': [('lulosa', False)],
          'luman': [('luma', True)],
          'lumen': [('lumen', True)],
          'lumens': [('lumen', True)],
          'lumnen': [('lumen', True)],
          'lumnens': [('lumen', True)],
          'lumors': [('luma', True)],
          'lump': [('lump', False)],
          'lump-': [('lump', False)],
          'lumper': [('lump', False)],
          'lumpers': [('lump', False)],
          'lumps': [('lump', False)],
          'lumps-': [('lump', False)],
          'lums': [('lums', False)],
          'lums-': [('lums', False)],
          'lumsar': [('lums', False)],
          'lumsarna': [('lums', False)],
          'lumsars': [('lums', False)],
          'lumsen': [('lums', False)],
          'lumsens': [('lums', False)],
          'lumset': [('lums', False)],
          'lun': [('lun', False)],
          'lunchar': [('lunchare', True)],
          'luncharna': [('lunchare', True)],
          'lund': [('lund', False)],
          'lund-': [('lund', False)],
          'lundar': [('lund', False)],
          'lundarna': [('lund', False)],
          'lundars': [('lund', True)],
          'lunder': [('lund', True)],
          'lunderna': [('lund', True)],
          'lunders': [('lund', True)],
          'lundran': [('lundra', False)],
          'lundrans': [('lundra', False)],
          'lundrar': [('lunder', False)],
          'lundrarna': [('lunder', False)],
          'lundrarnas': [('lundrare', False)],
          'lundras': [('lundra', False)],
          'lundringar': [('lundring', False)],
          'lundringarna': [('lundring', False)],
          'lundringarnas': [('lundring', False)],
          'lundringars': [('lundring', False)],
          'lunds': [('lund', True)],
          'lunds-': [('lund', False)],
          'lung': [('lunga', False)],
          'lung-': [('lunga', False)],
          'lunge': [('lunga', True)],
          'lunge-': [('lunga', False)],
          'lungor': [('lunga', False)],
          'lungorna': [('lunga', False)],
          'lungs': [('lunga', False)],
          'lungs-': [('lunga', False)],
          'lunk': [('lunk', False)],
          'lunk-': [('lunk', True)],
          'lunkarnas': [('lunk', False)],
          'lunkars': [('lunk', False)],
          'lunken': [('lunk', False)],
          'lunkens': [('lunk', False)],
          'lunks': [('lunk', False)],
          'lunks-': [('lunk', True)],
          'lunn': [('lunne', True)],
          'lunn-': [('lunne', True)],
          'lunnar': [('lunne', True)],
          'lunnarna': [('lunne', True)],
          'lunnarnas': [('lunne', True)],
          'lunnars': [('lunne', True)],
          'lunnen': [('lunne', True)],
          'lunnens': [('lunne', True)],
          'lunns': [('lunne', True)],
          'lunns-': [('lunne', True)],
          'luns': [('luns', False)],
          'luns-': [('luns', True)],
          'lunt': [('lunta', True)],
          'lunt-': [('lunta', False)],
          'luntarna': [('lunt', False)],
          'luntars': [('lunt', False)],
          'lunte': [('lunta', True)],
          'lunte-': [('lunta', False)],
          'lunten': [('lunt', False)],
          'luntens': [('lunt', False)],
          'lunts': [('lunta', False)],
          'lunts-': [('lunta', True)],
          'luon': [('luon', False)],
          'luons': [('luon', False)],
          'luor': [('luor', False)],
          'luors': [('luor', False)],
          'luparnas': [('lup', False)],
          'lupp': [('lupp', True)],
          'lupp-': [('lupp', True)],
          'lupps': [('lupp', True)],
          'lupps-': [('lupp', True)],
          'lurie': [('lurium', False)],
          'lurie-': [('lurium', False)],
          'lurier': [('lurium', False)],
          'lurierna': [('lurium', False)],
          'luriernas': [('lurium', False)],
          'lurk': [('lurk', True)],
          'lurk-': [('lurk', True)],
          'lurks': [('lurk', True)],
          'lurks-': [('lurk', False)],
          'lurna': [('lurna', False)],
          'lurnas': [('lurna', False)],
          'lurr': [('lurr', False)],
          'lurr-': [('lurr', False)],
          'lurrs': [('lurr', False)],
          'lurrs-': [('lurr', False)],
          'lus': [('lus', True)],
          'lus-': [('lus', True)],
          'lusarnas': [('lus', False)],
          'lusern': [('lusern', True)],
          'luserns': [('lusern', True)],
          'lusins': [('lusi', False)],
          'lusk': [('lusk', False)],
          'lusk-': [('lusk', False)],
          'luskar': [('lusk', False)],
          'luskarna': [('lusk', False)],
          'luskarnas': [('lusk', False)],
          'luskars': [('lusk', False)],
          'luske': [('luska', False)],
          'luske-': [('luska', False)],
          'lusken': [('lusk', False)],
          'luskens': [('lusk', False)],
          'lusker': [('lusk', False)],
          'luskerna': [('lusk', False)],
          'luskernas': [('lusk', False)],
          'luskers': [('lusk', False)],
          'luskor': [('luska', False)],
          'luskorna': [('luska', False)],
          'luskornas': [('luska', False)],
          'luskors': [('luska', False)],
          'luss': [('luss', False)],
          'lussar': [('luss', False)],
          'lussars': [('luss', False)],
          'lussebull': [('lussebulle', True), ('lussebulla', True)],
          'lussebull-': [('lussebulla', True), ('lussebulle', True)],
          'lussebulle': [('lussebulle', True), ('lussebulla', True)],
          'lussebulle-': [('lussebulle', True), ('lussebulla', True)],
          'lussebulls': [('lussebulle', True), ('lussebulla', True)],
          'lussebulls-': [('lussebulle', True), ('lussebulla', True)],
          'lussen': [('luss', False)],
          'lussens': [('luss', False)],
          'lusser': [('luss', False)],
          'lusserna': [('luss', False)],
          'lussernas': [('luss', False)],
          'lussers': [('luss', False)],
          'lust': [('lust', True)],
          'lust-': [('lust', False)],
          'lustarna': [('lust', True)],
          'lut': [('luta', True), ('lut', True)],
          'lut-': [('luta', True), ('lut', True)],
          'lutan': [('luta', False)],
          'lutar': [('lut', True)],
          'lutarna': [('lut', True)],
          'lutarnas': [('lut', False)],
          'luten': [('lut', True)],
          'lutens': [('lut', True)],
          'lutets': [('lut', False)],
          'luts': [('luta', True), ('lut', True)],
          'luts-': [('luta', True), ('lut', True)],
          'lutt': [('lutt', False)],
          'lutt-': [('lutt', False)],
          'luttar': [('lutt', False)],
          'luttarna': [('luttare', False)],
          'luttarnas': [('luttare', False)],
          'luttars': [('lutt', False)],
          'lutten': [('lutt', False)],
          'lutter': [('lutt', False)],
          'lutters': [('lutt', False)],
          'lutts': [('lutt', False)],
          'lutts-': [('lutt', False)],
          'luv': [('luva', True), ('luv', True)],
          'luv-': [('luva', True), ('luv', True)],
          'luvs': [('luva', True), ('luv', True)],
          'luvs-': [('luva', True), ('luv', True)],
          'lv': [('lv', False)],
          'lv-': [('lv', False)],
          'lvadar': [('lvad', False)],
          'lvadarna': [('lvad', False)],
          'lvadarnas': [('lvad', False)],
          'lvakan': [('lvak', False)],
          'lval': [('lval', False)],
          'lval-': [('lval', False)],
          'lvalen': [('lval', False)],
          'lvalens': [('lval', False)],
          'lvals': [('lval', False)],
          'lvals-': [('lval', False)],
          'lvan': [('lvan', False)],
          'lvana': [('lvana', False)],
          'lvane': [('lvana', False)],
          'lvane-': [('lvana', False)],
          'lvanen': [('lvan', False)],
          'lvaner': [('lvan', False)],
          'lvanernas': [('lvan', False)],
          'lvaners': [('lvan', False)],
          'lvankarnas': [('lvankare', False)],
          'lvanors': [('lvana', False)],
          'lvans': [('lvan', False)],
          'lvar': [('lv', False)],
          'lvar-': [('lvara', False)],
          'lvaran': [('lvara', False)],
          'lvarans': [('lvara', False)],
          'lvarna': [('lv', False)],
          'lvarnas': [('lv', False)],
          'lvars': [('lvar', False)],
          'lvas': [('lva', False)],
          'lvdans': [('lvdans', False)],
          'lve': [('lva', False)],
          'lve-': [('lva', False)],
          'lveck': [('lvecka', False)],
          'lveck-': [('lvecka', False)],
          'lvecks': [('lvecka', False)],
          'lvecks-': [('lvecka', False)],
          'lvel': [('lvel', False)],
          'lvel-': [('lvel', False)],
          'lvels': [('lvel', False)],
          'lvels-': [('lvel', False)],
          'lven': [('lv', False)],
          'lvens': [('lven', False)],
          'lvens-': [('lven', False)],
          'lver': [('lv', False)],
          'lverande': [('lverande', False)],
          'lverande-': [('lverande', False)],
          'lverkets': [('lverk', False)],
          'lvern': [('lver', False)],
          'lverna': [('lv', False)],
          'lvernas': [('lv', False)],
          'lverns': [('lver', False)],
          'lvers': [('lv', False)],
          'lvers-': [('lver', False)],
          'lversen': [('lvers', False)],
          'lvertet': [('lverte', False)],
          'lvet': [('lv', False)],
          'lvi': [('lvia', False)],
          'lvi-': [('lvia', False)],
          'lvian': [('lvia', False)],
          'lvians': [('lvia', False)],
          'lvie': [('lvia', False)],
          'lvie-': [('lvia', False)],
          'lvill': [('lvill', False)],
          'lvill-': [('lvill', False)],
          'lvillens': [('lvill', False)],
          'lvills': [('lvilla', False)],
          'lvills-': [('lvill', False)],
          'lvin': [('lvin', False)],
          'lvin-': [('lvin', False)],
          'lvind-': [('lvinda', False)],
          'lvindarnas': [('lvind', False)],
          'lvinds': [('lvind', False)],
          'lvinds-': [('lvind', False)],
          'lving': [('lvinge', False)],
          'lving-': [('lvinge', False)],
          'lvingar': [('lvinge', False)],
          'lvingarna': [('lvinge', False)],
          'lvingarnas': [('lvinge', False)],
          'lvingars': [('lvinge', False)],
          'lvingen': [('lvinge', False)],
          'lvingens': [('lvinge', False)],
          'lvings': [('lvinge', False)],
          'lvings-': [('lvinge', False)],
          'lvins': [('lvin', False)],
          'lvins-': [('lvin', False)],
          'lvinsten': [('lvinst', False)],
          'lvinstens': [('lvinst', False)],
          'lvinters': [('lvinter', False)],
          'lvis': [('lvis', False)],
          'lvis-': [('lvis', False)],
          'lvisa': [('lvisa', False)],
          'lvisar': [('lvis', False)],
          'lvisarna': [('lvis', False)],
          'lvisarnas': [('lvis', False)],
          'lvisars': [('lvis', False)],
          'lvisas': [('lvisa', False)],
          'lvise': [('lvisa', False)],
          'lvisen': [('lvis', False)],
          'lvisens': [('lvis', False)],
          'lvisor': [('lvisa', False)],
          'lvispar': [('lvisp', False)],
          'lvisparna': [('lvisp', False)],
          'lvisparnas': [('lvisp', False)],
          'lvispars': [('lvisp', False)],
          'lvläggar': [('lvlägg', False)],
          'lvläggarna': [('lvlägg', False)],
          'lvläggarnas': [('lvlägg', False)],
          'lvo': [('lvo', False)],
          'lvo-': [('lvo', False)],
          'lvor': [('lva', False)],
          'lvorna': [('lva', False)],
          'lvornas': [('lva', False)],
          'lvors': [('lva', False)],
          'lvosten': [('lvost', False)],
          'lvostens': [('lvost', False)],
          'lvrar': [('lver', False)],
          'lvrarna': [('lver', False)],
          'lvret': [('lver', False)],
          'lvrets': [('lver', False)],
          'lvs': [('lv', False)],
          'lvs-': [('lv', False)],
          'lvstudie': [('lvstudium', False)],
          'lvstudier': [('lvstudium', False)],
          'lvstudierna': [('lvstudium', False)],
          'lvtiden': [('lvtiden', False)],
          'lvtidens': [('lvtid', False)],
          'lvvårdarnas': [('lvvårdare', False)],
          'lvägar': [('lväg', False)],
          'lvägarna': [('lväg', False)],
          'lvägarnas': [('lväg', False)],
          'lvägs': [('lväg', False)],
          'lvälden': [('lvälde', False)],
          'lväldens': [('lvälde', False)],
          'lvärden': [('lvärde', False)],
          'lvärdens': [('lvärde', False)],
          'lvärdet': [('lvärde', False)],
          'lväsendets': [('lväsen', False)],
          'lvävar': [('lväv', False)],
          'lvävarna': [('lväv', False)],
          'lvävarnas': [('lväv', False)],
          'lväxlar': [('lväxel', False)],
          'lväxlarna': [('lväxel', False)],
          'lväxlarnas': [('lväxel', False)],
          'lvågarna': [('lvåg', False)],
          'lvårdar': [('lvårdare', False)],
          'lvårdarna': [('lvårdare', False)],
          'lvårdarnas': [('lvårdare', False)],
          'lvös-': [('lvö', False)],
          'ly': [('ly', False)],
          'ly-': [('ly', False)],
          'lyans': [('lya', False)],
          'lyck': [('lycka', False)],
          'lycke': [('lycka', False)],
          'lycke-': [('lycka', False)],
          'lycks': [('lycka', False)],
          'lye': [('lya', False)],
          'lye-': [('lya', False)],
          'lyen': [('ly', False)],
          'lyens': [('ly', False)],
          'lyer': [('ly', False)],
          'lyerna': [('ly', False)],
          'lyernas': [('ly', False)],
          'lyers': [('ly', False)],
          'lyfs': [('lyf', False)],
          'lyft': [('lyft', False)],
          'lyft-': [('lyft', False)],
          'lyftar': [('lyft', False)],
          'lyftarna': [('lyft', False)],
          'lyftarnas': [('lyftare', False)],
          'lyfte': [('lyfta', False)],
          'lyften': [('lyft', False)],
          'lyftens': [('lyft', False)],
          'lyftet': [('lyft', True)],
          'lyfts': [('lyft', True)],
          'lyfts-': [('lyft', False)],
          'lygar': [('lygare', False)],
          'lygarna': [('lygare', False)],
          'lygarnas': [('lygare', False)],
          'lyk-': [('lyka', False)],
          'lykling': [('lyklinga', False)],
          'lyklings-': [('lyklinga', False)],
          'lyks': [('lyka', False)],
          'lyks-': [('lyka', False)],
          'lykt': [('lykta', True)],
          'lykt-': [('lykta', True)],
          'lykte': [('lykta', False)],
          'lykte-': [('lykta', False)],
          'lykten': [('lykt', False)],
          'lyktens': [('lykt', False)],
          'lykts': [('lykta', True)],
          'lykts-': [('lykta', True)],
          'lyn': [('ly', False)],
          'lyn-': [('lyna', False)],
          'lyna': [('ly', False)],
          'lynas': [('ly', False)],
          'lynns-': [('lynne', False)],
          'lyns': [('ly', False)],
          'lyns-': [('lyna', False)],
          'lyor': [('lya', True)],
          'lyorna': [('lya', False)],
          'lyornas': [('lya', False)],
          'lyps': [('lyps', False)],
          'lyps-': [('lyps', False)],
          'lyr': [('lyra', True)],
          'lyr-': [('lyra', True)],
          'lyrers': [('lyr', False)],
          'lyriker': [('lyriker', True)],
          'lyrikerna': [('lyriker', True)],
          'lyrikernas': [('lyriker', True)],
          'lyrikers': [('lyriker', True)],
          'lyrs': [('lyra', True)],
          'lyrs-': [('lyra', True)],
          'lys': [('lyse', True), ('ly', True)],
          'lys-': [('lyse', True)],
          'lysarna': [('ly', False)],
          'lysch': [('lyscha', False)],
          'lysch-': [('lyscha', False)],
          'lyse': [('lyse', True)],
          'lysen': [('lyse', True)],
          'lysens': [('lyse', True)],
          'lyset': [('lyse', True)],
          'lysets': [('lyse', True)],
          'lyt': [('ly', False)],
          'lyt-': [('lyt', False)],
          'lyte': [('lyte', False)],
          'lyten': [('lyte', False)],
          'lytens': [('lyte', True)],
          'lytet': [('lyte', True)],
          'lytets': [('lyte', True)],
          'lyts': [('ly', False)],
          'lyts-': [('lyt', False)],
          'lytt': [('lytt', False)],
          'lytt-': [('lytt', False)],
          'lyttar': [('lytt', False)],
          'lytten': [('lytt', False)],
          'lyttens': [('lytt', False)],
          'lytts': [('lytt', False)],
          'lytts-': [('lytt', False)],
          'lyx': [('lyx', True)],
          'lyx-': [('lyx', True)],
          'lzon': [('lzon', False)],
          'lzons': [('lzon', False)],
          'läbb': [('läbb', True)],
          'läbbs': [('läbb', True)],
          'läbbs-': [('läbb', True)],
          'läck': [('läcka', True)],
          'läck-': [('läcka', True)],
          'läckar': [('läck', False)],
          'läckarna': [('läck', False)],
          'läckarnas': [('läckare', False)],
          'läcke': [('läcka', False)],
          'läcken': [('läck', False)],
          'läckens': [('läck', False)],
          'läcket': [('läck', False)],
          'läcks': [('läcka', True)],
          'läcks-': [('läcka', True)],
          'läd': [('läde', False)],
          'läd-': [('läder', False)],
          'lädar': [('läde', False)],
          'lädarna': [('läd', False)],
          'lädarnas': [('läd', False)],
          'lädars': [('läd', False)],
          'läde': [('läde', False)],
          'läde-': [('läde', False)],
          'läden': [('läde', False)],
          'lädens': [('läde', False)],
          'läder': [('läder', False)],
          'läderna': [('läder', False)],
          'lädernas': [('läder', False)],
          'läders': [('läder', False)],
          'lädes-': [('läde', False)],
          'lädet': [('läde', False)],
          'läds': [('läde', False)],
          'läds-': [('läde', False)],
          'läfs': [('läfs', False)],
          'lägar': [('lägare', False)],
          'lägarnas': [('lägare', False)],
          'läge': [('läge', False)],
          'läge-': [('läge', False)],
          'lägel-': [('lägel', True)],
          'lägen': [('läge', False)],
          'lägg': [('lägg', False)],
          'lägg-': [('lägg', False)],
          'läggar': [('lägg', True)],
          'läggarna': [('lägg', False)],
          'läggarnas': [('lägg', False)],
          'läggs': [('lägg', False)],
          'läggs-': [('lägg', False)],
          'läkarna': [('läkare', False)],
          'läkt': [('läkt', False)],
          'läkt-': [('läkt', True)],
          'läktar': [('läktare', True)],
          'läktarna': [('läktare', True)],
          'läktarnas': [('läktare', False)],
          'läkten': [('läkt', False)],
          'läktens': [('läkt', False)],
          'läktets': [('läkte', False)],
          'läkts': [('läkt', False)],
          'läkts-': [('läkt', False)],
          'lälv': [('lälv', False)],
          'lälvs': [('lälv', False)],
          'lälvs-': [('lälv', False)],
          'läm': [('läm', False)],
          'lämmar': [('läm', True)],
          'lämmarna': [('läm', True)],
          'lämmarnas': [('läm', True)],
          'lämme': [('lämma', False)],
          'lämparnas': [('lämpare', True)],
          'län': [('län', True)],
          'läna': [('lä', False)],
          'länas': [('lä', False)],
          'länd': [('länd', True)],
          'länd-': [('länd', True)],
          'ländar': [('lände', False)],
          'ländarna': [('lände', False)],
          'ländarnas': [('ländare', False)],
          'lände': [('lända', False)],
          'lände-': [('lände', False)],
          'länden': [('länd', True)],
          'ländens': [('länd', True)],
          'länder': [('länd', True), ('land', True)],
          'länderna': [('länd', True), ('land', True)],
          'ländernas': [('land', True), ('länd', True)],
          'länders': [('länd', True), ('land', True)],
          'länds': [('länd', True)],
          'länds-': [('länd', True)],
          'läng': [('länga', True)],
          'läng-': [('länga', True)],
          'längar': [('läng', False)],
          'längarna': [('läng', False)],
          'längarnas': [('läng', False)],
          'länge': [('länga', False)],
          'längen': [('läng', False)],
          'längens': [('läng', False)],
          'länger': [('läng', False)],
          'längerna': [('läng', False)],
          'längernas': [('läng', False)],
          'längers': [('läng', False)],
          'länget': [('läng', False)],
          'längets': [('länge', False)],
          'längs': [('länga', True)],
          'längs-': [('länga', False)],
          'länk': [('länk', False)],
          'länk-': [('länk', False)],
          'länkar': [('länk', True)],
          'länkarna': [('länk', True)],
          'länkarnas': [('länk', True)],
          'länke': [('länke', False)],
          'länken': [('länk', False)],
          'länkens': [('länk', False)],
          'länker': [('länk', False)],
          'länkerna': [('länk', False)],
          'länkernas': [('länk', False)],
          'länkers': [('länk', False)],
          'länket': [('länk', False)],
          'länks': [('länk', False)],
          'länks-': [('länk', False)],
          'läns': [('länsa', True), ('läns', True), ('län', True)],
          'läns-': [('länsa', True), ('läns', True), ('län', True)],
          'länt': [('länt', False)],
          'länt-': [('länta', False)],
          'läntans': [('länta', False)],
          'länte': [('länta', False)],
          'länts': [('länta', False)],
          'länts-': [('länt', False)],
          'läpp': [('läpp', False)],
          'läpp-': [('läpp', True)],
          'läppar': [('läpp', False)],
          'läpparna': [('läpp', False)],
          'läppen': [('läpp', False)],
          'läppens': [('läpp', False)],
          'läppet': [('läpp', False)],
          'läpps': [('läpp', False)],
          'läpps-': [('läpp', False)],
          'lär': [('lära', False)],
          'lär-': [('lära', False)],
          'läran': [('lära', False)],
          'lärans': [('lära', False)],
          'lärarnas': [('lärare', False)],
          'lärd': [('lärd', False)],
          'lärd-': [('lärd', False)],
          'lärden': [('lärd', False)],
          'lärdens': [('lärd', False)],
          'lärds': [('lärd', False)],
          'lärds-': [('lärd', False)],
          'lärgen': [('lärg', False)],
          'lärgens': [('lärg', False)],
          'lärk': [('lärk', True), ('lärka', True)],
          'lärk-': [('lärk', True), ('lärka', True)],
          'lärkar': [('lärk', True)],
          'lärkarna': [('lärk', True)],
          'lärke': [('lärka', False)],
          'lärke-': [('lärka', False)],
          'lärken': [('lärk', True)],
          'lärkens': [('lärk', True)],
          'lärks': [('lärk', True), ('lärka', True)],
          'lärks-': [('lärk', True), ('lärka', True)],
          'lärp': [('lärp', False)],
          'lärp-': [('lärp', False)],
          'lärpar': [('lärp', False)],
          'lärparnas': [('lärp', False)],
          'lärpe': [('lärpa', False)],
          'lärpe-': [('lärpa', False)],
          'lärpen': [('lärp', False)],
          'lärpens': [('lärp', False)],
          'lärps': [('lärp', False)],
          'lärps-': [('lärp', False)],
          'lärs': [('lära', False)],
          'lärs-': [('lära', True)],
          'läs': [('lä', False)],
          'läs-': [('lä', False)],
          'läsanden': [('läsande', True)],
          'läsandens': [('läsande', True)],
          'läsar': [('läsare', False)],
          'läsarna': [('läsare', True)],
          'läsarnas': [('läsare', True)],
          'läsk': [('läsk', False)],
          'läsk-': [('läsk', False)],
          'läskände': [('läskände', True), ('läskända', True)],
          'läskände-': [('läskända', True), ('läskände', True)],
          'läst-': [('läst', False)],
          'lästarna': [('läst', False)],
          'lästen': [('läst', False)],
          'lästens': [('läst', True)],
          'läster': [('läst', False)],
          'lästers': [('läst', True)],
          'lät': [('läta', False)],
          'läte': [('läte', False)],
          'läten': [('läte', False)],
          'lätens': [('läte', False)],
          'läter': [('läter', False)],
          'läters': [('läter', False)],
          'lätet': [('läte', False)],
          'läts': [('läta', False)],
          'läts-': [('läta', False)],
          'lätt': [('lätt', False)],
          'lätt-': [('lätt', False)],
          'lättar': [('lätt', False)],
          'lättarnas': [('lätt', False)],
          'lättars': [('lätt', False)],
          'lätten': [('lätt', False)],
          'lätter': [('lätt', False)],
          'lätterna': [('lätt', False)],
          'lätternas': [('lätt', False)],
          'lätters': [('lätt', False)],
          'lättighets': [('lättighet', False)],
          'lättrarna': [('lättrare', False)],
          'lättrarnas': [('lättrare', False)],
          'lätts': [('lätt', False)],
          'lätts-': [('lätt', False)],
          'läx': [('läxa', False)],
          'läx-': [('läxa', False)],
          'lå': [('lå', False)],
          'lå-': [('lå', False)],
          'låar': [('lå', False)],
          'låarna': [('lå', False)],
          'låd': [('låda', False)],
          'låd-': [('låda', False)],
          'lådan': [('låda', False)],
          'låder': [('låd', False)],
          'låder-': [('låder', False)],
          'låders': [('låder', False)],
          'lådors': [('låda', False)],
          'lådra': [('låder', False)],
          'lådran': [('låder', False)],
          'lådrans': [('låder', False)],
          'lådras': [('låder', False)],
          'lådre': [('låder', False)],
          'lådre-': [('låder', False)],
          'lådror': [('låder', False)],
          'lådrorna': [('låder', False)],
          'lådrornas': [('låder', False)],
          'lådrors': [('låder', False)],
          'låds': [('låda', False)],
          'låds-': [('låda', False)],
          'lådåren': [('lådåre', False)],
          'lådårens': [('lådåre', False)],
          'låg': [('låga', False)],
          'låg-': [('låga', False)],
          'lågar': [('lågare', False)],
          'lågarna': [('lågare', False)],
          'lågarnas': [('lågare', False)],
          'lågs': [('låga', False)],
          'lågs-': [('låga', False)],
          'låhackor': [('låhacka', False)],
          'låhackorna': [('låhacka', False)],
          'låhackornas': [('låhacka', False)],
          'låhackors': [('låhacka', False)],
          'låhacks-': [('låhacka', False)],
          'lån': [('lån', False)],
          'lånarna': [('lånare', False)],
          'långarna': [('långare', False)],
          'lånorna': [('lånor', False)],
          'lånors': [('lånor', False)],
          'låns': [('lån', True)],
          'låns-': [('lån', True)],
          'låpar': [('låpare', False)],
          'låparna': [('låpare', False)],
          'lår': [('lår', False)],
          'lår-': [('lår', True)],
          'lårarna': [('lår', False)],
          'lårarnas': [('lår', False)],
          'lårs': [('lår', True)],
          'lårs-': [('lår', False)],
          'lås': [('lås', True)],
          'lås-': [('lås', False)],
          'låsar': [('lås', True)],
          'låsarna': [('lås', True)],
          'låsarnas': [('lås', False)],
          'låsten': [('låst', False)],
          'låt': [('låt', True)],
          'låtar': [('låt', True)],
          'låtarna': [('låt', True)],
          'låtarnas': [('låt', False)],
          'låts': [('låt', True)],
          'lått': [('lått', False)],
          'lått-': [('lått', False)],
          'låtts': [('lått', False)],
          'léerna': [('lé', False)],
          'léernas': [('lé', False)],
          'löar': [('lö', False)],
          'löarna': [('lö', False)],
          'lödarna': [('lödare', False)],
          'löde': [('löde', False)],
          'löden': [('löde', False)],
          'lödens': [('löde', False)],
          'löderna': [('löd', False)],
          'lödernas': [('löd', False)],
          'löders': [('löd', False)],
          'lödet': [('löd', True)],
          'lödets': [('löd', False)],
          'lögat': [('löga', False)],
          'lögats': [('löga', False)],
          'lögonen': [('löga', False)],
          'lögonens': [('löga', False)],
          'lögons': [('löga', False)],
          'löj': [('löja', False)],
          'löj-': [('löja', False)],
          'löjar': [('löjare', False)],
          'löjarna': [('löjare', False)],
          'löjarnas': [('löjare', False)],
          'löje': [('löja', True), ('löje', True)],
          'löje-': [('löje', True), ('löja', True)],
          'löjen': [('löje', True)],
          'löjens': [('löje', True)],
          'löjs': [('löja', False)],
          'löjs-': [('löja', False)],
          'lökarnas': [('lök', False)],
          'löken': [('lök', False)],
          'lökens': [('lök', False)],
          'lön': [('lön', True)],
          'lönarna': [('lönare', False)],
          'löne': [('lön', False)],
          'löne-': [('lön', False)],
          'lönernas': [('lön', False)],
          'löns': [('lön', False)],
          'löns-': [('lön', False)],
          'lönskans': [('lönskan', False)],
          'löp': [('löpa', True), ('löp', True)],
          'löp-': [('löp', True), ('löpa', True)],
          'löpe': [('löpe', True), ('löpa', True)],
          'löpe-': [('löpe', True), ('löpa', True)],
          'löpet': [('löp', True), ('löpe', True)],
          'löpets': [('löpe', True), ('löp', True)],
          'löps': [('löpa', True), ('löp', True)],
          'löps-': [('löp', True), ('löpa', True)],
          'lören': [('lör', False)],
          'lörens': [('lör', False)],
          'löret': [('lör', False)],
          'lörets': [('lör', False)],
          'lörn': [('lör', False)],
          'lörnar': [('lörn', False)],
          'lörnarna': [('lörn', False)],
          'lörnen': [('lörn', False)],
          'lörnens': [('lörn', False)],
          'lörns': [('lör', False)],
          'lörns-': [('lörn', False)],
          'lörten': [('lört', False)],
          'lörtens': [('lört', False)],
          'lörts': [('lört', False)],
          'lös': [('lös', False)],
          'lös-': [('lösa', False)],
          'lösar': [('lösare', False)],
          'lösarna': [('lös', False)],
          'lösarnas': [('lös', False)],
          'lösen': [('lösen', False)],
          'lösens': [('lösen', True)],
          'löset': [('lös', False)],
          'lösets': [('lös', False)],
          'lösk-': [('löska', False)],
          'löske': [('löska', False)],
          'löskorna': [('löska', False)],
          'löskornas': [('löska', False)],
          'löskors': [('löska', False)],
          'löss': [('löss', True), ('lus', True)],
          'löss-': [('löss', True)],
          'lössen': [('löss', True), ('lus', True)],
          'lössens': [('löss', True), ('lus', True)],
          'löt': [('löt', True)],
          'löt-': [('löt', True)],
          'lötarnas': [('löt', True)],
          'löte': [('löte', False)],
          'löten': [('löt', True)],
          'lötens': [('löt', True)],
          'lötes': [('löte', False)],
          'lötet': [('löte', False)],
          'löts': [('löt', True)],
          'löts-': [('löt', True)],
          'lövarna': [('löv', False)],
          'm': [('m', True)],
          'm-': [('m', True)],
          'ma': [('ma', False)],
          'ma-': [('ma', False)],
          'machen': [('mach', True)],
          'machens': [('mach', True)],
          'macins': [('maci', False)],
          'mack': [('mack', True), ('macka', True)],
          'mack-': [('mack', True), ('macka', True)],
          'mackar': [('mack', False)],
          'mackarna': [('mack', True)],
          'mackars': [('mack', False)],
          'macke': [('macka', False)],
          'macke-': [('macka', True)],
          'mackel': [('mackel', True)],
          'mackel-': [('mackel', True)],
          'macken': [('mack', False)],
          'mackens': [('mack', False)],
          'macket': [('mack', False)],
          'mackets': [('mack', False)],
          'macklandets': [('macklande', True)],
          'mackor': [('macka', False)],
          'mackorna': [('macka', False)],
          'mackornas': [('macka', True)],
          'mackors': [('macka', True)],
          'macks': [('macka', True), ('mack', True)],
          'macks-': [('macka', True), ('mack', True)],
          'mad': [('mad', True)],
          'mad-': [('mad', True)],
          'madamens': [('madame', True)],
          'madan': [('madan', False)],
          'madans': [('madan', False)],
          'made': [('made', False)],
          'made-': [('made', False)],
          'mades': [('made', False)],
          'mads': [('mad', True)],
          'mads-': [('mad', True)],
          'maer': [('ma', False)],
          'maerna': [('ma', False)],
          'maernas': [('ma', False)],
          'maffians': [('maffia', False)],
          'mag': [('mage', True)],
          'mag-': [('mage', True)],
          'magar': [('mage', False)],
          'magarna': [('mage', False)],
          'magarnas': [('mage', False)],
          'magars': [('mage', False)],
          'mage': [('mage', False)],
          'mage-': [('mage', False)],
          'magen': [('mage', False)],
          'magens': [('mage', False)],
          'mager': [('mager', True)],
          'magerna': [('mager', True)],
          'magernas': [('mager', True)],
          'magers': [('mager', True)],
          'maget': [('mage', False)],
          'magis': [('magi', False)],
          'magms-': [('magma', True)],
          'magnet': [('magnet', False)],
          'magnets': [('magnet', False)],
          'mags': [('mage', True)],
          'mags-': [('mage', True)],
          'majans': [('maja', False)],
          'majas': [('maja', False)],
          'major': [('major', True)],
          'majors': [('major', False)],
          'majs': [('majs', True), ('maj', True)],
          'majs-': [('maj', True), ('majs', True)],
          'mak': [('maka', True)],
          'mak-': [('maka', True)],
          'maka': [('maka', False)],
          'makan': [('maka', False)],
          'makana': [('maka', False)],
          'makanas': [('maka', False)],
          'makans': [('maka', False)],
          'makar': [('make', True)],
          'makarna': [('make', True)],
          'makarnas': [('make', True)],
          'makars': [('make', True)],
          'makas': [('maka', False)],
          'make': [('make', True), ('maka', True)],
          'make-': [('make', True), ('maka', True)],
          'maken': [('make', True)],
          'makens': [('make', True)],
          'maker': [('maker', False)],
          'makerna': [('maker', False)],
          'makernas': [('maker', False)],
          'makers': [('maker', False)],
          'makes': [('make', True)],
          'makets': [('mak', False)],
          'makon': [('mako', True)],
          'makors': [('maka', True)],
          'makos': [('mako', True)],
          'maks': [('maka', True)],
          'maks-': [('maka', True)],
          'makter': [('makt', False)],
          'makteriet': [('makterium', False)],
          'makters': [('makt', False)],
          'malan': [('malan', False)],
          'malandets': [('malande', False)],
          'malar': [('mal', False)],
          'malbens': [('malben', False)],
          'malet': [('mal', False)],
          'malets': [('mal', False)],
          'malie-': [('malier', False)],
          'malien': [('mali', False)],
          'malier': [('malier', True)],
          'malierna': [('malier', False)],
          'maliernas': [('malier', True)],
          'maliers': [('malier', True)],
          'malin': [('malin', False)],
          'malins': [('mali', False)],
          'malis': [('malis', True)],
          'malj': [('malja', True)],
          'malj-': [('malja', True)],
          'malje': [('malja', True)],
          'malje-': [('malja', True)],
          'maljen': [('malj', False)],
          'maljens': [('malj', False)],
          'maljer': [('malj', False)],
          'maljerna': [('malj', False)],
          'maljernas': [('malj', False)],
          'maljers': [('malj', False)],
          'maljs': [('malja', True)],
          'maljs-': [('malja', True)],
          'mall': [('mall', False)],
          'mall-': [('mall', True)],
          'mallar': [('mall', True)],
          'mallars': [('mall', True)],
          'mallen': [('mall', True)],
          'malls': [('mall', True)],
          'malls-': [('mall', True)],
          'mals': [('mal', True)],
          'mals-': [('mal', False)],
          'malt-': [('malt', False)],
          'malts': [('malt', True)],
          'malts-': [('malt', True)],
          'malv': [('malva', True)],
          'malv-': [('malva', True)],
          'malvor': [('malva', True)],
          'malvorna': [('malva', True)],
          'malvornas': [('malva', True)],
          'malvors': [('malva', True)],
          'malvs': [('malva', True)],
          'malvs-': [('malva', True)],
          'mam': [('mam', False)],
          'mam-': [('mam', False)],
          'mamans-': [('maman', False)],
          'mambor': [('mamba', True), ('mambo', True)],
          'mamborna': [('mamba', True), ('mambo', True)],
          'mambornas': [('mamba', True), ('mambo', True)],
          'mambors': [('mambo', True), ('mamba', True)],
          'mamentet': [('mament', False)],
          'maments-': [('mament', False)],
          'mamers': [('mam', False)],
          'mammans': [('mamma', False)],
          'mams': [('mam', False)],
          'man': [('man', True)],
          'man-': [('man', True)],
          'mana': [('mana', True)],
          'manan': [('mana', True)],
          'manans': [('mana', True)],
          'manar': [('man', True)],
          'manarna': [('man', True)],
          'manarnas': [('man', True)],
          'manas': [('mana', True)],
          'mand': [('mand', False)],
          'mand-': [('mand', False)],
          'mandat': [('mandat', False)],
          'mandats': [('mandat', False)],
          'mandens': [('mande', False)],
          'mander': [('mand', False)],
          'manders': [('mand', False)],
          'mandets': [('mande', False)],
          'mandlar': [('mandel', False)],
          'mandlarna': [('mandel', False)],
          'mandlarnas': [('mandel', False)],
          'mandrar': [('mander', False)],
          'mandrarna': [('mander', False)],
          'mandrarnas': [('mander', False)],
          'mandrars': [('mander', False)],
          'mands': [('mand', False)],
          'mands-': [('mand', False)],
          'manens': [('man', False)],
          'maner': [('maner', True)],
          'manerna': [('maner', True)],
          'manernas': [('maner', False)],
          'maners': [('maner', True)],
          'manet': [('manet', False)],
          'manets': [('manet', True)],
          'mang': [('mang', False)],
          'mang-': [('mang', False)],
          'mangen': [('mang', False)],
          'mangens': [('mang', False)],
          'manger': [('mang', False)],
          'mangerna': [('mang', False)],
          'mangernas': [('mang', False)],
          'mangers': [('mang', False)],
          'mangs': [('mang', False)],
          'mangs-': [('mang', False)],
          'manhållanden': [('manhållande', False)],
          'manhållandena': [('manhållande', False)],
          'manhållandenas': [('manhållande', False)],
          'manhållandens': [('manhållande', False)],
          'mani': [('mani', False)],
          'mani-': [('mani', False)],
          'manien': [('mani', False)],
          'maniens': [('mani', False)],
          'manier': [('mani', False)],
          'manierna': [('mani', True)],
          'maniernas': [('mani', True)],
          'maniers': [('mani', False)],
          'maniets': [('manium', False)],
          'maniker': [('maniker', True)],
          'manikerna': [('maniker', True)],
          'manikernas': [('maniker', True)],
          'manikers': [('maniker', True)],
          'manin': [('mani', False)],
          'manins': [('mani', False)],
          'manis': [('mani', False)],
          'manister': [('manist', False)],
          'manisters': [('manist', False)],
          'mank': [('manke', True)],
          'mank-': [('manke', True)],
          'mankar': [('manke', True)],
          'mankarna': [('manke', True)],
          'mankarnas': [('manke', True)],
          'mankars': [('manke', True)],
          'manke': [('manke', True)],
          'manks': [('manke', True)],
          'manks-': [('manke', True)],
          'mann-': [('mann', False)],
          'mannar': [('man', True)],
          'mannarna': [('man', False)],
          'mannarnas': [('man', True)],
          'mannen': [('man', True)],
          'mannens': [('man', True)],
          'manner': [('mann', False)],
          'mannerna': [('mann', False)],
          'mannernas': [('mann', False)],
          'manners': [('mann', False)],
          'manns': [('mann', False)],
          'manns-': [('mann', False)],
          'mans': [('man', True)],
          'mans-': [('man', False)],
          'mansen': [('mans', False)],
          'mansens': [('mans', False)],
          'manser': [('mans', False)],
          'manserna': [('mans', False)],
          'mansernas': [('mans', False)],
          'mansers': [('mans', False)],
          'mansk': [('manska', False)],
          'mansk-': [('manska', False)],
          'mant': [('mant', False)],
          'manten': [('mant', False)],
          'mantens': [('mant', False)],
          'manter': [('mant', False)],
          'manterna': [('mant', False)],
          'manternas': [('mant', False)],
          'manters': [('mant', False)],
          'mantin': [('manti', False)],
          'mantins': [('manti', False)],
          'mantis': [('manti', False)],
          'manträden': [('manträde', False)],
          'manträdens': [('manträde', False)],
          'manträdet': [('manträde', False)],
          'maorier': [('maori', True), ('maorier', True)],
          'maorierna': [('maorier', True), ('maori', True)],
          'maoriernas': [('maori', True), ('maorier', True)],
          'maoriers': [('maori', True), ('maorier', True)],
          'mapas': [('mapa', False)],
          'mappars': [('mapp', True)],
          'mappen': [('mapp', True)],
          'mappens': [('mapp', True)],
          'mapps': [('mapp', True)],
          'mar': [('mara', True)],
          'mar-': [('mara', True)],
          'maran': [('mara', False)],
          'marans': [('mara', False)],
          'mardagen': [('mardag', False)],
          'mardagens': [('mardag', False)],
          'mardans': [('mardag', False)],
          'mardarna': [('mardag', False)],
          'mardarnas': [('mardag', False)],
          'mardars': [('mardag', False)],
          'mare': [('mara', True)],
          'maredans': [('maredans', False)],
          'marens': [('mare', False)],
          'mares': [('mare', False)],
          'marfars': [('marfars', False)],
          'margen': [('marg', True)],
          'margens': [('marg', True)],
          'marger': [('marg', True)],
          'margerna': [('marg', True)],
          'margernas': [('marg', True)],
          'margers': [('marg', True)],
          'marginaler': [('marginaler', True), ('marginal', True)],
          'marginalerna': [('marginaler', True), ('marginal', True)],
          'marginalernas': [('marginal', True), ('marginaler', True)],
          'marginalers': [('marginaler', True), ('marginal', True)],
          'marie': [('marie', False)],
          'marie-': [('marie', False)],
          'marier': [('marie', False)],
          'marierna': [('marie', False)],
          'mariernas': [('marie', False)],
          'mariers': [('marie', False)],
          'marill-': [('marilla', False)],
          'marin': [('marin', False)],
          'marisarnas': [('maris', False)],
          'marisen': [('maris', False)],
          'marisk': [('marisk', False)],
          'marisk-': [('marisk', False)],
          'marit-': [('marit', False)],
          'mariternas': [('marit', False)],
          'mariters': [('marit', False)],
          'markatt': [('markatta', True)],
          'markatt-': [('markatta', True)],
          'markatts': [('markatta', True)],
          'markatts-': [('markatta', True)],
          'market': [('market', False)],
          'markets': [('market', False)],
          'markis': [('markis', True)],
          'marleks': [('marleka', True)],
          'mars': [('mara', True), ('mars', True)],
          'mars-': [('mars', True), ('mara', True)],
          'marsken': [('marsk', True)],
          'marsklandets': [('marskland', True)],
          'mart': [('marter', True)],
          'mart-': [('marter', True)],
          'marter': [('marter', True)],
          'marterna': [('marter', True)],
          'marternas': [('marter', True)],
          'marters': [('marter', True)],
          'marts': [('marter', True)],
          'marts-': [('marter', True)],
          'marv': [('marv', False)],
          'marven': [('marv', False)],
          'marvens': [('marv', False)],
          'marvs': [('marv', False)],
          'marvs-': [('marv', False)],
          'mas': [('mas', True)],
          'mas-': [('mas', True)],
          'masar': [('mas', False)],
          'masarna': [('mas', False)],
          'masarnas': [('mas', False)],
          'masegrarnas': [('maseger', False)],
          'masen': [('mas', True)],
          'masens': [('mas', True)],
          'maser': [('maser', True)],
          'masers': [('maser', True)],
          'mask': [('maska', True), ('mask', True)],
          'mask-': [('maska', True), ('mask', True)],
          'maskarna': [('mask', False)],
          'maske': [('maska', False)],
          'maske-': [('maska', True)],
          'masker': [('mask', False)],
          'maskers': [('mask', False)],
          'masket': [('mask', False)],
          'maskets': [('mask', False)],
          'maskorna': [('maska', False)],
          'maskornas': [('maska', True)],
          'maskors': [('maska', True)],
          'maskot': [('maskot', True)],
          'maskots': [('maskot', True)],
          'maskrins': [('maskri', False)],
          'mass': [('massa', True)],
          'mass-': [('massa', True)],
          'masse': [('massa', False)],
          'masse-': [('massa', False)],
          'massiv': [('massiv', False)],
          'massiv-': [('massiv', False)],
          'massiven': [('massiv', False)],
          'massivens': [('massiv', True)],
          'massivet': [('massiv', True)],
          'massivs': [('massiv', False)],
          'massor': [('massa', False)],
          'massorna': [('massa', False)],
          'massornas': [('massa', False)],
          'massors': [('massa', False)],
          'mast-': [('mast', False)],
          'mastarnas': [('mastare', False)],
          'masten': [('mast', False)],
          'master': [('master', True), ('mast', True)],
          'masterna': [('mast', False)],
          'masternas': [('mast', False)],
          'masters': [('master', True), ('mast', True)],
          'mat': [('mat', True)],
          'mata': [('matum', False)],
          'matana': [('matum', False)],
          'matanas': [('ma', False)],
          'matar': [('matare', False)],
          'matar-': [('matare', False)],
          'matarens': [('matare', True)],
          'matarie': [('matarium', False)],
          'matarie-': [('matarium', False)],
          'matarier': [('matarium', False)],
          'matarierna': [('matarium', False)],
          'matariernas': [('matarium', False)],
          'matarna': [('matare', True)],
          'matarnas': [('matare', False)],
          'matas': [('matum', False)],
          'mate': [('mate', True)],
          'mate-': [('mate', True)],
          'mateket': [('matek', False)],
          'matekets': [('matek', False)],
          'maten': [('mat', True)],
          'matens': [('mat', True)],
          'materialet': [('material', False)],
          'materialets': [('material', False)],
          'materien': [('materie', True)],
          'materiens': [('materie', True)],
          'materier': [('materie', True), ('materia', True)],
          'materierna': [('materie', True), ('materia', True)],
          'materiernas': [('materie', True), ('materia', True)],
          'materiers': [('materie', True), ('materia', True)],
          'mates': [('mate', True)],
          'mates-': [('mate', True)],
          'matet': [('mate', True)],
          'matets': [('mate', True)],
          'matie': [('mation', False)],
          'matie-': [('mation', False)],
          'matien': [('mati', False)],
          'matiens': [('mati', False)],
          'matier': [('mation', False)],
          'matierna': [('mati', False)],
          'matiernas': [('mati', False)],
          'matiers': [('mation', False)],
          'matiet': [('mation', False)],
          'matiker': [('matiker', False)],
          'matikerna': [('matiker', False)],
          'matikernas': [('matiker', False)],
          'matikers': [('matiker', False)],
          'matiner': [('matiner', False)],
          'matinerna': [('matiner', False)],
          'matinernas': [('matiner', False)],
          'matiners': [('matiner', False)],
          'matins': [('mati', False)],
          'mation': [('mation', False)],
          'mationen': [('mation', False)],
          'mations': [('mation', False)],
          'matmors': [('matmor', True)],
          'mator': [('mator', False)],
          'mators': [('mator', False)],
          'matos': [('matos', True)],
          'matrin': [('matri', False)],
          'matris': [('matris', True)],
          'matron': [('matrona', True), ('matro', True)],
          'matron-': [('matrona', True)],
          'matrons': [('matro', True), ('matrona', True)],
          'matros': [('matros', True), ('matro', True)],
          'matros-': [('matros', False)],
          'mats': [('mat', True)],
          'mats-': [('mat', False)],
          'matt': [('matte', True), ('matta', True)],
          'matt-': [('matte', True), ('matta', True)],
          'mattan': [('matta', False)],
          'mattans': [('matta', False)],
          'mattar': [('matte', True)],
          'mattarna': [('matte', True)],
          'mattarnas': [('matte', True)],
          'mattars': [('matte', True)],
          'matte': [('matte', True), ('matta', True)],
          'matte-': [('matta', True), ('matte', True)],
          'matten': [('matte', True)],
          'mattens': [('matte', False)],
          'matter': [('matt', False)],
          'matteranden': [('matterande', True)],
          'matterandens': [('matterande', True)],
          'matters': [('matt', False)],
          'mattets': [('matte', True)],
          'matts': [('matta', True), ('matte', True)],
          'matts-': [('matte', True), ('matta', True)],
          'mazons': [('mazon', False)],
          'mbal': [('mbal', False)],
          'mbal-': [('mbal', False)],
          'mbalen': [('mbal', False)],
          'mbalens': [('mbal', False)],
          'mbals': [('mbal', False)],
          'mbals-': [('mbal', False)],
          'mban': [('mba', False)],
          'mbanan': [('mbana', False)],
          'mbanans': [('mbana', False)],
          'mbanden': [('mbande', False)],
          'mbandens': [('mbande', False)],
          'mbandet': [('mbande', False)],
          'mbandets': [('mband', False)],
          'mbane': [('mbana', False)],
          'mbane-': [('mbana', False)],
          'mbans': [('mba', False)],
          'mbar-': [('mbare', False)],
          'mbaren': [('mbare', False)],
          'mbarens': [('mbar', False)],
          'mbaret': [('mbar', False)],
          'mbarets': [('mbar', False)],
          'mbariet': [('mbarium', False)],
          'mbars': [('mbar', False)],
          'mbas': [('mba', False)],
          'mbasar': [('mbas', False)],
          'mbasarna': [('mbas', False)],
          'mbasars': [('mbas', False)],
          'mbe': [('mba', False)],
          'mbe-': [('mba', False)],
          'mbel': [('mbrer', False)],
          'mbel-': [('mbrer', False)],
          'mbens-': [('mben', False)],
          'mber': [('mb', False)],
          'mberna': [('mb', False)],
          'mbernas': [('mb', False)],
          'mbers': [('mb', False)],
          'mbete': [('mbete', False)],
          'mbeten': [('mbete', False)],
          'mbetens': [('mbete', False)],
          'mbetets': [('mbete', False)],
          'mbets': [('mbete', False)],
          'mbets-': [('mbete', False)],
          'mbie': [('mbie', False)],
          'mbie-': [('mbie', False)],
          'mbien': [('mbie', False)],
          'mbiens': [('mbie', False)],
          'mbier': [('mbie', False)],
          'mbierna': [('mbier', False)],
          'mbiernas': [('mbier', False)],
          'mbiers': [('mbier', False)],
          'mbies': [('mbie', False)],
          'mbies-': [('mbie', False)],
          'mbiesen': [('mbie', False)],
          'mbiesens': [('mbie', False)],
          'mbind': [('mbinda', False)],
          'mbind-': [('mbinda', False)],
          'mbinds': [('mbinda', False)],
          'mbinds-': [('mbinda', False)],
          'mbiner': [('mbin', False)],
          'mbinerna': [('mbin', False)],
          'mbinernas': [('mbin', False)],
          'mbiners': [('mbin', False)],
          'mbios': [('mbios', False)],
          'mbit': [('mbit', False)],
          'mbits': [('mbit', False)],
          'mbits-': [('mbit', False)],
          'mble': [('mble', False)],
          'mble-': [('mble', False)],
          'mblem': [('mblem', False)],
          'mblem-': [('mblem', False)],
          'mblems': [('mblem', False)],
          'mbler': [('mble', False)],
          'mblerna': [('mble', False)],
          'mblernas': [('mble', False)],
          'mblers': [('mble', False)],
          'mboer': [('mbo', False)],
          'mboerna': [('mbo', False)],
          'mboernas': [('mbo', False)],
          'mboers': [('mbo', False)],
          'mbol': [('mbol', False)],
          'mbol-': [('mbol', False)],
          'mbolaget': [('mbolag', False)],
          'mbolagets': [('mbolage', False)],
          'mbole': [('mbola', False)],
          'mbole-': [('mbola', False)],
          'mbolen': [('mbol', False)],
          'mbolens': [('mbol', False)],
          'mbolin': [('mboli', False)],
          'mbolins': [('mboli', False)],
          'mbols': [('mbol', False)],
          'mbols-': [('mbola', False)],
          'mbomb': [('mbomb', False)],
          'mbomber': [('mbomb', False)],
          'mbomberna': [('mbomb', False)],
          'mbombernas': [('mbomb', False)],
          'mbombers': [('mbomb', False)],
          'mbombs': [('mbomb', False)],
          'mbombs-': [('mbomb', False)],
          'mbors': [('mbo', False)],
          'mborst': [('mborst', False)],
          'mborst-': [('mborste', False)],
          'mborsten': [('mborste', False)],
          'mborstens': [('mborste', False)],
          'mbos-': [('mbos', False)],
          'mbot': [('mbo', False)],
          'mbots': [('mbo', False)],
          'mbours': [('mbours', False)],
          'mbra': [('mbra', False)],
          'mbran': [('mbra', False)],
          'mbrans': [('mbra', False)],
          'mbras': [('mbra', False)],
          'mbre': [('mbre', False)],
          'mbre-': [('mbre', False)],
          'mbrens': [('mbre', False)],
          'mbrer': [('mbrer', False)],
          'mbrers': [('mbrum', False)],
          'mbret': [('mbrum', False)],
          'mbrets': [('mbrum', False)],
          'mbroms': [('mbroms', False)],
          'mbromsar': [('mbroms', False)],
          'mbromsarna': [('mbroms', False)],
          'mbromsarnas': [('mbroms', False)],
          'mbror': [('mbra', False)],
          'mbrors': [('mbra', False)],
          'mbrytar': [('mbrytare', False)],
          'mbrytarna': [('mbrytare', False)],
          'mbrytarnas': [('mbrytare', False)],
          'mbräd': [('mbräd', False)],
          'mbräde': [('mbräde', False)],
          'mbräden': [('mbräd', False)],
          'mbrädens': [('mbräd', False)],
          'mbräder': [('mbräd', False)],
          'mbräderna': [('mbräd', False)],
          'mbrädernas': [('mbräd', False)],
          'mbräders': [('mbräd', False)],
          'mbräds': [('mbräd', False)],
          'mbräds-': [('mbräda', False)],
          'mbubbel': [('mbubbla', False)],
          'mbubbel-': [('mbubbla', False)],
          'mbul': [('mbul', False)],
          'mbul-': [('mbul', False)],
          'mbulans': [('mbulans', False)],
          'mbulens': [('mbul', False)],
          'mbuls': [('mbul', False)],
          'mburs': [('mburs', False)],
          'mburs-': [('mburs', False)],
          'mbus': [('mbu', False)],
          'mbus-': [('mbus', False)],
          'mbusen': [('mbus', False)],
          'mbusens': [('mbus', False)],
          'mbyx': [('mbyxa', False)],
          'mbyx-': [('mbyxa', False)],
          'mbyxorna': [('mbyxa', False)],
          'mbälte': [('mbälte', False)],
          'mbärs': [('mbär', False)],
          'mbärs-': [('mbär', False)],
          'mbåg': [('mbåge', False)],
          'mbåg-': [('mbåge', False)],
          'mbågs': [('mbåge', False)],
          'mbågs-': [('mbåge', False)],
          'mc-': [('mc', True)],
          'mcs': [('mc', True)],
          'md': [('md', False)],
          'md-': [('md', False)],
          'mdagar': [('mdag', False)],
          'mdagarnas': [('mdag', False)],
          'mdagen': [('mdag', False)],
          'mdagens': [('mdag', False)],
          'mdags': [('mdag', False)],
          'mdags-': [('mdag', False)],
          'mdator': [('mdator', False)],
          'mdators': [('mdator', False)],
          'mdegs-': [('mdeg', False)],
          'mdel': [('mdel', False)],
          'mden': [('md', False)],
          'mdens': [('md', False)],
          'mder': [('md', False)],
          'mderna': [('md', False)],
          'mdernas': [('md', False)],
          'mders': [('md', False)],
          'mds': [('md', False)],
          'mds-': [('md', False)],
          'mdyn': [('mdyna', False)],
          'mdyn-': [('mdyna', False)],
          'mdyns': [('mdyna', False)],
          'mdyns-': [('mdyna', False)],
          'mdödar': [('mdödare', False)],
          'mdödarna': [('mdödare', False)],
          'mdödarnas': [('mdödare', False)],
          'me': [('me', False)],
          'me-': [('me', False)],
          'mean': [('mean', False)],
          'means': [('mean', False)],
          'med': [('mede', True)],
          'med-': [('mede', True)],
          'medan': [('medan', False)],
          'medans': [('medan', False)],
          'medar': [('mede', True)],
          'medaren': [('medar', False)],
          'medarna': [('mede', True)],
          'medarnas': [('mede', True)],
          'medars': [('mede', True)],
          'mede': [('mede', True)],
          'meden': [('mede', True)],
          'medens': [('mede', True)],
          'medes': [('mede', True)],
          'medes-': [('mede', True)],
          'medfångens': [('medfånge', True)],
          'mediens': [('medi', False)],
          'medier': [('medium', True)],
          'medierna': [('medium', False)],
          'mediernas': [('medium', False)],
          'mediers': [('medium', True)],
          'medins': [('medi', False)],
          'medis': [('medi', False)],
          'medlar': [('medlare', False)],
          'medlarna': [('medlare', False)],
          'medlarnas': [('medlare', False)],
          'meds': [('mede', True)],
          'meds-': [('mede', True)],
          'medyn': [('medyna', False)],
          'medyn-': [('medyna', False)],
          'medödar': [('medöd', False)],
          'medödarnas': [('medöd', False)],
          'mefor': [('mefa', True)],
          'mefors': [('mefa', True)],
          'megalier': [('megali', False)],
          'megalierna': [('megali', False)],
          'megaliernas': [('megali', False)],
          'megaliers': [('megali', False)],
          'megat': [('mega', False)],
          'megaton': [('megaton', True)],
          'megatons': [('megaton', True)],
          'megats': [('mega', False)],
          'megär': [('megära', True)],
          'megär-': [('megära', True)],
          'megäran': [('megära', True)],
          'megärs': [('megära', True)],
          'megärs-': [('megära', True)],
          'mej': [('meja', False)],
          'mej-': [('meja', False)],
          'mejar': [('mejare', True)],
          'mejarna': [('mejare', True)],
          'mejarnas': [('mejare', True)],
          'mejs': [('meja', False)],
          'mejs-': [('meja', False)],
          'meke': [('meka', False)],
          'meke-': [('meka', False)],
          'meket': [('mek', False)],
          'mekets': [('mek', False)],
          'mel': [('mla', False)],
          'mel-': [('mla', False)],
          'melandet': [('meland', False)],
          'melers': [('mel', False)],
          'melie-': [('melia', False)],
          'melin': [('melin', False)],
          'melis-': [('melia', False)],
          'meliten': [('meliten', False)],
          'melitens': [('meliten', False)],
          'mell': [('mell', False)],
          'mell-': [('mell', False)],
          'mellen': [('mell', False)],
          'meller': [('mell', False)],
          'mellerna': [('mell', False)],
          'mellernas': [('mell', False)],
          'mellers': [('mell', False)],
          'mellis': [('mellis', True)],
          'mells': [('mell', False)],
          'mells-': [('mell', False)],
          'melon': [('meloner', True), ('melon', True)],
          'melon-': [('melon', True), ('meloner', True)],
          'meloner': [('melon', True), ('meloner', True)],
          'melonerna': [('meloner', True), ('melon', True)],
          'melonernas': [('meloner', True), ('melon', True)],
          'meloners': [('meloner', True), ('melon', True)],
          'melons': [('meloner', True), ('melon', True)],
          'melspol': [('melspol', False)],
          'melspolen': [('melspol', False)],
          'melspols': [('melspol', False)],
          'melspols-': [('melspol', False)],
          'meluck': [('melucker', False)],
          'mem': [('mem', True)],
          'mem-': [('mem', True)],
          'mems': [('mem', False)],
          'men': [('men', True), ('m', True)],
          'mena': [('me', False)],
          'menas': [('me', False)],
          'menet': [('men', False)],
          'menets': [('men', False)],
          'menheter': [('menhet', False)],
          'menheterna': [('menhet', False)],
          'menheternas': [('menhet', False)],
          'menheters': [('menhet', False)],
          'menhets': [('menhet', False)],
          'menhets-': [('menhet', False)],
          'menier': [('menier', False)],
          'menierna': [('menier', False)],
          'meniers': [('menier', False)],
          'menisk': [('menisk', True)],
          'menisk-': [('menisk', True)],
          'menits': [('menit', False)],
          'mens': [('mens', True), ('m', True), ('men', True)],
          'mens-': [('men', True), ('mens', True)],
          'mensen': [('mens', True)],
          'mensens': [('mens', False)],
          'menser': [('mens', False)],
          'menserna': [('mens', False)],
          'mensernas': [('mens', False)],
          'mensers': [('mens', False)],
          'mensk': [('menska', False)],
          'mensk-': [('menska', False)],
          'menskaps-': [('menskap', False)],
          'ment': [('ment', False)],
          'mentanden': [('mentande', False)],
          'mentandens': [('mentande', False)],
          'mentar': [('mentar', False)],
          'mentar-': [('mentar', False)],
          'mentarens': [('mentar', False)],
          'mentarierna': [('mentarium', False)],
          'mentariers': [('mentarium', False)],
          'menten': [('ment', False)],
          'mentens': [('ment', False)],
          'menter': [('ment', False)],
          'menterna': [('ment', False)],
          'menternas': [('ment', False)],
          'menters': [('ment', False)],
          'mentet': [('ment', False)],
          'mentierna': [('menti', False)],
          'mentorn': [('mentor', True)],
          'mentorns': [('mentor', True)],
          'ments-': [('ment', False)],
          'mer-': [('mer', False)],
          'mera': [('mera', False)],
          'meran': [('mera', False)],
          'merans': [('mera', False)],
          'merare': [('merare', False)],
          'merares': [('merare', False)],
          'merarna': [('merare', False)],
          'merarnas': [('merare', False)],
          'merflott': [('merflotte', False)],
          'merflott-': [('merflotte', False)],
          'merflotts-': [('merflotte', False)],
          'meri': [('meri', False)],
          'meri-': [('meri', False)],
          'merien': [('meri', False)],
          'meriens': [('meri', False)],
          'merier': [('meri', False)],
          'merierna': [('meri', False)],
          'meriers': [('meri', False)],
          'meriet': [('meri', False)],
          'merins': [('meri', False)],
          'meris': [('meri', False)],
          'meris-': [('meri', False)],
          'merit': [('merit', True)],
          'meriternas': [('merit', True)],
          'merits': [('merit', True)],
          'merman': [('merman', False)],
          'mermans': [('merman', False)],
          'merna': [('ma', False)],
          'mernas': [('ma', False)],
          'merornas': [('mera', False)],
          'mers-': [('mers', False)],
          'mersarnas': [('mer', False)],
          'mersen': [('merus', False)],
          'mersens': [('merus', False)],
          'merser': [('mers', False)],
          'merserna': [('mers', False)],
          'mersernas': [('mers', False)],
          'mersers': [('mers', False)],
          'mersets': [('merus', False)],
          'mersås': [('mersås', False)],
          'mertin': [('mertina', False)],
          'merungen': [('merung', False)],
          'merungens': [('merung', False)],
          'mervärden': [('mervärde', True)],
          'mervärdens': [('mervärde', True)],
          'mes': [('mes', False)],
          'mes-': [('mes', True)],
          'mesarnas': [('mes', False)],
          'messen': [('mess', True)],
          'messens': [('mess', True)],
          'mester': [('mester', False)],
          'mestern': [('mester', False)],
          'mesterns': [('mester', False)],
          'mesters': [('mester', False)],
          'met': [('m', True)],
          'metan': [('metan', True)],
          'metana': [('metana', False)],
          'metanas': [('metana', False)],
          'metanis': [('metanis', True)],
          'metans': [('metan', True)],
          'metar': [('metare', True)],
          'metarna': [('metare', True)],
          'mete': [('mete', True)],
          'meten': [('mete', True)],
          'metens': [('mete', True)],
          'meter': [('meter', False)],
          'meterna': [('meter', False)],
          'meternas': [('meter', False)],
          'meters': [('meter', False)],
          'metes': [('mete', True)],
          'metes-': [('mete', True)],
          'metet': [('mete', True)],
          'metikernas': [('metiker', False)],
          'metikers': [('metiker', False)],
          'metoden': [('metod', True)],
          'metodens': [('metod', True)],
          'metodiker': [('metodiker', True)],
          'metodikerna': [('metodiker', True)],
          'metodikernas': [('metodiker', True)],
          'metodikers': [('metodiker', True)],
          'metrons': [('metro', True)],
          'metror': [('metro', True)],
          'mets': [('m', True)],
          'mett': [('mett', False)],
          'mett-': [('mett', False)],
          'mette': [('metta', False)],
          'metten': [('mett', False)],
          'metter': [('mett', False)],
          'metterna': [('mett', False)],
          'metternas': [('mett', False)],
          'metters': [('mett', False)],
          'mettor': [('metta', False)],
          'mettornas': [('metta', False)],
          'mettors': [('metta', False)],
          'metts': [('mett', False)],
          'metts-': [('mett', False)],
          'metylen': [('metylen', True), ('metyl', True)],
          'metylens': [('metyl', True), ('metylen', True)],
          'meverket': [('meverk', False)],
          'meväxlar': [('meväxlare', False)],
          'meväxlarnas': [('meväxlare', False)],
          'mf': [('mf', False)],
          'mf-': [('mf', False)],
          'mfader': [('mfar', False)],
          'mfader-': [('mfar', False)],
          'mfadern': [('mfar', False)],
          'mfaderns': [('mfar', False)],
          'mfaders': [('mfar', False)],
          'mfaders-': [('mfar', False)],
          'mfan': [('mfa', False)],
          'mfans': [('mfa', False)],
          'mfar': [('mfar', False)],
          'mfar-': [('mfar', False)],
          'mfarna': [('mf', False)],
          'mfars': [('mf', False)],
          'mfars-': [('mfar', False)],
          'mfas': [('mfa', False)],
          'mfasen': [('mfas', False)],
          'mfasens': [('mfas', False)],
          'mfat': [('mfat', False)],
          'mfel': [('mfel', False)],
          'mfels': [('mfel', False)],
          'mfels-': [('mfel', False)],
          'mfen': [('mf', False)],
          'mfena': [('mfena', False)],
          'mfens': [('mf', False)],
          'mfer': [('mf', False)],
          'mfer-': [('mfer', False)],
          'mferna': [('mf', False)],
          'mfernas': [('mf', False)],
          'mfers': [('mf', False)],
          'mfet': [('mf', False)],
          'mfets': [('mf', False)],
          'mfjäll': [('mfjäll', False)],
          'mfjäll-': [('mfjäll', False)],
          'mfjälls': [('mfjäll', False)],
          'mfjälls-': [('mfjäll', False)],
          'mflott': [('mflotte', False)],
          'mflott-': [('mflotte', False)],
          'mflottar': [('mflotte', False)],
          'mflottarna': [('mflotte', False)],
          'mflottarnas': [('mflotte', False)],
          'mflotte': [('mflotte', False)],
          'mflotts': [('mflotte', False)],
          'mflotts-': [('mflotte', False)],
          'mfolierna': [('mfolie', False)],
          'mfonis': [('mfoni', False)],
          'mfora': [('mfora', False)],
          'mforas': [('mfora', False)],
          'mformar': [('mformare', False)],
          'mformarna': [('mformare', False)],
          'mformarnas': [('mformare', False)],
          'mforten': [('mfort', False)],
          'mfortens': [('mfort', False)],
          'mfots': [('mfot', False)],
          'mfs': [('mf', False)],
          'mfs-': [('mf', False)],
          'mfäder': [('mfar', False)],
          'mfäderna': [('mfar', False)],
          'mfädernas': [('mfar', False)],
          'mfäders': [('mfar', False)],
          'mfång': [('mfång', False)],
          'mfång-': [('mfång', False)],
          'mfången': [('mfång', False)],
          'mfångens': [('mfång', False)],
          'mfångs': [('mfång', False)],
          'mfångs-': [('mfång', False)],
          'mförsäkringar': [('mförsäkring', False)],
          'mförsäkringarna': [('mförsäkring', False)],
          'mförsäkringarnas': [('mförsäkring', False)],
          'mförsäkringars': [('mförsäkring', False)],
          'mg-': [('mg', True)],
          'mgaserna': [('mgas', False)],
          'mgasernas': [('mgas', False)],
          'mgasers': [('mgas', False)],
          'mgiften': [('mgift', False)],
          'mgiftens': [('mgift', False)],
          'mgiftet': [('mgifte', False)],
          'mgiftets': [('mgift', False)],
          'mgifts': [('mgift', False)],
          'mgifts-': [('mgift', False)],
          'mgiv': [('mgiv', False)],
          'mgiv-': [('mgiv', False)],
          'mgivar': [('mgivare', False)],
          'mgivarna': [('mgivare', False)],
          'mgivarnas': [('mgivare', False)],
          'mgivs': [('mgiv', False)],
          'mgivs-': [('mgiv', False)],
          'mgods': [('mgods', False)],
          'mgods-': [('mgods', False)],
          'mgräns': [('mgräns', False)],
          'mgräns-': [('mgräns', False)],
          'mgälder': [('mgälder', False)],
          'mgälderna': [('mgälder', False)],
          'mgäldernas': [('mgälder', False)],
          'mgälders': [('mgälder', False)],
          'mgälds': [('mgälder', False)],
          'mgälds-': [('mgälder', False)],
          'mgänge': [('mgänge', False)],
          'mgängen': [('mgänge', False)],
          'mgängens': [('mgänge', False)],
          'mgänget': [('mgänge', False)],
          'mgängets': [('mgänge', False)],
          'mgångar': [('mgång', False)],
          'mgångarna': [('mgång', False)],
          'mgångarnas': [('mgång', False)],
          'mgömme': [('mgömma', False)],
          'mgömme-': [('mgömma', False)],
          'mgöms': [('mgömma', False)],
          'mherr': [('mherre', False)],
          'mherr-': [('mherre', False)],
          'mherrs': [('mherre', False)],
          'mheter': [('mhet', False)],
          'mheterna': [('mhet', False)],
          'mheternas': [('mhet', False)],
          'mheters': [('mhet', False)],
          'mhets': [('mhet', False)],
          'mhets-': [('mhet', False)],
          'mhjälpar': [('mhjälp', False)],
          'mhjälparna': [('mhjälp', False)],
          'mhjälparnas': [('mhjälp', False)],
          'mhus': [('mhus', False)],
          'mhylle': [('mhylle', False)],
          'mhylls': [('mhylle', False)],
          'mhylls-': [('mhylle', False)],
          'mhälle': [('mhälle', False)],
          'mhällen': [('mhälle', False)],
          'mhällens': [('mhälle', False)],
          'mhälls': [('mhälle', False)],
          'mhälls-': [('mhälle', False)],
          'mhängen': [('mhänge', False)],
          'mhänget': [('mhänge', False)],
          'mhängets': [('mhänge', False)],
          'mhängs': [('mhänge', False)],
          'mhängs-': [('mhänge', False)],
          'mhål': [('mhål', False)],
          'mhåls': [('mhål', False)],
          'mhåls-': [('mhål', False)],
          'mhörighets': [('mhörighet', False)],
          'mi': [('mi', False)],
          'mi-': [('mi', False)],
          'miasmer': [('miasmer', True)],
          'miasmerna': [('miasmer', True)],
          'miasmers': [('miasmer', True)],
          'mibier': [('mibier', False)],
          'mibiernas': [('mibier', False)],
          'mibiers': [('mibier', False)],
          'mibit': [('mibit', False)],
          'mick-': [('mick', True)],
          'mickar': [('mick', False)],
          'mickarna': [('mick', False)],
          'mickels': [('mickel', True)],
          'micklar': [('mickel', True)],
          'micklarna': [('mickel', True)],
          'micklarnas': [('mickel', False)],
          'micks': [('mick', True)],
          'micks-': [('mick', True)],
          'micksen': [('mick', False)],
          'midar': [('midare', False)],
          'midarna': [('midare', False)],
          'midarnas': [('midare', False)],
          'mide': [('mide', False)],
          'mide-': [('mide', False)],
          'miden': [('mide', False)],
          'midens': [('mid', False)],
          'miderit': [('mideri', False)],
          'mides': [('mide', False)],
          'mides-': [('mide', False)],
          'midet': [('mide', False)],
          'midets': [('mide', False)],
          'mids': [('mid', False)],
          'mien': [('mi', False)],
          'miens': [('mi', False)],
          'mier': [('mi', False)],
          'mierna': [('mi', False)],
          'miernas': [('mi', False)],
          'miers': [('mi', False)],
          'mies': [('my', False)],
          'miet': [('mium', False)],
          'miets': [('mium', False)],
          'migheter': [('mighet', False)],
          'migheterna': [('mighet', False)],
          'migheternas': [('mighet', False)],
          'migheters': [('mighet', False)],
          'mighets-': [('mighet', False)],
          'mikalie': [('mikalie', False)],
          'mikaliernas': [('mikalie', False)],
          'mikaliers': [('mikalie', False)],
          'miker': [('miker', False)],
          'mikerna': [('miker', False)],
          'mikernas': [('miker', False)],
          'mikers': [('miker', False)],
          'mikon': [('miko', True)],
          'mikons': [('miko', True)],
          'mikos': [('miko', True)],
          'mikrobloggar': [('mikroblogg', True), ('mikrobloggare', True)],
          'mikrobloggarna': [('mikroblogg', True), ('mikrobloggare', True)],
          'mikrobloggarnas': [('mikroblogg', True), ('mikrobloggare', True)],
          'mikron': [('mikro', True), ('mikron', True)],
          'mikrons': [('mikro', True), ('mikron', True)],
          'mil': [('mila', True), ('mil', True)],
          'mil-': [('mil', True), ('mila', True)],
          'milandets': [('milande', False)],
          'milar': [('milare', False)],
          'milar-': [('milare', False)],
          'milarens': [('milare', False)],
          'milarna': [('milare', False)],
          'milarnas': [('milare', False)],
          'mile': [('mila', True)],
          'mile-': [('mila', True)],
          'milen': [('mil', True)],
          'milens': [('mil', True)],
          'milet': [('milet', False)],
          'milets': [('milet', False)],
          'mili': [('mili', False)],
          'mili-': [('mili', False)],
          'milis': [('milis', True)],
          'milis-': [('milis', True)],
          'milister': [('milist', False)],
          'milisters': [('milist', False)],
          'milj': [('milj', False)],
          'milj-': [('milj', False)],
          'miljen': [('milj', False)],
          'miljens': [('milj', False)],
          'miljs': [('milj', False)],
          'miljs-': [('milj', False)],
          'mill': [('mill', False)],
          'mill-': [('mill', False)],
          'millar': [('mille', True)],
          'millarna': [('mille', True)],
          'millarnas': [('mille', True)],
          'millen': [('mille', True)],
          'millens': [('mille', True)],
          'miller': [('mill', False)],
          'millerna': [('mill', False)],
          'millernas': [('mill', False)],
          'millers': [('mill', False)],
          'mills': [('mill', False)],
          'mills-': [('mill', False)],
          'milo': [('milo', True)],
          'milon': [('milo', True)],
          'milons': [('milo', True)],
          'milots': [('milo', True)],
          'mils': [('mil', True), ('mila', True)],
          'mils-': [('mila', True)],
          'mimandens': [('mimande', True)],
          'mimer': [('mim', True)],
          'mimers': [('mim', False)],
          'min': [('mina', True), ('min', True)],
          'min-': [('min', True), ('mina', True)],
          'mina': [('mina', True)],
          'minanden': [('minand', False)],
          'minans': [('mina', False)],
          'minarie-': [('minarium', False)],
          'minariers': [('minarium', False)],
          'minas': [('mina', True)],
          'minator': [('minator', False)],
          'minators': [('minator', False)],
          'minats-': [('minat', False)],
          'minens': [('min', True)],
          'minets': [('min', False)],
          'ming': [('ming', False)],
          'ming-': [('ming', False)],
          'mingar': [('ming', False)],
          'mingarna': [('ming', False)],
          'mingarnas': [('ming', False)],
          'mingars': [('ming', False)],
          'mingel': [('mingel', False)],
          'mingel-': [('mingel', True)],
          'mingen': [('ming', False)],
          'mingens': [('ming', False)],
          'mingornas': [('mingo', False)],
          'mingors': [('mingo', False)],
          'mings': [('ming', False)],
          'mings-': [('ming', False)],
          'minierna': [('minion', False)],
          'miniernas': [('minion', False)],
          'miniers': [('minion', False)],
          'miniker': [('miniker', False)],
          'minikerna': [('miniker', False)],
          'minikernas': [('miniker', False)],
          'minikers': [('miniker', False)],
          'minin': [('mininum', False)],
          'minin-': [('mininum', False)],
          'mininen': [('mininum', False)],
          'mininens': [('mininum', False)],
          'mininet': [('mininum', False)],
          'mininets': [('mininum', False)],
          'minister': [('minister', True)],
          'ministers': [('minister', True)],
          'mink': [('mink', False)],
          'minkar': [('mink', True)],
          'minkarna': [('mink', True)],
          'minkarnas': [('mink', True)],
          'minkars': [('mink', True)],
          'minker': [('mink', False)],
          'minkerna': [('mink', False)],
          'minkernas': [('mink', False)],
          'minkers': [('mink', False)],
          'minnen': [('minne', False)],
          'minnets': [('minne', False)],
          'minons': [('mino', False)],
          'minor': [('mina', True)],
          'minorna': [('mina', True)],
          'minornas': [('mina', True)],
          'minors': [('mina', True)],
          'minos': [('mino', False)],
          'minos-': [('minos', False)],
          'minosens': [('minos', False)],
          'mins': [('mina', True), ('min', True)],
          'mins-': [('min', True), ('mina', True)],
          'mint': [('mint', True)],
          'minton': [('minton', False)],
          'mintons': [('minton', False)],
          'mints-': [('mint', True)],
          'minär': [('minärer', False)],
          'minär-': [('minärer', False)],
          'minärer': [('minärer', False)],
          'minärerna': [('minärer', False)],
          'minärernas': [('minärer', False)],
          'minärers': [('minärer', False)],
          'minärs': [('minärer', False)],
          'minärs-': [('minärer', False)],
          'mirer': [('mir', False)],
          'mirerna': [('mir', False)],
          'mirernas': [('mir', False)],
          'mirers': [('mir', False)],
          'mis': [('mi', False)],
          'mis-': [('mi', False)],
          'misarna': [('mi', False)],
          'misarnas': [('mis', False)],
          'misationen': [('misation', False)],
          'misk': [('misk', False)],
          'misk-': [('misk', False)],
          'miskan': [('miska', False)],
          'miskans': [('miska', False)],
          'misket': [('misk', False)],
          'mismer': [('mism', False)],
          'mismerna': [('mism', False)],
          'mismernas': [('mism', False)],
          'mismers': [('mism', False)],
          'miss': [('misse', True), ('miss', True)],
          'miss-': [('misse', True), ('miss', True)],
          'missar': [('misse', True), ('miss', True)],
          'missarna': [('misse', True), ('miss', True)],
          'missarnas': [('misse', True), ('miss', True)],
          'missars': [('misse', True), ('miss', True)],
          'misse': [('misse', True)],
          'misse-': [('missa', False)],
          'missen': [('misse', True), ('miss', True)],
          'missens': [('misse', True), ('miss', True)],
          'misser': [('miss', False)],
          'misserna': [('miss', False)],
          'missernas': [('miss', False)],
          'missers': [('miss', True)],
          'mist-': [('mist', False)],
          'misten': [('mist', False)],
          'mistens': [('mist', False)],
          'mister': [('mister', True)],
          'misterna': [('mist', False)],
          'misternas': [('mist', False)],
          'misters': [('mister', True)],
          'mit': [('mi', False)],
          'mit-': [('mita', False)],
          'mita': [('mita', False)],
          'mitan': [('mita', False)],
          'mitar': [('mitare', False)],
          'mitar-': [('mitare', False)],
          'mitarens': [('mitare', False)],
          'mitarna': [('mitare', False)],
          'mitas': [('mita', False)],
          'miternas': [('mit', False)],
          'mitorierna': [('mitorium', False)],
          'mitoriernas': [('mitorium', False)],
          'mitoriers': [('mitorium', False)],
          'mitoriets': [('mitorium', False)],
          'miträden': [('miträd', False)],
          'miträdens': [('miträd', False)],
          'miträdet': [('miträd', False)],
          'miträdets': [('miträd', False)],
          'mits': [('mit', False)],
          'mits-': [('mita', False)],
          'mitt': [('mitt', False)],
          'mitt-': [('mitt', True)],
          'mittben': [('mittbena', True)],
          'mittbens': [('mittbena', True)],
          'mittbens-': [('mittbena', True)],
          'mitte': [('mitta', False)],
          'mitten': [('mitt', False)],
          'mittens': [('mitt', True)],
          'mitter': [('mitter', False)],
          'mitter-': [('mitter', False)],
          'mitters-': [('mitter', False)],
          'mittrar': [('mitter', False)],
          'mittrarna': [('mitter', False)],
          'mitts': [('mitt', False)],
          'mitts-': [('mitt', True)],
          'mium': [('mium', False)],
          'miums': [('mium', False)],
          'mixer': [('mixer', True), ('mix', True)],
          'mixerna': [('mix', True), ('mixer', True)],
          'mixernas': [('mixer', True), ('mix', True)],
          'mixers': [('mixer', True), ('mix', True)],
          'mjan': [('mjan', False)],
          'mjan-': [('mjan', False)],
          'mjans': [('mjan', False)],
          'mjaren': [('mjare', False)],
          'mjarnas': [('mjare', False)],
          'mje': [('mja', False)],
          'mje-': [('mja', False)],
          'mjon': [('mjon', False)],
          'mjoner': [('mjon', False)],
          'mjonerna': [('mjon', False)],
          'mjonernas': [('mjon', False)],
          'mjoners': [('mjon', False)],
          'mjons': [('mjon', False)],
          'mjärd': [('mjärde', True)],
          'mjärd-': [('mjärde', True)],
          'mjärdar': [('mjärde', True)],
          'mjärdarna': [('mjärde', True)],
          'mjärdars': [('mjärde', True)],
          'mjärden': [('mjärde', True)],
          'mjärdens': [('mjärde', True)],
          'mjärds': [('mjärde', True)],
          'mjärds-': [('mjärde', True)],
          'mjölk': [('mjölke', True), ('mjölk', True)],
          'mjölk-': [('mjölke', True), ('mjölk', True)],
          'mjölkar': [('mjölke', True), ('mjölkare', True)],
          'mjölkarna': [('mjölkare', True), ('mjölke', True)],
          'mjölkarnas': [('mjölke', True), ('mjölkare', True)],
          'mjölken': [('mjölk', True), ('mjölke', True)],
          'mjölkens': [('mjölke', True), ('mjölk', True)],
          'mjölks': [('mjölke', True), ('mjölk', True)],
          'mjölks-': [('mjölk', True), ('mjölke', True)],
          'mkallarna': [('mkallare', False)],
          'mkallarnas': [('mkallare', False)],
          'mkammar': [('mkammare', False)],
          'mkan': [('mkan', False)],
          'mkanden': [('mkande', False)],
          'mkans': [('mkan', False)],
          'mkans-': [('mkan', False)],
          'mkatt': [('mkatt', False)],
          'mkatten': [('mkatt', False)],
          'mkattens': [('mkatt', False)],
          'mkatts': [('mkatt', False)],
          'mkatts-': [('mkatt', False)],
          'mklasen': [('mklase', False)],
          'mklipp': [('mklipp', False)],
          'mklipps': [('mklipp', False)],
          'mklipps-': [('mklipp', False)],
          'mklock': [('mklocka', False)],
          'mklubb': [('mklubb', False)],
          'mklubbs': [('mklubb', False)],
          'mklubbs-': [('mklubb', False)],
          'mkningar': [('mkning', False)],
          'mkningarna': [('mkning', False)],
          'mkningarnas': [('mkning', False)],
          'mkningars': [('mkning', False)],
          'mknings': [('mkning', False)],
          'mknings-': [('mkning', False)],
          'mknippe': [('mknippe', False)],
          'mknippe-': [('mknippe', False)],
          'mknut': [('mknut', False)],
          'mknuts': [('mknut', False)],
          'mknuts-': [('mknut', False)],
          'mkom': [('mkom', False)],
          'mkom-': [('mkom', False)],
          'mkoms': [('mkom', False)],
          'mkomst-': [('mkomst', False)],
          'mkonst-': [('mkonst', False)],
          'mkonster': [('mkonst', False)],
          'mkonsternas': [('mkonst', False)],
          'mkonsters': [('mkonst', False)],
          'mkrafter': [('mkraft', False)],
          'mkrafterna': [('mkraft', False)],
          'mkrafternas': [('mkraft', False)],
          'mkrafters': [('mkraft', False)],
          'mkrafts': [('mkraft', False)],
          'mkrafts-': [('mkraft', False)],
          'mkramar': [('mkramare', False)],
          'mkramarna': [('mkramare', False)],
          'mkramarnas': [('mkramare', False)],
          'mkrans': [('mkrans', False)],
          'mkrans-': [('mkrans', False)],
          'mkrets-': [('mkrets', False)],
          'mkritiker': [('mkritiker', False)],
          'mkritikerna': [('mkritiker', False)],
          'mkritikernas': [('mkritiker', False)],
          'mkritikers': [('mkritiker', False)],
          'mkronan': [('mkrona', False)],
          'mkronans': [('mkrona', False)],
          'mkrons-': [('mkrona', False)],
          'mkrossar': [('mkross', False)],
          'mkulorna': [('mkula', False)],
          'mkulornas': [('mkula', False)],
          'mkulors': [('mkula', False)],
          'mkunskaps': [('mkunskap', False)],
          'mkurs': [('mkurs', False)],
          'mkurs-': [('mkurs', False)],
          'mkurv': [('mkurva', False)],
          'mkurv-': [('mkurva', False)],
          'mkurvor': [('mkurva', False)],
          'mkurvorna': [('mkurva', False)],
          'mkurvornas': [('mkurva', False)],
          'mkurvors': [('mkurva', False)],
          'mkurvs': [('mkurva', False)],
          'mkurvs-': [('mkurva', False)],
          'mkäll': [('mkälla', False)],
          'mkön': [('mkö', False)],
          'mköns': [('mkö', False)],
          'mkör': [('mkör', False)],
          'mkörs': [('mkör', False)],
          'ml': [('ml', True)],
          'ml-': [('ml', True)],
          'mlag': [('mlag', False)],
          'mlagen': [('mlag', False)],
          'mlaget': [('mlag', False)],
          'mlags': [('mlag', False)],
          'mlags-': [('mlag', False)],
          'mlamp-': [('mlampa', False)],
          'mlamps': [('mlampa', False)],
          'mlamps-': [('mlampa', False)],
          'mlan': [('mla', False)],
          'mlanden': [('mlande', False)],
          'mlandena': [('mlande', False)],
          'mlandenas': [('mlande', False)],
          'mlandens': [('mlande', False)],
          'mlandet': [('mlande', False)],
          'mlandets': [('mland', False)],
          'mlans': [('mla', False)],
          'mlar': [('mmel', False)],
          'mlaren': [('mlare', False)],
          'mlarna': [('mmel', False)],
          'mlars': [('mmel', False)],
          'mle': [('mla', False)],
          'mle-': [('mla', False)],
          'mler': [('mel', False)],
          'mlerna': [('mel', False)],
          'mlers': [('mel', False)],
          'mlet': [('mmel', False)],
          'mlets': [('mmel', False)],
          'mlighets': [('mlighet', False)],
          'mlik': [('mlike', False)],
          'mlik-': [('mlike', False)],
          'mlikar': [('mlike', False)],
          'mlikarna': [('mlike', False)],
          'mlikarnas': [('mlike', False)],
          'mliken': [('mlike', False)],
          'mlikens': [('mlike', False)],
          'mliks': [('mlike', False)],
          'mliks-': [('mlike', False)],
          'mlist': [('mlist', False)],
          'mlist-': [('mlist', False)],
          'mlivs': [('mliv', False)],
          'mlivs-': [('mliv', False)],
          'mlock': [('mlock', False)],
          'mlopp': [('mlopp', False)],
          'mlopps': [('mlopp', False)],
          'mlopps-': [('mlopp', False)],
          'mlor': [('mla', False)],
          'mlorna': [('mla', False)],
          'mlornas': [('mla', False)],
          'mlors': [('mla', False)],
          'mlott': [('mlott', False)],
          'mlott-': [('mlott', False)],
          'mlottens': [('mlott', False)],
          'mlotts': [('mlott', False)],
          'mls': [('mla', False)],
          'mluck': [('mlucka', False)],
          'mluck-': [('mlucka', False)],
          'mlykt-': [('mlykta', False)],
          'mlykts': [('mlykta', False)],
          'mläcks': [('mläcka', False)],
          'mläcks-': [('mläcka', False)],
          'mländar': [('mländare', False)],
          'mländarna': [('mländare', False)],
          'mländer': [('mland', False)],
          'mländerna': [('mland', False)],
          'mländernas': [('mland', False)],
          'mländers': [('mland', False)],
          'mlön': [('mlön', False)],
          'mlös': [('mlösa', False)],
          'mm': [('mm', False)],
          'mm-': [('mm', False)],
          'mmakar': [('mmakare', False)],
          'mmakarna': [('mmakare', False)],
          'mmakarnas': [('mmakare', False)],
          'mmaliernas': [('mmalier', False)],
          'mmana': [('mma', False)],
          'mmanas': [('mma', False)],
          'mmanden': [('mmande', False)],
          'mmanens': [('mmanens', False)],
          'mmanet': [('mman', False)],
          'mmanets': [('mman', False)],
          'mmans': [('mma', False)],
          'mmar': [('mmare', False)],
          'mmar-': [('mmare', False)],
          'mmare': [('mmare', False)],
          'mmaren': [('mmare', False)],
          'mmarens': [('mmar', False)],
          'mmarna': [('mmare', False)],
          'mmars': [('mme', False)],
          'mmas': [('mma', False)],
          'mmas-': [('mma', False)],
          'mmat': [('mma', False)],
          'mmaterier': [('mmateria', False)],
          'mmaterierna': [('mmateria', False)],
          'mmateriernas': [('mmateria', False)],
          'mmateriers': [('mmateria', False)],
          'mmats': [('mma', False)],
          'mmatt': [('mmatta', False)],
          'mmatt-': [('mmatta', False)],
          'mmatte': [('mmatta', False)],
          'mmatte-': [('mmatta', False)],
          'mmatts': [('mmatta', False)],
          'mmatts-': [('mmatta', False)],
          'mme': [('mma', False)],
          'mme-': [('mma', False)],
          'mmel': [('mmel', False)],
          'mmel-': [('mmel', False)],
          'mmerit': [('mmeri', False)],
          'mmerits': [('mmeri', False)],
          'mmerna': [('mmer', False)],
          'mmernas': [('m', False)],
          'mmers': [('mmer', False)],
          'mmers-': [('mmer', False)],
          'mmersen': [('mmers', False)],
          'mmersens': [('mmers', False)],
          'mmes': [('mme', False)],
          'mmes-': [('mme', False)],
          'mmet': [('mme', False)],
          'mmeten': [('mmet', False)],
          'mmetens': [('mmet', False)],
          'mmetoden': [('mmetod', False)],
          'mmier': [('mmy', False)],
          'mmierna': [('mmy', False)],
          'mmiernas': [('mmy', False)],
          'mmiers': [('mmy', False)],
          'mmil': [('mmil', False)],
          'mmils': [('mmil', False)],
          'mmils-': [('mmil', False)],
          'mmin-': [('mmin', False)],
          'mmina': [('mmi', False)],
          'mminas': [('mmi', False)],
          'mminens': [('mmin', False)],
          'mminet': [('mmin', False)],
          'mminister': [('mminister', False)],
          'mministers': [('mminister', False)],
          'mmisarna': [('mmis', False)],
          'mmiss': [('mmiss', False)],
          'mmiss-': [('mmiss', False)],
          'mmissen': [('mmiss', False)],
          'mmissens': [('mmiss', False)],
          'mmits': [('mmi', False)],
          'mmitte': [('mmitte', False)],
          'mmitten': [('mmitte', False)],
          'mmittens': [('mmitte', False)],
          'mmjölk': [('mmjölk', False)],
          'mmjölk-': [('mmjölk', False)],
          'mmjölken': [('mmjölk', False)],
          'mmjölkens': [('mmjölk', False)],
          'mmjölks': [('mmjölk', False)],
          'mmjölks-': [('mmjölk', False)],
          'mmlar': [('mmel', False)],
          'mmlarna': [('mmel', False)],
          'mmlarnas': [('mmel', False)],
          'mmlars': [('mmel', False)],
          'mmo': [('mma', False)],
          'mmo-': [('mma', False)],
          'mmock': [('mmock', False)],
          'mmoden': [('mmod', False)],
          'mmodens': [('mmod', False)],
          'mmoder': [('mmod', False)],
          'mmoder-': [('mmoder', False)],
          'mmodern': [('mmoder', False)],
          'mmoderns': [('mmoder', False)],
          'mmoders': [('mmod', False)],
          'mmoders-': [('mmoder', False)],
          'mmodet': [('mmode', False)],
          'mmodets': [('mmode', False)],
          'mmods': [('mmod', False)],
          'mmods-': [('mmod', False)],
          'mmon': [('mmon', False)],
          'mmons': [('mmon', False)],
          'mmor': [('mma', False)],
          'mmorna': [('mma', False)],
          'mmornas': [('mma', False)],
          'mmors': [('mma', False)],
          'mmos': [('mmo', False)],
          'mms': [('mm', False)],
          'mms-': [('mm', False)],
          'mmsugarna': [('mmsugare', False)],
          'mmus': [('mmus', False)],
          'mmussel-': [('mmussla', False)],
          'mmut': [('mmut', False)],
          'mmut-': [('mmut', False)],
          'mmutar': [('mmut', False)],
          'mmutarna': [('mmut', False)],
          'mmutarnas': [('mmut', False)],
          'mmuts': [('mmut', False)],
          'mmuts-': [('mmut', False)],
          'mmys': [('mmy', False)],
          'mmän': [('mman', False)],
          'mmödrar': [('mmoder', False)],
          'mmödrarna': [('mmoder', False)],
          'mmödrarnas': [('mmoder', False)],
          'mmödrars': [('mmoder', False)],
          'mn': [('mn', False)],
          'mn-': [('mn', False)],
          'mna': [('mna', False)],
          'mnader': [('mnad', False)],
          'mnaderna': [('mnad', False)],
          'mnadernas': [('mnad', False)],
          'mnaders': [('mnad', False)],
          'mnads': [('mnad', False)],
          'mnads-': [('mnad', False)],
          'mnanden': [('mnande', False)],
          'mnar-': [('mnare', False)],
          'mnaren': [('mnare', False)],
          'mnarens': [('mnare', False)],
          'mnarnas': [('mnare', False)],
          'mnas': [('mna', False)],
          'mnde': [('mnd', False)],
          'mnde-': [('mnd', False)],
          'mndernas': [('mnd', False)],
          'mnen': [('mn', False)],
          'mnens': [('mn', False)],
          'mner': [('mn', False)],
          'mnerna': [('mn', False)],
          'mnernas': [('mn', False)],
          'mners': [('mn', False)],
          'mnesen': [('mnes', False)],
          'mnesens': [('mnes', False)],
          'mnesierna': [('mnesi', False)],
          'mnet': [('mn', False)],
          'mnets': [('mne', False)],
          'mngångarnas': [('mngångare', False)],
          'mnist': [('mnist', False)],
          'mnit': [('mnit', False)],
          'mnor': [('mna', False)],
          'mnorna': [('mna', False)],
          'mnornas': [('mna', False)],
          'mnors': [('mna', False)],
          'mns': [('mn', False)],
          'mns-': [('mn', False)],
          'mnsdagar': [('mnsdag', False)],
          'mnsdagarna': [('mnsdag', False)],
          'mnsdagarnas': [('mnsdag', False)],
          'mnsdagars': [('mnsdag', False)],
          'mnsdags': [('mnsdag', False)],
          'mnsdags-': [('mnsdag', False)],
          'mnstans': [('mnstad', False)],
          'mntagets': [('mntag', False)],
          'mo': [('mo', True)],
          'mo-': [('mo', True)],
          'moan': [('moan', False)],
          'moans': [('moan', False)],
          'moar': [('mo', True)],
          'moars': [('mo', True)],
          'mobb': [('mobb', False)],
          'mobbens': [('mobb', False)],
          'mobbs': [('mobb', True)],
          'mobbs-': [('mobb', True)],
          'mock': [('mocka', False)],
          'mock-': [('mock', False)],
          'mockar': [('mock', False)],
          'mockarna': [('mock', False)],
          'mocken': [('mock', False)],
          'mockens': [('mock', False)],
          'mocks': [('mock', False)],
          'mocks-': [('mock', False)],
          'modans': [('modan', False)],
          'modds': [('modd', True)],
          'modds-': [('modd', False)],
          'mode': [('mode', True)],
          'mode-': [('mode', False)],
          'models': [('modrar', False)],
          'models-': [('modrar', False)],
          'moden': [('mode', False)],
          'modens': [('mode', True)],
          'moder': [('moder', True), ('mor', True)],
          'moder-': [('moder', True), ('mor', True)],
          'modern': [('moder', True), ('mor', True)],
          'moderns': [('moder', True), ('mor', True)],
          'moders': [('mor', True), ('moder', True)],
          'moders-': [('moder', True), ('mor', True)],
          'modes': [('mode', True)],
          'modet': [('mod', True), ('mode', True)],
          'modets': [('mode', True), ('mod', True)],
          'modiers': [('modi', False)],
          'modis': [('modi', False)],
          'mods': [('mods', True), ('mod', True)],
          'mods-': [('mods', True), ('mod', True)],
          'moge': [('moge', False)],
          'moge-': [('moge', False)],
          'mogen': [('moge', False)],
          'mogens': [('moge', False)],
          'mogrammet': [('mogram', False)],
          'mogrammets': [('mogram', False)],
          'mojan': [('moja', False)],
          'mojans': [('moja', False)],
          'mojets': [('moj', True)],
          'mojs': [('mojs', True), ('moj', True)],
          'mojs-': [('moj', True), ('mojs', True)],
          'mokar': [('mokare', True)],
          'mokarens': [('mokare', False)],
          'mokarna': [('mokare', False)],
          'mokarnas': [('mokare', True)],
          'molar': [('molar', True)],
          'molaren': [('molar', False)],
          'molars': [('molar', True)],
          'molets': [('mol', False)],
          'molk': [('molk', False)],
          'molk-': [('molk', False)],
          'molks': [('molk', False)],
          'molks-': [('molk', False)],
          'moll': [('moll', True)],
          'moll-': [('moll', True)],
          'mollen': [('moll', True)],
          'mollens': [('moll', True)],
          'molls': [('moll', True)],
          'mologier': [('mologi', False)],
          'mologierna': [('mologi', False)],
          'mologiers': [('mologi', False)],
          'molon': [('molo', True)],
          'molons': [('molo', True)],
          'molor': [('molo', True)],
          'molorna': [('molo', True)],
          'molornas': [('molo', True)],
          'molors': [('molo', True)],
          'molos': [('molo', True)],
          'molos-': [('molo', True)],
          'molt-': [('molt', False)],
          'molts': [('molt', False)],
          'molts-': [('molt', False)],
          'mometer': [('mometer', False)],
          'mometers': [('mometer', False)],
          'mområdets': [('mområde', False)],
          'moms': [('moms', True)],
          'moms-': [('moms', True)],
          'momsen': [('moms', True)],
          'mon': [('mo', False)],
          'mon-': [('mon', False)],
          'mona': [('mo', False)],
          'monas': [('mo', False)],
          'mond': [('mond', False)],
          'mond-': [('mond', False)],
          'monden': [('mond', False)],
          'mondens': [('mond', False)],
          'monder': [('mond', False)],
          'monders': [('mond', False)],
          'monds': [('mond', False)],
          'monds-': [('mond', False)],
          'mong': [('mong', False)],
          'mong-': [('mong', False)],
          'monger': [('mong', False)],
          'mongerna': [('mong', False)],
          'mongernas': [('mong', False)],
          'mongers': [('mong', False)],
          'mongs': [('mong', False)],
          'moni': [('moni', False)],
          'moni-': [('moni', False)],
          'monie': [('monium', False)],
          'monien': [('moni', False)],
          'moniens': [('moni', False)],
          'monier': [('monium', False)],
          'monierna': [('moni', False)],
          'moniernas': [('monium', False)],
          'moniers': [('monium', False)],
          'moniker': [('moniker', False)],
          'monikerna': [('moniker', False)],
          'monikernas': [('moniker', False)],
          'monikers': [('moniker', False)],
          'moniks-': [('monika', False)],
          'monin': [('moni', False)],
          'monins': [('moni', False)],
          'monis': [('moni', False)],
          'monnäs': [('monnä', False)],
          'monor': [('mono', False)],
          'monorna': [('mono', False)],
          'monornas': [('mono', False)],
          'monors': [('mono', False)],
          'mons': [('mo', True)],
          'mons-': [('mon', False)],
          'monster': [('monster', False)],
          'monsterna': [('monster', True)],
          'monsternas': [('monster', True)],
          'monsters': [('monster', True)],
          'monter': [('monter', True)],
          'monters': [('monter', True)],
          'mopar': [('mopar', False)],
          'mopar-': [('mopar', False)],
          'moparen': [('mopar', False)],
          'mopars': [('mopar', False)],
          'mopp': [('mopp', True), ('moppe', True)],
          'mopp-': [('mopp', True), ('moppe', True)],
          'moppar': [('mopp', True), ('moppe', True)],
          'mopparna': [('moppe', True), ('mopp', True)],
          'mopparnas': [('mopp', True), ('moppe', True)],
          'moppars': [('mopp', True), ('moppe', True)],
          'moppen': [('moppe', True), ('mopp', True)],
          'moppens': [('mopp', True), ('moppe', True)],
          'mopps': [('moppe', True), ('mopp', True)],
          'mopps-': [('mopp', True), ('moppe', True)],
          'mops': [('mops', True)],
          'mops-': [('mops', True)],
          'mopsar': [('mops', False)],
          'mopsarna': [('mops', False)],
          'mopsars': [('mops', False)],
          'mopsen': [('mops', False)],
          'mor': [('mor', True), ('mora', True)],
          'mor-': [('mora', True), ('mor', True)],
          'mora': [('mora', False)],
          'moran': [('mora', False)],
          'morans': [('mora', True)],
          'moras': [('mora', True), ('moras', True)],
          'morbrors-': [('morbror', True)],
          'mord': [('mord', False)],
          'mord-': [('mord', False)],
          'morden': [('mord', False)],
          'mordens': [('mord', False)],
          'mordnar': [('mordnare', False)],
          'mordnarna': [('mordnare', False)],
          'mordnarnas': [('mordnare', False)],
          'mords': [('mord', False)],
          'mords-': [('mord', False)],
          'morfin': [('morfin', True)],
          'morfins': [('morfin', True)],
          'morian': [('morian', True)],
          'morians': [('morian', True)],
          'morier': [('morier', False)],
          'morierna': [('morier', False)],
          'moriernas': [('morier', False)],
          'moriers': [('morier', False)],
          'morin': [('morin', False)],
          'morn': [('mor', False)],
          'morna': [('mo', False)],
          'mornar': [('morgon', False)],
          'mornarna': [('morgon', False)],
          'mornarnas': [('morgon', False)],
          'mornars': [('morgon', False)],
          'mornas': [('mo', False)],
          'morns': [('mor', False)],
          'moror': [('mora', False)],
          'mororna': [('mora', False)],
          'morornas': [('mora', True)],
          'morors': [('mora', True)],
          'morr': [('morr', True)],
          'morr-': [('morr', True)],
          'morrans': [('morra', False)],
          'morrs': [('morr', True)],
          'morrs-': [('morr', True)],
          'mors': [('mora', True), ('mor', True)],
          'mors-': [('mor', True), ('mora', True)],
          'morsor': [('morsa', False)],
          'morsorna': [('morsa', False)],
          'morsornas': [('morsa', True)],
          'morsors': [('morsa', False)],
          'morten': [('mort', False)],
          'morter': [('mort', False)],
          'morternas': [('mort', False)],
          'morters': [('mort', False)],
          'morts': [('mort', False)],
          'morts-': [('mort', False)],
          'mos': [('mos', True), ('mo', True)],
          'mos-': [('mo', True), ('mos', True)],
          'mosa': [('mosa', False)],
          'mosaiker': [('mosaik', True)],
          'mosaikerna': [('mosaik', True)],
          'mosaikernas': [('mosaik', True)],
          'mosaikers': [('mosaik', True)],
          'mosan': [('mosa', False)],
          'mosans': [('mosa', False)],
          'mosar': [('mos', False)],
          'mosarna': [('mo', False)],
          'mosarnas': [('mos', False)],
          'mosars': [('mos', False)],
          'mosas': [('mosa', False)],
          'mosin': [('mosin', False)],
          'moss': [('mosse', True), ('mossa', True)],
          'moss-': [('mosse', True), ('mossa', True)],
          'mossarna': [('mosse', False)],
          'mossarnas': [('mosse', False)],
          'mosse': [('mossa', True), ('mosse', True)],
          'mosse-': [('mossa', False)],
          'mostrar': [('moster', False)],
          'mostrarna': [('moster', False)],
          'mot': [('mot', False)],
          'mote': [('mote', False)],
          'mote-': [('mote', False)],
          'motes': [('mote', False)],
          'motet': [('mot', True)],
          'motets': [('mot', True)],
          'motor': [('motor', False)],
          'motors': [('motor', False)],
          'mots': [('mot', True)],
          'mott': [('mott', False)],
          'mott-': [('mott', False)],
          'motte': [('motte', False)],
          'motte-': [('motte', False)],
          'motten': [('mott', False)],
          'mottens': [('mott', True)],
          'motter': [('mott', False)],
          'motterna': [('mott', False)],
          'motternas': [('mott', False)],
          'motters': [('mott', False)],
          'mottin': [('motti', True)],
          'mottins': [('motti', True)],
          'motts': [('mott', True)],
          'motts-': [('mott', True)],
          'mours': [('mour', False)],
          'movar': [('movar', False)],
          'movaren': [('movar', False)],
          'movars': [('movar', False)],
          'mox': [('moxe', False)],
          'moxar': [('moxe', False)],
          'moxarnas': [('moxe', False)],
          'moxen': [('moxe', False)],
          'moxens': [('moxe', False)],
          'mp': [('mp', False)],
          'mp-': [('mp', False)],
          'mpakets': [('mpaket', False)],
          'mpande': [('mpande', False)],
          'mpande-': [('mpande', False)],
          'mpans-': [('mpans', False)],
          'mpar': [('mp', False)],
          'mpar-': [('mpar', False)],
          'mparen': [('mpare', False)],
          'mparens': [('mpar', False)],
          'mpares': [('mpare', False)],
          'mparna': [('mp', False)],
          'mpars': [('mp', False)],
          'mpars-': [('mpar', False)],
          'mparser': [('mpars', False)],
          'mparsers': [('mpars', False)],
          'mpatiens': [('mpati', False)],
          'mpatiernas': [('mpati', False)],
          'mpe': [('mpa', False)],
          'mpe-': [('mpa', False)],
          'mpelar': [('mpelare', False)],
          'mpelar-': [('mpelare', False)],
          'mpen': [('mp', False)],
          'mpengar': [('mpeng', False)],
          'mpengarna': [('mpeng', False)],
          'mpengarnas': [('mpeng', False)],
          'mpengars': [('mpeng', False)],
          'mpenning': [('mpenning', False)],
          'mpenningar': [('mpenning', False)],
          'mpenningarna': [('mpenning', False)],
          'mpenningarnas': [('mpenning', False)],
          'mpenningars': [('mpenning', False)],
          'mpennings': [('mpenning', False)],
          'mpennings-': [('mpenning', False)],
          'mpens': [('mp', False)],
          'mper': [('mp', False)],
          'mperier': [('mperium', False)],
          'mperierna': [('mperium', False)],
          'mperiernas': [('mperi', False)],
          'mperiers': [('mperi', False)],
          'mperiet': [('mperium', False)],
          'mperiets': [('mperi', False)],
          'mperits': [('mperi', False)],
          'mperna': [('mp', False)],
          'mpernas': [('mp', False)],
          'mpers': [('mp', False)],
          'mpers-': [('mper', False)],
          'mpersen': [('mper', False)],
          'mpersens': [('mper', False)],
          'mpet': [('mp', False)],
          'mpetarnas': [('mpetare', False)],
          'mpetens': [('mpet', False)],
          'mpeter': [('mpet', False)],
          'mpeters': [('mpet', False)],
          'mpets': [('mp', False)],
          'mpets-': [('mpet', False)],
          'mpetter': [('mpett', False)],
          'mphets': [('mphet', False)],
          'mpi': [('mpo', False)],
          'mpier': [('mpier', False)],
          'mpierna': [('mpier', False)],
          'mpiernas': [('mpier', False)],
          'mpiers': [('mpier', False)],
          'mpinell': [('mpinella', False)],
          'mpinell-': [('mpinella', False)],
          'mpinells': [('mpinella', False)],
          'mpinells-': [('mpinella', False)],
          'mpinnarnas': [('mpinne', False)],
          'mpinnens': [('mpinne', False)],
          'mpinns': [('mpinne', False)],
          'mpir-': [('mpir', False)],
          'mpire': [('mpire', False)],
          'mpire-': [('mpire', False)],
          'mpirin': [('mpiri', False)],
          'mpis': [('mpo', False)],
          'mpis-': [('mpis', False)],
          'mpisar': [('mpis', False)],
          'mpisarna': [('mpis', False)],
          'mpisars': [('mpis', False)],
          'mplandets': [('mplande', False)],
          'mplants': [('mplanta', False)],
          'mplants-': [('mplanta', False)],
          'mplar': [('mpel', False)],
          'mplarna': [('mpel', False)],
          'mplarnas': [('mpel', False)],
          'mplars': [('mpel', False)],
          'mplen': [('mpel', False)],
          'mplens': [('mpel', False)],
          'mplet': [('mplet', False)],
          'mplets': [('mpel', False)],
          'mplotter': [('mplott', False)],
          'mplotters': [('mplott', False)],
          'mpo-': [('mpo', False)],
          'mpor': [('mpa', False)],
          'mporna': [('mpa', False)],
          'mpornas': [('mpa', False)],
          'mpors': [('mpa', False)],
          'mportarnas': [('mport', False)],
          'mporter': [('mport', False)],
          'mporterna': [('mport', False)],
          'mporternas': [('mport', False)],
          'mporters': [('mport', False)],
          'mpositas': [('mpositum', False)],
          'mposter': [('mpost', False)],
          'mposters': [('mpost', False)],
          'mpot': [('mpo', False)],
          'mpott': [('mpott', False)],
          'mpott-': [('mpott', False)],
          'mpotts': [('mpott', False)],
          'mpotts-': [('mpott', False)],
          'mps': [('mp', False)],
          'mps-': [('mp', False)],
          'mpsen': [('mpus', False)],
          'mpsens': [('mpus', False)],
          'mpset': [('mpus', False)],
          'mpsets': [('mpus', False)],
          'mpsins': [('mpsi', False)],
          'mpstick-': [('mpsticka', False)],
          'mpsticks': [('mpsticka', False)],
          'mptus': [('mptu', False)],
          'mpull': [('mpull', False)],
          'mpull-': [('mpull', False)],
          'mpulls': [('mpull', False)],
          'mpulls-': [('mpull', False)],
          'mpump': [('mpump', False)],
          'mpumps': [('mpump', False)],
          'mpumps-': [('mpump', False)],
          'mpyren': [('mpyr', False)],
          'mpyrens': [('mpyr', False)],
          'mpyrer': [('mpyr', False)],
          'mpyrerna': [('mpyr', False)],
          'mpyrernas': [('mpyr', False)],
          'mpyrs': [('mpyr', False)],
          'mpörten': [('mpört', False)],
          'mpörtens': [('mpört', False)],
          'mpörts': [('mpört', False)],
          'mpörts-': [('mpört', False)],
          'mrande': [('mrande', False)],
          'mrande-': [('mrande', False)],
          'mranden': [('mrande', False)],
          'mrandens': [('mrande', False)],
          'mrandet': [('mrande', False)],
          'mrar': [('mmar', False)],
          'mras': [('mras', False)],
          'mrat': [('mrat', False)],
          'mraten': [('mrat', False)],
          'mratens': [('mrat', False)],
          'mrater': [('mrat', False)],
          'mraterna': [('mrat', False)],
          'mraternas': [('mrat', False)],
          'mraters': [('mrat', False)],
          'mrats': [('mrat', False)],
          'mren': [('mmer', False)],
          'mrenarna': [('mren', False)],
          'mrens': [('mmer', False)],
          'mrer': [('mrer', False)],
          'mrerna': [('mrer', False)],
          'mrernas': [('mrer', False)],
          'mrers': [('mrer', False)],
          'mrese': [('mresa', False)],
          'mrese-': [('mresa', False)],
          'mret': [('mmer', False)],
          'mrets': [('mmer', False)],
          'mrighets': [('mrighet', False)],
          'mrik': [('mrik', False)],
          'mrik-': [('mrik', False)],
          'mrikar': [('mrik', False)],
          'mrikarna': [('mrik', False)],
          'mrikars': [('mrik', False)],
          'mriken': [('mrik', False)],
          'mrikens': [('mrik', False)],
          'mriks': [('mrik', False)],
          'mriks-': [('mrik', False)],
          'mringar': [('mring', False)],
          'mringarna': [('mring', False)],
          'mringarnas': [('mring', False)],
          'mrisk': [('mriska', False)],
          'mrisk-': [('mriska', False)],
          'mrod': [('mrod', False)],
          'mrod-': [('mrod', False)],
          'mrods': [('mrod', False)],
          'mrods-': [('mrod', False)],
          'mroller': [('mroll', False)],
          'mrollerna': [('mroll', False)],
          'mrollernas': [('mroll', False)],
          'mrollers': [('mroll', False)],
          'mrolls': [('mroll', False)],
          'mrolls-': [('mroll', False)],
          'mromans': [('mroman', False)],
          'mros': [('mro', False)],
          'mros-': [('mro', False)],
          'mrot': [('mrot', False)],
          'mroten': [('mrot', False)],
          'mrotens': [('mrot', False)],
          'mrots': [('mrot', False)],
          'mrots-': [('mrot', False)],
          'mrs': [('mrs', True)],
          'mrull': [('mrulle', False)],
          'mrull-': [('mrulle', False)],
          'mrulle': [('mrulle', False)],
          'mrulle-': [('mrulle', False)],
          'mrulls': [('mrulle', False)],
          'mrulls-': [('mrulle', False)],
          'mrum': [('mrum', False)],
          'mrums-': [('mrum', False)],
          'mråden': [('mråd', False)],
          'mrådens': [('mråde', False)],
          'mrökens': [('mrök', False)],
          'mröre': [('mröre', False)],
          'mröre-': [('mröre', False)],
          'mröret': [('mröre', False)],
          'mrörets': [('mröre', False)],
          'ms': [('m', True)],
          'msage': [('msaga', False)],
          'msage-': [('msaga', False)],
          'msago': [('msaga', False)],
          'msago-': [('msaga', False)],
          'msaker': [('msak', False)],
          'msakerna': [('msak', False)],
          'msakernas': [('msak', False)],
          'msanden': [('msande', False)],
          'msandens': [('msande', False)],
          'msans': [('msa', False)],
          'msar': [('ms', False)],
          'msaren': [('msare', False)],
          'msarna': [('ms', False)],
          'msars': [('ms', False)],
          'msback-': [('msback', False)],
          'msbackar': [('msback', False)],
          'msbackars': [('msback', False)],
          'msbacken': [('msback', False)],
          'msbackens': [('msback', False)],
          'msbacks-': [('msback', False)],
          'mse': [('msa', False)],
          'mse-': [('msa', False)],
          'mseffekterna': [('mseffekter', False)],
          'msel': [('msel', False)],
          'msel-': [('msel', False)],
          'msels': [('msel', False)],
          'msen': [('ms', False)],
          'msens': [('ms', False)],
          'mser': [('ms', False)],
          'mserna': [('ms', False)],
          'msernas': [('ms', False)],
          'msers': [('ms', False)],
          'mset': [('ms', False)],
          'msförsäkringars': [('msförsäkring', False)],
          'mshopp': [('mshopp', False)],
          'mshopps': [('mshopp', False)],
          'mshopps-': [('mshopp', False)],
          'msidan': [('msida', False)],
          'msidans': [('msida', False)],
          'mside': [('msida', False)],
          'msides': [('msida', False)],
          'msikten': [('msikt', False)],
          'msiktens': [('msikt', False)],
          'msk': [('msk', True)],
          'msk-': [('msk', True)],
          'mskallen': [('mskalle', False)],
          'mskallens': [('mskalle', False)],
          'mskan': [('mska', False)],
          'mskans': [('mska', False)],
          'mskaps-': [('mskap', False)],
          'mskar': [('mske', False)],
          'mskarna': [('mske', False)],
          'mskarnas': [('mske', False)],
          'mskars': [('mske', False)],
          'mske': [('mske', False)],
          'msken': [('mske', False)],
          'mskens': [('mske', False)],
          'mskes': [('mske', False)],
          'mskes-': [('mske', False)],
          'mskiften': [('mskifte', False)],
          'mskiftens': [('mskifte', False)],
          'mskiftet': [('mskifte', False)],
          'mskiftets': [('mskifte', False)],
          'msko': [('msko', False)],
          'mskonst': [('mskonst', False)],
          'mskor': [('msko', False)],
          'mskorna': [('msko', False)],
          'mskornas': [('msko', False)],
          'mskors': [('msko', False)],
          'mskott': [('mskott', False)],
          'mskotten': [('mskott', False)],
          'mskottens': [('mskott', False)],
          'mskotts-': [('mskott', False)],
          'mskrams-': [('mskrams', False)],
          'mskäll': [('mskälla', False)],
          'mskäll-': [('mskälla', False)],
          'mskälls': [('mskälla', False)],
          'mskälls-': [('mskälla', False)],
          'mslag': [('mslag', False)],
          'mslagar': [('mslagare', False)],
          'mslagarna': [('mslagare', False)],
          'mslagarnas': [('mslagare', False)],
          'mslags': [('mslag', False)],
          'mslags-': [('mslag', False)],
          'mslan': [('msla', False)],
          'mslandet': [('msland', False)],
          'mslans': [('msla', False)],
          'mslas': [('msla', False)],
          'msle': [('msle', False)],
          'msle-': [('msle', False)],
          'mslet': [('msle', False)],
          'mslotts': [('mslott', False)],
          'mslån': [('mslå', False)],
          'mslåns': [('mslå', False)],
          'mslås': [('mslås', False)],
          'mslås-': [('mslås', False)],
          'msnäpp': [('msnäppa', False)],
          'msnäpp-': [('msnäppa', False)],
          'msnäpps': [('msnäppa', False)],
          'msnäpps-': [('msnäppa', False)],
          'msnåret': [('msnåret', False)],
          'msnårets': [('msnåret', False)],
          'msområdet': [('msområde', False)],
          'msor': [('msa', False)],
          'msorna': [('msa', False)],
          'msornas': [('msa', False)],
          'msors': [('msa', False)],
          'mspen': [('mspene', False)],
          'mspens': [('mspene', False)],
          'mspens-': [('mspene', False)],
          'msregionen': [('msregion', False)],
          'msregionens': [('msregion', False)],
          'msringar': [('msring', False)],
          'mstackar': [('mstack', False)],
          'mstackarna': [('mstack', False)],
          'mstackarnas': [('mstack', False)],
          'mstammar': [('mstam', False)],
          'mstammarna': [('mstam', False)],
          'mstammarnas': [('mstam', False)],
          'mstanden': [('mstand', False)],
          'mstandens': [('mstand', False)],
          'mstank': [('mstanke', False)],
          'mstank-': [('mstanke', False)],
          'mstankarna': [('mstanke', False)],
          'mstankarnas': [('mstanke', False)],
          'mstanken': [('mstanke', False)],
          'mstankens': [('mstanke', False)],
          'mstanks': [('mstanke', False)],
          'mstanks-': [('mstanke', False)],
          'mstans': [('mstad', False)],
          'mstar': [('mstare', False)],
          'mstar-': [('mstare', False)],
          'mstars': [('mstare', False)],
          'mstarter': [('mstart', False)],
          'mstarterna': [('mstart', False)],
          'mstarternas': [('mstart', False)],
          'mstarters': [('mstart', False)],
          'mstavarna': [('mstav', False)],
          'mstdags': [('mstdag', False)],
          'mstdags-': [('mstdag', False)],
          'mste': [('mste', False)],
          'mste-': [('mste', False)],
          'msteg': [('msteg', False)],
          'msteg-': [('msteg', False)],
          'mstegen': [('msteg', False)],
          'mstegens': [('msteg', False)],
          'mstegs': [('msteg', False)],
          'mstegs-': [('msteg', False)],
          'mstekar': [('mstek', False)],
          'mstekarna': [('mstek', False)],
          'mstekarnas': [('mstek', False)],
          'msten': [('mst', False)],
          'mstens': [('mst', False)],
          'mster': [('mster', False)],
          'msters': [('mster', False)],
          'mstet': [('mste', False)],
          'mstick': [('msticka', False)],
          'mstick-': [('msticka', False)],
          'msticks': [('msticka', False)],
          'msticks-': [('msticka', False)],
          'mstol': [('mstol', False)],
          'mstol-': [('mstol', False)],
          'mstols': [('mstol', False)],
          'mstols-': [('mstol', False)],
          'mstranden': [('mstrande', False)],
          'mstrandens': [('mstrande', False)],
          'mstrarnas': [('mster', False)],
          'mstringens': [('mstring', False)],
          'mstrum': [('mstrumma', False)],
          'mstrums-': [('mstrumma', False)],
          'mstruts': [('mstrut', False)],
          'mstruts-': [('mstrut', False)],
          'mstrån': [('mstrå', False)],
          'mstråns': [('mstrå', False)],
          'mstråt': [('mstrå', False)],
          'mstråts': [('mstrå', False)],
          'mstump': [('mstump', False)],
          'mstump-': [('mstump', False)],
          'mstumps': [('mstump', False)],
          'mstumps-': [('mstump', False)],
          'mstycken': [('mstycke', False)],
          'mstyckena': [('mstycke', False)],
          'mstyckenas': [('mstycke', False)],
          'mstyckens': [('mstycke', False)],
          'mstycket': [('mstycke', False)],
          'mstyckets': [('mstycke', False)],
          'mstycks': [('mstycke', False)],
          'mstyrkan': [('mstyrka', False)],
          'mstyrke': [('mstyrka', False)],
          'mställanden': [('mställande', False)],
          'mställandena': [('mställande', False)],
          'mställandenas': [('mställande', False)],
          'mställandens': [('mställande', False)],
          'mställen': [('mställ', False)],
          'mställens': [('mställe', False)],
          'mstället': [('mställ', False)],
          'mställets': [('mställ', False)],
          'mställningar': [('mställning', False)],
          'mställningarna': [('mställning', False)],
          'mställningarnas': [('mställning', False)],
          'mställningars': [('mställning', False)],
          'mställnings': [('mställning', False)],
          'mställnings-': [('mställning', False)],
          'mständer': [('mstand', False)],
          'mständerna': [('mstand', False)],
          'mständernas': [('mstand', False)],
          'mständers': [('mstand', False)],
          'mstötarnas': [('mstöt', False)],
          'msug': [('msug', False)],
          'msugar': [('msugare', False)],
          'msugarnas': [('msugare', False)],
          'msun': [('msu', False)],
          'msuns': [('msu', False)],
          'msus': [('msu', False)],
          'msvale': [('msvala', False)],
          'msverken': [('msverk', False)],
          'msverkens': [('msverk', False)],
          'msverket': [('msverk', False)],
          'msverks': [('msverk', False)],
          'msverks-': [('msverk', False)],
          'msving-': [('msving', False)],
          'msvingar': [('msving', False)],
          'msvingarnas': [('msving', False)],
          'msvingars': [('msving', False)],
          'msvingen': [('msving', False)],
          'msyns': [('msyn', False)],
          'msyre': [('msyra', False)],
          'msyre-': [('msyra', False)],
          'mt': [('mt', False)],
          'mt-': [('mt', False)],
          'mtagen': [('mtag', False)],
          'mtagens': [('mtag', False)],
          'mtaget': [('mtag', False)],
          'mtak': [('mtak', False)],
          'mtaken': [('mtak', False)],
          'mtaket': [('mtak', False)],
          'mtalandena': [('mtalande', False)],
          'mtalandenas': [('mtalande', False)],
          'mtalen': [('mtal', False)],
          'mtalens': [('mtal', False)],
          'mtalet': [('mtal', False)],
          'mtan': [('mta', False)],
          'mtanden': [('mtande', False)],
          'mtandens': [('mtande', False)],
          'mtank-': [('mtank', False)],
          'mtankar': [('mtank', False)],
          'mtankarna': [('mtank', False)],
          'mtankarnas': [('mtank', False)],
          'mtankars': [('mtank', False)],
          'mtanke-': [('mtanke', False)],
          'mtanken': [('mtank', False)],
          'mtankens': [('mtank', False)],
          'mtanks': [('mtank', False)],
          'mtanks-': [('mtank', False)],
          'mtans': [('mta', False)],
          'mtar': [('mte', False)],
          'mtaren': [('mtare', False)],
          'mtarna': [('mte', False)],
          'mtarnas': [('mte', False)],
          'mtars': [('mt', False)],
          'mten': [('mt', False)],
          'mtens': [('mt', False)],
          'mter': [('mt', False)],
          'mterier': [('mteri', False)],
          'mterierna': [('mteri', False)],
          'mteriernas': [('mteri', False)],
          'mteriets': [('mteri', False)],
          'mterits': [('mteri', False)],
          'mterna': [('mt', False)],
          'mternas': [('mt', False)],
          'mters': [('mt', False)],
          'mtes': [('mte', False)],
          'mtes-': [('mte', False)],
          'mtet': [('mt', False)],
          'mtets': [('mt', False)],
          'mtiden': [('mtid', False)],
          'mtidens': [('mtiden', False)],
          'mtiders': [('mtid', False)],
          'mtions-': [('mtion', False)],
          'mtmans': [('mtman', False)],
          'mtom-': [('mtom', False)],
          'mtoms': [('mtom', False)],
          'mtonerna': [('mton', False)],
          'mtox-': [('mtoxe', False)],
          'mtrav': [('mtrave', False)],
          'mtrav-': [('mtrave', False)],
          'mtravar': [('mtrave', False)],
          'mtravarna': [('mtrave', False)],
          'mtravarnas': [('mtrave', False)],
          'mtraven': [('mtrave', False)],
          'mtravens': [('mtrave', False)],
          'mtravs': [('mtrave', False)],
          'mtravs-': [('mtrave', False)],
          'mtricks': [('mtrick', False)],
          'mtricks-': [('mtrick', False)],
          'mtrycken': [('mtryck', False)],
          'mtryckens': [('mtryck', False)],
          'mtrycket': [('mtryck', False)],
          'mtryckets': [('mtryck', False)],
          'mtrycks': [('mtryck', False)],
          'mtrycks-': [('mtryck', False)],
          'mträd': [('mträd', False)],
          'mträd-': [('mträd', False)],
          'mträden': [('mträd', False)],
          'mträdens': [('mträd', False)],
          'mträdet': [('mträd', False)],
          'mträdets': [('mträd', False)],
          'mträds': [('mträd', False)],
          'mträn': [('mträd', False)],
          'mträna': [('mträd', False)],
          'mtränas': [('mträd', False)],
          'mträns': [('mträd', False)],
          'mts': [('mt', False)],
          'mts-': [('mt', False)],
          'mtsk': [('mtska', False)],
          'mtsk-': [('mtska', False)],
          'mtskor': [('mtska', False)],
          'mtskorna': [('mtska', False)],
          'mtskornas': [('mtska', False)],
          'mtskors': [('mtska', False)],
          'mturer': [('mtur', False)],
          'mtyckens': [('mtycke', False)],
          'mtycket': [('mtycke', False)],
          'mtycks': [('mtycke', False)],
          'mtändar': [('mtändare', False)],
          'mtänder': [('mtand', False)],
          'mtänders': [('mtand', False)],
          'mtåg': [('mtåg', False)],
          'mtågs': [('mtåg', False)],
          'mtågs-': [('mtåg', False)],
          'mu': [('mu', False)],
          'muck': [('muck', True)],
          'muck-': [('muck', True)],
          'muckarnas': [('muckare', True)],
          'mucker': [('muck', False)],
          'muckerna': [('muck', False)],
          'muckernas': [('muck', False)],
          'muckers': [('muck', False)],
          'mucks': [('muck', True)],
          'mucks-': [('muck', False)],
          'mudd': [('mudd', True)],
          'mudd-': [('mudd', True)],
          'muddar': [('mudd', True)],
          'muddarna': [('mudd', False)],
          'muddarnas': [('mudd', False)],
          'muddars': [('mudd', True)],
          'mudden': [('mudd', False)],
          'muddens': [('mudd', False)],
          'mudds': [('mudd', True)],
          'mudds-': [('mudd', False)],
          'muer': [('mu', False)],
          'muerna': [('mu', False)],
          'muernas': [('mu', False)],
          'muers': [('mu', False)],
          'muff': [('muff', False)],
          'muff-': [('muff', False)],
          'muffar': [('muff', True)],
          'muffarna': [('muff', True)],
          'mufflar': [('muffel', True)],
          'mufflarna': [('muffel', True)],
          'mufflarnas': [('muffel', True)],
          'muffs': [('muff', False)],
          'muffs-': [('muff', True)],
          'mugg': [('mugg', False)],
          'mugg-': [('mugg', True)],
          'muggar': [('mugg', False)],
          'muggarna': [('mugg', False)],
          'muggarnas': [('mugg', True)],
          'muggars': [('mugg', False)],
          'muggen': [('mugg', False)],
          'muggens': [('mugg', False)],
          'muggs': [('mugg', False)],
          'muggs-': [('mugg', False)],
          'mul': [('mule', True), ('mula', True)],
          'mul-': [('mule', True), ('mula', True)],
          'mula': [('mula', False)],
          'mulan': [('mula', False)],
          'mulans': [('mula', True)],
          'mular': [('mule', False)],
          'mularnas': [('mule', False)],
          'mulars': [('mule', True)],
          'mulas': [('mula', False)],
          'mule': [('mula', True), ('mule', True)],
          'mulen': [('mule', True)],
          'mulens': [('mule', False)],
          'mull': [('mull', False)],
          'mull-': [('mull', True)],
          'mulls': [('mull', False)],
          'mulls-': [('mull', False)],
          'mulor': [('mula', True)],
          'mulorna': [('mula', True)],
          'mulornas': [('mula', True)],
          'mulors': [('mula', True)],
          'muls': [('mula', True), ('mule', True)],
          'muls-': [('mule', True), ('mula', True)],
          'mult': [('multe', True)],
          'mult-': [('multe', True)],
          'multarnas': [('multe', True)],
          'multen': [('multe', True)],
          'multens': [('multe', True)],
          'multet': [('mult', False)],
          'mults': [('multe', True)],
          'mults-': [('multe', True)],
          'mulus': [('mulus', False)],
          'mumlet': [('mummel', True)],
          'mumlets': [('mummel', True)],
          'mums': [('mums', False)],
          'mums-': [('mums', False)],
          'mumsar': [('mums', False)],
          'mumsarna': [('mums', False)],
          'mumsars': [('mums', False)],
          'mumsen': [('mums', False)],
          'mumsens': [('mums', False)],
          'mumset': [('mums', False)],
          'mun': [('mun', False)],
          'mund': [('mund', False)],
          'mund-': [('mund', False)],
          'munds': [('mund', False)],
          'mungo': [('mungo', True)],
          'mungo-': [('mungo', True)],
          'mungornas': [('mungo', True)],
          'mungors': [('mungo', True)],
          'munk': [('munk', False)],
          'munk-': [('munk', True)],
          'munkarnas': [('munk', False)],
          'munkars': [('munk', False)],
          'munkavlar': [('munkavle', True), ('munkavel', True)],
          'munkavlarna': [('munkavle', True), ('munkavel', True)],
          'munkavlarnas': [('munkavel', True), ('munkavle', True)],
          'munkavlars': [('munkavel', True), ('munkavle', True)],
          'munken': [('munk', True)],
          'munkens': [('munk', False)],
          'munks': [('munk', False)],
          'munks-': [('munk', False)],
          'munnarna': [('mun', False)],
          'munnarnas': [('mun', False)],
          'munnars': [('mun', False)],
          'muns': [('mun', False)],
          'muns-': [('mun', False)],
          'mupp': [('mupp', True)],
          'mupp-': [('mupp', True)],
          'muppar': [('mupp', True)],
          'mupparna': [('mupp', True)],
          'mupps': [('mupp', True)],
          'mupps-': [('mupp', True)],
          'murar': [('mur', True), ('murare', True)],
          'murarna': [('mur', True), ('murare', True)],
          'murarnas': [('murare', True), ('mur', True)],
          'murfarna': [('murf', False)],
          'murr': [('murr', True), ('murre', True)],
          'murr-': [('murr', True), ('murre', True)],
          'murrens': [('murre', False)],
          'murrs': [('murr', True), ('murre', True)],
          'murrs-': [('murr', True), ('murre', True)],
          'mursten': [('mursten', True)],
          'murstens': [('mursten', True)],
          'mus': [('mus', True)],
          'musan': [('musa', True)],
          'musans': [('musa', True)],
          'musarnas': [('mus', False)],
          'muser': [('musa', True)],
          'muserna': [('musa', True)],
          'musernas': [('musa', True)],
          'musers': [('musa', True)],
          'mussel': [('mussla', True)],
          'mussel-': [('mussla', True)],
          'must-': [('must', False)],
          'muster': [('must', True)],
          'musterna': [('must', True)],
          'musternas': [('must', True)],
          'musters': [('must', True)],
          'mut': [('muta', True)],
          'mut-': [('muta', True)],
          'mutan': [('muta', True)],
          'mutar': [('mutare', False)],
          'mutarna': [('mutare', False)],
          'mutarnas': [('mutare', False)],
          'muts': [('muta', True)],
          'muts-': [('muta', True)],
          'mutsanden': [('mutsande', False)],
          'mutsandens': [('mutsande', False)],
          'mutsarnas': [('mutsare', False)],
          'mutsen': [('muts', False)],
          'mutsens': [('muts', False)],
          'mutt': [('mutta', True)],
          'mutt-': [('mutta', True)],
          'muttar': [('mutt', False)],
          'muttars': [('mutt', False)],
          'mutte': [('mutta', True)],
          'mutten': [('mutt', False)],
          'mutträden': [('mutträd', False)],
          'mutträdens': [('mutträd', False)],
          'mutträdet': [('mutträd', False)],
          'mutträdets': [('mutträd', False)],
          'mutts': [('mutta', True)],
          'mutts-': [('mutta', True)],
          'mvalen': [('mval', False)],
          'mvalens': [('mval', False)],
          'mvals': [('mval', False)],
          'mvals-': [('mval', False)],
          'mvant': [('mvante', False)],
          'mvant-': [('mvante', False)],
          'mvanten': [('mvante', False)],
          'mvantens': [('mvante', False)],
          'mvants': [('mvante', False)],
          'mvants-': [('mvante', False)],
          'mvar': [('mvara', False)],
          'mvar-': [('mvara', False)],
          'mvaran': [('mvara', False)],
          'mvarans': [('mvara', False)],
          'mvas': [('mvas', False)],
          'mvas-': [('mvas', False)],
          'mvasen': [('mvas', False)],
          'mvasens': [('mvas', False)],
          'mveck': [('mveck', False)],
          'mveck-': [('mveck', False)],
          'mvecks': [('mveck', False)],
          'mvecks-': [('mveck', False)],
          'mvets': [('mvete', False)],
          'mviktar': [('mviktare', False)],
          'mviktarna': [('mviktare', False)],
          'mvill': [('mvilla', False)],
          'mvills': [('mvilla', False)],
          'mvin': [('mvin', False)],
          'mvind': [('mvind', False)],
          'mvinds': [('mvind', False)],
          'mvinds-': [('mvind', False)],
          'mving': [('mvinge', False)],
          'mving-': [('mvinge', False)],
          'mvingar': [('mvinge', False)],
          'mvingarna': [('mvinge', False)],
          'mvingarnas': [('mvinge', False)],
          'mvingars': [('mvinge', False)],
          'mvingen': [('mvinge', False)],
          'mvingens': [('mvinge', False)],
          'mvings': [('mvinge', False)],
          'mvings-': [('mvinge', False)],
          'mvins': [('mvin', False)],
          'mvins-': [('mvin', False)],
          'mvipp': [('mvippa', False)],
          'mvipp-': [('mvippa', False)],
          'mvipps': [('mvippa', False)],
          'mvipps-': [('mvippa', False)],
          'mvir': [('mvir', False)],
          'mvir-': [('mvir', False)],
          'mvirs': [('mvir', False)],
          'mvirs-': [('mvir', False)],
          'mvisar': [('mvisare', False)],
          'mvisarna': [('mvisare', False)],
          'mvisarnas': [('mvisare', False)],
          'mvist': [('mvist', False)],
          'mvist-': [('mvist', False)],
          'mvisten': [('mvist', False)],
          'mvistens': [('mvist', False)],
          'mvistet': [('mvist', False)],
          'mvistets': [('mvist', False)],
          'mvreden': [('mvred', False)],
          'mvredens': [('mvred', False)],
          'mvägar': [('mväg', False)],
          'mvägarna': [('mväg', False)],
          'mvägarnas': [('mväg', False)],
          'mvägs': [('mväg', False)],
          'mvälden': [('mvälde', False)],
          'mväldens': [('mvälde', False)],
          'mvärden': [('mvärd', False)],
          'mvärdens': [('mvärd', False)],
          'mväsendet': [('mväsen', False)],
          'mväsendets': [('mväsen', False)],
          'my': [('my', True)],
          'my-': [('my', True)],
          'myckets': [('mycke', False)],
          'myckningar': [('myckning', False)],
          'myckningarna': [('myckning', False)],
          'myckningarnas': [('myckning', False)],
          'myckningars': [('myckning', False)],
          'mycknings': [('myckning', False)],
          'mycknings-': [('myckning', False)],
          'myen': [('my', True)],
          'myens': [('my', True)],
          'myer': [('my', False)],
          'myerna': [('my', False)],
          'myernas': [('my', False)],
          'myers': [('my', False)],
          'mygg': [('mygg', True), ('mygga', True)],
          'mygg-': [('mygg', True), ('mygga', True)],
          'mygge': [('mygga', False)],
          'myggen': [('mygg', True)],
          'myggens': [('mygg', True)],
          'mygget': [('mygg', True)],
          'myggs': [('mygg', True), ('mygga', True)],
          'myggs-': [('mygg', True), ('mygga', True)],
          'myglar': [('myglare', True)],
          'myglarna': [('myglare', True)],
          'myglarnas': [('myglare', True)],
          'myllan': [('mylla', True)],
          'myllandet': [('myllande', True)],
          'mylle': [('mylla', True)],
          'mylle-': [('mylla', True)],
          'myn': [('my', True)],
          'myna': [('my', True)],
          'mynas': [('my', True)],
          'myns': [('my', False)],
          'mynt': [('mynta', True), ('mynt', True)],
          'mynt-': [('mynta', True), ('mynt', True)],
          'myntar': [('myntare', False)],
          'myntarnas': [('myntare', False)],
          'myntet': [('mynt', False)],
          'mynts': [('mynta', True), ('mynt', True)],
          'mynts-': [('mynta', True), ('mynt', True)],
          'myon': [('myon', True)],
          'myons': [('myon', True)],
          'myr': [('myr', True), ('myra', True)],
          'myr-': [('myr', True), ('myra', True)],
          'myrs': [('myr', True), ('myra', True)],
          'myrs-': [('myr', True), ('myra', True)],
          'mys': [('my', True), ('mys', True)],
          'mys-': [('my', True), ('mys', True)],
          'mysarna': [('my', False)],
          'mysets': [('mys', True)],
          'mysk': [('mysk', True)],
          'mysk-': [('mysk', True)],
          'mysterier': [('mysterium', True)],
          'mysterierna': [('mysterium', True)],
          'mysteriers': [('mysterium', True)],
          'mysteriet': [('mysterium', True)],
          'myt': [('my', True), ('myt', True)],
          'myt-': [('myt', True)],
          'mytets': [('myt', False)],
          'myts': [('my', True), ('myt', True)],
          'myts-': [('myt', False)],
          'mäck': [('mäck', False)],
          'mäck-': [('mäck', False)],
          'mäckar': [('mäck', False)],
          'mäckarna': [('mäck', False)],
          'mäcken': [('mäck', False)],
          'mäckens': [('mäck', False)],
          'mäcket': [('mäck', False)],
          'mäcks': [('mäck', False)],
          'mäcks-': [('mäck', False)],
          'mädar': [('mädare', False)],
          'mädarna': [('mädare', False)],
          'mäklar': [('mäklare', False)],
          'mäklarnas': [('mäklare', False)],
          'mäktan': [('mäktan', False)],
          'mäktans': [('mäktan', False)],
          'mälan': [('mälan', False)],
          'mälans': [('mälan', False)],
          'mälar': [('mälare', False)],
          'mälarna': [('mälare', False)],
          'mälarnas': [('mälare', False)],
          'mälden': [('mäld', False)],
          'mäldens': [('mäld', False)],
          'mälder': [('mäld', True)],
          'mälderna': [('mäld', True)],
          'mäldernas': [('mäld', True)],
          'mälders': [('mäld', True)],
          'mälds': [('mäld', True)],
          'mälds-': [('mäld', True)],
          'mäle': [('mäle', False)],
          'mälen': [('mäle', False)],
          'mälens': [('mäle', False)],
          'mälet': [('mäle', False)],
          'mälets': [('mäle', False)],
          'mäll': [('mäll', False)],
          'mäll-': [('mäll', True)],
          'mällan': [('mälla', False)],
          'mällanden': [('mällande', False)],
          'mällandena': [('mällande', False)],
          'mällandenas': [('mällande', False)],
          'mällandens': [('mällande', False)],
          'mällars': [('mäll', False)],
          'mälle': [('mälla', False)],
          'mälle-': [('mälla', False)],
          'mällen': [('mäll', False)],
          'mället': [('mäll', False)],
          'mällets': [('mäll', False)],
          'mälls': [('mäll', False)],
          'mälls-': [('mäll', False)],
          'mäls': [('mäle', False)],
          'mäls-': [('mäle', False)],
          'mält': [('mälta', True)],
          'mälte': [('mälta', False)],
          'mälte-': [('mälta', False)],
          'män': [('man', True)],
          'mänd': [('mända', False)],
          'mänd-': [('mända', False)],
          'mändar': [('mände', False)],
          'mändarna': [('mände', False)],
          'mänds': [('mända', False)],
          'mänds-': [('mända', False)],
          'mäng': [('mäng', False)],
          'mängen': [('mäng', False)],
          'mängens': [('mäng', False)],
          'mänger': [('mäng', False)],
          'mängerna': [('mäng', False)],
          'mängernas': [('mäng', False)],
          'mängers': [('mäng', False)],
          'mänget': [('mäng', False)],
          'mängs-': [('mäng', False)],
          'männen': [('man', False)],
          'männens': [('man', False)],
          'mäns': [('man', True)],
          'märe': [('märe', False)],
          'mären': [('mär', True)],
          'märens': [('mär', True)],
          'märet': [('märe', False)],
          'märets': [('märe', False)],
          'märgen': [('märg', False)],
          'märgens': [('märg', False)],
          'märgs-': [('märg', False)],
          'märkarnas': [('märkare', False)],
          'märks': [('märke', False)],
          'märks-': [('märke', False)],
          'märr-': [('märr', True)],
          'märrs-': [('märr', True)],
          'märs': [('märs', True), ('mär', True)],
          'märs-': [('märs', True), ('mär', True)],
          'märt': [('märta', False)],
          'märt-': [('märta', False)],
          'märtanden': [('märtande', False)],
          'märtandens': [('märtande', False)],
          'märts': [('märta', False)],
          'märts-': [('märta', False)],
          'mäsk': [('mäsk', True)],
          'mäsk-': [('mäsk', True)],
          'mäss': [('mässa', True), ('mäss', True)],
          'mäss-': [('mässa', True), ('mäss', True)],
          'mässar': [('mäss', True)],
          'mässars': [('mäss', True)],
          'mässe': [('mässa', False)],
          'mässe-': [('mässa', False)],
          'mässens': [('mäss', False)],
          'mästar': [('mästare', False)],
          'mästarnas': [('mästare', False)],
          'mät-': [('mät', True)],
          'mäte': [('mäte', False)],
          'mäten': [('mäte', False)],
          'mätens': [('mäte', False)],
          'mäter': [('mäter', False)],
          'mäters': [('mäter', False)],
          'mätet': [('mäte', False)],
          'må': [('må', False)],
          'må-': [('må', False)],
          'mågarnas': [('måg', True)],
          'måhacks': [('måhackor', False)],
          'måkarna': [('måkare', True)],
          'målar': [('målare', False)],
          'målarna': [('målare', False)],
          'målarnas': [('målare', False)],
          'målen': [('mål', False)],
          'måligheter': [('målighet', False)],
          'måligheterna': [('målighet', False)],
          'måligheternas': [('målighet', False)],
          'måligheters': [('målighet', False)],
          'målighets-': [('målighet', False)],
          'mållan': [('målla', True)],
          'målle-': [('målla', True)],
          'målls-': [('målla', False)],
          'målskytten': [('målskytt', True), ('målskytte', True)],
          'målskyttens': [('målskytt', True), ('målskytte', True)],
          'mån': [('mån', True), ('måne', True)],
          'mån-': [('måne', True), ('mån', True)],
          'månar': [('måne', False)],
          'månarnas': [('måne', False)],
          'måne': [('måne', False)],
          'månen': [('måne', False)],
          'månens': [('måne', False)],
          'måns': [('mån', True), ('måne', True)],
          'måns-': [('måne', True), ('mån', True)],
          'mår': [('måra', True), ('mår', True)],
          'mår-': [('måra', True), ('mår', True)],
          'mård': [('mård', True)],
          'mård-': [('mård', True)],
          'mårdar': [('mård', True)],
          'mårdarna': [('mård', True)],
          'mårds': [('mård', True)],
          'mårds-': [('mård', True)],
          'mårs': [('mår', True), ('måra', True)],
          'mårs-': [('mår', True), ('måra', True)],
          'mås': [('mås', True)],
          'mås-': [('mås', False)],
          'måsar': [('mås', False)],
          'måsarnas': [('mås', False)],
          'måsten': [('måste', True)],
          'måstens': [('måste', True)],
          'mått': [('mått', False)],
          'mått-': [('mått', False)],
          'måtts': [('mått', False)],
          'måtts-': [('mått', True)],
          'méerna': [('mé', False)],
          'méernas': [('mé', False)],
          'möbor': [('möba', False)],
          'möborna': [('möba', False)],
          'möbornas': [('möbo', False)],
          'möbors': [('möba', False)],
          'möd': [('möda', True)],
          'möd-': [('möda', True)],
          'möde': [('möda', True)],
          'mödrar': [('mor', True), ('moder', True)],
          'mödrarna': [('mor', True), ('moder', True)],
          'mödrarnas': [('mor', True), ('moder', True)],
          'mödrars': [('moder', True), ('mor', True)],
          'möds': [('möda', True)],
          'möds-': [('möda', True)],
          'möglandet': [('möglande', True)],
          'möglandets': [('möglande', True)],
          'möns': [('mö', False)],
          'mör': [('mö', False)],
          'mördarnas': [('mördare', False)],
          'mören': [('mör', False)],
          'mörens': [('mör', False)],
          'möret': [('mör', False)],
          'mörets': [('mör', False)],
          'mörjan': [('mörja', False)],
          'mörjarnas': [('mörjare', False)],
          'mörnar': [('mörn', False)],
          'mörnarna': [('mörn', False)],
          'mörnen': [('mörn', False)],
          'mörnens': [('mörn', False)],
          'mörns-': [('mörn', False)],
          'mörs': [('mö', True)],
          'mörsarna': [('mörsare', True)],
          'mörtar': [('mört', True)],
          'mörtarna': [('mört', False)],
          'mörtens': [('mört', True)],
          'mörts': [('mört', True)],
          'mös': [('mö', False)],
          'mös-': [('mö', True)],
          'möss': [('mössa', True), ('mus', True)],
          'mösse': [('mössa', False)],
          'möte': [('möte', False)],
          'möten': [('möte', False)],
          'mötens': [('möte', False)],
          'mötes': [('möte', False)],
          'mötes-': [('möte', False)],
          'mötet': [('möte', False)],
          'n': [('n', True)],
          'n-': [('n', True)],
          'na': [('', False)],
          'na-': [('na', False)],
          'nabb': [('nabbe', True)],
          'nabb-': [('nabbe', True)],
          'nabbar': [('nabbe', True)],
          'nabben': [('nabbe', True)],
          'nabbens': [('nabbe', True)],
          'nabbs': [('nabbe', True)],
          'nabbs-': [('nabbe', True)],
          'nabon': [('nabo', True)],
          'nabons': [('nabo', True)],
          'nacen': [('nac', False)],
          'nack': [('nacke', False)],
          'nack-': [('nacke', True)],
          'nackar': [('nacke', True)],
          'nackarna': [('nacke', True)],
          'nackarnas': [('nacke', True)],
          'nacke': [('nacke', True)],
          'nacke-': [('nacka', False)],
          'nacken': [('nacke', True)],
          'nackens': [('nacke', True)],
          'nacker': [('nack', False)],
          'nackers': [('nack', False)],
          'nacket': [('nack', False)],
          'nackets': [('nack', False)],
          'nackor': [('nacka', False)],
          'nackorna': [('nacka', False)],
          'nackornas': [('nacka', False)],
          'nackors': [('nacka', False)],
          'nacks': [('nacke', True)],
          'nacks-': [('nacke', True)],
          'nadier': [('nadier', False)],
          'nadiernas': [('nadier', False)],
          'nadiers': [('nadier', False)],
          'nadon': [('nado', False)],
          'nador': [('nado', False)],
          'nadorna': [('nado', False)],
          'nadornas': [('nado', False)],
          'nadors': [('nado', False)],
          'nados-': [('nado', False)],
          'nadosen': [('nado', False)],
          'nadsverket': [('nadsverket', False)],
          'naer': [('na', False)],
          'naerna': [('na', False)],
          'naernas': [('na', False)],
          'nafadern': [('nafar', False)],
          'nafaderns': [('nafar', False)],
          'nafaders': [('nafar', False)],
          'nafars': [('nafar', False)],
          'nafs': [('nafs', True)],
          'nafs-': [('nafs', True)],
          'naftans': [('nafta', False)],
          'nagar': [('nagare', False)],
          'nagar-': [('nagare', False)],
          'nagarna': [('nagare', False)],
          'nagarnas': [('nagare', False)],
          'nage': [('nage', False)],
          'nage-': [('nage', False)],
          'nagen': [('nage', False)],
          'nagens': [('nage', False)],
          'nager': [('nager', False)],
          'nagerna': [('nage', False)],
          'nagernas': [('nage', False)],
          'nagers': [('nager', False)],
          'naget': [('nage', False)],
          'nagets': [('nag', False)],
          'nagg': [('nagg', False)],
          'nagg-': [('nagg', True)],
          'naggar': [('nagg', True)],
          'naggarna': [('nagg', True)],
          'naggarnas': [('nagg', False)],
          'naggars': [('nagg', False)],
          'naggen': [('nagg', False)],
          'naggens': [('nagg', False)],
          'naggs': [('nagg', True)],
          'naggs-': [('nagg', True)],
          'nagog': [('nagoga', False)],
          'nagog-': [('nagoga', False)],
          'nagogs': [('nagoga', False)],
          'nagogs-': [('nagoga', False)],
          'nak-': [('nak', False)],
          'naker': [('naker', False)],
          'nakers': [('naker', False)],
          'nakets': [('nak', False)],
          'naks': [('nak', False)],
          'naks-': [('nak', False)],
          'nakter': [('nakt', False)],
          'nakters': [('nakt', False)],
          'nalandets': [('nalande', False)],
          'nalar': [('nalare', False)],
          'nalar-': [('nalare', False)],
          'nalarens': [('nalare', False)],
          'nalarna': [('nalare', False)],
          'nalarnas': [('nalare', False)],
          'naldags': [('naldag', False)],
          'naldags-': [('naldag', False)],
          'nalet': [('nal', False)],
          'nalets': [('nal', False)],
          'nalfen': [('nalfena', False)],
          'nalfens': [('nalfena', False)],
          'nalg': [('nalg', False)],
          'nalgen': [('nalg', False)],
          'nalgens': [('nalg', False)],
          'nalgs': [('nalg', False)],
          'nalgs-': [('nalg', False)],
          'nali': [('nalier', False)],
          'nali-': [('nalier', False)],
          'nalie-': [('nalier', False)],
          'nalierna': [('nalier', False)],
          'nalin': [('nalin', False)],
          'nalis': [('nalis', False)],
          'naljers': [('nalje', False)],
          'nallagen': [('nallag', False)],
          'nallanden': [('nallande', False)],
          'nallandens': [('nallande', True)],
          'nallandet': [('nallande', True)],
          'nallar': [('nalle', True)],
          'nallarna': [('nalle', False)],
          'nallarnas': [('nalle', False)],
          'nallars': [('nalle', True)],
          'nallen': [('nalle', True)],
          'nallens': [('nalle', False)],
          'nallön': [('nallön', False)],
          'nals': [('nal', False)],
          'nals-': [('naler', False)],
          'nalvals': [('nalval', False)],
          'nalvals-': [('nalval', False)],
          'nam': [('nam', False)],
          'nam-': [('nam', False)],
          'namatens': [('namat', False)],
          'namenten': [('nament', False)],
          'namentens': [('nament', False)],
          'namentet': [('nament', False)],
          'naments-': [('nament', False)],
          'names': [('names', False)],
          'namet': [('nam', False)],
          'namets': [('nam', False)],
          'namin': [('nami', False)],
          'namins': [('nami', False)],
          'namn': [('namne', True), ('namn', True)],
          'namn-': [('namne', True), ('namn', True)],
          'namnarnas': [('namne', True)],
          'namnen': [('namne', True), ('namn', True)],
          'namnens': [('namne', True), ('namn', True)],
          'namnes': [('namne', True)],
          'namnes-': [('namne', True)],
          'namns': [('namne', True), ('namn', True)],
          'namns-': [('namne', True), ('namn', True)],
          'namor': [('namo', False)],
          'namorna': [('namo', False)],
          'namornas': [('namo', False)],
          'namors': [('namo', False)],
          'namos-': [('namo', False)],
          'nams': [('nam', False)],
          'nan': [('na', False)],
          'nana': [('na', False)],
          'nanas': [('nanas', False)],
          'nanas-': [('nanas', False)],
          'nand': [('nand', False)],
          'nand-': [('nand', False)],
          'nandagen': [('nandag', False)],
          'nandagens': [('nandag', False)],
          'nandens': [('nande', False)],
          'nander': [('nand', False)],
          'nanders': [('nand', False)],
          'nandets': [('nande', False)],
          'nands': [('nand', False)],
          'nands-': [('nand', False)],
          'nanens': [('nan', False)],
          'nani': [('nani', False)],
          'nani-': [('nani', False)],
          'nanien': [('nani', False)],
          'naniens': [('nani', False)],
          'nanin': [('nani', False)],
          'nanins': [('nani', False)],
          'nanis': [('nani', False)],
          'nanister': [('nanist', False)],
          'nanisters': [('nanist', False)],
          'nans': [('na', False)],
          'nansen': [('nans', False)],
          'nansens': [('nans', False)],
          'nanser': [('nans', False)],
          'nanserna': [('nans', False)],
          'nansernas': [('nans', False)],
          'nansers': [('nans', False)],
          'nanskris': [('nanskris', False)],
          'nant': [('nant', False)],
          'nanten': [('nant', False)],
          'nantens': [('nant', False)],
          'nanter': [('nant', False)],
          'nanterna': [('nant', False)],
          'nanternas': [('nant', False)],
          'nanters': [('nant', False)],
          'nanträden': [('nanträd', False)],
          'nanträdens': [('nanträd', False)],
          'nanträdet': [('nanträd', False)],
          'nanträdets': [('nanträd', False)],
          'nants-': [('nant', False)],
          'nap': [('nap', False)],
          'nap-': [('napa', False)],
          'napan': [('napa', False)],
          'napans': [('napa', False)],
          'napas': [('napa', False)],
          'nape': [('nape', False)],
          'napets': [('nap', False)],
          'napp': [('napp', False)],
          'napp-': [('napp', False)],
          'nappar': [('napp', False)],
          'napparna': [('napp', False)],
          'napparnas': [('napp', True)],
          'nappars': [('napp', False)],
          'nappen': [('napp', False)],
          'nappens': [('napp', False)],
          'napperna': [('napp', False)],
          'nappernas': [('napp', False)],
          'nappers': [('napp', False)],
          'napps': [('napp', False)],
          'napps-': [('napp', False)],
          'naps': [('naps', False)],
          'naps-': [('naps', False)],
          'nar': [('nar', True)],
          'nar-': [('nar', True)],
          'naran': [('nara', False)],
          'narans': [('nara', False)],
          'narar': [('nar', True)],
          'nararna': [('nar', True)],
          'narars': [('nar', True)],
          'nard': [('nard', False)],
          'nard-': [('nard', False)],
          'narden': [('nard', False)],
          'nardens': [('nard', False)],
          'narder': [('nard', False)],
          'narderna': [('nard', False)],
          'nardernas': [('nard', False)],
          'narders': [('nard', False)],
          'nards': [('nard', False)],
          'nards-': [('nard', False)],
          'nare': [('nare', False)],
          'nare-': [('nare', True)],
          'naren': [('nar', True), ('nare', True)],
          'narens': [('nar', True), ('nare', True)],
          'nares': [('nare', False)],
          'naret': [('naret', False)],
          'narets': [('naret', False)],
          'narie': [('narie', False)],
          'narier': [('nario', False)],
          'narierna': [('nario', False)],
          'nariernas': [('nario', False)],
          'narismer': [('narism', False)],
          'narismerna': [('narism', False)],
          'narismernas': [('narism', False)],
          'narismers': [('narism', False)],
          'narkarnas': [('narkare', False)],
          'narkotika': [('narkotikum', True), ('narkotika', True)],
          'narkotikas': [('narkotikum', True), ('narkotika', True)],
          'narmar': [('narm', False)],
          'narmarna': [('narm', False)],
          'narmarnas': [('narm', False)],
          'narna': [('nare', False)],
          'narr': [('narr', False)],
          'narr-': [('narr', False)],
          'narrar': [('narr', False)],
          'narrarna': [('narr', True)],
          'narrarnas': [('narr', False)],
          'narrars': [('narr', False)],
          'narrens': [('narr', False)],
          'narrs-': [('narr', False)],
          'nars': [('nar', True)],
          'nars-': [('nar', True)],
          'nart': [('nart', False)],
          'narten': [('nart', False)],
          'nartens': [('nart', False)],
          'narter': [('nart', False)],
          'narterna': [('nart', False)],
          'narternas': [('nart', False)],
          'narters': [('nart', False)],
          'narts': [('nart', False)],
          'narts-': [('nart', False)],
          'narv': [('narv', True)],
          'narv-': [('narv', False)],
          'narven': [('narv', False)],
          'narvens': [('narv', True)],
          'narvs': [('narv', False)],
          'narvs-': [('narv', True)],
          'nas': [('', False)],
          'nas-': [('nas', False)],
          'nasar': [('nasare', True)],
          'nasar-': [('nasare', True)],
          'nasarens': [('nasare', True)],
          'nasarna': [('nasare', True)],
          'nasarnas': [('nasare', True)],
          'nasierna': [('nasium', False)],
          'nasiers': [('nasium', False)],
          'nasins': [('nasi', False)],
          'nasis': [('nasi', False)],
          'nask': [('nask', False)],
          'nask-': [('naska', False)],
          'naskar': [('nasker', False)],
          'naskarnas': [('nasker', False)],
          'naskars': [('nasker', False)],
          'nasket': [('nask', False)],
          'naskets': [('nask', False)],
          'nasm': [('nasm', False)],
          'nasm-': [('nasm', False)],
          'nasmer': [('nasm', False)],
          'nasmerna': [('nasm', False)],
          'nasmernas': [('nasm', False)],
          'nasmers': [('nasm', False)],
          'nass': [('nass', False)],
          'nassar': [('nasse', True)],
          'nassarna': [('nasse', True)],
          'nassarnas': [('nasse', True)],
          'nassen': [('nasse', True)],
          'nassens': [('nasse', True)],
          'nast-': [('nast', False)],
          'nastar': [('nast', False)],
          'nastarna': [('nast', False)],
          'nasten': [('nast', False)],
          'naster': [('nast', False)],
          'nasterna': [('nast', False)],
          'nasternas': [('nast', False)],
          'nasters': [('nast', False)],
          'nastis': [('nasti', False)],
          'nat': [('nate', True)],
          'nat-': [('nate', True)],
          'nata': [('nata', False)],
          'natan': [('nata', False)],
          'natarna': [('nate', True)],
          'natars': [('nate', True)],
          'natas': [('nata', False)],
          'nate': [('nate', True)],
          'nate-': [('nate', False)],
          'naten': [('nate', False)],
          'natens': [('nate', True)],
          'nates': [('nate', False)],
          'nates-': [('nate', True)],
          'natidens': [('natid', False)],
          'natiderna': [('natid', False)],
          'natidernas': [('natid', False)],
          'natids': [('natid', False)],
          'natids-': [('natid', False)],
          'natiker': [('natiker', False)],
          'natikerna': [('natiker', False)],
          'natikernas': [('natiker', False)],
          'natikers': [('natiker', False)],
          'natin': [('natin', False)],
          'nation': [('nation', False)],
          'nationen': [('nation', False)],
          'nations': [('nation', False)],
          'nativets': [('nativ', False)],
          'nator': [('nator', False)],
          'nators': [('nator', False)],
          'natos': [('nato', False)],
          'natron': [('natron', True)],
          'natrons': [('natron', True)],
          'nats': [('nate', True)],
          'nats-': [('nate', True)],
          'natt': [('natt', False)],
          'natt-': [('natt', False)],
          'nattar': [('natte', False)],
          'nattarna': [('natte', False)],
          'nattarnas': [('nattare', False)],
          'natte': [('natte', False)],
          'natten': [('natt', False)],
          'nattens': [('natt', True)],
          'nattet': [('natt', False)],
          'nattkvisten': [('nattkvist', True), ('nattkvisten', True)],
          'nattkvistens': [('nattkvist', True), ('nattkvisten', True)],
          'natts': [('natt', False)],
          'natts-': [('natt', False)],
          'nattsidan': [('nattsidan', True)],
          'nattsidans': [('nattsidan', True)],
          'naturtillgångar': [('naturtillgångar', True), ('naturtillgång', True)],
          'naturtillgångarna': [('naturtillgång', True), ('naturtillgångar', True)],
          'naturtillgångarnas': [('naturtillgångar', True), ('naturtillgång', True)],
          'naturtillgångars': [('naturtillgångar', True), ('naturtillgång', True)],
          'naturtillgångs': [('naturtillgång', True), ('naturtillgångar', True)],
          'naturtillgångs-': [('naturtillgång', True), ('naturtillgångar', True)],
          'naut': [('naut', False)],
          'nauten': [('naut', False)],
          'nautens': [('naut', False)],
          'nauter': [('naut', False)],
          'nauterna': [('naut', False)],
          'nauternas': [('naut', False)],
          'nauters': [('naut', False)],
          'nautiker': [('nautiker', True)],
          'nautikerna': [('nautiker', True)],
          'nautikernas': [('nautiker', True)],
          'nautikers': [('nautiker', True)],
          'nauts': [('naut', False)],
          'navandens': [('navande', False)],
          'navar': [('navare', True)],
          'navarnas': [('navare', True)],
          'naven': [('nav', False)],
          'navens': [('nav', True)],
          'naver': [('naver', True)],
          'navernas': [('nav', False)],
          'naverns': [('naver', True)],
          'navers': [('naver', True)],
          'navet': [('nav', False)],
          'navets': [('nav', False)],
          'navlarna': [('navel', True)],
          'nback': [('nbacke', False)],
          'nback-': [('nbacke', False)],
          'nbackar': [('nbacke', False)],
          'nbackarna': [('nbacke', False)],
          'nbackarnas': [('nbacke', False)],
          'nbackars': [('nbacke', False)],
          'nbacke': [('nbacke', False)],
          'nbacke-': [('nbacke', False)],
          'nbacken': [('nbacke', False)],
          'nbackens': [('nbacke', False)],
          'nbacks': [('nbacke', False)],
          'nbacks-': [('nbacke', False)],
          'nbagg': [('nbagge', False)],
          'nbagg-': [('nbagge', False)],
          'nbaggar': [('nbagge', False)],
          'nbaggarna': [('nbagge', False)],
          'nbaggarnas': [('nbagge', False)],
          'nbaggars': [('nbagge', False)],
          'nbaggen': [('nbagge', False)],
          'nbaggens': [('nbagge', False)],
          'nbaggs': [('nbagge', False)],
          'nbaggs-': [('nbagge', False)],
          'nbanan': [('nbana', False)],
          'nbanans': [('nbana', False)],
          'nbandets': [('nband', False)],
          'nbane': [('nbana', False)],
          'nbane-': [('nbana', False)],
          'nbaner': [('nbaner', False)],
          'nbaners': [('nbaner', False)],
          'nbarren': [('nbarr', False)],
          'nbarrens': [('nbarr', False)],
          'nben': [('nben', False)],
          'nben-': [('nbena', False)],
          'nbens': [('nbena', False)],
          'nbens-': [('nben', False)],
          'nbet': [('nbet', False)],
          'nbet-': [('nbet', False)],
          'nbete': [('nbete', False)],
          'nbete-': [('nbete', False)],
          'nbets': [('nbet', False)],
          'nbets-': [('nbet', False)],
          'nbevis': [('nbevis', False)],
          'nbil': [('nbil', False)],
          'nbilar': [('nbil', False)],
          'nbilars': [('nbil', False)],
          'nbils': [('nbil', False)],
          'nbils-': [('nbil', False)],
          'nbits': [('nbit', False)],
          'nbits-': [('nbit', False)],
          'nblask': [('nblask', False)],
          'nblask-': [('nblask', False)],
          'nblom': [('nblomma', False)],
          'nblom-': [('nblomma', False)],
          'nbloms': [('nblomma', False)],
          'nbloms-': [('nblomma', False)],
          'nbläck': [('nbläck', False)],
          'nbläck-': [('nbläck', False)],
          'nbläcks': [('nbläck', False)],
          'nbläcks-': [('nbläck', False)],
          'nblåns': [('nblånor', False)],
          'nblåns-': [('nblånor', False)],
          'nbolaget': [('nbolag', False)],
          'nbomb': [('nbomb', False)],
          'nbomber': [('nbomb', False)],
          'nbomberna': [('nbomb', False)],
          'nbombernas': [('nbomb', False)],
          'nbombers': [('nbomb', False)],
          'nbombs': [('nbomb', False)],
          'nbombs-': [('nbomb', False)],
          'nbond': [('nbonde', False)],
          'nbondens': [('nbonde', False)],
          'nbonds': [('nbonde', False)],
          'nborgar': [('nborg', False)],
          'nborgarna': [('nborg', False)],
          'nborgarnas': [('nborg', False)],
          'nborgen': [('nborg', False)],
          'nborgens': [('nborg', False)],
          'nborr': [('nborre', False)],
          'nborr-': [('nborre', False)],
          'nborrar': [('nborre', False)],
          'nborrarna': [('nborre', False)],
          'nborrarnas': [('nborre', False)],
          'nborrars': [('nborre', False)],
          'nborren': [('nborre', False)],
          'nborrens': [('nborre', False)],
          'nborrs': [('nborre', False)],
          'nborrs-': [('nborre', False)],
          'nborst': [('nborst', False)],
          'nborst-': [('nborst', False)],
          'nborsten': [('nborst', False)],
          'nborstens': [('nborst', False)],
          'nbot': [('nbot', False)],
          'nbots': [('nbot', False)],
          'nbroder': [('nbroder', False)],
          'nbrodern': [('nbror', False)],
          'nbroderns': [('nbror', False)],
          'nbroders': [('nbror', False)],
          'nbrons': [('nbro', False)],
          'nbrors': [('nbror', False)],
          'nbrors-': [('nbror', False)],
          'nbrynen': [('nbryn', False)],
          'nbrynens': [('nbryn', False)],
          'nbrynet': [('nbryn', False)],
          'nbrynets': [('nbryn', False)],
          'nbryns': [('nbryn', False)],
          'nbryns-': [('nbryn', False)],
          'nbrytar': [('nbrytare', False)],
          'nbrytarna': [('nbrytare', False)],
          'nbrytarnas': [('nbrytare', False)],
          'nbräck': [('nbräcka', False)],
          'nbräck-': [('nbräcka', False)],
          'nbräcks': [('nbräcka', False)],
          'nbräcks-': [('nbräcka', False)],
          'nbräde': [('nbräda', False)],
          'nbräds': [('nbräda', False)],
          'nbräds-': [('nbräda', False)],
          'nbråk': [('nbråk', False)],
          'nbråks': [('nbråk', False)],
          'nbråks-': [('nbråk', False)],
          'nbröder': [('nbror', False)],
          'nbröderna': [('nbroder', False)],
          'nbrödernas': [('nbroder', False)],
          'nbröders': [('nbroder', False)],
          'nbröst': [('nbröst', False)],
          'nbröst-': [('nbröst', False)],
          'nbulle': [('nbulla', False)],
          'nbyx': [('nbyxa', False)],
          'nbyx-': [('nbyxa', False)],
          'nbälte': [('nbälte', False)],
          'nbärs': [('nbär', False)],
          'nbärs-': [('nbär', False)],
          'nbåg': [('nbåge', False)],
          'nbåg-': [('nbåge', False)],
          'nbågs': [('nbåge', False)],
          'nbågs-': [('nbåge', False)],
          'nbön': [('nbön', False)],
          'nböns': [('nbön', False)],
          'nböns-': [('nbön', False)],
          'nböter': [('nbot', False)],
          'nböterna': [('nbot', False)],
          'nböternas': [('nbot', False)],
          'nböters': [('nbot', False)],
          'nc-': [('nc', False)],
          'ncan': [('ncan', False)],
          'ncans': [('ncan', False)],
          'nce': [('nny', False)],
          'ncell': [('ncell', False)],
          'ncens': [('nny', False)],
          'ncern': [('ncer', False)],
          'ncerns': [('ncer', False)],
          'ncers': [('ncer', False)],
          'nces': [('nny', False)],
          'nchar-': [('nchare', False)],
          'ncharen': [('nchare', False)],
          'ncharens': [('nchare', False)],
          'ncharnas': [('nch', False)],
          'nchars': [('nch', False)],
          'nchis': [('nchis', False)],
          'nchis-': [('nchis', False)],
          'nchon': [('ncho', False)],
          'nchons': [('ncho', False)],
          'nchor': [('ncho', False)],
          'nchorna': [('ncho', False)],
          'nchornas': [('ncho', False)],
          'nchos': [('ncho', False)],
          'nchos-': [('ncho', False)],
          'nchosen': [('ncho', False)],
          'nchosens': [('ncho', False)],
          'nciers': [('ncier', False)],
          'ncilians': [('ncilians', False)],
          'ncitet': [('ncitet', False)],
          'ncitets': [('ncitet', False)],
          'ncors': [('nco', False)],
          'ncs-': [('nc', False)],
          'nd': [('nd', False)],
          'nd-': [('nd', False)],
          'ndagar': [('ndag', False)],
          'ndagarna': [('ndag', False)],
          'ndagarnas': [('ndag', False)],
          'ndagars': [('ndag', False)],
          'ndagen': [('ndag', False)],
          'ndagens': [('ndag', False)],
          'ndags': [('ndag', False)],
          'ndags-': [('ndag', False)],
          'ndaler': [('ndal', False)],
          'ndalerna': [('ndal', False)],
          'ndalernas': [('ndal', False)],
          'ndalers': [('ndal', False)],
          'ndan': [('nda', False)],
          'ndanden': [('ndande', False)],
          'ndandens': [('ndande', False)],
          'ndans-': [('ndan', False)],
          'ndanten': [('ndante', False)],
          'ndantens': [('ndante', False)],
          'ndar-': [('ndar', False)],
          'ndaren': [('ndare', False)],
          'ndarens': [('ndar', False)],
          'ndaret': [('ndar', False)],
          'ndarets': [('ndar', False)],
          'ndarnas': [('ndare', False)],
          'ndars': [('nd', False)],
          'ndars-': [('ndar', False)],
          'ndaten': [('ndat', False)],
          'ndatens': [('ndat', False)],
          'ndator': [('ndator', False)],
          'ndators': [('ndator', False)],
          'ndbackens': [('ndbacke', False)],
          'ndbens': [('ndben', False)],
          'ndboj': [('ndboja', False)],
          'ndbojs-': [('ndboja', False)],
          'ndbor': [('ndbo', False)],
          'ndborgarna': [('ndborg', False)],
          'ndborgarnas': [('ndborg', False)],
          'ndborr': [('ndborr', False)],
          'ndborr-': [('ndborr', False)],
          'ndborrar': [('ndborr', False)],
          'ndborrarna': [('ndborr', False)],
          'ndborrarnas': [('ndborr', False)],
          'ndborrars': [('ndborr', False)],
          'ndborren': [('ndborr', False)],
          'ndborrens': [('ndborr', False)],
          'ndborrs': [('ndborr', False)],
          'ndborrs-': [('ndborr', False)],
          'nddock': [('nddocka', False)],
          'nddocks-': [('nddocka', False)],
          'nddyn': [('nddyn', False)],
          'nddyns': [('nddyn', False)],
          'nde': [('nda', False)],
          'nde-': [('nda', False)],
          'ndeanden': [('ndeande', False)],
          'ndeandens': [('ndeande', False)],
          'ndel': [('ndel', False)],
          'ndelandet': [('ndelande', False)],
          'ndelandets': [('ndeland', False)],
          'ndelars': [('ndel', False)],
          'ndels': [('ndel', False)],
          'ndels-': [('ndel', False)],
          'nden': [('nd', False)],
          'ndens': [('nd', False)],
          'nder': [('nd', False)],
          'nder-': [('nder', False)],
          'nderbyxorna': [('nderbyxorna', False)],
          'nderbyxornas': [('nderbyxorna', False)],
          'nderits': [('nderi', False)],
          'ndern': [('nder', False)],
          'nderna': [('nd', False)],
          'nderns': [('nder', False)],
          'nders': [('nd', False)],
          'nders-': [('nder', False)],
          'ndes': [('ndes', False)],
          'ndes-': [('ndes', False)],
          'ndet': [('nd', False)],
          'ndets': [('nde', False)],
          'ndfångens': [('ndfång', False)],
          'ndgum': [('ndgumma', False)],
          'ndgum-': [('ndgumma', False)],
          'ndgums': [('ndgumma', False)],
          'ndgums-': [('ndgumma', False)],
          'ndgångar': [('ndgångare', False)],
          'ndgångarna': [('ndgångare', False)],
          'ndgångarnas': [('ndgångare', False)],
          'ndi': [('nd', False)],
          'ndian': [('ndian', False)],
          'ndians': [('ndian', False)],
          'ndierna': [('ndier', False)],
          'ndiernas': [('ndier', False)],
          'ndiers': [('ndier', False)],
          'ndiesarna': [('ndy', False)],
          'ndiesarnas': [('ndy', False)],
          'ndiet': [('ndium', False)],
          'ndiets': [('ndium', False)],
          'ndin': [('ndi', False)],
          'ndins': [('ndin', False)],
          'ndis': [('ndis', False)],
          'nditorierna': [('nditori', False)],
          'nditoriernas': [('nditori', False)],
          'nditoriers': [('nditori', False)],
          'nditoriets': [('nditori', False)],
          'ndiv': [('ndiv', False)],
          'ndiv-': [('ndiv', False)],
          'ndiver': [('ndiv', False)],
          'ndiverna': [('ndiv', False)],
          'ndivernas': [('ndivum', False)],
          'ndivers': [('ndivum', False)],
          'ndivs': [('ndiv', False)],
          'ndivs-': [('ndiv', False)],
          'ndkatt': [('ndkatt', False)],
          'ndkatts-': [('ndkatt', False)],
          'ndkåren': [('ndkår', False)],
          'ndkårens': [('ndkår', False)],
          'ndlandet': [('ndland', False)],
          'ndlandets': [('ndland', False)],
          'ndlar': [('ndel', False)],
          'ndlarna': [('ndel', False)],
          'ndlarnas': [('ndel', False)],
          'ndlars': [('ndel', False)],
          'ndmor-': [('ndmora', False)],
          'ndmors': [('ndmora', False)],
          'ndmors-': [('ndmora', False)],
          'ndo-': [('ndo', False)],
          'ndock-': [('ndocka', False)],
          'ndocks': [('ndocka', False)],
          'ndolen': [('ndol', False)],
          'ndolens': [('ndole', False)],
          'ndoler': [('ndol', False)],
          'ndolerna': [('ndol', False)],
          'ndolernas': [('ndol', False)],
          'ndolers': [('ndol', False)],
          'ndologen': [('ndolog', False)],
          'ndologens': [('ndolog', False)],
          'ndologer': [('ndolog', False)],
          'ndologerna': [('ndolog', False)],
          'ndologernas': [('ndolog', False)],
          'ndologers': [('ndolog', False)],
          'ndomar': [('ndom', False)],
          'ndomarna': [('ndom', False)],
          'ndomarnas': [('ndom', False)],
          'ndomen': [('ndom', False)],
          'ndon-': [('ndon', False)],
          'ndona': [('ndo', False)],
          'ndonas': [('ndo', False)],
          'ndor': [('nda', False)],
          'ndorer': [('ndor', False)],
          'ndorerna': [('ndor', False)],
          'ndorernas': [('ndor', False)],
          'ndorers': [('ndor', False)],
          'ndorna': [('nda', False)],
          'ndornas': [('nda', False)],
          'ndors': [('nda', False)],
          'ndos': [('ndo', False)],
          'ndos-': [('ndos', False)],
          'ndosen': [('ndos', False)],
          'ndosens': [('ndos', False)],
          'ndot': [('ndo', False)],
          'ndra': [('ndra', False)],
          'ndraden': [('ndrad', False)],
          'ndradens': [('ndrad', False)],
          'ndrads': [('ndrad', False)],
          'ndrads-': [('ndrad', False)],
          'ndramer': [('ndrama', False)],
          'ndramerna': [('ndrama', False)],
          'ndramernas': [('ndrama', False)],
          'ndrar': [('nder', False)],
          'ndrarna': [('nder', False)],
          'ndrars': [('nder', False)],
          'ndrer': [('nder', False)],
          'ndrerna': [('nder', False)],
          'ndrernas': [('nder', False)],
          'ndrers': [('nder', False)],
          'ndricks': [('ndricka', False)],
          'ndricks-': [('ndricka', False)],
          'ndriens': [('ndri', False)],
          'ndringar': [('ndring', False)],
          'ndringarnas': [('ndring', False)],
          'ndringars': [('ndring', False)],
          'ndrinkar': [('ndrink', False)],
          'ndrinkarna': [('ndrink', False)],
          'ndrinkarnas': [('ndrink', False)],
          'ndrins': [('ndri', False)],
          'ndrisk': [('ndrisk', False)],
          'ndrisk-': [('ndrisk', False)],
          'ndrivar': [('ndrivare', False)],
          'ndrivarna': [('ndrivare', False)],
          'ndrivarnas': [('ndrivare', False)],
          'ndrogen': [('ndrogener', False)],
          'ndropp': [('ndroppe', False)],
          'ndropp-': [('ndroppe', False)],
          'ndroppar': [('ndroppar', False)],
          'ndropparna': [('ndroppar', False)],
          'ndropparnas': [('ndroppar', False)],
          'ndroppars': [('ndroppar', False)],
          'ndropps-': [('ndroppe', False)],
          'ndrorna': [('ndra', False)],
          'ndroten': [('ndrote', False)],
          'ndrotens': [('ndrot', False)],
          'ndrots': [('ndrot', False)],
          'ndrots-': [('ndrot', False)],
          'ndrov': [('ndrova', False)],
          'ndrov-': [('ndrova', False)],
          'ndrovs': [('ndrova', False)],
          'ndrovs-': [('ndrova', False)],
          'ndrås': [('ndrå', False)],
          'ndrås-': [('ndrå', False)],
          'ndrömmar': [('ndröm', False)],
          'ndrömmarna': [('ndröm', False)],
          'ndrömmarnas': [('ndröm', False)],
          'nds': [('nd', False)],
          'nds-': [('nd', False)],
          'ndsarna': [('nd', False)],
          'ndsarnas': [('nd', False)],
          'ndsdagar': [('ndsdag', False)],
          'ndsdagarna': [('ndsdag', False)],
          'ndsdagarnas': [('ndsdag', False)],
          'ndsdagars': [('ndsdag', False)],
          'ndsdags': [('ndsdag', False)],
          'ndsdags-': [('ndsdag', False)],
          'ndsen': [('nd', False)],
          'ndsens': [('nd', False)],
          'ndsfaktorer': [('ndsfaktorer', False)],
          'ndsfaktorers': [('ndsfaktorer', False)],
          'ndsk': [('ndske', False)],
          'ndsk-': [('ndske', False)],
          'ndskalas': [('ndskala', False)],
          'ndskallens': [('ndskall', False)],
          'ndskammar': [('ndskammare', False)],
          'ndskartans': [('ndskartan', False)],
          'ndske': [('ndska', False)],
          'ndske-': [('ndska', False)],
          'ndskor': [('ndska', False)],
          'ndskorna': [('ndska', False)],
          'ndskornas': [('ndska', False)],
          'ndskors': [('ndska', False)],
          'ndskotts': [('ndskott', False)],
          'ndskrafter': [('ndskraft', False)],
          'ndskrafterna': [('ndskraft', False)],
          'ndskrafternas': [('ndskraft', False)],
          'ndskrafters': [('ndskraft', False)],
          'ndskrafts': [('ndskraft', False)],
          'ndskrafts-': [('ndskraft', False)],
          'ndslagar': [('ndslag', False)],
          'ndslagarna': [('ndslag', False)],
          'ndslagarnas': [('ndslag', False)],
          'ndslanden': [('ndslande', False)],
          'ndslandens': [('ndslande', False)],
          'ndslandet': [('ndslande', False)],
          'ndslandets': [('ndsland', False)],
          'ndslås': [('ndslås', False)],
          'ndsprivilegiernas': [('ndsprivilegium', False)],
          'ndstalet': [('ndstal', False)],
          'ndsteg': [('ndstege', False)],
          'ndsteg-': [('ndstege', False)],
          'ndstegen': [('ndstege', False)],
          'ndstegens': [('ndstege', False)],
          'ndstegs': [('ndstege', False)],
          'ndstegs-': [('ndstege', False)],
          'ndstoner': [('ndston', False)],
          'ndstonerna': [('ndston', False)],
          'ndstonernas': [('ndston', False)],
          'ndstoners': [('ndston', False)],
          'ndstons': [('ndstoner', False)],
          'ndstons-': [('ndstoner', False)],
          'ndstormar': [('ndstorm', False)],
          'ndtrav': [('ndtrav', False)],
          'ndtrav-': [('ndtrav', False)],
          'ndtraven': [('ndtrav', False)],
          'ndtravens': [('ndtrav', False)],
          'ndtravs': [('ndtrav', False)],
          'ndtravs-': [('ndtrav', False)],
          'ndts': [('ndt', False)],
          'ndu': [('ndu', False)],
          'ndu-': [('ndu', False)],
          'ndue': [('ndue', False)],
          'ndue-': [('ndue', False)],
          'nduen': [('ndu', False)],
          'nduens': [('ndue', False)],
          'nduer': [('ndue', False)],
          'nduerna': [('ndu', False)],
          'nduernas': [('ndue', False)],
          'nduers': [('ndue', False)],
          'ndun': [('ndu', False)],
          'ndunkarna': [('ndunk', False)],
          'nduns': [('ndu', False)],
          'ndus': [('ndu', False)],
          'ndus-': [('ndus', False)],
          'ndvits': [('ndvita', False)],
          'ndvits-': [('ndvita', False)],
          'ndvägen': [('ndvägen', False)],
          'ndyn': [('ndy', False)],
          'ndyns': [('ndy', False)],
          'ndys': [('ndy', False)],
          'ndängarnas': [('ndäng', False)],
          'ndålighets': [('ndålighet', False)],
          'ndålighets-': [('ndålighet', False)],
          'ndån': [('ndå', False)],
          'ndåns': [('ndå', False)],
          'ndår': [('ndår', False)],
          'ndåren': [('ndår', False)],
          'ndårens': [('ndår', False)],
          'ndårs': [('ndår', False)],
          'ndårs-': [('ndår', False)],
          'ndås': [('ndå', False)],
          'ne': [('ne', False)],
          'neasen': [('nea', False)],
          'neasens': [('nea', False)],
          'nebanan': [('nebanan', False)],
          'nebulosan': [('nebulosa', True)],
          'nebulosans': [('nebulosa', False)],
          'ned': [('ned', False)],
          'nedan': [('nedan', True)],
          'nedans': [('nedan', True)],
          'nedans-': [('nedan', True)],
          'nedar': [('nedare', False)],
          'nedar-': [('nedare', False)],
          'nedarens': [('nedare', False)],
          'nedarna': [('nedare', False)],
          'nedos': [('nedosa', False)],
          'nedos-': [('nedosa', False)],
          'neds': [('ned', False)],
          'neds-': [('ned', False)],
          'nee': [('nea', False)],
          'nee-': [('nea', False)],
          'neens': [('nee', False)],
          'neer': [('ne', False)],
          'neerna': [('ne', False)],
          'neernas': [('ne', False)],
          'neers': [('ne', False)],
          'negar': [('negare', False)],
          'negarna': [('negare', False)],
          'negarnas': [('negare', False)],
          'nege': [('nege', False)],
          'nege-': [('nege', False)],
          'negen': [('nege', False)],
          'negens': [('nege', False)],
          'neger': [('neger', True)],
          'negerna': [('nege', False)],
          'negernas': [('nege', False)],
          'negers': [('neger', True)],
          'neges': [('nege', False)],
          'neges-': [('nege', False)],
          'negs': [('neg', False)],
          'nejden': [('nejd', True)],
          'nejdens': [('nejd', True)],
          'nejder': [('nejd', True)],
          'nejders': [('nejd', True)],
          'nejs': [('nej', True)],
          'nejs-': [('nejs', False)],
          'nejsers': [('nejs', False)],
          'nek': [('nek', False)],
          'nek-': [('nek', True)],
          'nekar': [('nek', True)],
          'nekarens': [('nekare', False)],
          'nekarna': [('nek', True)],
          'nekarnas': [('nek', True)],
          'neker': [('nek', True)],
          'nekers': [('nek', True)],
          'neks': [('nek', True)],
          'neks-': [('nek', True)],
          'nekt': [('nekt', False)],
          'nekt-': [('nekt', False)],
          'nektar': [('nektar', True)],
          'nektars': [('nektar', True)],
          'nekten': [('nekt', False)],
          'nektens': [('nekt', False)],
          'nekts': [('nekt', False)],
          'nekts-': [('nekt', False)],
          'nekurs': [('nekur', False)],
          'nelanden': [('nelande', False)],
          'nelandens': [('nelande', False)],
          'nelandets': [('nelande', False)],
          'nelers': [('nel', False)],
          'nell': [('nell', False)],
          'nell-': [('nell', False)],
          'nellan': [('nella', False)],
          'nelle': [('nella', False)],
          'nelle-': [('nella', False)],
          'nellen': [('nell', False)],
          'neller': [('nell', False)],
          'nellerna': [('nell', False)],
          'nellernas': [('nell', False)],
          'nellers': [('nell', False)],
          'nellet': [('nell', False)],
          'nellets': [('nell', False)],
          'nellor': [('nella', False)],
          'nellorna': [('nella', False)],
          'nellornas': [('nella', False)],
          'nellors': [('nella', False)],
          'nells': [('nell', False)],
          'nells-': [('nell', False)],
          'nem': [('nem', False)],
          'nem-': [('nem', False)],
          'nemang': [('nemang', False)],
          'nemang-': [('nemang', False)],
          'nemangs': [('nemang', False)],
          'nemangs-': [('nemang', False)],
          'nematts': [('nematta', False)],
          'nementen': [('nement', False)],
          'nementens': [('nement', False)],
          'nementet': [('nement', False)],
          'nements-': [('nement', False)],
          'nemien': [('nemi', False)],
          'nemiens': [('nemi', False)],
          'nemier': [('nemi', False)],
          'nemierna': [('nemi', False)],
          'nemiernas': [('nemi', False)],
          'nemiers': [('nemi', False)],
          'nemis': [('nemi', False)],
          'nemon': [('nemon', False)],
          'nemons': [('nemon', False)],
          'nems': [('nem', False)],
          'nen': [('nen', True), ('n', True)],
          'nena': [('ne', False)],
          'nenas': [('ne', False)],
          'nenhets': [('nenhet', False)],
          'nenhets-': [('nenhet', False)],
          'nens': [('nen', True), ('n', True)],
          'nens-': [('nen', True)],
          'nensen': [('nens', False)],
          'nensens': [('nens', False)],
          'nenser': [('nens', False)],
          'nenserna': [('nens', False)],
          'nensernas': [('nens', False)],
          'nensers': [('nens', False)],
          'nent': [('nent', False)],
          'nentanden': [('nentande', False)],
          'nentandens': [('nentande', False)],
          'nenten': [('nent', False)],
          'nentens': [('nent', False)],
          'nenter': [('nent', False)],
          'nenterna': [('nent', False)],
          'nenternas': [('nent', False)],
          'nenters': [('nent', False)],
          'neoler': [('neol', False)],
          'neolerna': [('neol', False)],
          'neolernas': [('neol', False)],
          'neolers': [('neol', False)],
          'neon': [('neon', True)],
          'neor': [('nea', False)],
          'neorden': [('neorden', False)],
          'neordens': [('neorden', False)],
          'neorna': [('nea', False)],
          'neornas': [('nea', False)],
          'neors': [('nea', False)],
          'nepens': [('nep', False)],
          'nepets': [('nep', False)],
          'ner-': [('ner', False)],
          'nerams': [('neramsa', False)],
          'nerams-': [('neramsa', False)],
          'nerare': [('nerare', False)],
          'nerares': [('nerare', False)],
          'nerarna': [('nerare', False)],
          'nerarnas': [('nerare', False)],
          'nergin': [('nergi', False)],
          'nergins': [('nergi', False)],
          'neri': [('neri', False)],
          'neri-': [('neri', False)],
          'nerien': [('nerium', True)],
          'neriens': [('nerium', True)],
          'nerier': [('nerium', True)],
          'nerierna': [('nerium', True)],
          'neriernas': [('nerium', True)],
          'neriers': [('nerium', True)],
          'neriet': [('neri', False)],
          'neris': [('neri', False)],
          'neris-': [('neri', False)],
          'nerit': [('neri', False)],
          'nernas': [('ner', False)],
          'ners-': [('ner', False)],
          'nersarnas': [('ner', False)],
          'nersen': [('ner', False)],
          'nerstans': [('nerstad', False)],
          'nertens': [('nert', False)],
          'nerter': [('nert', False)],
          'nerters': [('nert', False)],
          'nerts': [('nerts', True)],
          'nerts-': [('nerts', True)],
          'nerv': [('nerv', False)],
          'nerv-': [('nerv', True)],
          'nervals': [('nervals', False)],
          'nerven': [('nerv', False)],
          'nervens': [('nerv', False)],
          'nerver': [('nerv', False)],
          'nervers': [('nerv', False)],
          'nervs': [('nerv', False)],
          'nervs-': [('nerv', True)],
          'nervände': [('nervände', True), ('nervända', True)],
          'nervände-': [('nervända', True), ('nervände', True)],
          'neråns': [('nerå', False)],
          'nerår': [('nerå', False)],
          'nerårs': [('nerå', False)],
          'nes': [('ne', False)],
          'nes-': [('ne', False)],
          'nesan': [('nesa', True)],
          'nesans': [('nesa', True)],
          'nesar': [('nesare', False)],
          'nesarna': [('ne', False)],
          'nesarnas': [('nes', False)],
          'nesed': [('nesed', False)],
          'neseds': [('nesed', False)],
          'neseds-': [('nesed', False)],
          'neserier': [('neseri', False)],
          'neserierna': [('neseri', False)],
          'nesides': [('nesida', False)],
          'nesier': [('nesi', False)],
          'nesierna': [('nesier', False)],
          'nesiernas': [('nesi', False)],
          'nesiers': [('nesi', False)],
          'nesiet': [('nesium', False)],
          'nesiets': [('nesium', False)],
          'nesis': [('nesi', False)],
          'nesit': [('nesit', False)],
          'neslagar': [('neslag', False)],
          'neslagarna': [('neslag', False)],
          'neslagarnas': [('neslag', False)],
          'ness': [('ness', False)],
          'ness-': [('nessa', False)],
          'nessar': [('ness', False)],
          'nessars': [('ness', False)],
          'nesse': [('nessa', False)],
          'nesse-': [('nessa', False)],
          'nessen': [('ness', False)],
          'nessens': [('ness', False)],
          'nesser': [('ness', False)],
          'nesserna': [('ness', False)],
          'nessernas': [('ness', False)],
          'nessers': [('ness', False)],
          'nessor': [('nessa', False)],
          'nessors': [('nessa', False)],
          'nest-': [('nest', False)],
          'nestan': [('nestad', False)],
          'nestick': [('nesticka', False)],
          'nestick-': [('nesticka', False)],
          'nesticks': [('nesticka', False)],
          'nesticks-': [('nesticka', False)],
          'nestigar': [('nestig', False)],
          'nestigarna': [('nestig', False)],
          'nestigarnas': [('nestig', False)],
          'nestigen': [('nestig', False)],
          'nestigens': [('nestig', False)],
          'nestis': [('nesti', False)],
          'nestons': [('nesto', False)],
          'nestor': [('nestor', True)],
          'nestos': [('nesto', False)],
          'nestos-': [('nesto', False)],
          'net': [('n', True)],
          'netarnas': [('net', False)],
          'neten': [('net', False)],
          'netens': [('net', False)],
          'neter': [('net', False)],
          'neters': [('net', False)],
          'netets': [('net', False)],
          'netian': [('netian', False)],
          'netians': [('netian', False)],
          'netiker': [('netik', False)],
          'netikerna': [('netik', False)],
          'netikernas': [('netiker', False)],
          'netikers': [('netiker', False)],
          'netron': [('netron', False)],
          'nets': [('n', False)],
          'nett': [('nett', False)],
          'nett-': [('nett', False)],
          'netten': [('nett', False)],
          'netter': [('nett', False)],
          'netterna': [('nett', False)],
          'netternas': [('nett', False)],
          'netters': [('nett', False)],
          'netts': [('nett', False)],
          'netts-': [('nett', False)],
          'neuron': [('neuron', True)],
          'neurons': [('neuron', True)],
          'neuros': [('neuros', False)],
          'neuros-': [('neuros', False)],
          'neutrinor': [('neutrinor', True)],
          'neutrinorna': [('neutrinor', True)],
          'neutrinornas': [('neutrinor', True)],
          'neutrinors': [('neutrinor', True)],
          'never': [('never', False)],
          'neverket': [('neverk', False)],
          'nevers': [('never', False)],
          'nfader': [('nfader', False)],
          'nfader-': [('nfader', False)],
          'nfadern': [('nfader', False)],
          'nfaderns': [('nfader', False)],
          'nfaders': [('nfader', False)],
          'nfaders-': [('nfader', False)],
          'nfan': [('nfana', False)],
          'nfan-': [('nfana', False)],
          'nfans': [('nfana', False)],
          'nfans-': [('nfana', False)],
          'nfar': [('nfar', False)],
          'nfar-': [('nfar', False)],
          'nfare': [('nfara', False)],
          'nfaren': [('nfar', False)],
          'nfarens': [('nfar', False)],
          'nfars': [('nfar', False)],
          'nfars-': [('nfar', False)],
          'nfasen': [('nfas', False)],
          'nfasens': [('nfas', False)],
          'nfasonerna': [('nfason', False)],
          'nfasonernas': [('nfason', False)],
          'nfasoners': [('nfason', False)],
          'nfel': [('nfel', False)],
          'nfels': [('nfel', False)],
          'nfels-': [('nfel', False)],
          'nfink': [('nfink', False)],
          'nfink-': [('nfink', False)],
          'nfinks': [('nfink', False)],
          'nfinks-': [('nfink', False)],
          'nfirmanden': [('nfirmand', False)],
          'nfiskar': [('nfisk', False)],
          'nfiskarna': [('nfisk', False)],
          'nfiskarnas': [('nfisk', False)],
          'nflagg': [('nflagga', False)],
          'nflagg-': [('nflagga', False)],
          'nflaggs': [('nflagga', False)],
          'nflaggs-': [('nflagga', False)],
          'nflin': [('nflin', False)],
          'nflis': [('nflisa', False)],
          'nflis-': [('nflisa', False)],
          'nfläck': [('nfläck', False)],
          'nfläcks': [('nfläck', False)],
          'nflödet': [('nflöde', False)],
          'nfolien': [('nfolie', False)],
          'nfolierna': [('nfolie', False)],
          'nfon': [('nfo', False)],
          'nfoni': [('nfonia', False)],
          'nfoni-': [('nfonia', False)],
          'nfons': [('nfo', False)],
          'nfordringarna': [('nfordring', False)],
          'nfot': [('nfo', False)],
          'nfots': [('nfot', False)],
          'nfots-': [('nfot', False)],
          'nframställningar': [('nframställning', False)],
          'nframställningarna': [('nframställning', False)],
          'nframställningarnas': [('nframställning', False)],
          'nframställningars': [('nframställning', False)],
          'nfrans': [('nfrans', False)],
          'nfrans-': [('nfrans', False)],
          'nfur': [('nfur', False)],
          'nfur-': [('nfur', False)],
          'nfäder': [('nfader', False)],
          'nfäderna': [('nfader', False)],
          'nfädernas': [('nfader', False)],
          'nfäders': [('nfader', False)],
          'nfäll': [('nfäll', False)],
          'nfäll-': [('nfäll', False)],
          'nfälle': [('nfälle', False)],
          'nfällen': [('nfälle', False)],
          'nfällens': [('nfälle', False)],
          'nfälls': [('nfäll', False)],
          'nfälls-': [('nfäll', False)],
          'nfången': [('nfånge', False)],
          'nfångens': [('nfånge', False)],
          'nfår': [('nfår', False)],
          'nfår-': [('nfår', False)],
          'nfårs': [('nfår', False)],
          'nfårs-': [('nfår', False)],
          'nförar': [('nförare', False)],
          'nförarna': [('nförare', False)],
          'nförarnas': [('nförare', False)],
          'nfören': [('nföre', False)],
          'nförens': [('nföre', False)],
          'nförsäkringar': [('nförsäkring', False)],
          'nförsäkringarna': [('nförsäkring', False)],
          'nförsäkringarnas': [('nförsäkring', False)],
          'nförsäkringars': [('nförsäkring', False)],
          'nga': [('ngar', False)],
          'nga-': [('ngar', False)],
          'ngal': [('ngal', False)],
          'ngal-': [('ngal', False)],
          'ngalen': [('ngal', False)],
          'ngalens': [('ngal', False)],
          'ngales': [('ngales', False)],
          'ngals': [('ngal', False)],
          'ngals-': [('ngal', False)],
          'ngan': [('ngan', False)],
          'ngandens': [('ngande', False)],
          'ngans': [('ngan', False)],
          'ngans-': [('ngan', False)],
          'ngarden': [('ngarde', False)],
          'ngardens': [('ngarde', False)],
          'ngaren': [('ngare', False)],
          'ngars': [('ng', False)],
          'ngas': [('ngas', False)],
          'ngasernas': [('ngas', False)],
          'ngate': [('ngata', False)],
          'ngate-': [('ngata', False)],
          'ngats': [('ngata', False)],
          'ngbackarna': [('ngback', False)],
          'ngbacks-': [('ngback', False)],
          'ngbills': [('ngbilla', False)],
          'ngdags-': [('ngdags', False)],
          'ngdans': [('ngdans', False)],
          'ngdomar': [('ngdomare', False)],
          'ngdomarna': [('ngdomare', False)],
          'ngdomarnas': [('ngdomare', False)],
          'nge': [('nga', False)],
          'nge-': [('nga', False)],
          'ngel': [('ngel', False)],
          'ngel-': [('ngel', False)],
          'ngelsaxar': [('ngelsaxare', False)],
          'ngelsaxarna': [('ngelsaxare', False)],
          'ngelsaxarnas': [('ngelsaxare', False)],
          'ngelsen': [('ngelse', False)],
          'ngelsens': [('ngelse', False)],
          'ngen': [('ng', False)],
          'ngenie': [('ngenium', False)],
          'ngenie-': [('ngenium', False)],
          'ngenier': [('ngenium', False)],
          'ngenierna': [('ngenium', False)],
          'ngeniernas': [('ngenium', False)],
          'ngeniers': [('ngenium', False)],
          'ngeniet': [('ngenium', False)],
          'ngeniets': [('ngenium', False)],
          'ngens': [('ng', False)],
          'ngens-': [('ngens', False)],
          'nger': [('ng', False)],
          'ngeriernas': [('ngeri', False)],
          'ngerkrokarnas': [('ngerkrokar', False)],
          'ngerna': [('ng', False)],
          'ngernas': [('ng', False)],
          'ngers': [('ng', False)],
          'ngers-': [('nger', False)],
          'ngersarna': [('nger', False)],
          'ngersarnas': [('nger', False)],
          'ngersen': [('nger', False)],
          'ngersens': [('nger', False)],
          'nget': [('ng', False)],
          'ngettens': [('ngett', False)],
          'ngetter': [('nget', False)],
          'ngetterna': [('ngett', False)],
          'ngetternas': [('ngett', False)],
          'ngetters': [('ngett', False)],
          'nggas': [('nggas', False)],
          'nghets': [('nghet', False)],
          'ngie': [('ngium', False)],
          'ngie-': [('ngium', False)],
          'ngier': [('ngium', False)],
          'ngierna': [('ngium', False)],
          'ngiers': [('ngium', False)],
          'ngiften': [('ngifte', False)],
          'ngiftens': [('ngifte', False)],
          'ngiftet': [('ngifte', False)],
          'ngiftets': [('ngifte', False)],
          'ngip': [('ngipa', False)],
          'ngip-': [('ngipa', False)],
          'ngips': [('ngipa', False)],
          'ngips-': [('ngipa', False)],
          'ngis': [('ngis', False)],
          'ngis-': [('ngis', False)],
          'ngit': [('ngit', False)],
          'ngivar': [('ngivare', False)],
          'ngivarna': [('ngivare', False)],
          'ngivarnas': [('ngivare', False)],
          'ngkammar': [('ngkammare', False)],
          'ngkapp-': [('ngkappa', False)],
          'ngla': [('ngla', False)],
          'nglans': [('ngla', False)],
          'nglar': [('ngel', False)],
          'nglarna': [('ngel', False)],
          'nglarnas': [('ngel', False)],
          'nglars': [('ngel', False)],
          'nglen': [('ngel', False)],
          'nglens': [('ngel', False)],
          'nglien': [('nglie', False)],
          'ngliens': [('nglie', False)],
          'ngliet': [('nglie', False)],
          'ngliets': [('nglie', False)],
          'nglin': [('nglina', False)],
          'nglina': [('nglina', False)],
          'nglinas': [('nglina', False)],
          'nglins': [('nglina', False)],
          'nglors': [('ngla', False)],
          'nglott': [('nglotta', False)],
          'nglott-': [('nglott', False)],
          'nglotts': [('nglott', False)],
          'nglotts-': [('nglott', False)],
          'ngmoder': [('ngmor', False)],
          'ngmoder-': [('ngmoder', False)],
          'ngmodern': [('ngmoder', False)],
          'ngmoderns': [('ngmoder', False)],
          'ngmoders': [('ngmoder', False)],
          'ngmoders-': [('ngmoder', False)],
          'ngmor': [('ngmor', False)],
          'ngmors': [('ngmor', False)],
          'ngmödrar': [('ngmoder', False)],
          'ngmödrarna': [('ngmor', False)],
          'ngmödrarnas': [('ngmoder', False)],
          'ngmödrars': [('ngmoder', False)],
          'ngn': [('ng', False)],
          'ngna': [('ng', False)],
          'ngnas': [('ng', False)],
          'ngns': [('ng', False)],
          'ngo': [('ngo', False)],
          'ngo-': [('ngo', False)],
          'ngods': [('ngods', False)],
          'ngods-': [('ngods', False)],
          'ngonens': [('ngon', False)],
          'ngor': [('nga', False)],
          'ngorna': [('nga', False)],
          'ngornas': [('ngo', False)],
          'ngors': [('ngo', False)],
          'ngos': [('ngos', False)],
          'ngos-': [('ngos', False)],
          'ngosarna': [('ngos', False)],
          'ngosen': [('ngos', False)],
          'ngosens': [('ngos', False)],
          'ngot': [('ngo', False)],
          'ngots': [('ngo', False)],
          'ngranden': [('ngrande', False)],
          'ngrandens': [('ngrande', False)],
          'ngrandet': [('ngrande', False)],
          'ngrandets': [('ngrande', False)],
          'ngrann': [('ngranne', False)],
          'ngrann-': [('ngranne', False)],
          'ngranns': [('ngranne', False)],
          'ngranns-': [('ngranne', False)],
          'ngrar': [('nger', False)],
          'ngrar-': [('ngrare', False)],
          'ngraren': [('ngrare', False)],
          'ngrarens': [('ngrare', False)],
          'ngrarna': [('nger', False)],
          'ngrarnas': [('ngrare', False)],
          'ngrars': [('nger', False)],
          'ngrems': [('ngrem', False)],
          'ngrems-': [('ngrem', False)],
          'ngrev': [('ngrev', False)],
          'ngrevar': [('ngrev', False)],
          'ngrevarna': [('ngrev', False)],
          'ngrevarnas': [('ngrev', False)],
          'ngrevars': [('ngrev', False)],
          'ngreven': [('ngrev', False)],
          'ngrevens': [('ngrev', False)],
          'ngrevs': [('ngrev', False)],
          'ngrevs-': [('ngrev', False)],
          'ngripar': [('ngripare', False)],
          'ngriparna': [('ngripare', False)],
          'ngriparnas': [('ngripare', False)],
          'ngrull': [('ngrulla', False)],
          'ngrull-': [('ngrulla', False)],
          'ngrulle': [('ngrulla', False)],
          'ngrulle-': [('ngrulla', False)],
          'ngrulls': [('ngrulla', False)],
          'ngrums': [('ngrum', False)],
          'ngrums-': [('ngrum', False)],
          'ngrundan': [('ngrunda', False)],
          'ngrynet': [('ngryn', False)],
          'ngrynets': [('ngryn', False)],
          'ngräns': [('ngräns', False)],
          'ngräns-': [('ngräns', False)],
          'ngsback': [('ngsback', False)],
          'ngsbackarna': [('ngsback', False)],
          'ngsbackarnas': [('ngsback', False)],
          'ngsbacks': [('ngsback', False)],
          'ngsdags': [('ngsdag', False)],
          'ngsdags-': [('ngsdag', False)],
          'ngsdans': [('ngsdag', False)],
          'ngsdelarnas': [('ngsdelare', False)],
          'ngsen': [('ngs', False)],
          'ngsens': [('ng', False)],
          'ngsfiskar': [('ngsfiskare', False)],
          'ngsfiskarna': [('ngsfiskare', False)],
          'ngsfiskarnas': [('ngsfisk', False)],
          'ngsflaggs-': [('ngsflagga', False)],
          'ngsframställningarnas': [('ngsframställan', False)],
          'ngside': [('ngside', False)],
          'ngside-': [('ngside', False)],
          'ngsides': [('ngside', False)],
          'ngskalas': [('ngskala', False)],
          'ngskals-': [('ngskala', False)],
          'ngskostnader': [('ngskostnad', False)],
          'ngskostnaderna': [('ngskostnad', False)],
          'ngskostnadernas': [('ngskostnad', False)],
          'ngskostnaders': [('ngskostnad', False)],
          'ngskostnads': [('ngskostnad', False)],
          'ngskostnads-': [('ngskostnad', False)],
          'ngslagerna': [('ngslager', False)],
          'ngslandet': [('ngslande', False)],
          'ngslandets': [('ngsland', False)],
          'ngsområdets': [('ngsområde', False)],
          'ngsprogrammet': [('ngsprogram', False)],
          'ngsprogrammets': [('ngsprogram', False)],
          'ngsställens': [('ngsställe', False)],
          'ngstank': [('ngstanke', False)],
          'ngstankar': [('ngstanke', False)],
          'ngsten': [('ngst', False)],
          'ngstens': [('ngsten', False)],
          'ngster': [('ngst', False)],
          'ngsters': [('ngst', False)],
          'ngsvans': [('ngsvan', False)],
          'ngsverkets': [('ngsverk', False)],
          'ngsvägar': [('ngsväg', False)],
          'ngsvägarna': [('ngsväg', False)],
          'ngsvägarnas': [('ngsväg', False)],
          'ngsvägars': [('ngsväg', False)],
          'ngsvägs': [('ngsväg', False)],
          'ngsvägs-': [('ngsväg', False)],
          'ngsvärdens': [('ngsvärde', False)],
          'ngsvärdet': [('ngsvärde', False)],
          'ngtanden': [('ngtand', False)],
          'ngtandens': [('ngtand', False)],
          'ngubbs': [('ngubbe', False)],
          'ngubbs-': [('ngubbe', False)],
          'ngus': [('ngus', False)],
          'ngvård': [('ngvård', False)],
          'ngvårds': [('ngvård', False)],
          'ngvårds-': [('ngvård', False)],
          'ngärden': [('ngärde', False)],
          'ngärdens': [('ngärde', False)],
          'ngångar': [('ngångare', False)],
          'ngångarna': [('ngångare', False)],
          'ngångarnas': [('ngång', False)],
          'ngåve-': [('ngåva', False)],
          'ngåvor': [('ngåva', False)],
          'ngåvors': [('ngåva', False)],
          'nhake': [('nhake', False)],
          'nhake-': [('nhake', False)],
          'nhaken': [('nhake', False)],
          'nhakens': [('nhake', False)],
          'nhalv': [('nhalva', False)],
          'nhalv-': [('nhalva', False)],
          'nhalvs': [('nhalva', False)],
          'nhalvs-': [('nhalva', False)],
          'nhandlar': [('nhandel', False)],
          'nhandlarna': [('nhandel', False)],
          'nhandlarnas': [('nhandel', False)],
          'nhands': [('nhand', False)],
          'nhands-': [('nhand', False)],
          'nhas': [('nhas', False)],
          'nhasens': [('nhas', False)],
          'nheter': [('nhet', False)],
          'nheterna': [('nhet', False)],
          'nheternas': [('nhet', False)],
          'nheters': [('nhet', False)],
          'nhets': [('nhet', False)],
          'nhets-': [('nhet', False)],
          'nhimlen': [('nhimmel', False)],
          'nholts': [('nholts', False)],
          'nholts-': [('nholts', False)],
          'nhonas': [('nhona', False)],
          'nhoparna': [('nhop', False)],
          'nhots-': [('nhot', False)],
          'nhundars': [('nhund', False)],
          'nhus': [('nhus', False)],
          'nhytt': [('nhytt', False)],
          'nhytt-': [('nhytt', False)],
          'nhytts': [('nhytt', False)],
          'nhytts-': [('nhytt', False)],
          'nhyvlar': [('nhyvel', False)],
          'nhyvlarna': [('nhyvel', False)],
          'nhyvlarnas': [('nhyvel', False)],
          'nhäll': [('nhäll', False)],
          'nhäll-': [('nhäll', False)],
          'nhälls': [('nhäll', False)],
          'nhälls-': [('nhäll', False)],
          'nhästarnas': [('nhäst', False)],
          'nhävd': [('nhävd', False)],
          'nhävds': [('nhävd', False)],
          'nhävds-': [('nhävd', False)],
          'nhål': [('nhål', False)],
          'nhål-': [('nhål', False)],
          'nhåls': [('nhål', False)],
          'nhåls-': [('nhål', False)],
          'nhölje': [('nhölje', False)],
          'nhörighets': [('nhörighet', False)],
          'nhös': [('nhös', False)],
          'ni': [('ni', False)],
          'ni-': [('ni', False)],
          'nianden': [('niande', True)],
          'nibb': [('nibb', False)],
          'nibbarnas': [('nibb', False)],
          'nibbars': [('nibb', False)],
          'nibbens': [('nibb', False)],
          'nibbs': [('nibb', False)],
          'nibbs-': [('nibb', False)],
          'nic': [('nic', False)],
          'nic-': [('nic', False)],
          'nicens': [('nic', False)],
          'nicier': [('nicier', False)],
          'nicierna': [('nicier', False)],
          'niciers': [('nicier', False)],
          'nicina': [('nikus', False)],
          'nicinas': [('nikus', False)],
          'nicis': [('nikus', False)],
          'nick-': [('nick', False)],
          'nickar': [('nick', False)],
          'nickarna': [('nick', False)],
          'nickarnas': [('nick', True)],
          'nickels': [('nickel', True)],
          'nicker': [('nick', False)],
          'nickers': [('nick', False)],
          'nicklar': [('nickel', False)],
          'nicklarnas': [('nickel', False)],
          'nicks': [('nick', False)],
          'nicks-': [('nick', False)],
          'nics': [('nic', False)],
          'nidar': [('nidare', False)],
          'nidarna': [('nidare', False)],
          'nidarnas': [('nidare', False)],
          'nide': [('nide', False)],
          'niden': [('nid', False)],
          'nidens': [('nid', False)],
          'niderit': [('nideri', False)],
          'nides': [('nide', False)],
          'nidet': [('nide', False)],
          'nidets': [('nide', False)],
          'nids': [('nid', False)],
          'nids-': [('nide', False)],
          'nie': [('nier', False)],
          'nie-': [('nia', False)],
          'nieller': [('niello', True)],
          'niellernas': [('niello', True)],
          'nien': [('ni', False)],
          'niens': [('ni', False)],
          'nier': [('nier', False)],
          'nierna': [('nier', False)],
          'nies': [('ny', False)],
          'nietidens': [('nietiden', True)],
          'niets': [('nium', False)],
          'niffen': [('niff', False)],
          'nigheter': [('nighet', False)],
          'nigheterna': [('nighet', False)],
          'nigheternas': [('nighet', False)],
          'nigheters': [('nighet', False)],
          'nighets-': [('nighet', False)],
          'nik': [('nika', False)],
          'nik-': [('nika', False)],
          'nikan': [('nika', False)],
          'nikandens': [('nikande', False)],
          'nikans': [('nika', False)],
          'nikarnas': [('nik', False)],
          'nikas': [('nika', False)],
          'nikator': [('nikator', False)],
          'nikators': [('nikator', False)],
          'niker': [('niker', False)],
          'nikerna': [('niker', False)],
          'nikernas': [('niker', False)],
          'nikers': [('niker', False)],
          'niks': [('nika', False)],
          'niks-': [('nika', False)],
          'nikten': [('nikt', True)],
          'niktens': [('nikt', True)],
          'niktet': [('nikt', True)],
          'nikts': [('nikt', True)],
          'nikts-': [('nikt', True)],
          'nikurs': [('nikur', False)],
          'nilanden': [('niland', False)],
          'nilandens': [('niland', False)],
          'nilandet': [('niland', False)],
          'nilandets': [('niland', False)],
          'nilin': [('nilin', False)],
          'nilins': [('nilin', False)],
          'nilj': [('nilj', False)],
          'nilj-': [('nilj', False)],
          'nilje': [('nilja', False)],
          'nilje-': [('nilja', False)],
          'niljen': [('nilj', False)],
          'niljens': [('nilj', False)],
          'niljs': [('nilj', False)],
          'nill': [('nill', False)],
          'nill-': [('nill', False)],
          'nillan': [('nilla', False)],
          'nillen': [('nill', False)],
          'nillens': [('nille', False)],
          'nills': [('nill', False)],
          'nimet': [('nim', False)],
          'nimets': [('nim', False)],
          'nin': [('ni', False)],
          'nina': [('ni', False)],
          'ninas': [('ni', False)],
          'niner': [('ninum', False)],
          'ninerna': [('ninum', False)],
          'ninernas': [('ninum', False)],
          'niners': [('ninum', False)],
          'ning': [('ning', False)],
          'ning-': [('ning', False)],
          'ningar': [('ning', False)],
          'ningarna': [('ning', False)],
          'ningarnas': [('ning', False)],
          'ningars': [('ning', False)],
          'ningen': [('ning', False)],
          'ningens': [('ning', False)],
          'nings': [('ning', False)],
          'nings-': [('ning', False)],
          'ningsbot': [('ningsbo', False)],
          'ningsbots': [('ningsbo', False)],
          'ningscentrers': [('ningscenter', False)],
          'ningscentret': [('ningscenter', False)],
          'ningscentrets': [('ningscenter', False)],
          'ningsdags': [('ningsdag', False)],
          'ningsdags-': [('ningsdag', False)],
          'ningsdelar': [('ningsdel', False)],
          'ningsdos': [('ningsdosa', False)],
          'ningsdos-': [('ningsdosa', False)],
          'ningsfång-': [('ningsfånge', False)],
          'ningsfångens': [('ningsfånge', False)],
          'ningsfångs': [('ningsfånge', False)],
          'ningskasse': [('ningskassa', False)],
          'ningskostnader': [('ningskostnad', False)],
          'ningskostnaderna': [('ningskostnad', False)],
          'ningskostnadernas': [('ningskostnad', False)],
          'ningskostnaders': [('ningskostnad', False)],
          'ningskostnads': [('ningskostnad', False)],
          'ningskostnads-': [('ningskostnad', False)],
          'ningskrans': [('ningskrans', False)],
          'ningskrans-': [('ningskrans', False)],
          'ningskurs': [('ningskur', False)],
          'ningskurs-': [('ningskur', False)],
          'ningslins': [('ningslina', False)],
          'ningslins-': [('ningslina', False)],
          'ningsställen': [('ningsställ', False)],
          'ningsställens': [('ningsställe', False)],
          'ningsstället': [('ningsställ', False)],
          'ningsställets': [('ningsställ', False)],
          'ningstank': [('ningstanke', False)],
          'ningstankar': [('ningstanke', False)],
          'ningstanken': [('ningstank', False)],
          'ninier': [('ninier', False)],
          'ninierna': [('ninier', False)],
          'ninne': [('ninna', False)],
          'ninne-': [('ninna', False)],
          'ninons': [('nino', False)],
          'ninos': [('nino', False)],
          'nins': [('ni', False)],
          'niol': [('niol', False)],
          'niol-': [('niol', False)],
          'niols': [('niol', False)],
          'nion': [('nion', False)],
          'nionen': [('nion', False)],
          'nionens': [('nion', False)],
          'nioner': [('nion', False)],
          'nionerna': [('nion', False)],
          'nionernas': [('nion', False)],
          'nioners': [('nion', False)],
          'nions': [('nion', False)],
          'nior': [('nia', False)],
          'niorna': [('nia', False)],
          'niornas': [('nia', False)],
          'niors': [('nia', False)],
          'nip': [('nipa', True)],
          'nip-': [('nipa', False)],
          'nipan': [('nipa', False)],
          'nipans': [('nipa', True)],
          'niparnas': [('nip', False)],
          'nipas': [('nipa', False)],
          'nippe': [('nippa', False)],
          'nippe-': [('nippa', False)],
          'nipper': [('nipper', True)],
          'nippets': [('nippe', False)],
          'nipplar': [('nippel', True)],
          'nipplarna': [('nippel', True)],
          'nipplarnas': [('nippel', True)],
          'nips': [('nipa', False)],
          'nips-': [('nipa', False)],
          'nirer': [('nir', False)],
          'nirerna': [('nir', False)],
          'nirernas': [('nir', False)],
          'nirers': [('nir', False)],
          'nirk': [('nirk', False)],
          'nirk-': [('nirk', False)],
          'nirket': [('nirk', False)],
          'nirks': [('nirk', False)],
          'nirks-': [('nirk', False)],
          'nirr': [('nirr', False)],
          'nirr-': [('nirr', False)],
          'nirrs-': [('nirr', False)],
          'nis-': [('nia', False)],
          'nisarna': [('ni', False)],
          'nisarnas': [('ni', False)],
          'nisationen': [('nisation', False)],
          'nisen': [('ni', False)],
          'nisens': [('ni', False)],
          'nish': [('nish', False)],
          'nish-': [('nish', False)],
          'niskan': [('niska', False)],
          'niskans': [('niska', False)],
          'niske': [('niska', False)],
          'niske-': [('niska', False)],
          'nisko': [('niska', False)],
          'nismer': [('nism', False)],
          'nismerna': [('nism', False)],
          'nismernas': [('nism', False)],
          'nismers': [('nism', False)],
          'niss': [('niss', False)],
          'niss-': [('nissa', False)],
          'nissarna': [('nisse', False)],
          'nissarnas': [('nisse', False)],
          'nisse': [('nisse', True)],
          'nisse-': [('nisse', True)],
          'nissel': [('nissel', False)],
          'nissel-': [('nissel', False)],
          'nissen': [('nisse', True)],
          'nissens': [('nisse', True)],
          'nist-': [('nist', False)],
          'niste': [('nista', False)],
          'nisten': [('nist', False)],
          'nistens': [('nist', False)],
          'nister': [('nist', False)],
          'nisterier': [('nisterium', False)],
          'nisterierna': [('nisterium', False)],
          'nisteriers': [('nisterium', False)],
          'nisteriet': [('nisterium', False)],
          'nistern': [('nister', False)],
          'nisterna': [('nist', False)],
          'nisternas': [('nist', False)],
          'nisterns': [('nister', False)],
          'nisters': [('nist', False)],
          'nistik': [('nistik', False)],
          'nistik-': [('nistik', False)],
          'nistiker': [('nistik', False)],
          'nistikerna': [('nistik', False)],
          'nistikernas': [('nistik', False)],
          'nistikers': [('nistik', False)],
          'nistiks': [('nistik', False)],
          'nistiks-': [('nistik', False)],
          'nistor': [('nista', False)],
          'nistors': [('nista', False)],
          'nit': [('nit', True)],
          'nitarnas': [('nit', False)],
          'nitens': [('nit', True)],
          'niternas': [('nit', False)],
          'nitet': [('nit', False)],
          'nitets': [('nit', True)],
          'nitor': [('nitor', False)],
          'nitors': [('nitor', False)],
          'nits': [('nit', False)],
          'nits-': [('nit', True)],
          'nitsarnas': [('nitsare', False)],
          'nitsen': [('nits', False)],
          'nitsens': [('nits', False)],
          'nitt': [('nitt', False)],
          'nitt-': [('nitt', False)],
          'nittar': [('nitt', False)],
          'nittarna': [('nitt', False)],
          'nitten': [('nitt', False)],
          'nitter': [('nitter', False)],
          'nitter-': [('nitter', False)],
          'nitts': [('nitt', False)],
          'nitts-': [('nitt', False)],
          'nium': [('nium', False)],
          'niums': [('nium', False)],
          'nivar': [('niv', False)],
          'nivets': [('niv', False)],
          'nivor': [('nivor', False)],
          'nivors': [('nivor', False)],
          'nj': [('nj', False)],
          'nj-': [('nj', False)],
          'njack': [('njack', False)],
          'njack-': [('njacka', False)],
          'njacks': [('njacka', False)],
          'njacks-': [('njack', False)],
          'njan': [('nja', False)],
          'njans': [('nja', False)],
          'nje': [('nja', False)],
          'nje-': [('nja', False)],
          'njoar': [('njoar', False)],
          'njoars': [('njoar', False)],
          'njoll': [('njolle', False)],
          'njoll-': [('njolle', False)],
          'njolle': [('njolle', False)],
          'njon': [('njon', False)],
          'njoner': [('njon', False)],
          'njonerna': [('njon', False)],
          'njonernas': [('njon', False)],
          'njoners': [('njon', False)],
          'njons': [('njon', False)],
          'njor': [('nja', False)],
          'njorna': [('nja', False)],
          'njornas': [('nja', False)],
          'njos': [('njo', False)],
          'njos-': [('njo', False)],
          'njs': [('nj', False)],
          'njs-': [('nj', False)],
          'njutar': [('njutare', False)],
          'njutarna': [('njutare', False)],
          'njutarnas': [('njutare', False)],
          'njär': [('njär', False)],
          'njär-': [('njär', False)],
          'njärs': [('njär', False)],
          'njärs-': [('njär', False)],
          'njörn': [('njör', False)],
          'njörns': [('njör', False)],
          'nkalas': [('nkalas', False)],
          'nkammar': [('nkammare', False)],
          'nkammarna': [('nkammare', False)],
          'nkammarnas': [('nkammare', False)],
          'nkan': [('nka', False)],
          'nkanden': [('nkande', False)],
          'nkans': [('nka', False)],
          'nkapp': [('nkappa', False)],
          'nkapp-': [('nkappa', False)],
          'nkappe': [('nkappa', False)],
          'nkapps': [('nkappa', False)],
          'nkapps-': [('nkappa', False)],
          'nkar-': [('nkare', False)],
          'nkare': [('nkare', False)],
          'nkare-': [('nkare', False)],
          'nkaren': [('nkare', False)],
          'nkarens': [('nkare', False)],
          'nkaret': [('nkare', False)],
          'nkarets': [('nkare', False)],
          'nkars': [('nk', False)],
          'nkars-': [('nkar', False)],
          'nkart': [('nkarta', False)],
          'nkart-': [('nkarta', False)],
          'nkartan': [('nkarta', False)],
          'nkarts': [('nkarta', False)],
          'nkarts-': [('nkarta', False)],
          'nkas': [('nka', False)],
          'nke': [('nka', False)],
          'nke-': [('nka', False)],
          'nkeen': [('nkee', False)],
          'nkel': [('nkel', False)],
          'nkel-': [('nkel', False)],
          'nkels': [('nkel', False)],
          'nkels-': [('nkel', False)],
          'nken': [('nk', False)],
          'nken-': [('nken', False)],
          'nkens': [('nk', False)],
          'nkerits': [('nkeri', False)],
          'nkersens': [('nker', False)],
          'nkesen': [('nkes', False)],
          'nkesens': [('nkes', False)],
          'nket': [('nk', False)],
          'nkick': [('nkick', False)],
          'nkick-': [('nkick', False)],
          'nkicks': [('nkick', False)],
          'nkicks-': [('nkick', False)],
          'nkikar': [('nkik', False)],
          'nkikarna': [('nkik', False)],
          'nkikarnas': [('nkik', False)],
          'nkill': [('nkill', False)],
          'nkill-': [('nkill', False)],
          'nkillen': [('nkill', False)],
          'nkillens': [('nkill', False)],
          'nkills': [('nkill', False)],
          'nkills-': [('nkill', False)],
          'nkins': [('nkin', False)],
          'nkis-': [('nkis', False)],
          'nkisen': [('nkis', False)],
          'nkisens': [('nkis', False)],
          'nkist': [('nkist', False)],
          'nkist-': [('nkista', False)],
          'nkistans': [('nkista', False)],
          'nklan': [('nkla', False)],
          'nklandets': [('nklande', False)],
          'nklans': [('nkla', False)],
          'nklapp': [('nklapp', False)],
          'nklapps': [('nklapp', False)],
          'nklapps-': [('nklapp', False)],
          'nklar': [('nkel', False)],
          'nklarna': [('nkel', False)],
          'nklarnas': [('nkel', False)],
          'nklars': [('nkel', False)],
          'nklas': [('nkla', False)],
          'nklav': [('nklav', False)],
          'nklav-': [('nklav', False)],
          'nklaven': [('nklav', False)],
          'nklavens': [('nklav', False)],
          'nklaver': [('nklav', False)],
          'nklavers': [('nklav', False)],
          'nklavs': [('nklav', False)],
          'nklavs-': [('nklav', False)],
          'nkler': [('nkler', False)],
          'nklerna': [('nkler', False)],
          'nklernas': [('nkel', False)],
          'nklers': [('nkler', False)],
          'nklet': [('nkel', False)],
          'nklets': [('nkel', False)],
          'nkling': [('nkling', False)],
          'nkling-': [('nkling', False)],
          'nklings': [('nkling', False)],
          'nklings-': [('nkling', False)],
          'nkliniker': [('nklinik', False)],
          'nklinikerna': [('nklinik', False)],
          'nklinikernas': [('nklinik', False)],
          'nklinikers': [('nklinik', False)],
          'nklipp': [('nklipp', False)],
          'nklipps': [('nklipp', False)],
          'nklipps-': [('nklipp', False)],
          'nklon': [('nklo', False)],
          'nklons': [('nklo', False)],
          'nklor': [('nklo', False)],
          'nklorna': [('nkla', False)],
          'nklornas': [('nkla', False)],
          'nklors': [('nkla', False)],
          'nklyft': [('nklyfta', False)],
          'nklyft-': [('nklyfta', False)],
          'nklyfts': [('nklyfta', False)],
          'nklyfts-': [('nklyfta', False)],
          'nklädes-': [('nkläder', False)],
          'nkningar': [('nkning', False)],
          'nkningarna': [('nkning', False)],
          'nkningarnas': [('nkning', False)],
          'nkningars': [('nkning', False)],
          'nknings': [('nkning', False)],
          'nknings-': [('nkning', False)],
          'nknot': [('nknota', False)],
          'nknot-': [('nknota', False)],
          'nknots': [('nknota', False)],
          'nknots-': [('nknota', False)],
          'nknut': [('nknut', False)],
          'nknuts': [('nknut', False)],
          'nknuts-': [('nknut', False)],
          'nko-': [('nko', False)],
          'nkock': [('nkock', False)],
          'nkocks': [('nkock', False)],
          'nkocks-': [('nkock', False)],
          'nkol': [('nkol', False)],
          'nkol-': [('nkol', False)],
          'nkols': [('nkol', False)],
          'nkols-': [('nkol', False)],
          'nkomat': [('nkomat', False)],
          'nkomats': [('nkomat', False)],
          'nkomst-': [('nkomst', False)],
          'nkomster': [('nkomst', False)],
          'nkomsterna': [('nkomst', False)],
          'nkomsternas': [('nkomst', False)],
          'nkomsters': [('nkomst', False)],
          'nkon': [('nko', False)],
          'nkona': [('nko', False)],
          'nkonas': [('nko', False)],
          'nkons': [('nko', False)],
          'nkonst-': [('nkonst', False)],
          'nkonsterna': [('nkonst', False)],
          'nkonsternas': [('nkonst', False)],
          'nkonsters': [('nkonst', False)],
          'nkonter': [('nkonter', False)],
          'nkonters': [('nkonter', False)],
          'nkop': [('nkop', False)],
          'nkop-': [('nkop', False)],
          'nkopp': [('nkoppa', False)],
          'nkopp-': [('nkoppa', False)],
          'nkoppor': [('nkoppor', False)],
          'nkopporna': [('nkoppor', False)],
          'nkoppornas': [('nkoppor', False)],
          'nkoppors': [('nkoppor', False)],
          'nkopps': [('nkoppa', False)],
          'nkopps-': [('nkoppa', False)],
          'nkops': [('nkop', False)],
          'nkor': [('nka', False)],
          'nkordans': [('nkordans', False)],
          'nkorden': [('nkorden', False)],
          'nkordens': [('nkorden', False)],
          'nkorna': [('nka', False)],
          'nkornas': [('nka', False)],
          'nkors': [('nka', False)],
          'nkors-': [('nkors', False)],
          'nkos': [('nko', False)],
          'nkos-': [('nko', False)],
          'nkot': [('nko', False)],
          'nkots': [('nko', False)],
          'nkrafternas': [('nkraft', False)],
          'nkrafters': [('nkraft', False)],
          'nkrafts': [('nkraft', False)],
          'nkrafts-': [('nkraft', False)],
          'nkrar': [('nker', False)],
          'nkrarna': [('nker', False)],
          'nkrater': [('nkrater', False)],
          'nkrets-': [('nkrets', False)],
          'nkringar': [('nkring', False)],
          'nkringars': [('nkring', False)],
          'nkrokarnas': [('nkrok', False)],
          'nkronan': [('nkrona', False)],
          'nkronans': [('nkrona', False)],
          'nkrons-': [('nkrona', False)],
          'nkrossar': [('nkross', False)],
          'nkrossarnas': [('nkross', False)],
          'nkrån': [('nkrån', False)],
          'nkråns': [('nkrån', False)],
          'nkröken': [('nkröken', False)],
          'nkrökens': [('nkröken', False)],
          'nkställen': [('nkställe', False)],
          'nkställens': [('nkställe', False)],
          'nkstället': [('nkställe', False)],
          'nkställets': [('nkställe', False)],
          'nkter': [('nkter', False)],
          'nkterna': [('nkter', False)],
          'nkternas': [('nkter', False)],
          'nkters': [('nkter', False)],
          'nktioner': [('nktion', False)],
          'nktionerna': [('nktion', False)],
          'nktionernas': [('nktion', False)],
          'nktioners': [('nktion', False)],
          'nktions': [('nktion', False)],
          'nktons': [('nkton', False)],
          'nktuarie': [('nktuarium', False)],
          'nktuarierna': [('nktuarium', False)],
          'nktuariers': [('nktuarium', False)],
          'nkull': [('nkulle', False)],
          'nkull-': [('nkulle', False)],
          'nkullar': [('nkulle', False)],
          'nkullarna': [('nkulle', False)],
          'nkullarnas': [('nkulle', False)],
          'nkullars': [('nkulle', False)],
          'nkulle': [('nkulle', False)],
          'nkulle-': [('nkulle', False)],
          'nkullen': [('nkulle', False)],
          'nkullens': [('nkulle', False)],
          'nkulls': [('nkulla', False)],
          'nkulls-': [('nkulla', False)],
          'nkulorna': [('nkula', False)],
          'nkulornas': [('nkula', False)],
          'nkulors': [('nkula', False)],
          'nkungar': [('nkunge', False)],
          'nkungarna': [('nkunge', False)],
          'nkungarnas': [('nkunge', False)],
          'nkungars': [('nkunge', False)],
          'nkungen': [('nkunge', False)],
          'nkungens': [('nkunge', False)],
          'nkunskaps': [('nkunskap', False)],
          'nkur-': [('nkur', False)],
          'nkurrens': [('nkurrens', False)],
          'nkurs': [('nkur', False)],
          'nkurs-': [('nkur', False)],
          'nkuts': [('nkuts', False)],
          'nkuts-': [('nkuts', False)],
          'nkvarter': [('nkvarter', False)],
          'nkvarters': [('nkvarter', False)],
          'nkvisitor': [('nkvisitor', False)],
          'nkvisitors': [('nkvisitor', False)],
          'nkyl': [('nkyla', False)],
          'nkyl-': [('nkyla', False)],
          'nkäll-': [('nkälla', False)],
          'nkärr': [('nkärra', False)],
          'nkärr-': [('nkärra', False)],
          'nkärrs': [('nkärra', False)],
          'nkärrs-': [('nkärra', False)],
          'nkår': [('nkår', False)],
          'nkåren': [('nkår', False)],
          'nkårens': [('nkår', False)],
          'nkårs': [('nkår', False)],
          'nkårs-': [('nkår', False)],
          'nkök': [('nkök', False)],
          'nkök-': [('nkök', False)],
          'nköks': [('nkök', False)],
          'nköks-': [('nkök', False)],
          'nkön': [('nkön', False)],
          'nkön-': [('nkön', False)],
          'nköns': [('nkön', False)],
          'nkör': [('nkör', False)],
          'nkörs': [('nkör', False)],
          'nkös': [('nkös', False)],
          'nlack': [('nlack', False)],
          'nlag': [('nlag', False)],
          'nlag-': [('nlaga', False)],
          'nlagans': [('nlaga', False)],
          'nlagarna': [('nlag', False)],
          'nlagarnas': [('nlag', False)],
          'nlage': [('nlaga', False)],
          'nlage-': [('nlaga', False)],
          'nlagen': [('nlag', False)],
          'nlagerna': [('nlager', False)],
          'nlaget': [('nlag', False)],
          'nlagor': [('nlaga', False)],
          'nlagorna': [('nlaga', False)],
          'nlagornas': [('nlaga', False)],
          'nlagors': [('nlaga', False)],
          'nlags': [('nlag', False)],
          'nlags-': [('nlag', False)],
          'nlamp': [('nlampa', False)],
          'nlamp-': [('nlampa', False)],
          'nlamps': [('nlampa', False)],
          'nlamps-': [('nlampa', False)],
          'nlandets': [('nland', False)],
          'nlar': [('nnel', False)],
          'nlarna': [('nnel', False)],
          'nlarnas': [('nnel', False)],
          'nlars': [('nnel', False)],
          'nlav': [('nlav', False)],
          'nlav-': [('nlav', False)],
          'nlavar': [('nlav', False)],
          'nlavarna': [('nlav', False)],
          'nlavarnas': [('nlav', False)],
          'nlavars': [('nlav', False)],
          'nlaven': [('nlav', False)],
          'nlavens': [('nlav', False)],
          'nlavs': [('nlav', False)],
          'nlavs-': [('nlav', False)],
          'nlek': [('nlek', False)],
          'nlekar': [('nlek', False)],
          'nlekarna': [('nlek', False)],
          'nlekarnas': [('nlek', False)],
          'nleken': [('nlek', False)],
          'nlekens': [('nlek', False)],
          'nleks-': [('nlek', False)],
          'nletets': [('nlete', False)],
          'nlets': [('nlete', False)],
          'nligans': [('nliga', False)],
          'nlighets': [('nlighet', False)],
          'nlik': [('nlika', False)],
          'nlik-': [('nlika', False)],
          'nlike': [('nlika', False)],
          'nlike-': [('nlika', False)],
          'nliks': [('nlika', False)],
          'nliks-': [('nlika', False)],
          'nlir': [('nlir', False)],
          'nliren': [('nlir', False)],
          'nlirens': [('nlir', False)],
          'nlirs': [('nlir', False)],
          'nlirs-': [('nlir', False)],
          'nlist': [('nlist', False)],
          'nlist-': [('nlist', False)],
          'nlivs': [('nliv', False)],
          'nlivs-': [('nliv', False)],
          'nlok': [('nloka', False)],
          'nlok-': [('nloka', False)],
          'nloks': [('nloka', False)],
          'nloks-': [('nloka', False)],
          'nlopp': [('nloppa', False)],
          'nlopp-': [('nloppa', False)],
          'nlopps': [('nloppa', False)],
          'nlopps-': [('nloppa', False)],
          'nluck': [('nlucka', False)],
          'nluck-': [('nlucka', False)],
          'nlucks': [('nlucka', False)],
          'nlucks-': [('nlucka', False)],
          'nlut': [('nlut', False)],
          'nlut-': [('nlut', False)],
          'nlutar': [('nlut', False)],
          'nluten': [('nlut', False)],
          'nluts': [('nlut', False)],
          'nluts-': [('nlut', False)],
          'nläggar': [('nläggare', False)],
          'nläggarna': [('nläggare', False)],
          'nläggarnas': [('nläggare', False)],
          'nländar': [('nländare', False)],
          'nländarna': [('nländare', False)],
          'nländer': [('nland', False)],
          'nländerna': [('nland', False)],
          'nländernas': [('nland', False)],
          'nländers': [('nland', False)],
          'nlåns': [('nlån', False)],
          'nlåns-': [('nlån', False)],
          'nlås': [('nlås', False)],
          'nlåt': [('nlåt', False)],
          'nlön': [('nlön', False)],
          'nlöss': [('nlus', False)],
          'nlössen': [('nlus', False)],
          'nlössens': [('nlus', False)],
          'nmack': [('nmack', False)],
          'nmack-': [('nmack', False)],
          'nmacks': [('nmack', False)],
          'nmacks-': [('nmack', False)],
          'nmakar': [('nmakare', False)],
          'nmakarna': [('nmakare', False)],
          'nmakarnas': [('nmakare', False)],
          'nmalts': [('nmalt', False)],
          'nman': [('nman', False)],
          'nmanets': [('nmanet', False)],
          'nmannens': [('nman', False)],
          'nmans': [('nman', False)],
          'nmask': [('nmask', False)],
          'nmask-': [('nmask', False)],
          'nmaster': [('nmast', False)],
          'nmasters': [('nmast', False)],
          'nmat': [('nmat', False)],
          'nmaten': [('nmat', False)],
          'nmats': [('nmat', False)],
          'nmatt': [('nmatta', False)],
          'nmatt-': [('nmatta', False)],
          'nmatte': [('nmatta', False)],
          'nmatte-': [('nmatta', False)],
          'nmatts': [('nmatta', False)],
          'nmatts-': [('nmatta', False)],
          'nmelon': [('nmelon', False)],
          'nmelon-': [('nmelon', False)],
          'nmeloner': [('nmelon', False)],
          'nmelonerna': [('nmelon', False)],
          'nmelonernas': [('nmelon', False)],
          'nmeloners': [('nmelon', False)],
          'nmelons': [('nmelon', False)],
          'nmen': [('num', False)],
          'nmens': [('num', False)],
          'nmet': [('num', False)],
          'nmetoden': [('nmetoden', False)],
          'nmetodens': [('nmetoden', False)],
          'nmets': [('num', False)],
          'nminister': [('nminister', False)],
          'nministers': [('nminister', False)],
          'nmjölk': [('nmjölk', False)],
          'nmjölk-': [('nmjölk', False)],
          'nmjölken': [('nmjölk', False)],
          'nmjölkens': [('nmjölk', False)],
          'nmjölks': [('nmjölk', False)],
          'nmjölks-': [('nmjölk', False)],
          'nmo': [('nmo', False)],
          'nmoder': [('nmoder', False)],
          'nmoder-': [('nmoder', False)],
          'nmodern': [('nmoder', False)],
          'nmoderns': [('nmoder', False)],
          'nmoders': [('nmoder', False)],
          'nmoders-': [('nmoder', False)],
          'nmodet': [('nmod', False)],
          'nmodets': [('nmod', False)],
          'nmods': [('nmod', False)],
          'nmods-': [('nmod', False)],
          'nmos': [('nmos', False)],
          'nmos-': [('nmos', False)],
          'nmosen': [('nmos', False)],
          'nmosens': [('nmos', False)],
          'nmotet': [('nmot', False)],
          'nmots': [('nmot', False)],
          'nmurar': [('nmur', False)],
          'nmurarna': [('nmur', False)],
          'nmurarnas': [('nmur', False)],
          'nmussel-': [('nmussla', False)],
          'nmygg': [('nmygga', False)],
          'nmygg-': [('nmygga', False)],
          'nmyggs': [('nmygga', False)],
          'nmyggs-': [('nmygga', False)],
          'nmän': [('nman', False)],
          'nmäns': [('nman', False)],
          'nmödrar': [('nmoder', False)],
          'nmödrarna': [('nmoder', False)],
          'nmödrarnas': [('nmoder', False)],
          'nmödrars': [('nmoder', False)],
          'nmöss': [('nmössa', False)],
          'nna': [('nna', False)],
          'nnader': [('nnad', False)],
          'nnaderna': [('nnad', False)],
          'nnadernas': [('nnad', False)],
          'nnaders': [('nnad', False)],
          'nnads': [('nnad', False)],
          'nnads-': [('nnad', False)],
          'nnagets': [('nnage', False)],
          'nnal': [('nnal', False)],
          'nnal-': [('nnal', False)],
          'nnalen': [('nnal', False)],
          'nnalens': [('nnal', False)],
          'nnaler': [('nnal', False)],
          'nnalerna': [('nnal', False)],
          'nnalernas': [('nnal', False)],
          'nnalers': [('nnal', False)],
          'nnals': [('nnaler', False)],
          'nnamn': [('nnamn', False)],
          'nnamn-': [('nnamn', False)],
          'nnamnen': [('nnamn', False)],
          'nnamnens': [('nnamn', False)],
          'nnamns': [('nnamn', False)],
          'nnamns-': [('nnamn', False)],
          'nnanas': [('nna', False)],
          'nnanden': [('nnande', False)],
          'nnans-': [('nnans', False)],
          'nnar': [('nnare', False)],
          'nnar-': [('nnare', False)],
          'nnaren': [('nnare', False)],
          'nnarens': [('nnare', False)],
          'nnarna': [('nn', False)],
          'nnars': [('nne', False)],
          'nnas': [('nna', False)],
          'nnas-': [('nna', False)],
          'nnat': [('nna', False)],
          'nnats': [('nna', False)],
          'nnattens': [('nnatt', False)],
          'nnbens': [('nnben', False)],
          'nnbit': [('nnbit', False)],
          'nne-': [('nna', False)],
          'nnean': [('nnea', False)],
          'nneans': [('nnea', False)],
          'nnen': [('nne', False)],
          'nnens': [('nn', False)],
          'nnents': [('nnent', False)],
          'nnents-': [('nnent', False)],
          'nner': [('nn', False)],
          'nnerier': [('nneri', False)],
          'nnerierna': [('nneri', False)],
          'nneriernas': [('nneri', False)],
          'nneriers': [('nneri', False)],
          'nnerna': [('nn', False)],
          'nnernas': [('nn', False)],
          'nners': [('nn', False)],
          'nnet': [('nn', False)],
          'nnets': [('nne', False)],
          'nneutrinor': [('nneutrino', False)],
          'nneutrinorna': [('nneutrino', False)],
          'nneutrinornas': [('nneutrino', False)],
          'nneutrinors': [('nneutrino', False)],
          'nnfällen': [('nnfäll', False)],
          'nnfällens': [('nnfäll', False)],
          'nnglas': [('nnglas', False)],
          'nngångar': [('nngång', False)],
          'nngångarna': [('nngång', False)],
          'nnie': [('nnium', False)],
          'nnie-': [('nnium', False)],
          'nnier': [('nnium', False)],
          'nnierna': [('nnium', False)],
          'nniernas': [('nny', False)],
          'nniers': [('nnium', False)],
          'nniet': [('nnium', False)],
          'nniets': [('nni', False)],
          'nnin': [('nnin', False)],
          'nnin-': [('nnin', False)],
          'nninen': [('nnin', False)],
          'nninens': [('nnin', False)],
          'nninet': [('nnin', False)],
          'nninets': [('nnin', False)],
          'nningsdelar': [('nningsdelare', False)],
          'nnins': [('nnin', False)],
          'nnisen': [('nnis', False)],
          'nnisens': [('nnis', False)],
          'nnitens': [('nnit', False)],
          'nnitet': [('nnitet', False)],
          'nnitets': [('nnitet', False)],
          'nnjack': [('nnjacka', False)],
          'nnjacks-': [('nnjacka', False)],
          'nnkungar': [('nnkung', False)],
          'nnkungarna': [('nnkung', False)],
          'nnkungarnas': [('nnkung', False)],
          'nnkungars': [('nnkung', False)],
          'nnkungen': [('nnkung', False)],
          'nnkungens': [('nnkung', False)],
          'nnlar': [('nnel', False)],
          'nnlarna': [('nnel', False)],
          'nnlarnas': [('nnel', False)],
          'nnlars': [('nnel', False)],
          'nnmos': [('nnmo', False)],
          'nno': [('nna', False)],
          'nnons': [('nnons', False)],
          'nnons-': [('nnons', False)],
          'nnonsens': [('nnons', False)],
          'nnor': [('nna', False)],
          'nnorna': [('nna', False)],
          'nnornas': [('nna', False)],
          'nnors': [('nna', False)],
          'nnrar': [('nner', False)],
          'nnrarna': [('nner', False)],
          'nnrars': [('nner', False)],
          'nnriken': [('nnrike', False)],
          'nnrikens': [('nnrike', False)],
          'nns': [('nn', False)],
          'nns-': [('nn', False)],
          'nnsets': [('nns', False)],
          'nnskallen': [('nnskalle', False)],
          'nnskallens': [('nnskalle', False)],
          'nnskaps': [('nnskap', False)],
          'nnskar-': [('nnskar', False)],
          'nnskarens': [('nnskar', False)],
          'nnskars': [('nnskar', False)],
          'nnskurs-': [('nnskur', False)],
          'nnsort': [('nnsort', False)],
          'nnsorter': [('nnsort', False)],
          'nnsorterna': [('nnsort', False)],
          'nnsorternas': [('nnsort', False)],
          'nnsorters': [('nnsort', False)],
          'nnsorts': [('nnsort', False)],
          'nnsorts-': [('nnsort', False)],
          'nnyen': [('nnye', False)],
          'nnyens': [('nnye', False)],
          'nnyer': [('nnye', False)],
          'nnyerna': [('nnye', False)],
          'nnyernas': [('nnye', False)],
          'nnyers': [('nnye', False)],
          'nnys': [('nny', False)],
          'nnyte': [('nnyta', False)],
          'nnäs-': [('nnäsa', False)],
          'nnör': [('nnör', False)],
          'nnör-': [('nnör', False)],
          'nnören': [('nnör', False)],
          'nnörens': [('nnör', False)],
          'nnörs': [('nnör', False)],
          'nnörs-': [('nnör', False)],
          'nnötter': [('nnöt', False)],
          'nnötterna': [('nnöt', False)],
          'nnötternas': [('nnöt', False)],
          'no': [('noa', False)],
          'no-': [('na', False)],
          'noas': [('noa', False)],
          'noas-': [('noa', True)],
          'nobb': [('nobb', False)],
          'nobbar': [('nobb', False)],
          'nobbarna': [('nobb', True)],
          'nobbarnas': [('nobb', False)],
          'nobbars': [('nobb', False)],
          'nobbens': [('nobb', True)],
          'nobbs': [('nobb', False)],
          'nobbs-': [('nobb', False)],
          'noben': [('noben', False)],
          'nobens': [('noben', False)],
          'nober': [('nober', False)],
          'nobers': [('nober', False)],
          'nock-': [('nock', True)],
          'nockar': [('nock', True)],
          'nockarna': [('nock', False)],
          'nocken': [('nock', True)],
          'nockens': [('nock', True)],
          'nocks': [('nock', False)],
          'nocks-': [('nock', False)],
          'noddar': [('nodd', False)],
          'noddars': [('nodd', False)],
          'nodds': [('nodd', False)],
          'nodds-': [('nodd', False)],
          'noden': [('nod', False)],
          'nodens': [('nod', False)],
          'noders': [('nod', False)],
          'nodlarnas': [('nodlare', False)],
          'nods': [('nod', False)],
          'nods-': [('nod', False)],
          'noe': [('noa', False)],
          'noe-': [('noa', False)],
          'nogars': [('noge', False)],
          'noge': [('noge', False)],
          'nogenerna': [('nogen', False)],
          'nogens': [('nogen', False)],
          'noget': [('nog', False)],
          'nogets': [('nog', False)],
          'nogrammet': [('nogram', False)],
          'nogrammets': [('nogram', False)],
          'noj': [('noja', True)],
          'noj-': [('noja', True)],
          'nojan': [('noja', True)],
          'nojans': [('noja', True)],
          'nojs': [('nojs', True), ('noja', True)],
          'nojs-': [('noja', True), ('nojs', True)],
          'nokarnas': [('nok', False)],
          'nokopps': [('nokopp', False)],
          'nokopps-': [('nokopp', False)],
          'noli-': [('nolia', False)],
          'nolie-': [('nolia', False)],
          'nolin': [('nolin', False)],
          'nolis': [('nolia', False)],
          'nolis-': [('nolia', False)],
          'noll': [('nolla', True), ('noll', True)],
          'noll-': [('nolla', True), ('noll', True)],
          'nolle': [('nolla', True)],
          'nollen': [('nolle', False)],
          'nolls': [('nolla', True), ('noll', True)],
          'nolls-': [('nolla', True), ('noll', True)],
          'nologier': [('nologi', False)],
          'nologierna': [('nologi', False)],
          'nologiers': [('nologi', False)],
          'nols-': [('nola', False)],
          'nomads': [('nomad', True)],
          'nomaliernas': [('nomali', False)],
          'nomaliers': [('nomali', False)],
          'nomen': [('nomen', False)],
          'nomens': [('nomen', True)],
          'nometer': [('nometer', False)],
          'nometerna': [('nometer', False)],
          'nometernas': [('nometer', False)],
          'nometers': [('nometer', False)],
          'nomiker': [('nomiker', False)],
          'nomikerna': [('nomiker', False)],
          'nomikernas': [('nomiker', False)],
          'nomikers': [('nomiker', False)],
          'nomon-': [('nomon', False)],
          'nområdets': [('nområde', False)],
          'noms': [('nom', False)],
          'noms-': [('nom', False)],
          'non': [('nona', True)],
          'non-': [('nona', True)],
          'nona': [('nona', True)],
          'nonan': [('nona', True)],
          'nonans': [('nona', True)],
          'nonas': [('nona', True)],
          'nong': [('nong', False)],
          'nong-': [('nong', False)],
          'nongs': [('nong', False)],
          'nonie': [('nonie', True)],
          'nonie-': [('nonie', True)],
          'nonier': [('nonie', True)],
          'nonierna': [('nonie', True)],
          'noniernas': [('nonie', True)],
          'noniers': [('nonie', True)],
          'nons': [('nona', True)],
          'nons-': [('nona', True)],
          'nonsen': [('nons', False)],
          'nonsens': [('nonsens', True)],
          'nonsets': [('nonset', False)],
          'noorna': [('noa', False)],
          'noornas': [('noa', False)],
          'noparnas': [('nop', False)],
          'nopins': [('nopi', False)],
          'nopp': [('noppa', True), ('nopp', True)],
          'nopp-': [('noppa', True), ('nopp', True)],
          'noppar': [('nopp', False)],
          'nopparen': [('noppare', False)],
          'nopparens': [('noppare', False)],
          'nopparna': [('nopp', False)],
          'nopparnas': [('nopp', True)],
          'noppars': [('nopp', False)],
          'noppe': [('noppa', True)],
          'noppe-': [('noppa', True)],
          'noppen': [('nopp', False)],
          'noppens': [('nopp', False)],
          'noppor': [('noppa', True)],
          'nopporna': [('noppa', True)],
          'noppornas': [('noppa', True)],
          'noppors': [('noppa', True)],
          'nopps': [('noppa', True), ('nopp', True)],
          'nopps-': [('noppa', True), ('nopp', True)],
          'nops': [('nops', False)],
          'nops-': [('nops', False)],
          'nopsen': [('nops', False)],
          'nor': [('nor', True)],
          'nor-': [('nor', True)],
          'nora': [('nora', False)],
          'noran': [('nora', False)],
          'norar': [('norar', False)],
          'noras': [('nora', False)],
          'nord': [('nord', True)],
          'nord-': [('nord', True)],
          'nordan': [('nordan', True)],
          'nordans-': [('nordan', True)],
          'nordbor': [('nordbo', True)],
          'norden': [('nord', True)],
          'nordens': [('nord', True)],
          'nordnar': [('norden', False)],
          'nordnarnas': [('norden', False)],
          'nords': [('nord', False)],
          'noren': [('nor', True)],
          'norens': [('nor', True)],
          'nores': [('nore', False)],
          'nores-': [('nore', False)],
          'norin': [('norina', False)],
          'norin-': [('norina', False)],
          'norins': [('norina', False)],
          'norkar': [('nork', False)],
          'norkarna': [('nork', False)],
          'normanden': [('normand', True)],
          'normandens': [('normand', True)],
          'normar': [('norm', False)],
          'normarna': [('norm', False)],
          'normarnas': [('norm', False)],
          'norn': [('norna', True)],
          'norn-': [('norna', True)],
          'norna': [('norna', True)],
          'nornas': [('norna', True)],
          'norne': [('norna', True)],
          'norns': [('norna', True)],
          'norns-': [('norna', True)],
          'noror': [('nora', False)],
          'nororna': [('nora', False)],
          'norornas': [('nora', False)],
          'norors': [('nora', False)],
          'noros': [('noro', False)],
          'norr': [('norr', True)],
          'norr-': [('norr', True)],
          'norrar': [('norr', False)],
          'norrarna': [('norr', False)],
          'norrarnas': [('norr', False)],
          'norrars': [('norr', False)],
          'norren': [('norr', False)],
          'norrens': [('norr', False)],
          'norrs': [('norr', False)],
          'norrs-': [('norr', False)],
          'nors': [('nors', True), ('nor', True)],
          'nors-': [('nor', True), ('nors', True)],
          'norsar': [('nors', True)],
          'norsars': [('nors', True)],
          'norsk': [('norska', True)],
          'norsk-': [('norska', False)],
          'norten': [('nort', False)],
          'norternas': [('nort', False)],
          'norts-': [('nort', False)],
          'nos': [('nos', True)],
          'nos-': [('nos', True)],
          'nosar': [('nos', False)],
          'nosarna': [('nos', True)],
          'nosarnas': [('nos', False)],
          'nosars': [('nos', False)],
          'nosen': [('nos', True)],
          'nosens': [('nos', True)],
          'nosi': [('nosi', False)],
          'nosier': [('nosi', False)],
          'nosiernas': [('nosi', False)],
          'nosins': [('nosi', False)],
          'nost-': [('nost', False)],
          'nostas': [('nostas', False)],
          'not': [('not', True)],
          'not-': [('not', True)],
          'nota': [('nota', False)],
          'notarnas': [('not', False)],
          'notas': [('nota', False)],
          'notis': [('notis', False)],
          'notonin': [('notoni', False)],
          'notonins': [('notoni', False)],
          'nots': [('not', True)],
          'nots-': [('not', True)],
          'nott': [('nott', False)],
          'nott-': [('nott', False)],
          'notten': [('nott', False)],
          'notterna': [('nott', False)],
          'notternas': [('nott', False)],
          'notters': [('nott', False)],
          'notts': [('nott', False)],
          'notts-': [('nott', False)],
          'notypen': [('notype', False)],
          'notypens': [('notype', False)],
          'notyper': [('notype', False)],
          'notyperna': [('notype', False)],
          'notypernas': [('notype', False)],
          'notypers': [('notype', False)],
          'nov': [('nova', False)],
          'nov-': [('nova', False)],
          'novis': [('novis', True)],
          'novs': [('nova', False)],
          'novs-': [('nova', False)],
          'noxar': [('noxe', False)],
          'noxars': [('noxe', False)],
          'noxen': [('noxe', False)],
          'noxins': [('noxi', False)],
          'npar': [('npar', False)],
          'npar-': [('npar', False)],
          'nparens': [('npar', False)],
          'npars-': [('npar', False)],
          'npelar': [('npelare', False)],
          'npelar-': [('npelare', False)],
          'npenning': [('npenning', False)],
          'npenning-': [('npenning', False)],
          'npenningar': [('npenning', False)],
          'npenningarna': [('npenning', False)],
          'npenningarnas': [('npenning', False)],
          'npenningars': [('npenning', False)],
          'npennings': [('npenning', False)],
          'npennings-': [('npenning', False)],
          'npiller': [('npiller', False)],
          'npillers': [('npiller', False)],
          'npinnarnas': [('npinne', False)],
          'npinnens': [('npinne', False)],
          'nplanet': [('nplan', False)],
          'nplanets': [('nplan', False)],
          'nplants': [('nplanta', False)],
          'nplants-': [('nplanta', False)],
          'npojk': [('npojke', False)],
          'npojk-': [('npojke', False)],
          'npojks': [('npojke', False)],
          'npojks-': [('npojke', False)],
          'nportarnas': [('nport', False)],
          'nposter': [('npost', False)],
          'nposters': [('npost', False)],
          'npraktiker': [('npraktiker', False)],
          'npraktikerna': [('npraktiker', False)],
          'npraktikernas': [('npraktiker', False)],
          'npraktikers': [('npraktiker', False)],
          'npressar': [('npress', False)],
          'npressarna': [('npress', False)],
          'npressarnas': [('npress', False)],
          'nprickar': [('nprick', False)],
          'nprickarna': [('nprick', False)],
          'nprickarnas': [('nprick', False)],
          'npricks': [('nprick', False)],
          'npricks-': [('nprick', False)],
          'nproblemet': [('nproblem', False)],
          'nproblemets': [('nproblem', False)],
          'nprocessen': [('nprocessen', False)],
          'nprocessens': [('nprocessen', False)],
          'nprogrammet': [('nprogram', False)],
          'npump': [('npump', False)],
          'npumps': [('npump', False)],
          'npumps-': [('npump', False)],
          'nput': [('nput', False)],
          'nput-': [('nput', False)],
          'nputs-': [('nputs', False)],
          'npöls': [('npöl', False)],
          'npöls-': [('npöl', False)],
          'nr': [('nr', True)],
          'nr-': [('nr', True)],
          'nrack': [('nrack', False)],
          'nrack-': [('nrack', False)],
          'nrackar': [('nrack', False)],
          'nrackarna': [('nrack', False)],
          'nrackarnas': [('nrack', False)],
          'nracks': [('nrack', False)],
          'nracks-': [('nrack', False)],
          'nradens': [('nrad', False)],
          'nrads': [('nrad', False)],
          'nramar': [('nram', False)],
          'nramarna': [('nram', False)],
          'nrams': [('nram', False)],
          'nrams-': [('nram', False)],
          'nran': [('nran', False)],
          'nrande': [('nrande', False)],
          'nrande-': [('nrande', False)],
          'nranden': [('nrande', False)],
          'nrandens': [('nrande', False)],
          'nrandet': [('nrande', False)],
          'nrans': [('nran', False)],
          'nrans-': [('nran', False)],
          'nrarnas': [('ner', False)],
          'nrej': [('nrej', False)],
          'nrej-': [('nrej', False)],
          'nrejar': [('nrej', False)],
          'nrejarna': [('nrej', False)],
          'nrejarnas': [('nrej', False)],
          'nrejs': [('nrej', False)],
          'nrejs-': [('nrej', False)],
          'nremiss': [('nremiss', False)],
          'nremiss-': [('nremiss', False)],
          'nremmar': [('nrem', False)],
          'nremmarna': [('nrem', False)],
          'nremmarnas': [('nrem', False)],
          'nrems': [('nrem', False)],
          'nrems-': [('nrem', False)],
          'nren': [('nre', False)],
          'nrens': [('nre', False)],
          'nrep': [('nrep', False)],
          'nrep-': [('nrep', False)],
          'nrepet': [('nrep', False)],
          'nrepets': [('nrep', False)],
          'nreps': [('nrep', False)],
          'nreps-': [('nrep', False)],
          'nrer': [('nre', False)],
          'nrerna': [('nre', False)],
          'nrernas': [('nre', False)],
          'nrese': [('nresa', False)],
          'nrese-': [('nresa', False)],
          'nrev': [('nrev', False)],
          'nrev-': [('nrev', False)],
          'nrevens': [('nrev', False)],
          'nrevs': [('nrev', False)],
          'nrevs-': [('nrev', False)],
          'nriggar': [('nriggare', False)],
          'nriggarna': [('nriggare', False)],
          'nriggarnas': [('nriggare', False)],
          'nrik': [('nrik', False)],
          'nrik-': [('nrik', False)],
          'nrikar': [('nrik', False)],
          'nrikarna': [('nrik', False)],
          'nrikars': [('nrik', False)],
          'nriken': [('nrik', False)],
          'nrikens': [('nrik', False)],
          'nriket': [('nrike', False)],
          'nrikets': [('nrike', False)],
          'nriks': [('nrik', False)],
          'nriks-': [('nrik', False)],
          'nrim': [('nrim', False)],
          'nrims': [('nrim', False)],
          'nrims-': [('nrim', False)],
          'nringarna': [('nring', False)],
          'nringarnas': [('nring', False)],
          'nris': [('nris', False)],
          'nris-': [('nris', False)],
          'nrisk': [('nrisk', False)],
          'nrisk-': [('nrisk', False)],
          'nristar': [('nristare', False)],
          'nristarna': [('nristare', False)],
          'nristarnas': [('nristare', False)],
          'nrock': [('nrock', False)],
          'nrockar': [('nrock', False)],
          'nrockarna': [('nrock', False)],
          'nrockarnas': [('nrock', False)],
          'nromans': [('nroman', False)],
          'nroparen': [('nropare', False)],
          'nroparnas': [('nropare', False)],
          'nropen': [('nrop', False)],
          'nropens': [('nrop', False)],
          'nrops': [('nrop', False)],
          'nros': [('nros', False)],
          'nros-': [('nros', False)],
          'nrov': [('nrov', False)],
          'nrovs': [('nrov', False)],
          'nrovs-': [('nrov', False)],
          'nrull': [('nrulle', False)],
          'nrull-': [('nrulle', False)],
          'nrullar': [('nrulle', False)],
          'nrulle': [('nrulle', False)],
          'nrulle-': [('nrulle', False)],
          'nrulls': [('nrulle', False)],
          'nrulls-': [('nrulle', False)],
          'nrum': [('nrum', False)],
          'nrums': [('nrum', False)],
          'nrums-': [('nrum', False)],
          'nrundans': [('nrunda', False)],
          'nry': [('nry', False)],
          'nry-': [('nry', False)],
          'nrykten': [('nrykte', False)],
          'nryktens': [('nrykte', False)],
          'nrys': [('nry', False)],
          'nrys-': [('nry', False)],
          'nräcke': [('nräcke', False)],
          'nräcken': [('nräcke', False)],
          'nräckens': [('nräcke', False)],
          'nräcket': [('nräcke', False)],
          'nräckets': [('nräcke', False)],
          'nräk-': [('nräka', False)],
          'nräkors': [('nräka', False)],
          'nräks-': [('nräka', False)],
          'nränderna': [('nrand', False)],
          'nrändernas': [('nrand', False)],
          'nränders': [('nrand', False)],
          'nränn': [('nränna', False)],
          'nränn-': [('nränna', False)],
          'nränns': [('nränna', False)],
          'nränns-': [('nränna', False)],
          'nrättens': [('nrätt', False)],
          'nrättigheters': [('nrättighet', False)],
          'nrättighets-': [('nrättighet', False)],
          'nrån': [('nrån', False)],
          'nråns': [('nrån', False)],
          'nrökens': [('nrök', False)],
          'nröst': [('nröst', False)],
          'nröst-': [('nröst', False)],
          'nrösten': [('nröst', False)],
          'nröstens': [('nröst', False)],
          'nrövar': [('nröv', False)],
          'nrövarna': [('nröv', False)],
          'nrövarnas': [('nröv', False)],
          'ns': [('n', True)],
          'nsage': [('nsaga', False)],
          'nsage-': [('nsaga', False)],
          'nsago': [('nsaga', False)],
          'nsago-': [('nsaga', False)],
          'nsaker': [('nsak', False)],
          'nsakerna': [('nsak', False)],
          'nsakernas': [('nsak', False)],
          'nsakers': [('nsak', False)],
          'nsalen': [('nsal', False)],
          'nsalens': [('nsal', False)],
          'nsana': [('nsum', False)],
          'nsanas': [('nsum', False)],
          'nsanden': [('nsande', False)],
          'nsandens': [('nsande', False)],
          'nsans': [('nsa', False)],
          'nsar': [('ns', False)],
          'nsaren': [('nsare', False)],
          'nsarna': [('ns', False)],
          'nsars': [('ns', False)],
          'nsarv': [('nsarve', False)],
          'nsarv-': [('nsarve', False)],
          'nsarvar': [('nsarve', False)],
          'nsarvarna': [('nsarve', False)],
          'nsarvarnas': [('nsarve', False)],
          'nsarvars': [('nsarve', False)],
          'nsarven': [('nsarve', False)],
          'nsarvens': [('nsarve', False)],
          'nsarvs': [('nsarve', False)],
          'nsarvs-': [('nsarve', False)],
          'nsat': [('nsat', False)],
          'nsat-': [('nsat', False)],
          'nsaten': [('nsat', False)],
          'nsatens': [('nsat', False)],
          'nsats-': [('nsats', False)],
          'nsaxar': [('nsax', False)],
          'nsaxarna': [('nsax', False)],
          'nsaxarnas': [('nsax', False)],
          'nsbasar': [('nsbas', False)],
          'nsbasars': [('nsbas', False)],
          'nsbit': [('nsbit', False)],
          'nsbot': [('nsbot', False)],
          'nsbots': [('nsbot', False)],
          'nsbull-': [('nsbulle', False)],
          'nsbytet': [('nsbyte', False)],
          'nscenters': [('nscenter', False)],
          'nsch': [('nsch', False)],
          'nsch-': [('nsch', False)],
          'nschen': [('nsch', False)],
          'nschens': [('nsch', False)],
          'nscher': [('nsch', False)],
          'nschers': [('nsch', False)],
          'nsdagar': [('nsdagar', False)],
          'nsdagarna': [('nsdagar', False)],
          'nsdagarnas': [('nsdagar', False)],
          'nsdagars': [('nsdagar', False)],
          'nsdelars': [('nsdelar', False)],
          'nsdels': [('nsdelar', False)],
          'nsdels-': [('nsdelar', False)],
          'nse': [('nsa', False)],
          'nse-': [('nsa', False)],
          'nseffekt': [('nseffekt', False)],
          'nseffekt-': [('nseffekt', False)],
          'nseffekter': [('nseffekt', False)],
          'nseffekternas': [('nseffekt', False)],
          'nseffekters': [('nseffekt', False)],
          'nseffekts': [('nseffekt', False)],
          'nseffekts-': [('nseffekt', False)],
          'nsekter': [('nsekt', False)],
          'nsekters': [('nsekt', False)],
          'nsel': [('nsel', False)],
          'nsel-': [('nsel', False)],
          'nsels': [('nsel', False)],
          'nsels-': [('nsel', False)],
          'nsen': [('ns', False)],
          'nsen-': [('nsen', False)],
          'nsens': [('ns', False)],
          'nsens-': [('nsens', False)],
          'nsentens': [('nsent', False)],
          'nser': [('ns', False)],
          'nser-': [('nser', False)],
          'nserier': [('nseri', False)],
          'nserierna': [('nseri', False)],
          'nseriernas': [('nseri', False)],
          'nseriers': [('nseri', False)],
          'nsern': [('nser', False)],
          'nserna': [('ns', False)],
          'nsernas': [('ns', False)],
          'nserns': [('nser', False)],
          'nsers': [('ns', False)],
          'nsers-': [('nser', False)],
          'nserv': [('nserv', False)],
          'nserv-': [('nserv', False)],
          'nserven': [('nserv', False)],
          'nservens': [('nserv', False)],
          'nserver': [('nserv', False)],
          'nservers': [('nserv', False)],
          'nservs': [('nserv', False)],
          'nservs-': [('nserv', False)],
          'nset': [('ns', False)],
          'nsets': [('nset', False)],
          'nsetter': [('nsett', False)],
          'nsetters': [('nsett', False)],
          'nsex': [('nsexa', False)],
          'nsex-': [('nsexa', False)],
          'nsfaktorer': [('nsfaktor', False)],
          'nsfaktorers': [('nsfaktor', False)],
          'nsfiskar': [('nsfisk', False)],
          'nsfiskarna': [('nsfisk', False)],
          'nsflagg': [('nsflagga', False)],
          'nsflagg-': [('nsflagg', False)],
          'nsflaggs': [('nsflagga', False)],
          'nsflaggs-': [('nsflagg', False)],
          'nsförsäkringars': [('nsförsäkring', False)],
          'nsgåvornas': [('nsgåva', False)],
          'nshaken': [('nshak', False)],
          'nshakens': [('nshak', False)],
          'nshets': [('nshets', False)],
          'nshets-': [('nshets', False)],
          'nshor': [('nshora', False)],
          'nshots': [('nshot', False)],
          'nshots-': [('nshot', False)],
          'nsi': [('nsia', False)],
          'nsi-': [('nsia', False)],
          'nsian': [('nsia', False)],
          'nsians': [('nsia', False)],
          'nsid': [('nsid', False)],
          'nsid-': [('nsid', False)],
          'nsidan': [('nsida', False)],
          'nsidans': [('nsida', False)],
          'nside': [('nsida', False)],
          'nside-': [('nsida', False)],
          'nsiden': [('nsid', False)],
          'nsidens': [('nsid', False)],
          'nsider': [('nsid', False)],
          'nsiderna': [('nsid', False)],
          'nsidernas': [('nsid', False)],
          'nsiders': [('nsid', False)],
          'nsides': [('nsida', False)],
          'nsie': [('nsia', False)],
          'nsie-': [('nsia', False)],
          'nsignore': [('nsignore', False)],
          'nsignore-': [('nsignore', False)],
          'nsignoren': [('nsignore', False)],
          'nsignorens': [('nsignore', False)],
          'nsignorer': [('nsignore', False)],
          'nsignorerna': [('nsignore', False)],
          'nsignorernas': [('nsignore', False)],
          'nsignorers': [('nsignore', False)],
          'nsikten': [('nsikt', False)],
          'nsiktens': [('nsikte', False)],
          'nsikts': [('nsikte', False)],
          'nsikts-': [('nsikte', False)],
          'nsilians': [('nsilians', False)],
          'nsilie': [('nsilier', False)],
          'nsilie-': [('nsilium', False)],
          'nsilier': [('nsilier', False)],
          'nsilierna': [('nsilium', False)],
          'nsiliernas': [('nsilium', False)],
          'nsiliers': [('nsilier', False)],
          'nsin-': [('nsin', False)],
          'nsinen': [('nsin', False)],
          'nsinens': [('nsin', False)],
          'nsins': [('nsin', False)],
          'nsis': [('nsia', False)],
          'nsis-': [('nsia', False)],
          'nsistens': [('nsistens', False)],
          'nsistens-': [('nsistens', False)],
          'nsitet': [('nsitet', False)],
          'nsitets': [('nsitet', False)],
          'nsiv': [('nsiv', False)],
          'nsiv-': [('nsiv', False)],
          'nsiven': [('nsiv', False)],
          'nsivens': [('nsiv', False)],
          'nsiver': [('nsiv', False)],
          'nsiverna': [('nsiv', False)],
          'nsivernas': [('nsiv', False)],
          'nsivers': [('nsiv', False)],
          'nsivs': [('nsiv', False)],
          'nsivs-': [('nsiv', False)],
          'nsjukan': [('nsjuka', False)],
          'nsk': [('nska', False)],
          'nsk-': [('nska', False)],
          'nskall': [('nskall', False)],
          'nskall-': [('nskall', False)],
          'nskallen': [('nskall', False)],
          'nskallens': [('nskall', False)],
          'nskalls': [('nskall', False)],
          'nskalls-': [('nskall', False)],
          'nskan': [('nska', False)],
          'nskana': [('nska', False)],
          'nskanas': [('nska', False)],
          'nskans-': [('nskan', False)],
          'nskaps-': [('nskap', False)],
          'nskar': [('nskar', False)],
          'nskar-': [('nskare', False)],
          'nskare': [('nskara', False)],
          'nskare-': [('nskara', False)],
          'nskaren': [('nskar', False)],
          'nskarens': [('nskare', False)],
          'nskarnas': [('nsk', False)],
          'nskars': [('nsk', False)],
          'nskars-': [('nskar', False)],
          'nskasse-': [('nskassa', False)],
          'nskat': [('nska', False)],
          'nskat-': [('nskata', False)],
          'nskate': [('nskata', False)],
          'nskats': [('nska', False)],
          'nskats-': [('nskata', False)],
          'nskattepengar': [('nskattepengar', False)],
          'nskatts-': [('nskatt', False)],
          'nsken': [('nsk', False)],
          'nsken-': [('nskena', False)],
          'nskens': [('nsken', False)],
          'nskens-': [('nskena', False)],
          'nskiften': [('nskifte', False)],
          'nskiftens': [('nskifte', False)],
          'nskiftet': [('nskifte', False)],
          'nskiftets': [('nskifte', False)],
          'nskist': [('nskista', False)],
          'nskist-': [('nskista', False)],
          'nsko': [('nsko', False)],
          'nsko-': [('nska', False)],
          'nskol': [('nskol', False)],
          'nskol-': [('nskol', False)],
          'nskols': [('nskol', False)],
          'nskols-': [('nskol', False)],
          'nskon': [('nsko', False)],
          'nskonst': [('nskonst', False)],
          'nskor': [('nsko', False)],
          'nskorna': [('nsko', False)],
          'nskornas': [('nsko', False)],
          'nskors': [('nsko', False)],
          'nskot': [('nskota', False)],
          'nskot-': [('nskota', False)],
          'nskots': [('nskota', False)],
          'nskots-': [('nskota', False)],
          'nskott': [('nskott', False)],
          'nskotten': [('nskott', False)],
          'nskottens': [('nskott', False)],
          'nskotts-': [('nskott', False)],
          'nskrap-': [('nskrapa', False)],
          'nskrik': [('nskrik', False)],
          'nskrik-': [('nskrik', False)],
          'nskriks': [('nskrik', False)],
          'nskriks-': [('nskrik', False)],
          'nskrin': [('nskri', False)],
          'nskrins': [('nskri', False)],
          'nskull': [('nskull', False)],
          'nskull-': [('nskulla', False)],
          'nskulle': [('nskulla', False)],
          'nskulle-': [('nskulla', False)],
          'nskullen': [('nskull', False)],
          'nskullens': [('nskull', False)],
          'nskulls': [('nskull', False)],
          'nskulls-': [('nskulla', False)],
          'nskulor': [('nskula', False)],
          'nskulorna': [('nskula', False)],
          'nskulornas': [('nskula', False)],
          'nskulors': [('nskula', False)],
          'nskurs': [('nskur', False)],
          'nskurs-': [('nskurs', False)],
          'nskyl': [('nskyla', False)],
          'nskyl-': [('nskyla', False)],
          'nskyls': [('nskyla', False)],
          'nskyls-': [('nskyla', False)],
          'nskäll': [('nskälla', False)],
          'nskäll-': [('nskälla', False)],
          'nskälls': [('nskälla', False)],
          'nskälls-': [('nskälla', False)],
          'nskänk': [('nskänk', False)],
          'nskänks': [('nskänk', False)],
          'nskär': [('nskära', False)],
          'nskär-': [('nskära', False)],
          'nskärmar': [('nskärm', False)],
          'nskärmarnas': [('nskärm', False)],
          'nskärs': [('nskära', False)],
          'nskärs-': [('nskära', False)],
          'nskåp': [('nskåpa', False)],
          'nskåp-': [('nskåpa', False)],
          'nskåps': [('nskåpa', False)],
          'nskåps-': [('nskåpa', False)],
          'nskår': [('nskår', False)],
          'nskåren': [('nskår', False)],
          'nskårens': [('nskår', False)],
          'nskårs': [('nskår', False)],
          'nskårs-': [('nskår', False)],
          'nskön': [('nskö', False)],
          'nskön-': [('nsköna', False)],
          'nsköns': [('nskö', False)],
          'nskör': [('nskör', False)],
          'nskörs': [('nskör', False)],
          'nskörs-': [('nskör', False)],
          'nskötar': [('nskötare', False)],
          'nskötarna': [('nskötare', False)],
          'nskötarnas': [('nskötare', False)],
          'nslag': [('nslag', False)],
          'nslag-': [('nslag', False)],
          'nslags': [('nslag', False)],
          'nslags-': [('nslag', False)],
          'nslams': [('nslam', False)],
          'nslams-': [('nslam', False)],
          'nslan': [('nsla', False)],
          'nslandet': [('nsland', False)],
          'nslandets': [('nslande', False)],
          'nslans': [('nsla', False)],
          'nslar': [('nsel', False)],
          'nslarna': [('nsel', False)],
          'nslarnas': [('nsel', False)],
          'nslas': [('nsla', False)],
          'nsleken': [('nslek', False)],
          'nslekens': [('nslek', False)],
          'nsleks': [('nslek', False)],
          'nsleks-': [('nslek', False)],
          'nslet': [('nsle', False)],
          'nslider': [('nslider', False)],
          'nsliders': [('nslider', False)],
          'nsling': [('nsling', False)],
          'nsling-': [('nsling', False)],
          'nslings': [('nsling', False)],
          'nslings-': [('nsling', False)],
          'nslit': [('nsli', False)],
          'nslits': [('nsli', False)],
          'nslån': [('nslån', False)],
          'nslåns': [('nslån', False)],
          'nslås': [('nslås', False)],
          'nslås-': [('nslås', False)],
          'nsmatt': [('nsmatta', False)],
          'nsmatt-': [('nsmatta', False)],
          'nsmatts': [('nsmatta', False)],
          'nsmatts-': [('nsmatta', False)],
          'nsmor': [('nsmor', False)],
          'nsmors': [('nsmor', False)],
          'nsmäll': [('nsmäll', False)],
          'nsmällar': [('nsmäll', False)],
          'nsmällarna': [('nsmäll', False)],
          'nsmällarnas': [('nsmäll', False)],
          'nsmälls': [('nsmäll', False)],
          'nsmälls-': [('nsmäll', False)],
          'nsnåret': [('nsnåret', False)],
          'nsnårets': [('nsnåret', False)],
          'nsolvens': [('nsolvens', False)],
          'nsområdet': [('nsområde', False)],
          'nson': [('nson', False)],
          'nsoner': [('nson', False)],
          'nsonerna': [('nson', False)],
          'nsonernas': [('nson', False)],
          'nsoners': [('nson', False)],
          'nsons': [('nson', False)],
          'nsopp': [('nsopp', False)],
          'nsopp-': [('nsopp', False)],
          'nsopps': [('nsopp', False)],
          'nsopps-': [('nsopp', False)],
          'nsor': [('nsa', False)],
          'nsorden': [('nsorden', False)],
          'nsordens': [('nsorden', False)],
          'nsorna': [('nsa', False)],
          'nsornas': [('nsa', False)],
          'nsors': [('nsa', False)],
          'nsort-': [('nsorter', False)],
          'nsortier': [('nsortium', False)],
          'nsortierna': [('nsortium', False)],
          'nsortiernas': [('nsortium', False)],
          'nsortiers': [('nsortium', False)],
          'nsos': [('nsos', False)],
          'nsos-': [('nsos', False)],
          'nsosen': [('nsos', False)],
          'nsosens': [('nsos', False)],
          'nsots': [('nsot', False)],
          'nspar': [('nspar', False)],
          'nsparens': [('nsparens', False)],
          'nspars': [('nspar', False)],
          'nspat': [('nspat', False)],
          'nspats': [('nspat', False)],
          'nspets': [('nspets', False)],
          'nspets-': [('nspets', False)],
          'nspire': [('nspira', False)],
          'nspire-': [('nspira', False)],
          'nspisar': [('nspis', False)],
          'nspisarna': [('nspis', False)],
          'nspisarnas': [('nspis', False)],
          'nspol': [('nspole', False)],
          'nspol-': [('nspole', False)],
          'nspolar': [('nspole', False)],
          'nspolen': [('nspole', False)],
          'nspolens': [('nspole', False)],
          'nspols': [('nspole', False)],
          'nsportar': [('nsport', False)],
          'nsportarna': [('nsport', False)],
          'nspring': [('nspringa', False)],
          'nspring-': [('nspringa', False)],
          'nsprings': [('nspringa', False)],
          'nsprings-': [('nspringa', False)],
          'nsprit': [('nsprit', False)],
          'nsprits': [('nsprit', False)],
          'nsprits-': [('nsprit', False)],
          'nsprut': [('nspruta', False)],
          'nsprut-': [('nspruta', False)],
          'nspruts': [('nspruta', False)],
          'nspruts-': [('nspruta', False)],
          'nspumps': [('nspump', False)],
          'nspumps-': [('nspump', False)],
          'nsregionen': [('nsregion', False)],
          'nsregionens': [('nsregion', False)],
          'nsringar': [('nsring', False)],
          'nsskal': [('nsskal', False)],
          'nsskalas': [('nsskala', False)],
          'nsskals': [('nsskal', False)],
          'nsskals-': [('nsskal', False)],
          'nsskiften': [('nsskifte', False)],
          'nsskiftens': [('nsskifte', False)],
          'nssot': [('nssot', False)],
          'nssots': [('nssot', False)],
          'nssteg': [('nssteg', False)],
          'nssteg-': [('nssteg', False)],
          'nsstegens': [('nssteg', False)],
          'nsstegs-': [('nssteg', False)],
          'nsställen': [('nsställe', False)],
          'nsstället': [('nsställe', False)],
          'nsställets': [('nsställe', False)],
          'nst': [('nst', False)],
          'nstadie': [('nstadium', False)],
          'nstadie-': [('nstadium', False)],
          'nstadier': [('nstadium', False)],
          'nstadierna': [('nstadium', False)],
          'nstadiernas': [('nstadium', False)],
          'nstadiers': [('nstadium', False)],
          'nstadiet': [('nstadium', False)],
          'nstadiets': [('nstadium', False)],
          'nstadium': [('nstadium', False)],
          'nstadiums': [('nstadium', False)],
          'nstalets': [('nstal', False)],
          'nstammar': [('nstam', False)],
          'nstammarna': [('nstam', False)],
          'nstammarnas': [('nstam', False)],
          'nstampen': [('nstamp', False)],
          'nstampens': [('nstamp', False)],
          'nstans': [('nstans', False)],
          'nstans-': [('nstans', False)],
          'nstarter': [('nstart', False)],
          'nstarterna': [('nstart', False)],
          'nstarternas': [('nstart', False)],
          'nstarters': [('nstart', False)],
          'nstavarna': [('nstav', False)],
          'nstdags': [('nstdag', False)],
          'nstdags-': [('nstdag', False)],
          'nste': [('nst', False)],
          'nste-': [('nst', False)],
          'nsteg': [('nsteg', False)],
          'nsteg-': [('nsteg', False)],
          'nstegen': [('nsteg', False)],
          'nstegens': [('nsteg', False)],
          'nstegs': [('nsteg', False)],
          'nstegs-': [('nsteg', False)],
          'nstekar': [('nstek', False)],
          'nstekarna': [('nstek', False)],
          'nstekarnas': [('nstek', False)],
          'nstekniker': [('nsteknik', False)],
          'nsteknikerna': [('nsteknik', False)],
          'nsteknikernas': [('nsteknik', False)],
          'nsteknikers': [('nsteknik', False)],
          'nsten': [('nsten', False)],
          'nstens': [('nsten', False)],
          'nster': [('nster', False)],
          'nsterhak': [('nsterhake', False)],
          'nsterhak-': [('nsterhake', False)],
          'nsterhaks': [('nsterhake', False)],
          'nsterna': [('nster', False)],
          'nsternas': [('nster', False)],
          'nsters': [('nster', False)],
          'nstick': [('nstick', False)],
          'nstick-': [('nstick', False)],
          'nsticks': [('nstick', False)],
          'nsticks-': [('nstick', False)],
          'nstillgångarnas': [('nstillgångar', False)],
          'nstillgångs-': [('nstillgångar', False)],
          'nstim': [('nstimme', False)],
          'nstim-': [('nstimme', False)],
          'nstimmen': [('nstimme', False)],
          'nstimmens': [('nstimme', False)],
          'nstims': [('nstimme', False)],
          'nstims-': [('nstimme', False)],
          'nstol': [('nstol', False)],
          'nstol-': [('nstol', False)],
          'nstols': [('nstol', False)],
          'nstols-': [('nstol', False)],
          'nstormar': [('nstorm', False)],
          'nstormarna': [('nstorm', False)],
          'nstormarnas': [('nstorm', False)],
          'nstorn': [('nstorn', False)],
          'nstorns': [('nstorn', False)],
          'nstran': [('nstran', False)],
          'nstranden': [('nstrande', False)],
          'nstrandens': [('nstrande', False)],
          'nstrans': [('nstrans', False)],
          'nstrans-': [('nstrans', False)],
          'nstras': [('nstras', False)],
          'nstreamer': [('nstream', False)],
          'nstreamers': [('nstream', False)],
          'nstringens': [('nstring', False)],
          'nstrum-': [('nstrum', False)],
          'nstrums': [('nstrum', False)],
          'nsträck': [('nsträcka', False)],
          'nsträck-': [('nsträcka', False)],
          'nsträcks': [('nsträcka', False)],
          'nsträcks-': [('nsträcka', False)],
          'nstrån': [('nstrå', False)],
          'nstråns': [('nstrå', False)],
          'nstråt': [('nstrå', False)],
          'nstråts': [('nstrå', False)],
          'nstudie': [('nstudie', False)],
          'nstudie-': [('nstudie', False)],
          'nstudier': [('nstudie', False)],
          'nstudierna': [('nstudie', False)],
          'nstudiernas': [('nstudie', False)],
          'nstudiers': [('nstudie', False)],
          'nstycken': [('nstycke', False)],
          'nstyckena': [('nstycke', False)],
          'nstyckenas': [('nstycke', False)],
          'nstyckens': [('nstycke', False)],
          'nstycket': [('nstycke', False)],
          'nstyckets': [('nstycke', False)],
          'nstycks': [('nstycke', False)],
          'nstyren': [('nstyre', False)],
          'nstyrens': [('nstyre', False)],
          'nstyret': [('nstyre', False)],
          'nstyrkan': [('nstyrka', False)],
          'nstyrke': [('nstyrka', False)],
          'nställanden': [('nställande', False)],
          'nställandena': [('nställande', False)],
          'nställandenas': [('nställande', False)],
          'nställandens': [('nställande', False)],
          'nställen': [('nställ', False)],
          'nställens': [('nställ', False)],
          'nstället': [('nställ', False)],
          'nställets': [('nställe', False)],
          'nställningar': [('nställning', False)],
          'nställningarna': [('nställning', False)],
          'nställningarnas': [('nställning', False)],
          'nställningars': [('nställning', False)],
          'nställnings': [('nställning', False)],
          'nställnings-': [('nställning', False)],
          'nstänk': [('nstänk', False)],
          'nstänks': [('nstänk', False)],
          'nstänks-': [('nstänk', False)],
          'nstår': [('nstå', False)],
          'nstötarnas': [('nstöt', False)],
          'nsug': [('nsuga', False)],
          'nsugarna': [('nsug', False)],
          'nsugarnas': [('nsug', False)],
          'nsul': [('nsul', False)],
          'nsul-': [('nsul', False)],
          'nsuls': [('nsul', False)],
          'nsur': [('nsur', False)],
          'nsur-': [('nsur', False)],
          'nsuran': [('nsuran', False)],
          'nsurans': [('nsuran', False)],
          'nsurans-': [('nsuran', False)],
          'nsurs': [('nsur', False)],
          'nsval': [('nsval', False)],
          'nsvale': [('nsvala', False)],
          'nsvalen': [('nsval', False)],
          'nsvalens': [('nsval', False)],
          'nsvals': [('nsval', False)],
          'nsvals-': [('nsval', False)],
          'nsvanor': [('nsvana', False)],
          'nsvanorna': [('nsvana', False)],
          'nsvanornas': [('nsvana', False)],
          'nsvanors': [('nsvana', False)],
          'nsvans': [('nsvans', False)],
          'nsvans-': [('nsvans', False)],
          'nsvar': [('nsvar', False)],
          'nsvarar': [('nsvarare', False)],
          'nsvararna': [('nsvarare', False)],
          'nsvararnas': [('nsvarare', False)],
          'nsvepen': [('nsvep', False)],
          'nsvepens': [('nsvep', False)],
          'nsvepet': [('nsvep', False)],
          'nsvepets': [('nsvep', False)],
          'nsveps': [('nsvep', False)],
          'nsveps-': [('nsvep', False)],
          'nsverken': [('nsverk', False)],
          'nsverkens': [('nsverk', False)],
          'nsverket': [('nsverk', False)],
          'nsverks': [('nsverk', False)],
          'nsverks-': [('nsverk', False)],
          'nsving': [('nsvinge', False)],
          'nsving-': [('nsvinge', False)],
          'nsvingar': [('nsvinge', False)],
          'nsvingarna': [('nsvinge', False)],
          'nsvingarnas': [('nsvinge', False)],
          'nsvingars': [('nsvinge', False)],
          'nsvingen': [('nsvinge', False)],
          'nsvingens': [('nsvinge', False)],
          'nsvings': [('nsvinge', False)],
          'nsvings-': [('nsvinge', False)],
          'nsviter': [('nsvit', False)],
          'nsviterna': [('nsvit', False)],
          'nsviternas': [('nsvit', False)],
          'nsviters': [('nsvit', False)],
          'nsvägens': [('nsväg', False)],
          'nsvärden': [('nsvärde', False)],
          'nsvärdens': [('nsvärde', False)],
          'nsvärdet': [('nsvärde', False)],
          'nsvärdets': [('nsvärde', False)],
          'nsvärmen': [('nsvärme', False)],
          'nsvärmens': [('nsvärme', False)],
          'nsväsendet': [('nsväsen', False)],
          'nsylt': [('nsylt', False)],
          'nsylt-': [('nsylt', False)],
          'nsylts': [('nsylt', False)],
          'nsylts-': [('nsylt', False)],
          'nsyns': [('nsyn', False)],
          'nsyre': [('nsyra', False)],
          'nsyre-': [('nsyra', False)],
          'nsändarna': [('nsändare', False)],
          'nsäs': [('nsäs', False)],
          'nsås': [('nsås', False)],
          'nsås-': [('nsås', False)],
          'nsögonen': [('nsögon', False)],
          'nsögonens': [('nsögon', False)],
          'nsögons': [('nsögon', False)],
          'nsören': [('nsör', False)],
          'nsörens': [('nsör', False)],
          'nsös-': [('nsös', False)],
          'nt': [('nt', False)],
          'ntabus': [('ntabus', False)],
          'ntack': [('ntacka', False)],
          'ntack-': [('ntacka', False)],
          'ntacks': [('ntacka', False)],
          'ntacks-': [('ntacka', False)],
          'ntagen': [('ntag', False)],
          'ntagens': [('ntag', False)],
          'ntaget': [('ntag', False)],
          'ntagets': [('ntage', False)],
          'ntaggar': [('ntagg', False)],
          'ntaggarna': [('ntagg', False)],
          'ntaggarnas': [('ntagg', False)],
          'ntak': [('ntak', False)],
          'ntaken': [('ntak', False)],
          'ntaket': [('ntak', False)],
          'ntalen': [('ntal', False)],
          'ntalens': [('ntal', False)],
          'ntalerna': [('ntal', False)],
          'ntalernas': [('ntal', False)],
          'ntalet': [('ntal', False)],
          'ntalong': [('ntalonger', False)],
          'ntalong-': [('ntalonger', False)],
          'ntalonger': [('ntalonger', False)],
          'ntalongerna': [('ntalonger', False)],
          'ntalongernas': [('ntalonger', False)],
          'ntalongers': [('ntalonger', False)],
          'ntalongs': [('ntalonger', False)],
          'ntalongs-': [('ntalonger', False)],
          'ntan-': [('ntan', False)],
          'ntana': [('ntum', False)],
          'ntanas': [('ntum', False)],
          'ntanden': [('ntande', False)],
          'ntandens': [('ntande', False)],
          'ntank-': [('ntank', False)],
          'ntankar': [('ntank', False)],
          'ntankarna': [('ntank', False)],
          'ntankarnas': [('ntank', False)],
          'ntankars': [('ntank', False)],
          'ntanken': [('ntank', False)],
          'ntankens': [('ntank', False)],
          'ntanks': [('ntank', False)],
          'ntanks-': [('ntank', False)],
          'ntans': [('nta', False)],
          'ntans-': [('ntan', False)],
          'ntant': [('ntanter', False)],
          'ntant-': [('ntanter', False)],
          'ntanter': [('ntanter', False)],
          'ntanterna': [('ntanter', False)],
          'ntanternas': [('ntanter', False)],
          'ntanters': [('ntanter', False)],
          'ntants': [('ntant', False)],
          'ntants-': [('ntanter', False)],
          'ntaren': [('ntare', False)],
          'ntarna': [('nt', False)],
          'ntars': [('nt', False)],
          'ntars-': [('ntar', False)],
          'ntask': [('ntask', False)],
          'ntask-': [('ntask', False)],
          'ntastens': [('ntast', False)],
          'ntat': [('ntat', False)],
          'ntats': [('ntat', False)],
          'ntax': [('ntax', False)],
          'ntax-': [('ntaxa', False)],
          'ntbet-': [('ntbete', False)],
          'ntbete': [('ntbete', False)],
          'ntbit': [('ntbit', False)],
          'ntbitar': [('ntbit', False)],
          'ntbitarna': [('ntbit', False)],
          'ntbitarnas': [('ntbit', False)],
          'nte': [('nta', False)],
          'nte-': [('nta', False)],
          'ntegranden': [('ntegrand', False)],
          'ntegrandens': [('ntegrand', False)],
          'ntekniker': [('nteknik', False)],
          'nteknikerna': [('nteknik', False)],
          'nteknikernas': [('nteknik', False)],
          'nteknikers': [('nteknik', False)],
          'ntel': [('ntel', False)],
          'ntelen': [('ntel', False)],
          'ntelens': [('ntel', False)],
          'ntelers': [('ntele', False)],
          'ntellans': [('ntella', False)],
          'nteln': [('ntel', False)],
          'ntelns': [('ntel', False)],
          'ntels': [('ntel', False)],
          'ntels-': [('ntel', False)],
          'ntemer': [('ntem', False)],
          'ntemerna': [('ntem', False)],
          'ntemernas': [('ntem', False)],
          'ntemers': [('ntem', False)],
          'ntemet': [('ntem', False)],
          'ntemets': [('ntem', False)],
          'nten': [('nt', False)],
          'ntens': [('nt', False)],
          'nter': [('nt', False)],
          'nter-': [('nter', False)],
          'nteranden': [('nterande', False)],
          'nterandens': [('nterande', False)],
          'nterhake': [('nterhake', False)],
          'nterhake-': [('nterhake', False)],
          'nterien': [('nteri', False)],
          'nterier': [('nteri', False)],
          'nterierna': [('nteri', False)],
          'nteriernas': [('nteri', False)],
          'nteriets': [('nteri', False)],
          'nterin': [('nteri', False)],
          'nterits': [('nteri', False)],
          'ntern': [('nter', False)],
          'ntern-': [('nterna', False)],
          'nterna': [('nt', False)],
          'nternas': [('nt', False)],
          'nterns': [('nter', False)],
          'nterns-': [('nterna', False)],
          'nters': [('nt', False)],
          'nters-': [('nter', False)],
          'ntersen': [('nter', False)],
          'ntersens': [('nter', False)],
          'ntes': [('ntes', False)],
          'ntes-': [('ntes', False)],
          'ntessens': [('ntessens', False)],
          'ntet': [('nt', False)],
          'nteters': [('ntet', False)],
          'ntets': [('ntet', False)],
          'nthandlar': [('nthandel', False)],
          'nthandlarna': [('nthandel', False)],
          'nthet': [('nthet', False)],
          'nthets': [('nthet', False)],
          'ntian': [('ntia', False)],
          'ntian-': [('ntiana', False)],
          'ntiana': [('ntia', False)],
          'ntianas': [('ntia', False)],
          'ntians': [('ntia', False)],
          'ntias': [('ntia', False)],
          'ntias-': [('ntia', False)],
          'ntiden': [('ntid', False)],
          'ntider': [('ntid', False)],
          'ntiders': [('ntid', False)],
          'ntie': [('ntier', False)],
          'ntie-': [('ntier', False)],
          'ntien': [('ntie', False)],
          'ntiens': [('ntie', False)],
          'ntierna': [('ntie', False)],
          'nties': [('ntie', False)],
          'ntiet': [('ntium', False)],
          'ntigen': [('ntigen', False)],
          'ntighets': [('ntighet', False)],
          'ntik': [('ntik', False)],
          'ntik-': [('ntik', False)],
          'ntiks': [('ntik', False)],
          'ntiks-': [('ntik', False)],
          'ntilen': [('ntil', False)],
          'ntilens': [('ntil', False)],
          'ntilens-': [('ntilena', False)],
          'ntilj': [('ntilj', False)],
          'ntilj-': [('ntilj', False)],
          'ntiljs': [('ntilj', False)],
          'ntim': [('ntimme', False)],
          'ntim-': [('ntimme', False)],
          'ntimmarna': [('ntimme', False)],
          'ntin': [('nti', False)],
          'ntin-': [('ntin', False)],
          'ntinens': [('ntin', False)],
          'ntiner': [('ntin', False)],
          'ntinerna': [('ntin', False)],
          'ntinernas': [('ntin', False)],
          'ntiners': [('ntin', False)],
          'ntinne': [('ntinna', False)],
          'ntins': [('nti', False)],
          'ntions-': [('ntion', False)],
          'ntior': [('ntior', False)],
          'ntiors': [('ntior', False)],
          'ntipp': [('ntippa', False)],
          'ntipp-': [('ntippa', False)],
          'ntipps': [('ntippa', False)],
          'ntipps-': [('ntippa', False)],
          'ntis': [('nti', False)],
          'ntit': [('ntit', False)],
          'ntit-': [('ntit', False)],
          'ntitan': [('ntita', False)],
          'ntitans': [('ntita', False)],
          'ntits': [('ntit', False)],
          'ntiv': [('ntiv', False)],
          'ntiv-': [('ntiv', False)],
          'ntiven': [('ntiv', False)],
          'ntivens': [('ntiv', False)],
          'ntivet': [('ntiv', False)],
          'ntivs': [('ntiv', False)],
          'ntjacks': [('ntjack', False)],
          'ntjacks-': [('ntjack', False)],
          'ntlandets': [('ntlande', False)],
          'ntlar': [('ntel', False)],
          'ntlarna': [('ntel', False)],
          'ntlarnas': [('ntel', False)],
          'ntmans': [('ntman', False)],
          'ntningskurs': [('ntningskur', False)],
          'ntningskurs-': [('ntningskur', False)],
          'ntnot': [('ntnota', False)],
          'ntnot-': [('ntnota', False)],
          'ntnots': [('ntnota', False)],
          'ntnots-': [('ntnota', False)],
          'nto-': [('nto', False)],
          'ntol': [('ntol', False)],
          'ntol-': [('ntol', False)],
          'ntolen': [('ntol', False)],
          'ntolens': [('ntol', False)],
          'ntolkar': [('ntolk', False)],
          'ntolkarna': [('ntolk', False)],
          'ntolkarnas': [('ntolk', False)],
          'ntols': [('ntol', False)],
          'ntom-': [('ntom', False)],
          'ntoms': [('ntom', False)],
          'nton': [('nton', False)],
          'ntoner': [('nton', False)],
          'ntonerna': [('nton', False)],
          'ntonernas': [('nton', False)],
          'ntoners': [('nton', False)],
          'ntons': [('nton', False)],
          'ntor': [('nta', False)],
          'ntoren': [('ntor', False)],
          'ntorens': [('ntor', False)],
          'ntorer': [('ntor', False)],
          'ntorerna': [('ntor', False)],
          'ntorernas': [('ntor', False)],
          'ntorers': [('ntor', False)],
          'ntorn': [('ntor', False)],
          'ntorna': [('nta', False)],
          'ntornas': [('nta', False)],
          'ntorns': [('ntor', False)],
          'ntors': [('nta', False)],
          'ntorv': [('ntorv', False)],
          'ntorvs': [('ntorv', False)],
          'ntorvs-': [('ntorv', False)],
          'ntos': [('nto', False)],
          'ntos-': [('nto', False)],
          'ntpakten': [('ntpakten', False)],
          'ntra': [('ntra', False)],
          'ntradans': [('ntradans', False)],
          'ntran': [('ntra', False)],
          'ntrana': [('ntrum', False)],
          'ntranas': [('ntrum', False)],
          'ntrans': [('ntran', False)],
          'ntrans-': [('ntran', False)],
          'ntrapp': [('ntrappa', False)],
          'ntrapp-': [('ntrappa', False)],
          'ntrapps': [('ntrappa', False)],
          'ntrapps-': [('ntrappa', False)],
          'ntrar': [('nter', False)],
          'ntrarna': [('nter', False)],
          'ntrarnas': [('ntrare', False)],
          'ntrars': [('nter', False)],
          'ntras': [('ntrum', False)],
          'ntras-': [('ntras', False)],
          'ntrat': [('ntra', False)],
          'ntrats': [('ntra', False)],
          'ntratt': [('ntratt', False)],
          'ntratts': [('ntratt', False)],
          'ntratts-': [('ntratt', False)],
          'ntren': [('nter', False)],
          'ntrer': [('nter', False)],
          'ntrerna': [('nter', False)],
          'ntrernas': [('nter', False)],
          'ntrian': [('ntrian', False)],
          'ntrians': [('ntrian', False)],
          'ntringar': [('ntring', False)],
          'ntringars': [('ntring', False)],
          'ntringens': [('ntring', False)],
          'ntron': [('ntro', False)],
          'ntrons': [('ntro', False)],
          'ntropins': [('ntropi', False)],
          'ntror': [('ntra', False)],
          'ntros': [('ntro', False)],
          'ntrosor': [('ntros', False)],
          'ntrosorna': [('ntros', False)],
          'ntrosornas': [('ntros', False)],
          'ntrosors': [('ntros', False)],
          'ntrull': [('ntrulle', False)],
          'ntrull-': [('ntrulle', False)],
          'ntrullar': [('ntrulle', False)],
          'ntrullarnas': [('ntrulle', False)],
          'ntrullen': [('ntrulle', False)],
          'ntrullens': [('ntrulle', False)],
          'ntrum': [('ntrum', False)],
          'ntrum-': [('ntrum', False)],
          'ntrums': [('ntrum', False)],
          'ntrums-': [('ntrum', False)],
          'ntrycken': [('ntryck', False)],
          'ntryckens': [('ntryck', False)],
          'ntrycket': [('ntryck', False)],
          'ntryckets': [('ntryck', False)],
          'ntrycks': [('ntryck', False)],
          'ntrycks-': [('ntryck', False)],
          'ntryn': [('ntry', False)],
          'ntryns': [('ntry', False)],
          'nträd': [('nträd', False)],
          'nträd-': [('nträd', False)],
          'nträde': [('nträde', False)],
          'nträde-': [('nträde', False)],
          'nträdet': [('nträde', False)],
          'nträdets': [('nträd', False)],
          'nträds': [('nträd', False)],
          'nträn': [('nträd', False)],
          'nträna': [('nträd', False)],
          'ntränas': [('nträd', False)],
          'nträns': [('nträd', False)],
          'nträt': [('nträ', False)],
          'nträts': [('nträ', False)],
          'nts-': [('nt', False)],
          'ntsaks': [('ntsak', False)],
          'ntsaks-': [('ntsak', False)],
          'ntsar': [('nts', False)],
          'ntsarnas': [('nts', False)],
          'ntsars': [('nts', False)],
          'ntsie': [('ntsia', False)],
          'ntställen': [('ntställe', False)],
          'ntstället': [('ntställe', False)],
          'ntsång': [('ntsång', False)],
          'ntsångs': [('ntsång', False)],
          'ntsångs-': [('ntsång', False)],
          'ntum': [('ntum', False)],
          'ntum-': [('ntum', False)],
          'ntumen': [('ntum', False)],
          'ntumens': [('ntum', False)],
          'ntums': [('ntum', False)],
          'ntung': [('ntung', False)],
          'ntung-': [('ntung', False)],
          'ntungs': [('ntung', False)],
          'ntur': [('ntur', False)],
          'ntur-': [('ntur', False)],
          'nturer': [('ntur', False)],
          'nturerna': [('ntur', False)],
          'nturernas': [('ntur', False)],
          'nturs': [('ntur', False)],
          'nturs-': [('ntur', False)],
          'ntus': [('ntus', False)],
          'ntus-': [('ntus', False)],
          'ntut': [('ntuta', False)],
          'ntut-': [('ntuta', False)],
          'ntuts': [('ntuta', False)],
          'ntuts-': [('ntuta', False)],
          'ntycket': [('ntycke', False)],
          'ntydan': [('ntydan', False)],
          'ntydans': [('ntydan', False)],
          'ntylen': [('ntyl', False)],
          'ntylens': [('ntyl', False)],
          'ntypen': [('ntyp', False)],
          'ntyper': [('ntyp', False)],
          'ntyperna': [('ntyp', False)],
          'ntypernas': [('ntyp', False)],
          'ntypers': [('ntyp', False)],
          'ntyr': [('ntyr', False)],
          'ntyr-': [('ntyr', False)],
          'ntyren': [('ntyr', False)],
          'ntyrens': [('ntyr', False)],
          'ntyret': [('ntyr', False)],
          'ntyrets': [('ntyr', False)],
          'ntyrs': [('ntyr', False)],
          'ntyrs-': [('ntyr', False)],
          'ntåg': [('ntåg', False)],
          'ntågs': [('ntåg', False)],
          'ntågs-': [('ntåg', False)],
          'ntångar': [('ntångare', False)],
          'ntångarna': [('ntångare', False)],
          'ntångarnas': [('ntångare', False)],
          'nu': [('nu', True)],
          'nu-': [('nu', True)],
          'nua': [('nuum', False)],
          'nuas': [('nua', False)],
          'nubb': [('nubb', False)],
          'nubb-': [('nubb', True)],
          'nubbar': [('nubbe', False)],
          'nubbarna': [('nubbe', True)],
          'nubbarnas': [('nubbe', True)],
          'nubbars': [('nubbe', True)],
          'nubbe': [('nubbe', True)],
          'nubbe-': [('nubbe', True)],
          'nubben': [('nubb', True), ('nubbe', True)],
          'nubbens': [('nubbe', True), ('nubb', True)],
          'nubbet': [('nubb', True)],
          'nubbets': [('nubb', True)],
          'nubbor': [('nubba', False)],
          'nubborna': [('nubba', False)],
          'nubbornas': [('nubba', False)],
          'nubbors': [('nubba', False)],
          'nubbs': [('nubb', False)],
          'nubbs-': [('nubb', False)],
          'nuck': [('nucka', True)],
          'nuck-': [('nucka', True)],
          'nucker': [('nuck', False)],
          'nuckerna': [('nuck', False)],
          'nuckernas': [('nuck', False)],
          'nuckers': [('nuck', False)],
          'nucks': [('nucka', True)],
          'nucks-': [('nucka', True)],
          'nudd': [('nudd', False)],
          'nudd-': [('nudd', False)],
          'nuddar': [('nudd', False)],
          'nuddarna': [('nudd', False)],
          'nuddarnas': [('nudd', False)],
          'nuddars': [('nudd', False)],
          'nudden': [('nudd', False)],
          'nuddens': [('nudd', False)],
          'nudds': [('nudd', False)],
          'nudds-': [('nudd', False)],
          'nudel': [('nudel', True)],
          'nudel-': [('nudel', True)],
          'nudels': [('nudel', True)],
          'nudels-': [('nudel', True)],
          'nudlar': [('nudel', True)],
          'nudlarna': [('nudel', True)],
          'nudlarnas': [('nudel', True)],
          'nudlars': [('nudel', True)],
          'nue': [('nua', False)],
          'nue-': [('nua', False)],
          'nuens': [('nuens', False)],
          'nuer': [('nu', False)],
          'nuerna': [('nu', False)],
          'nuernas': [('nu', False)],
          'nuers': [('nu', False)],
          'nuet': [('nu', True)],
          'nuets': [('nu', True)],
          'nuettens': [('nuett', False)],
          'nuetters': [('nuett', False)],
          'nuff': [('nuff', False)],
          'nuff-': [('nuff', False)],
          'nuffar': [('nuff', False)],
          'nuffarna': [('nuff', False)],
          'nuffs': [('nuff', False)],
          'nuffs-': [('nuff', False)],
          'nugg': [('nugga', False)],
          'nugge': [('nugga', False)],
          'nuggs': [('nugga', False)],
          'nuggs-': [('nugga', False)],
          'nulas': [('nulum', False)],
          'null': [('null', False)],
          'null-': [('null', False)],
          'nullar': [('nullare', False)],
          'nullarna': [('nullare', False)],
          'nullarnas': [('nullare', False)],
          'nulls': [('null', False)],
          'nulls-': [('null', False)],
          'numen': [('numen', True)],
          'numens': [('numen', True)],
          'nun': [('nuna', True)],
          'nun-': [('nuna', True)],
          'nung': [('nung', False)],
          'nung-': [('nung', False)],
          'nungar': [('nung', False)],
          'nungarna': [('nung', False)],
          'nungarnas': [('nung', False)],
          'nungars': [('nung', False)],
          'nungen': [('nung', False)],
          'nungens': [('nung', False)],
          'nungs': [('nung', False)],
          'nungs-': [('nung', False)],
          'nunn': [('nunna', True)],
          'nunn-': [('nunna', True)],
          'nunne': [('nunna', False)],
          'nuns': [('nuna', True)],
          'nuns-': [('nuna', True)],
          'nuor': [('nua', False)],
          'nuorna': [('nua', False)],
          'nuornas': [('nua', False)],
          'nuors': [('nua', False)],
          'nuri': [('nuri', False)],
          'nuri-': [('nuri', False)],
          'nuriens': [('nuri', False)],
          'nurins': [('nuri', False)],
          'nuris': [('nuri', False)],
          'nurre': [('nurra', False)],
          'nurren': [('nurr', False)],
          'nurrens': [('nurr', False)],
          'nus': [('nu', True)],
          'nusan': [('nusa', False)],
          'nusans': [('nusa', False)],
          'nusarnas': [('nus', False)],
          'nusk': [('nusk', False)],
          'nusk-': [('nusk', False)],
          'nuskarna': [('nusker', False)],
          'nuskarnas': [('nusker', False)],
          'nuskars': [('nusker', False)],
          'nuss': [('nuss', False)],
          'nussarna': [('nussare', False)],
          'nussarnas': [('nussare', False)],
          'nussel': [('nussel', False)],
          'nussel-': [('nussel', False)],
          'nussen': [('nuss', False)],
          'nussens': [('nuss', False)],
          'nutan': [('nuta', False)],
          'nutarnas': [('nut', False)],
          'nutidens': [('nutid', True)],
          'nutrarna': [('nut', False)],
          'nutt': [('nutt', False)],
          'nutt-': [('nutt', False)],
          'nuttar': [('nutte', False)],
          'nuttarna': [('nutte', False)],
          'nuttarnas': [('nutte', False)],
          'nuttars': [('nutt', False)],
          'nutte-': [('nutte', False)],
          'nutten': [('nutt', False)],
          'nuttens': [('nutte', False)],
          'nutts': [('nutt', False)],
          'nutts-': [('nutte', False)],
          'nuv': [('nuva', False)],
          'nuv-': [('nuva', False)],
          'nuvs': [('nuva', False)],
          'nuvs-': [('nuva', False)],
          'nval': [('nval', False)],
          'nval-': [('nval', False)],
          'nvalarna': [('nval', False)],
          'nvalen': [('nval', False)],
          'nvalens': [('nval', False)],
          'nvallar': [('nvall', False)],
          'nvallarna': [('nvall', False)],
          'nvallarnas': [('nvall', False)],
          'nvalls-': [('nvall', False)],
          'nvals': [('nval', False)],
          'nvals-': [('nval', False)],
          'nvana': [('nvana', False)],
          'nvane': [('nvana', False)],
          'nvane-': [('nvana', False)],
          'nvar': [('nvara', False)],
          'nvar-': [('nvara', False)],
          'nvaran': [('nvara', False)],
          'nvarans': [('nvara', False)],
          'nvard': [('nvard', False)],
          'nvard-': [('nvard', False)],
          'nvarden': [('nvard', False)],
          'nvardens': [('nvard', False)],
          'nvards': [('nvard', False)],
          'nvards-': [('nvard', False)],
          'nvas': [('nvas', False)],
          'nvas-': [('nvas', False)],
          'nvasen': [('nvas', False)],
          'nvasens': [('nvas', False)],
          'nvatten': [('nvatten', False)],
          'nveck': [('nveck', False)],
          'nveck-': [('nveck', False)],
          'nvecks': [('nveck', False)],
          'nvecks-': [('nveck', False)],
          'nverkets': [('nverk', False)],
          'nvett': [('nvett', False)],
          'nvetts': [('nvett', False)],
          'nvetts-': [('nvett', False)],
          'nvig': [('nvig', False)],
          'nvig-': [('nvig', False)],
          'nvigs': [('nvig', False)],
          'nvigs-': [('nvig', False)],
          'nviktorie': [('nviktorium', False)],
          'nviktorie-': [('nviktorium', False)],
          'nvill': [('nvilla', False)],
          'nvills': [('nvilla', False)],
          'nvin': [('nvin', False)],
          'nvind': [('nvind', False)],
          'nvindarnas': [('nvind', False)],
          'nvinds': [('nvind', False)],
          'nvinds-': [('nvind', False)],
          'nving': [('nvinge', False)],
          'nving-': [('nvinge', False)],
          'nvingar': [('nvinge', False)],
          'nvingarna': [('nvinge', False)],
          'nvingarnas': [('nvinge', False)],
          'nvingars': [('nvinge', False)],
          'nvingen': [('nvinge', False)],
          'nvingens': [('nvinge', False)],
          'nvings': [('nvinge', False)],
          'nvings-': [('nvinge', False)],
          'nvins': [('nvin', False)],
          'nvins-': [('nvin', False)],
          'nvinter': [('nvinter', False)],
          'nvinters': [('nvinter', False)],
          'nviol': [('nviol', False)],
          'nviol-': [('nviol', False)],
          'nviols': [('nviol', False)],
          'nviols-': [('nviol', False)],
          'nvisa': [('nvisa', False)],
          'nvisas': [('nvisa', False)],
          'nvise': [('nvisa', False)],
          'nvisor': [('nvisa', False)],
          'nvisors': [('nvisa', False)],
          'nvit': [('nvit', False)],
          'nvit-': [('nvit', False)],
          'nvitas': [('nvita', False)],
          'nvite': [('nvita', False)],
          'nviten': [('nvit', False)],
          'nvitens': [('nvit', False)],
          'nviter': [('nvit', False)],
          'nviterna': [('nvit', False)],
          'nviters': [('nvit', False)],
          'nvits': [('nvit', False)],
          'nvits-': [('nvita', False)],
          'nvägar': [('nväg', False)],
          'nvägarna': [('nväg', False)],
          'nvägarnas': [('nväg', False)],
          'nvägars': [('nväg', False)],
          'nvägen': [('nväg', False)],
          'nvägs': [('nväg', False)],
          'nvägs-': [('nväg', False)],
          'nvälden': [('nvälde', False)],
          'nväldens': [('nvälde', False)],
          'nvändar': [('nvändare', False)],
          'nvändarna': [('nvändare', False)],
          'nvärden': [('nvärde', False)],
          'nvärdens': [('nvärde', False)],
          'nvärmar': [('nvärmare', False)],
          'nvärmarna': [('nvärmare', False)],
          'nvärmarnas': [('nvärmare', False)],
          'nväxlar': [('nväxel', False)],
          'nväxlarna': [('nväxel', False)],
          'nväxlarnas': [('nväxel', False)],
          'nvågar': [('nvåg', False)],
          'nvågarna': [('nvåg', False)],
          'nvårar': [('nvår', False)],
          'nvårdar': [('nvårdare', False)],
          'nvårdarna': [('nvårdare', False)],
          'nvårdarnas': [('nvårdare', False)],
          'nx': [('nx', False)],
          'nx-': [('nx', False)],
          'nxar': [('nx', False)],
          'nxarna': [('nx', False)],
          'nxarnas': [('nx', False)],
          'nxars': [('nx', False)],
          'nxen': [('nx', False)],
          'nxens': [('nx', False)],
          'nxer': [('nx', False)],
          'nxerna': [('nx', False)],
          'nxernas': [('nx', False)],
          'nxers': [('nx', False)],
          'nxn': [('nxn', True)],
          'ny': [('ny', False)],
          'ny-': [('ny', False)],
          'nyan': [('nyan', False)],
          'nyans': [('nyans', True)],
          'nyaren': [('nyare', False)],
          'nyarnas': [('nyare', False)],
          'nyck-': [('nyck', True)],
          'nyckar': [('nyck', False)],
          'nyckarna': [('nyck', False)],
          'nyckars': [('nyck', False)],
          'nyckel': [('nyckel', False)],
          'nyckel-': [('nyckel', False)],
          'nyckels': [('nyckel', False)],
          'nyckels-': [('nyckel', False)],
          'nycken': [('nyck', False)],
          'nyckens': [('nyck', False)],
          'nycklar': [('nyckel', False)],
          'nycklarna': [('nyckel', True)],
          'nycklarnas': [('nyckel', False)],
          'nycklars': [('nyckel', False)],
          'nyckningar': [('nyckning', False)],
          'nyckningarna': [('nyckning', False)],
          'nyckningarnas': [('nyckning', False)],
          'nyckningars': [('nyckning', False)],
          'nycknings': [('nyckning', False)],
          'nycknings-': [('nyckning', False)],
          'nycks': [('nyck', False)],
          'nycks-': [('nyck', False)],
          'nyen': [('ny', True)],
          'nyens': [('ny', True)],
          'nyer': [('ny', False)],
          'nyerna': [('ny', False)],
          'nyernas': [('ny', False)],
          'nyers': [('ny', False)],
          'nyft': [('nyft', False)],
          'nyft-': [('nyft', False)],
          'nyften': [('nyft', False)],
          'nyftens': [('nyft', False)],
          'nyftet': [('nyft', False)],
          'nyfts': [('nyft', False)],
          'nyfts-': [('nyft', False)],
          'nyheter': [('nyhet', True)],
          'nyheterna': [('nyhet', True)],
          'nyheternas': [('nyhet', True)],
          'nyheters': [('nyhet', True)],
          'nyhets': [('nyhet', True)],
          'nyhets-': [('nyhet', False)],
          'nyllen': [('nylle', True)],
          'nyllens': [('nylle', True)],
          'nyltarnas': [('nyltare', False)],
          'nympar': [('nympar', False)],
          'nympar-': [('nympar', False)],
          'nymparens': [('nympar', False)],
          'nympars': [('nympar', False)],
          'nyn': [('ny', False)],
          'nyna': [('ny', True)],
          'nynas': [('ny', True)],
          'nyns': [('ny', False)],
          'nyp': [('nyp', True), ('nypa', True)],
          'nyp-': [('nypa', True), ('nyp', True)],
          'nypets': [('nyp', False)],
          'nyps': [('nyp', True), ('nypa', True)],
          'nyps-': [('nyp', True), ('nypa', True)],
          'nyrers': [('nyr', False)],
          'nys': [('nys', True), ('ny', True)],
          'nys-': [('nys', True), ('ny', True)],
          'nysarna': [('ny', False)],
          'nysets': [('nys', True)],
          'nyst': [('nyst', False)],
          'nyst-': [('nyst', False)],
          'nysten': [('nyst', False)],
          'nystens': [('nyst', False)],
          'nystet': [('nyst', False)],
          'nystets': [('nyst', False)],
          'nyt': [('ny', True)],
          'nyte': [('nyte', False)],
          'nyten': [('nyte', False)],
          'nytens': [('nyte', False)],
          'nytet': [('nyte', False)],
          'nyts': [('ny', True)],
          'nyts-': [('nyte', False)],
          'nytt': [('nytta', True)],
          'nytte': [('nytta', False)],
          'nyttet': [('nytt', False)],
          'nytts': [('nytta', True)],
          'nytts-': [('nytta', True)],
          'nyx': [('nyxa', False)],
          'nyx-': [('nyxa', False)],
          'nzolan': [('nzola', False)],
          'nzolans': [('nzola', False)],
          'nzon': [('nzon', False)],
          'nzons': [('nzon', False)],
          'näbb': [('näbba', True), ('näbb', True)],
          'näbb-': [('näbba', True), ('näbb', True)],
          'näbbs': [('näbba', True), ('näbb', True)],
          'näbbs-': [('näbba', True), ('näbb', True)],
          'näck': [('näck', False)],
          'näck-': [('näck', False)],
          'näcke': [('näcka', False)],
          'näcken': [('näck', False)],
          'näckens': [('näck', False)],
          'näcket': [('näck', False)],
          'näcks': [('näck', False)],
          'näcks-': [('näck', False)],
          'nägg-': [('nägg', False)],
          'näggs': [('nägg', False)],
          'näll': [('näll', False)],
          'näll-': [('näll', False)],
          'nällanden': [('nällande', False)],
          'nällandena': [('nällande', False)],
          'nällandenas': [('nällande', False)],
          'nällandens': [('nällande', False)],
          'nället': [('näll', False)],
          'nällets': [('näll', False)],
          'nälls': [('näll', False)],
          'nälls-': [('näll', False)],
          'nälvor': [('nälvor', False)],
          'nälvorna': [('nälvor', False)],
          'nälvornas': [('nälvor', False)],
          'nälvors': [('nälvor', False)],
          'nälvs': [('nälvor', False)],
          'nälvs-': [('nälvor', False)],
          'nämne-': [('nämne', False)],
          'nän': [('nä', False)],
          'näna': [('nä', False)],
          'nänas': [('nä', False)],
          'näng': [('näng', False)],
          'nängar': [('näng', False)],
          'nängarna': [('näng', False)],
          'nängen': [('näng', False)],
          'nängs': [('näng', False)],
          'nängs-': [('näng', False)],
          'näns': [('nä', False)],
          'näpp': [('näpp', False)],
          'näpp-': [('näpp', False)],
          'näppe': [('näppa', False)],
          'näppe-': [('näppa', False)],
          'näppen': [('näpp', False)],
          'näppens': [('näpp', False)],
          'näppet': [('näpp', False)],
          'näppets': [('näppe', False)],
          'näpps': [('näpp', False)],
          'näpps-': [('näpp', False)],
          'näran': [('nära', False)],
          'närans': [('nära', False)],
          'närj': [('närj', False)],
          'närj-': [('närj', False)],
          'närmar': [('närm', False)],
          'närmarnas': [('närm', False)],
          'närpe': [('närpa', False)],
          'närpe-': [('närpa', False)],
          'närpen': [('närp', False)],
          'närpens': [('närp', False)],
          'närtanden': [('närtande', False)],
          'närtandens': [('närtande', False)],
          'näs': [('näs', True), ('näsa', True)],
          'näs-': [('näs', True), ('näsa', True)],
          'nässans': [('nässans', False)],
          'näst': [('näst', True), ('näste', True)],
          'näst-': [('näst', True), ('näste', True)],
          'näste': [('nästa', True), ('näste', True)],
          'näste-': [('nästa', True)],
          'nästen': [('näst', True), ('näste', True)],
          'nästens': [('näst', True), ('näste', True)],
          'nästet': [('näst', True), ('näste', True)],
          'nästets': [('näst', True), ('näste', True)],
          'nät': [('nät', True)],
          'nät-': [('nät', False)],
          'nätets': [('nät', False)],
          'näts': [('nät', True)],
          'nätter': [('natt', False)],
          'nätterna': [('natt', False)],
          'nätternas': [('natt', False)],
          'nätters': [('natt', False)],
          'näv': [('näva', True), ('näve', True)],
          'näv-': [('näva', True), ('näve', True)],
          'nävan': [('näva', False)],
          'nävans': [('näva', False)],
          'nävar': [('näve', False)],
          'nävarna': [('näve', False)],
          'nävarnas': [('näve', True)],
          'nävars': [('näve', False)],
          'näve': [('näve', True), ('näva', True)],
          'näven': [('näve', False)],
          'nävens': [('näve', False)],
          'näver': [('näver', False)],
          'nävers': [('näver', True)],
          'nävs': [('näve', True), ('näva', True)],
          'nävs-': [('näve', True), ('näva', True)],
          'nå': [('nå', False)],
          'nå-': [('nå', False)],
          'nåd': [('nåd', False)],
          'nåd-': [('nåd', False)],
          'nådarnas': [('nåd', True)],
          'nåder': [('nåd', False)],
          'nåders': [('nåd', False)],
          'nåds': [('nåd', False)],
          'nåds-': [('nåd', False)],
          'nåker': [('nåker', False)],
          'nåkers': [('nåker', False)],
          'nålarnas': [('nål', False)],
          'nålars': [('nål', False)],
          'nålen': [('nål', False)],
          'nångarna': [('nångare', False)],
          'nåns': [('nå', False)],
          'når': [('når', False)],
          'når-': [('når', False)],
          'nårs': [('når', False)],
          'nårs-': [('når', False)],
          'nås': [('nå', False)],
          'nåtarnas': [('nåt', True)],
          'néerna': [('né', False)],
          'néernas': [('né', False)],
          'nés-': [('né', False)],
          'nöar': [('nö', False)],
          'nöarna': [('nö', False)],
          'nödan': [('nödan', False)],
          'nöden': [('nöd', False)],
          'nödens': [('nöd', False)],
          'nödflagg': [('nödflagga', True), ('nödflagg', True)],
          'nödflaggs': [('nödflagga', True), ('nödflagg', True)],
          'nödflaggs-': [('nödflagga', True), ('nödflagg', True)],
          'nögats': [('nöga', False)],
          'nögonens': [('nöga', False)],
          'nöje': [('nöje', False)],
          'nöjen': [('nöje', False)],
          'nöjens': [('nöje', False)],
          'nökan': [('nöka', False)],
          'nökans': [('nöka', False)],
          'nöken': [('nöken', False)],
          'nökens': [('nöken', False)],
          'nökor': [('nöka', False)],
          'nön': [('nö', False)],
          'nöns': [('nö', False)],
          'nör': [('nöre', False)],
          'nör-': [('nöre', False)],
          'nördar': [('nörd', True)],
          'nördarna': [('nörd', True)],
          'nöre': [('nöre', False)],
          'nöre-': [('nöre', False)],
          'nören': [('nöre', False)],
          'nörens': [('nöre', False)],
          'nöret': [('nöre', False)],
          'nörn': [('nör', False)],
          'nörns': [('nör', False)],
          'nörs': [('nöre', False)],
          'nörs-': [('nöre', False)],
          'nörskor': [('nörsko', False)],
          'nörskorna': [('nörsko', False)],
          'nörskornas': [('nörsko', False)],
          'nörskors': [('nörsko', False)],
          'nörtens': [('nört', False)],
          'nös': [('nö', False)],
          'nös-': [('nö', False)],
          'nösarna': [('nös', False)],
          'nösarnas': [('nös', False)],
          'nösk': [('nöske', False)],
          'nöskor': [('nösko', False)],
          'nöt-': [('nöt', True)],
          'nötets': [('nöt', False)],
          'nötter': [('nöt', True)],
          'nötterna': [('nöt', True)],
          'nötternas': [('nöt', True)],
          'nötters': [('nöt', True)],
          'növrarnas': [('növer', False)],
          'o': [('o', True)],
          'o-': [('o', True)],
          'oa': [('oa', False)],
          'oa-': [('oa', False)],
          'oachen': [('oach', False)],
          'oachens': [('oach', False)],
          'oacher': [('oach', False)],
          'oacherna': [('oach', False)],
          'oachernas': [('oach', False)],
          'oachers': [('oach', False)],
          'oadiesarna': [('oadie', False)],
          'oadiesarnas': [('oadie', False)],
          'oafer': [('oafer', False)],
          'oaje': [('oaje', False)],
          'oaje-': [('oaje', False)],
          'oajen': [('oaje', False)],
          'oajens': [('oaje', False)],
          'oak-': [('oak', False)],
          'oaks': [('oak', False)],
          'oaks-': [('oak', False)],
          'oakören': [('oakör', False)],
          'oakörens': [('oakör', False)],
          'oalan': [('oala', False)],
          'oalans': [('oala', False)],
          'oalas': [('oala', False)],
          'oalgen': [('oalg', False)],
          'oalgs-': [('oalg', False)],
          'oall': [('oall', False)],
          'oall-': [('oall', False)],
          'oallen': [('oall', False)],
          'oaller': [('oall', False)],
          'oallerna': [('oall', False)],
          'oallernas': [('oall', False)],
          'oallers': [('oall', False)],
          'oalls': [('oall', False)],
          'oals': [('oal', False)],
          'oals-': [('oal', False)],
          'oaltar': [('oaltare', False)],
          'oaltarna': [('oaltare', False)],
          'oaltarnas': [('oaltare', False)],
          'oan': [('oa', False)],
          'oandarna': [('oande', False)],
          'oanden': [('oande', False)],
          'oandens': [('oande', False)],
          'oandets': [('oande', False)],
          'oanens': [('oan', False)],
          'oans': [('oa', False)],
          'oansk': [('oanska', False)],
          'oansk-': [('oanska', False)],
          'oanstalter': [('oanstalt', False)],
          'oanstalterna': [('oanstalt', False)],
          'oanstalternas': [('oanstalt', False)],
          'oanstalters': [('oanstalt', False)],
          'oanstalts': [('oanstalt', False)],
          'oanstalts-': [('oanstalt', False)],
          'oaorden': [('oaord', False)],
          'oap-': [('oapa', False)],
          'oapan': [('oapa', False)],
          'oapas': [('oapa', False)],
          'oar': [('oar', False)],
          'oard': [('oard', False)],
          'oard-': [('oard', False)],
          'oarden': [('oard', False)],
          'oardens': [('oard', False)],
          'oardet': [('oard', False)],
          'oards': [('oard', False)],
          'oards-': [('oard', False)],
          'oaren': [('oar', False)],
          'oarnas': [('o', False)],
          'oars': [('oar', False)],
          'oarslet': [('oarsle', False)],
          'oarstens': [('oarsten', False)],
          'oarten': [('oart', True)],
          'oartens': [('oart', True)],
          'oarter': [('oart', True)],
          'oarterna': [('oart', True)],
          'oarv': [('oarv', False)],
          'oarven': [('oarv', False)],
          'oarvens': [('oarv', False)],
          'oarvs': [('oarv', False)],
          'oarvs-': [('oarv', False)],
          'oas': [('oas', True)],
          'oas-': [('oas', True)],
          'oasits': [('oasits', False)],
          'oast-': [('oast', False)],
          'oasten': [('oast', False)],
          'oastolen': [('oastol', False)],
          'oastolens': [('oastol', False)],
          'oatar': [('oat', False)],
          'oatarnas': [('oat', False)],
          'oatars': [('oat', False)],
          'oats-': [('oat', False)],
          'ob': [('ob', False)],
          'ob-': [('ob', False)],
          'obanan': [('obana', False)],
          'obanans': [('obana', False)],
          'obandets': [('oband', False)],
          'obane': [('obana', False)],
          'obane-': [('obana', False)],
          'obar': [('obar', False)],
          'obarna': [('ob', False)],
          'obarnas': [('ob', False)],
          'obars': [('ob', False)],
          'obb': [('obbe', False)],
          'obb-': [('obb', False)],
          'obbar': [('obbare', False)],
          'obbarna': [('obbare', False)],
          'obbarnas': [('obbare', False)],
          'obbars': [('obbe', False)],
          'obbe': [('obbe', False)],
          'obben': [('obb', False)],
          'obbens': [('obbe', False)],
          'obbier': [('obby', False)],
          'obblar': [('obblare', False)],
          'obblarna': [('obblare', False)],
          'obblarnas': [('obblare', False)],
          'obblet': [('obbel', False)],
          'obblets': [('obbel', False)],
          'obel': [('obel', False)],
          'obel-': [('obel', False)],
          'obels': [('obel', False)],
          'obels-': [('obel', False)],
          'oben': [('ob', False)],
          'obens': [('ob', False)],
          'obens-': [('oben', False)],
          'ober': [('ob', False)],
          'oberna': [('ob', False)],
          'obernas': [('ob', False)],
          'obers': [('ob', False)],
          'obier': [('obi', False)],
          'obil': [('obil', False)],
          'obil-': [('obil', False)],
          'obilars': [('obil', False)],
          'obils': [('obil', False)],
          'obils-': [('obil', False)],
          'obin': [('obi', False)],
          'obiner': [('obin', False)],
          'obinerna': [('obin', False)],
          'obinernas': [('obin', False)],
          'obiners': [('obin', False)],
          'obins': [('obin', False)],
          'obis': [('obis', False)],
          'obis-': [('obis', False)],
          'obit': [('obit', False)],
          'obitar': [('obit', False)],
          'obitarna': [('obit', False)],
          'obitars': [('obit', False)],
          'obits': [('obit', False)],
          'obits-': [('obit', False)],
          'oblar': [('obel', False)],
          'oblarna': [('obel', False)],
          'oblarnas': [('obel', False)],
          'oblem': [('oblem', False)],
          'oblem-': [('oblem', False)],
          'oblems': [('oblem', False)],
          'oblems-': [('oblem', False)],
          'oblessen': [('obless', False)],
          'obloggar': [('oblogg', False)],
          'obloggarna': [('oblogg', False)],
          'obloggarnas': [('oblogg', False)],
          'oblom': [('oblomma', False)],
          'oblom-': [('oblomma', False)],
          'obloms': [('oblomma', False)],
          'obloms-': [('oblomma', False)],
          'oboen': [('oboe', True)],
          'oboens': [('oboe', True)],
          'oboer': [('oboe', True)],
          'oboerna': [('oboe', True)],
          'oboernas': [('oboe', True)],
          'oboers': [('oboe', True)],
          'obol': [('obol', True)],
          'obol-': [('obol', True)],
          'obolens': [('obol', True)],
          'obols': [('obol', True)],
          'obond': [('obonde', False)],
          'obonds': [('obonde', False)],
          'obor': [('obo', False)],
          'obors': [('obo', False)],
          'oborst': [('oborste', False)],
          'oborst-': [('oborste', False)],
          'oborsten': [('oborste', False)],
          'oborstens': [('oborste', False)],
          'obot': [('obot', False)],
          'obots': [('obot', False)],
          'obra': [('obra', False)],
          'obran': [('obra', False)],
          'obrans': [('obra', False)],
          'obras': [('obra', False)],
          'obroder': [('obroder', False)],
          'obrodern': [('obroder', False)],
          'obroderns': [('obroder', False)],
          'obroders': [('obroder', False)],
          'obroms': [('obroms', False)],
          'obromsar': [('obroms', False)],
          'obromsarna': [('obroms', False)],
          'obromsarnas': [('obroms', False)],
          'obror': [('obra', False)],
          'obrors': [('obra', False)],
          'obrs': [('obra', False)],
          'obröder': [('obroder', False)],
          'obröderna': [('obroder', False)],
          'obrödernas': [('obroder', False)],
          'obröders': [('obroder', False)],
          'obröst': [('obröst', False)],
          'obröst-': [('obröst', False)],
          'obs': [('ob', False)],
          'obs-': [('ob', False)],
          'obyx': [('obyxa', False)],
          'obyx-': [('obyxa', False)],
          'obyxorna': [('obyxa', False)],
          'obyxornas': [('obyxa', False)],
          'obåg': [('obåge', False)],
          'obåg-': [('obåge', False)],
          'obågs': [('obåge', False)],
          'obågs-': [('obåge', False)],
          'obön': [('oböna', False)],
          'obön-': [('oböna', False)],
          'oböne': [('oböna', False)],
          'oböne-': [('oböna', False)],
          'oböns': [('oböna', False)],
          'oböns-': [('oböna', False)],
          'oc': [('oc', False)],
          'ocadors': [('ocado', False)],
          'ocell': [('ocell', False)],
          'ocen': [('ocen', False)],
          'ocens': [('ocen', False)],
          'ocent-': [('ocent', False)],
          'ocenter': [('ocent', False)],
          'ocenters': [('ocent', False)],
          'ocentrer': [('ocenter', False)],
          'ocentrerna': [('ocenter', False)],
          'ocentrernas': [('ocenter', False)],
          'ocentrers': [('ocenter', False)],
          'ocentret': [('ocenter', False)],
          'ocentrets': [('ocenter', False)],
          'ocents': [('ocent', False)],
          'ochettens': [('ochette', False)],
          'ochetters': [('ochette', False)],
          'ocialen': [('ocialen', False)],
          'ocialens': [('ocialen', False)],
          'ocider': [('ocid', False)],
          'ociders': [('ocid', False)],
          'ocins': [('ocin', False)],
          'ocitet': [('ocitet', False)],
          'ocitets': [('ocitet', False)],
          'ock': [('ock', False)],
          'ock-': [('ocka', False)],
          'ockan': [('ocka', False)],
          'ockans': [('ocka', False)],
          'ockarnas': [('ock', False)],
          'ockelsens': [('ockelse', False)],
          'ocken': [('ocken', False)],
          'ockens': [('ocken', False)],
          'ocker': [('ocker', False)],
          'ockers': [('ocker', False)],
          'ockersens': [('ockers', False)],
          'ockets': [('ock', False)],
          'ockfiskar': [('ockfisk', False)],
          'ockfiskarnas': [('ockfisk', False)],
          'ocklarna': [('ockel', False)],
          'ocknarna': [('ocken', False)],
          'ocknarnas': [('ocken', False)],
          'ocko': [('ocko', False)],
          'ocks': [('ocka', False)],
          'ocks-': [('ocka', False)],
          'ocor': [('oca', False)],
          'ocorna': [('oca', False)],
          'ocornas': [('oca', False)],
          'od': [('od', False)],
          'od-': [('od', False)],
          'odagar': [('odag', False)],
          'odagarna': [('odag', False)],
          'odagarnas': [('odag', False)],
          'odagars': [('odag', False)],
          'odagen': [('odag', False)],
          'odagens': [('odag', False)],
          'odags': [('odag', False)],
          'odags-': [('odag', False)],
          'odamens': [('odam', False)],
          'odamer': [('odam', False)],
          'odan': [('odan', False)],
          'odanden': [('odande', False)],
          'odandens': [('odande', False)],
          'odans': [('oda', False)],
          'odans-': [('odan', False)],
          'odar': [('od', False)],
          'odaren': [('odare', False)],
          'odarna': [('od', False)],
          'odarnas': [('od', False)],
          'odars': [('od', False)],
          'odator': [('odator', False)],
          'odators': [('odator', False)],
          'odbit': [('odbit', False)],
          'odd-': [('odd', False)],
          'oddagar': [('oddagar', False)],
          'oddagarna': [('oddagar', False)],
          'oddagarnas': [('oddagar', False)],
          'oddagars': [('oddagar', False)],
          'oddags': [('oddagar', False)],
          'oddags-': [('oddagar', False)],
          'oddar': [('oddy', False)],
          'oddarna': [('odd', False)],
          'oddarnas': [('odd', False)],
          'oddars': [('oddy', False)],
          'oddlar': [('oddlare', False)],
          'oddlarna': [('oddlare', False)],
          'oddlarnas': [('oddlare', False)],
          'odds': [('odds', True)],
          'odds-': [('odds', True)],
          'ode': [('ode', True)],
          'ode-': [('oda', False)],
          'odeg': [('odega', False)],
          'odeg-': [('odega', False)],
          'odegs': [('odega', False)],
          'odegs-': [('odega', False)],
          'odel': [('odrar', False)],
          'odel-': [('odrar', False)],
          'odels': [('odel', False)],
          'odels-': [('odel', False)],
          'odemens': [('odem', False)],
          'oden': [('ode', True)],
          'odens': [('ode', True)],
          'oder': [('od', False)],
          'oder-': [('oder', False)],
          'oderits': [('oderi', False)],
          'oderna': [('od', False)],
          'odernas': [('od', False)],
          'oders-': [('oder', False)],
          'odes': [('ode', True)],
          'odes-': [('odes', False)],
          'odet': [('ode', True)],
          'odet-': [('odet', False)],
          'odeter': [('odet', False)],
          'odeterna': [('odet', False)],
          'odeternas': [('odet', False)],
          'odeters': [('odet', False)],
          'odets': [('ode', False)],
          'odets-': [('odet', False)],
          'odier': [('odi', False)],
          'odierna': [('odi', False)],
          'odiernas': [('odi', False)],
          'odiers': [('odium', False)],
          'odiet': [('odium', False)],
          'odiets': [('odium', False)],
          'odiken': [('odik', False)],
          'odikens': [('odik', False)],
          'odiller': [('odiller', False)],
          'odillers': [('odiller', False)],
          'odin': [('odi', False)],
          'oding': [('oding', False)],
          'oding-': [('oding', False)],
          'odingar': [('oding', False)],
          'odingarna': [('oding', False)],
          'odingarnas': [('oding', False)],
          'odingars': [('oding', False)],
          'odingen': [('oding', False)],
          'odingens': [('oding', False)],
          'odings': [('oding', False)],
          'odings-': [('oding', False)],
          'odis': [('odis', False)],
          'odis-': [('odis', False)],
          'odkas': [('odka', False)],
          'odlar': [('odlare', True)],
          'odlarna': [('odlare', True)],
          'odlarnas': [('odlare', True)],
          'odlars': [('odel', False)],
          'odline-': [('odlina', False)],
          'odlins-': [('odlina', False)],
          'odomar': [('odom', False)],
          'odomarna': [('odom', False)],
          'odomarnas': [('odom', False)],
          'odon': [('odon', False)],
          'odon-': [('odon', True)],
          'odons': [('odon', False)],
          'odons-': [('odon', True)],
          'odor': [('oda', False)],
          'odorna': [('oda', False)],
          'odornas': [('oda', False)],
          'odors': [('oda', False)],
          'odramer': [('odram', False)],
          'odramerna': [('odram', False)],
          'odramernas': [('odram', False)],
          'odramers': [('odram', False)],
          'odranden': [('odrand', False)],
          'odrandens': [('odrand', False)],
          'odrar': [('odrar', False)],
          'odrarna': [('odrar', False)],
          'odrarnas': [('odrar', False)],
          'odrars': [('odrar', False)],
          'odringar': [('odring', False)],
          'odringarnas': [('odring', False)],
          'odringars': [('odring', False)],
          'odrotens': [('odrot', False)],
          'odrots': [('odrot', False)],
          'odrots-': [('odrot', False)],
          'ods': [('ode', True)],
          'ods-': [('ode', True)],
          'odskotts': [('odskott', False)],
          'odspott': [('odspott', False)],
          'odspotts-': [('odspott', False)],
          'odsupar': [('odsupare', False)],
          'odus-': [('odus', False)],
          'odvite': [('odvite', False)],
          'odådra': [('odåder', False)],
          'odådran': [('odåder', False)],
          'odådrans': [('odåder', False)],
          'odådras': [('odåder', False)],
          'odådre': [('odåder', False)],
          'odådre-': [('odåder', False)],
          'odådror': [('odåder', False)],
          'odådrorna': [('odåder', False)],
          'odådrornas': [('odåder', False)],
          'odådrors': [('odåder', False)],
          'oe': [('oe', False)],
          'oe-': [('oe', False)],
          'oeffekterna': [('oeffekt', False)],
          'oem': [('oem', False)],
          'oem-': [('oem', False)],
          'oems': [('oem', False)],
          'oen': [('o', True)],
          'oendets': [('oende', False)],
          'oens': [('o', True)],
          'oer-': [('oer', False)],
          'oers-': [('oer', False)],
          'oes': [('oe', False)],
          'oes-': [('oe', False)],
          'oesier': [('oesi', False)],
          'oesiernas': [('oesi', False)],
          'oesiers': [('oesi', False)],
          'oesis': [('oesi', False)],
          'oet': [('o', True)],
          'oeten': [('oet', False)],
          'oetens': [('oet', False)],
          'oeter': [('oet', False)],
          'oeters': [('oet', False)],
          'oets': [('o', False)],
          'oett': [('oett', False)],
          'oett-': [('oett', False)],
          'oetten': [('oett', False)],
          'oetter': [('oett', False)],
          'oetterna': [('oett', False)],
          'oetternas': [('oett', False)],
          'oetters': [('oett', False)],
          'oetts': [('oett', False)],
          'oetts-': [('oett', False)],
          'of': [('of', False)],
          'of-': [('of', False)],
          'ofader': [('ofader', False)],
          'ofader-': [('ofader', False)],
          'ofadern': [('ofader', False)],
          'ofaderns': [('ofader', False)],
          'ofaders': [('ofader', False)],
          'ofaders-': [('ofader', False)],
          'ofan': [('ofan', False)],
          'ofan-': [('ofan', False)],
          'ofans': [('ofan', False)],
          'ofar': [('ofara', False)],
          'ofar-': [('ofara', False)],
          'ofare': [('ofara', False)],
          'ofars': [('ofara', False)],
          'ofars-': [('ofara', False)],
          'ofel': [('ofler', False)],
          'ofel-': [('ofler', False)],
          'ofels': [('ofler', False)],
          'ofels-': [('ofler', False)],
          'ofem': [('ofem', False)],
          'ofem-': [('ofem', False)],
          'ofems': [('ofem', False)],
          'ofems-': [('ofem', False)],
          'ofen': [('of', False)],
          'ofens': [('of', False)],
          'ofer': [('of', False)],
          'oferna': [('of', False)],
          'ofernas': [('of', False)],
          'ofers': [('of', False)],
          'ofet': [('ofet', False)],
          'ofets': [('ofet', False)],
          'ofets-': [('ofet', False)],
          'off': [('offa', False)],
          'off-': [('offa', False)],
          'offar': [('offare', False)],
          'offarna': [('offare', False)],
          'offarnas': [('off', False)],
          'offel': [('offla', False)],
          'offel-': [('offla', False)],
          'offens': [('off', False)],
          'offer': [('offer', False)],
          'offers': [('offer', True)],
          'officerare': [('officerare', True), ('officer', True)],
          'officerares': [('officerare', True), ('officer', True)],
          'officerarna': [('officerare', True), ('officer', True)],
          'officerarnas': [('officerare', True), ('officer', True)],
          'offla': [('offel', False)],
          'offlan': [('offla', False)],
          'offlans': [('offla', False)],
          'offlas': [('offel', False)],
          'offle': [('offel', False)],
          'offle-': [('offel', False)],
          'offlor': [('offel', False)],
          'offlorna': [('offla', False)],
          'offlornas': [('offla', False)],
          'offlors': [('offla', False)],
          'offs': [('offa', False)],
          'offs-': [('offa', False)],
          'offset': [('offset', True)],
          'offsets': [('offset', True)],
          'ofilen': [('ofil', False)],
          'ofilens': [('ofil', False)],
          'ofink': [('ofink', False)],
          'ofink-': [('ofink', False)],
          'ofinks': [('ofink', False)],
          'ofinks-': [('ofink', False)],
          'ofis': [('ofi', False)],
          'ofit': [('ofit', False)],
          'ofits': [('ofit', False)],
          'oflerna': [('ofler', False)],
          'oflers': [('ofler', False)],
          'oflyt': [('oflyt', True)],
          'oflyts': [('oflyt', True)],
          'ofon': [('ofon', False)],
          'ofonis': [('ofoni', False)],
          'ofor': [('ofor', False)],
          'ofor-': [('ofor', False)],
          'oforer': [('ofor', False)],
          'oforerna': [('ofor', False)],
          'oforernas': [('ofor', False)],
          'oforers': [('ofor', False)],
          'ofors': [('ofor', False)],
          'ofors-': [('ofor', False)],
          'oforten': [('oforte', False)],
          'ofortens': [('oforte', False)],
          'ofortet': [('oforte', False)],
          'ofortets': [('oforte', False)],
          'ofoton': [('ofoto', False)],
          'ofotons': [('ofoto', False)],
          'oframställningar': [('oframställning', False)],
          'ofs': [('of', False)],
          'ofs-': [('of', False)],
          'ofsarnas': [('ofs', False)],
          'oft': [('ofta', False)],
          'oft-': [('ofta', False)],
          'oftan': [('ofta', False)],
          'oftets': [('oft', False)],
          'ofts': [('ofta', False)],
          'ofts-': [('ofta', False)],
          'ofyll': [('ofyll', False)],
          'ofyll-': [('ofyll', False)],
          'ofylls': [('ofyll', False)],
          'ofäder': [('ofader', False)],
          'ofäderna': [('ofader', False)],
          'ofädernas': [('ofader', False)],
          'ofäders': [('ofader', False)],
          'ofångar': [('ofångare', False)],
          'ofångarna': [('ofångare', False)],
          'ofångarnas': [('ofångare', False)],
          'ofår': [('ofår', False)],
          'ofår-': [('ofår', False)],
          'ofårs': [('ofår', False)],
          'ofårs-': [('ofår', False)],
          'ofördelar': [('ofördel', False)],
          'ofördelarna': [('ofördel', False)],
          'ofördelarnas': [('ofördel', False)],
          'oförsäkringar': [('oförsäkring', False)],
          'oförsäkringarna': [('oförsäkring', False)],
          'oförsäkringarnas': [('oförsäkring', False)],
          'oförsäkringars': [('oförsäkring', False)],
          'og': [('og', False)],
          'og-': [('og', False)],
          'ogale': [('ogala', False)],
          'ogals-': [('ogala', False)],
          'ogamen': [('ogam', False)],
          'ogamens': [('ogam', False)],
          'ogan': [('oga', False)],
          'ogandens': [('ogande', False)],
          'ogans': [('ogan', False)],
          'ogans-': [('ogans', False)],
          'ogansen': [('ogan', False)],
          'ogansens': [('ogan', False)],
          'ogar': [('og', False)],
          'ogaren': [('ogare', False)],
          'ogarna': [('og', False)],
          'ogarnas': [('og', False)],
          'ogars': [('og', False)],
          'ogas': [('ogas', False)],
          'ogasernas': [('ogas', False)],
          'ogat': [('ogat', False)],
          'ogat-': [('ogat', False)],
          'ogate': [('ogata', False)],
          'ogate-': [('ogata', False)],
          'ogaten': [('ogat', False)],
          'ogatens': [('ogat', False)],
          'ogators': [('ogata', False)],
          'ogats': [('ogata', False)],
          'ogats-': [('ogat', False)],
          'ogbill': [('ogbill', False)],
          'ogbill-': [('ogbill', False)],
          'ogbills-': [('ogbill', False)],
          'ogde': [('ogde', False)],
          'ogde-': [('ogde', False)],
          'ogden': [('ogde', False)],
          'ogdens': [('ogde', False)],
          'oge': [('oga', False)],
          'oge-': [('oga', False)],
          'ogel': [('ogel', False)],
          'ogementets': [('ogement', False)],
          'ogements': [('ogement', False)],
          'ogen': [('og', False)],
          'ogen-': [('ogen', False)],
          'ogener': [('ogen', False)],
          'ogenernas': [('ogen', False)],
          'ogeners': [('ogen', False)],
          'ogenien': [('ogeni', False)],
          'ogeniens': [('ogeni', False)],
          'ogens': [('og', False)],
          'ogens-': [('ogen', False)],
          'oger': [('og', False)],
          'ogeriernas': [('ogeri', False)],
          'ogerna': [('og', False)],
          'ogernas': [('og', False)],
          'ogers': [('og', False)],
          'oggar': [('ogg', False)],
          'oggi': [('oggi', False)],
          'oggi-': [('oggi', False)],
          'oggis': [('oggi', False)],
          'ogglas': [('ogglas', False)],
          'oghets': [('oghet', False)],
          'ogie': [('ogium', False)],
          'ogie-': [('ogium', False)],
          'ogiernas': [('ogi', False)],
          'ogin': [('ogi', False)],
          'ogina': [('ogi', False)],
          'oginas': [('ogi', False)],
          'ogins': [('ogi', False)],
          'ogits': [('ogi', False)],
          'ogloss': [('ogloss', False)],
          'ogloss-': [('ogloss', False)],
          'ogms-': [('ogm', False)],
          'ognar': [('ognare', False)],
          'ognarna': [('ognare', False)],
          'ognarnas': [('ognare', False)],
          'ognen': [('ogne', False)],
          'ognens': [('ogne', False)],
          'ogner': [('ogne', False)],
          'ognerna': [('ogne', False)],
          'ognosis': [('ognosi', False)],
          'ogon': [('ogon', False)],
          'ogonen': [('ogon', False)],
          'ogonens': [('ogon', False)],
          'ogonier': [('ogoni', False)],
          'ogoniernas': [('ogoni', False)],
          'ogons': [('ogon', False)],
          'ogor': [('oga', False)],
          'ogorna': [('oga', False)],
          'ogornas': [('oga', False)],
          'ogors': [('oga', False)],
          'ografen': [('ograf', False)],
          'ografens': [('ograf', False)],
          'ografit': [('ografi', False)],
          'ografits': [('ografi', False)],
          'ogren': [('oger', False)],
          'ogrens': [('ogren', False)],
          'ogrundan': [('ogrunda', False)],
          'ogrynet': [('ogryn', False)],
          'ogrynets': [('ogryn', False)],
          'ogs': [('og', False)],
          'ogs-': [('og', False)],
          'ogsbackar': [('ogsbacke', False)],
          'ogsbackars': [('ogsbacke', False)],
          'ogsbacken': [('ogsbacke', False)],
          'ogsbackens': [('ogsbacke', False)],
          'ogsbacks-': [('ogsbacke', False)],
          'ogslandets': [('ogsland', False)],
          'ogsområdets': [('ogsområde', False)],
          'ogsvans-': [('ogsvans', False)],
          'ogsvägar': [('ogsväg', False)],
          'ogsvägarna': [('ogsväg', False)],
          'ogsvägarnas': [('ogsväg', False)],
          'ogsvägars': [('ogsväg', False)],
          'ogsvägs': [('ogsväg', False)],
          'ogsvägs-': [('ogsväg', False)],
          'ogubbs': [('ogubbe', False)],
          'ogul': [('ogul', False)],
          'ogul-': [('ogul', False)],
          'oguls': [('ogul', False)],
          'oguls-': [('ogul', False)],
          'ogun': [('ogun', False)],
          'oguns': [('ogun', False)],
          'ogym': [('ogym', False)],
          'ogym-': [('ogym', False)],
          'ogymmen': [('ogym', False)],
          'ogymmens': [('ogym', False)],
          'ogymmet': [('ogym', False)],
          'ogymmets': [('ogym', False)],
          'ogångar': [('ogång', False)],
          'ogångarna': [('ogång', False)],
          'ogångarnas': [('ogång', False)],
          'ohag': [('ohag', False)],
          'ohag-': [('ohag', False)],
          'ohagen': [('ohag', False)],
          'ohagens': [('ohag', False)],
          'ohags': [('ohag', False)],
          'ohags-': [('ohag', False)],
          'ohan': [('ohan', False)],
          'ohan-': [('ohan', False)],
          'ohandlar': [('ohandlare', False)],
          'ohandlarna': [('ohandlare', False)],
          'ohandlarnas': [('ohandlare', False)],
          'ohands': [('ohand', False)],
          'ohands-': [('ohand', False)],
          'ohans': [('ohan', False)],
          'oheter': [('ohet', False)],
          'oheterna': [('ohet', False)],
          'oheternas': [('ohet', False)],
          'oheters': [('ohet', False)],
          'ohets': [('ohet', False)],
          'ohets-': [('ohet', False)],
          'ohus': [('ohus', False)],
          'ohäll': [('ohäll', False)],
          'ohälls': [('ohäll', False)],
          'ohälls-': [('ohäll', False)],
          'ohästar': [('ohäst', False)],
          'ohästarnas': [('ohäst', False)],
          'ohästars': [('ohäst', False)],
          'oiden': [('oid', False)],
          'oidens': [('oid', False)],
          'oidins': [('oidi', False)],
          'oidis': [('oidi', False)],
          'oidos': [('oidos', False)],
          'oids': [('oid', False)],
          'oiker': [('oiker', False)],
          'oikerna': [('oiker', False)],
          'oikernas': [('oiker', False)],
          'oikers': [('oiker', False)],
          'oile': [('oile', False)],
          'oile-': [('oile', False)],
          'oilen': [('oile', False)],
          'oilens': [('oile', False)],
          'oiler': [('oiler', False)],
          'oilerna': [('oiler', False)],
          'oilernas': [('oiler', False)],
          'oilers': [('oiler', False)],
          'oilettens': [('oilette', False)],
          'oin': [('oin', False)],
          'oine': [('oine', False)],
          'oine-': [('oine', False)],
          'oinen': [('oine', False)],
          'oinens': [('oine', False)],
          'oines': [('oine', False)],
          'oines-': [('oine', False)],
          'oinet': [('oine', False)],
          'oinets': [('oin', False)],
          'oinister': [('oinist', False)],
          'oinisters': [('oinist', False)],
          'oinkomst-': [('oinkomst', False)],
          'oinkomster': [('oinkomst', False)],
          'oinkomsterna': [('oinkomst', False)],
          'oinkomsternas': [('oinkomst', False)],
          'oinkomsters': [('oinkomst', False)],
          'oins': [('oin', False)],
          'oint': [('oint', False)],
          'ointer': [('oint', False)],
          'ointern': [('ointer', False)],
          'ointerna': [('oint', False)],
          'ointernas': [('oint', False)],
          'ointerns': [('ointer', False)],
          'ointers': [('oint', False)],
          'oints-': [('oint', False)],
          'oirer': [('oir', False)],
          'oirerna': [('oir', False)],
          'oirernas': [('oir', False)],
          'oirers': [('oir', False)],
          'oismer': [('oism', False)],
          'oismerna': [('oism', False)],
          'oismernas': [('oism', False)],
          'oist-': [('oist', False)],
          'oisten': [('oist', False)],
          'oistens': [('oist', False)],
          'oister': [('oist', False)],
          'oisterna': [('oist', False)],
          'oisternas': [('oist', False)],
          'oisters': [('oist', False)],
          'oj': [('oj', False)],
          'oj-': [('oj', False)],
          'ojan': [('ojan', False)],
          'ojans': [('ojan', False)],
          'ojar': [('oj', False)],
          'ojar-': [('ojar', False)],
          'ojaren': [('ojare', False)],
          'ojarens': [('ojar', False)],
          'ojarna': [('oj', False)],
          'ojarnas': [('oj', False)],
          'ojars': [('oj', False)],
          'oje': [('oja', False)],
          'oje-': [('oja', False)],
          'ojen': [('oj', False)],
          'ojens': [('oj', False)],
          'ojer': [('oj', False)],
          'ojerna': [('oj', False)],
          'ojernas': [('oj', False)],
          'ojers': [('oj', False)],
          'ojet': [('oj', False)],
          'ojets': [('ojet', False)],
          'ojj-': [('ojja', False)],
          'ojjs': [('ojja', False)],
          'ojkar': [('ojk', False)],
          'ojkarna': [('ojk', False)],
          'ojkarnas': [('ojk', False)],
          'ojkars': [('ojk', False)],
          'ojke': [('ojke', False)],
          'ojke-': [('ojke', False)],
          'ojken': [('ojke', False)],
          'ojkens': [('ojke', False)],
          'ojks-': [('ojk', False)],
          'ojon': [('ojo', False)],
          'ojons': [('ojo', False)],
          'ojor': [('oja', False)],
          'ojorna': [('oja', False)],
          'ojornas': [('oja', False)],
          'ojors': [('oja', False)],
          'ojos': [('ojo', False)],
          'ojos-': [('ojo', False)],
          'ojs': [('oj', False)],
          'ojs-': [('oj', False)],
          'ok': [('ok', False)],
          'ok-': [('ok', False)],
          'okad': [('okad', False)],
          'okad-': [('okad', False)],
          'okadens': [('okad', False)],
          'okader': [('okad', False)],
          'okaders': [('okad', False)],
          'okador': [('okado', False)],
          'okadors': [('okado', False)],
          'okads': [('okad', False)],
          'okads-': [('okad', False)],
          'okajer': [('okajer', False)],
          'okajers': [('okajer', False)],
          'okal': [('okal', False)],
          'okal-': [('okal', False)],
          'okalis': [('okalis', False)],
          'okalis-': [('okalis', False)],
          'okals': [('okal', False)],
          'okals-': [('okal', False)],
          'okammar': [('okammare', False)],
          'okams': [('okam', False)],
          'okams-': [('okam', False)],
          'okan': [('okan', False)],
          'okan-': [('okan', False)],
          'okanden': [('okande', False)],
          'okans': [('oka', False)],
          'okapp': [('okappa', False)],
          'okapp-': [('okappa', False)],
          'okappe': [('okappa', False)],
          'okapps': [('okappa', False)],
          'okapps-': [('okappa', False)],
          'okar': [('ok', False)],
          'okar-': [('okare', False)],
          'okard': [('okard', False)],
          'okard-': [('okard', False)],
          'okards': [('okard', False)],
          'okards-': [('okard', False)],
          'okare': [('okare', False)],
          'okaren': [('okare', False)],
          'okarens': [('okar', False)],
          'okaret': [('okar', False)],
          'okarets': [('okar', False)],
          'okarna': [('ok', False)],
          'okars': [('ok', False)],
          'okars-': [('okar', False)],
          'okart': [('okarta', False)],
          'okart-': [('okarta', False)],
          'okartan': [('okarta', False)],
          'okarts': [('okarta', False)],
          'okarts-': [('okarta', False)],
          'okas': [('oka', False)],
          'okaten': [('okat', False)],
          'okatens': [('okat', False)],
          'okatet': [('okat', False)],
          'okatets': [('okat', False)],
          'okativ': [('okativ', False)],
          'okativ-': [('okativ', False)],
          'okativs': [('okativ', False)],
          'okats': [('okat', False)],
          'okats-': [('okat', False)],
          'okatt': [('okatt', False)],
          'okatt-': [('okatt', False)],
          'okatten': [('okatt', False)],
          'okattens': [('okatt', False)],
          'okatts': [('okatt', False)],
          'okatts-': [('okatt', False)],
          'oke': [('oka', False)],
          'oke-': [('oka', False)],
          'okel': [('okel', False)],
          'okel-': [('okel', False)],
          'okels-': [('okel', False)],
          'oken': [('ok', False)],
          'okens': [('ok', False)],
          'okenskaper': [('okenskap', False)],
          'okenskaperna': [('okenskap', False)],
          'okenskapernas': [('okenskap', False)],
          'okenskapers': [('okenskap', False)],
          'okenskaps': [('okenskap', False)],
          'oker': [('oke', False)],
          'okerit': [('okerit', False)],
          'okerits': [('okeri', False)],
          'okerna': [('ok', False)],
          'okernas': [('oke', False)],
          'okers': [('oke', False)],
          'oket': [('ok', False)],
          'okets': [('ok', True)],
          'okien': [('okie', False)],
          'okiens': [('okie', False)],
          'okill': [('okill', False)],
          'okill-': [('okill', False)],
          'okillen': [('okill', False)],
          'okillens': [('okill', False)],
          'okills': [('okill', False)],
          'okills-': [('okill', False)],
          'okin': [('oki', False)],
          'okinons': [('okinon', False)],
          'okis': [('oki', False)],
          'okist-': [('okista', False)],
          'okistan': [('okista', False)],
          'okistans': [('okista', False)],
          'okkasse': [('okkasse', False)],
          'oklads-': [('oklad', False)],
          'oklar': [('okel', False)],
          'oklarna': [('okel', False)],
          'oklarnas': [('okel', False)],
          'oklars': [('okel', False)],
          'oklas': [('oklas', False)],
          'oklas-': [('oklas', False)],
          'oklasen': [('oklas', False)],
          'oklasens': [('oklas', False)],
          'oklav': [('oklav', False)],
          'oklav-': [('oklav', False)],
          'oklaven': [('oklav', False)],
          'oklavens': [('oklav', False)],
          'oklaver': [('oklav', False)],
          'oklavers': [('oklav', False)],
          'oklavs': [('oklav', False)],
          'oklavs-': [('oklav', False)],
          'oklernas': [('okel', False)],
          'okliniker': [('oklinik', False)],
          'oklinikerna': [('oklinik', False)],
          'oklinikernas': [('oklinik', False)],
          'oklinikers': [('oklinik', False)],
          'oklipp': [('oklipp', False)],
          'oklipps': [('oklipp', False)],
          'oklipps-': [('oklipp', False)],
          'oklis': [('oklis', False)],
          'oklubb': [('oklubba', False)],
          'oklubb-': [('oklubba', False)],
          'oklubbs': [('oklubba', False)],
          'oklubbs-': [('oklubba', False)],
          'oklädes': [('okläder', False)],
          'oklädes-': [('okläder', False)],
          'okningar': [('okning', False)],
          'okningarna': [('okning', False)],
          'okningarnas': [('okning', False)],
          'okningars': [('okning', False)],
          'oknings': [('okning', False)],
          'oknings-': [('okning', False)],
          'oknäs': [('oknäsa', False)],
          'oknäs-': [('oknäsa', False)],
          'oko-': [('oko', False)],
          'okock': [('okock', False)],
          'okock-': [('okock', False)],
          'okocks': [('okock', False)],
          'okocks-': [('okock', False)],
          'okokos': [('okoko', False)],
          'okollon': [('okollon', False)],
          'okollons': [('okollon', False)],
          'okon': [('oko', False)],
          'okonder': [('okonder', False)],
          'okonders': [('okonder', False)],
          'okondrien': [('okondri', False)],
          'okondriens': [('okondrie', False)],
          'okondrier': [('okondrie', False)],
          'okondrierna': [('okondrie', False)],
          'okondriernas': [('okondri', False)],
          'okondriers': [('okondrie', False)],
          'okons': [('oko', False)],
          'okonst-': [('okonst', False)],
          'okonster': [('okonst', False)],
          'okonsterna': [('okonst', False)],
          'okonsternas': [('okonst', False)],
          'okopp': [('okopp', False)],
          'okopp-': [('okopp', False)],
          'okoppar': [('okopp', False)],
          'okoppars': [('okopp', False)],
          'okoppor': [('okoppor', False)],
          'okopporna': [('okoppor', False)],
          'okoppornas': [('okoppor', False)],
          'okoppors': [('okoppor', False)],
          'okopps': [('okoppor', False)],
          'okopps-': [('okoppor', False)],
          'okopter': [('okopter', False)],
          'okopters': [('okopter', False)],
          'okor': [('oka', False)],
          'okord': [('okord', False)],
          'okord-': [('okord', False)],
          'okords': [('okord', False)],
          'okords-': [('okord', False)],
          'okorna': [('oka', False)],
          'okornas': [('oka', False)],
          'okors': [('oka', False)],
          'okos-': [('okos', False)],
          'okott': [('okott', False)],
          'okott-': [('okott', False)],
          'okotten': [('okott', False)],
          'okottens': [('okott', False)],
          'okotts': [('okott', False)],
          'okotts-': [('okott', False)],
          'okrar': [('oker', False)],
          'okrarna': [('oker', False)],
          'okrater': [('okrat', False)],
          'okraters': [('okrat', False)],
          'okrats': [('okrat', False)],
          'okrats-': [('okrat', False)],
          'okrets-': [('okrets', False)],
          'okris': [('okris', False)],
          'okris-': [('okris', False)],
          'okrit': [('okrit', False)],
          'okrit-': [('okrit', False)],
          'okrits': [('okrit', False)],
          'okronan': [('okrona', False)],
          'okronans': [('okrona', False)],
          'okrons-': [('okrona', False)],
          'okrull': [('okrulle', False)],
          'okrull-': [('okrulle', False)],
          'okrulle': [('okrulle', False)],
          'okrulls': [('okrulle', False)],
          'okrulls-': [('okrulle', False)],
          'oks': [('ok', False)],
          'oks-': [('ok', False)],
          'oksens': [('oks', False)],
          'oktor': [('oktor', False)],
          'oktorn': [('oktorn', False)],
          'oktorns': [('oktorn', False)],
          'oktors': [('oktor', False)],
          'okulornas': [('okula', False)],
          'okulors': [('okula', False)],
          'okunskaps': [('okunskap', True)],
          'okur': [('oku', False)],
          'okurnas': [('oku', False)],
          'okurs': [('oku', False)],
          'okus': [('okus', False)],
          'okus-': [('okus', False)],
          'okusar': [('okus', False)],
          'okusarna': [('okus', False)],
          'okusarnas': [('okus', False)],
          'okusars': [('okus', False)],
          'okusen': [('okus', False)],
          'okusens': [('okus', False)],
          'okut': [('oku', False)],
          'okuts': [('oku', False)],
          'okvier': [('okvium', False)],
          'okviernas': [('okvium', False)],
          'okviers': [('okvium', False)],
          'okviet': [('okvium', False)],
          'okviets': [('okvium', False)],
          'okyl': [('okyla', False)],
          'okyl-': [('okyla', False)],
          'okyls': [('okyla', False)],
          'okyls-': [('okyla', False)],
          'okäll': [('okälla', False)],
          'okäng': [('okäng', False)],
          'okäng-': [('okäng', False)],
          'okängs': [('okäng', False)],
          'okön': [('okön', False)],
          'oköns': [('okön', False)],
          'okör': [('okör', False)],
          'okörs': [('okör', False)],
          'okörs-': [('okör', False)],
          'ol': [('ol', False)],
          'ol-': [('ol', False)],
          'olack': [('olack', False)],
          'olag': [('olag', False)],
          'olagarna': [('olag', False)],
          'olagarnas': [('olag', False)],
          'olagen': [('olag', False)],
          'olagens': [('olag', False)],
          'olags': [('olag', False)],
          'olags-': [('olag', False)],
          'olam': [('olam', False)],
          'olam-': [('olam', False)],
          'olamen': [('olam', False)],
          'olamens': [('olam', False)],
          'olamer': [('olam', False)],
          'olamerna': [('olam', False)],
          'olamernas': [('olam', False)],
          'olamers': [('olam', False)],
          'olams': [('olam', False)],
          'olams-': [('olam', False)],
          'olan': [('ola', False)],
          'olan-': [('olan', False)],
          'olanden': [('olande', False)],
          'olandena': [('olande', False)],
          'olandenas': [('olande', False)],
          'olandens': [('olande', False)],
          'olandet': [('olande', False)],
          'olandets': [('olande', False)],
          'olaner': [('olan', False)],
          'olanerna': [('olan', False)],
          'olanernas': [('olan', False)],
          'olaners': [('olan', False)],
          'olans': [('ola', False)],
          'olanternas': [('olanterna', False)],
          'olar': [('ol', False)],
          'olar-': [('olar', False)],
          'olaren': [('olare', False)],
          'olarens': [('olar', False)],
          'olarer': [('olar', False)],
          'olarerna': [('olar', False)],
          'olarernas': [('olar', False)],
          'olarers': [('olar', False)],
          'olarie': [('olarie', False)],
          'olarie-': [('olarium', False)],
          'olarier': [('olarie', False)],
          'olarierna': [('olarium', False)],
          'olariernas': [('olarie', False)],
          'olariers': [('olarie', False)],
          'olarna': [('ol', False)],
          'olarnas': [('ol', False)],
          'olarområdet': [('olarområde', False)],
          'olars': [('ol', False)],
          'olars-': [('olar', False)],
          'olas-': [('ola', False)],
          'olat': [('olat', True)],
          'olat-': [('olat', True)],
          'olaten': [('olat', False)],
          'olatens': [('olat', False)],
          'olater': [('olat', True)],
          'olaterna': [('olat', True)],
          'olaternas': [('olat', True)],
          'olaters': [('olat', True)],
          'olats': [('olat', True)],
          'olats-': [('olat', True)],
          'olbull-': [('olbulle', False)],
          'oldans': [('oldans', False)],
          'oldans-': [('oldans', False)],
          'older': [('older', False)],
          'olders': [('older', False)],
          'oldrarnas': [('older', False)],
          'ole': [('ola', False)],
          'ole-': [('ola', False)],
          'oleans': [('oleans', False)],
          'oleer': [('oleum', False)],
          'oleerna': [('oleum', False)],
          'oleernas': [('oleum', False)],
          'olekternas': [('olekt', False)],
          'olen': [('ol', False)],
          'olens': [('ol', False)],
          'oler': [('ol', False)],
          'oler-': [('oler', False)],
          'olerans': [('olerans', False)],
          'olerna': [('ol', False)],
          'olernas': [('ol', False)],
          'oleror': [('olero', False)],
          'olerorna': [('olero', False)],
          'olerornas': [('olero', False)],
          'olerors': [('olero', False)],
          'olers': [('ol', False)],
          'olers-': [('oler', False)],
          'oles': [('oles', False)],
          'oles-': [('oles', False)],
          'olesen': [('oles', False)],
          'olesens': [('oles', False)],
          'olet': [('ol', False)],
          'oleten': [('olet', False)],
          'oletens': [('olet', False)],
          'oletet': [('olet', False)],
          'olets-': [('olet', False)],
          'olettens': [('olett', False)],
          'olfar': [('olfare', False)],
          'olfarna': [('olfare', False)],
          'olgångar': [('olgång', False)],
          'olgångarna': [('olgång', False)],
          'olgångarnas': [('olgång', False)],
          'olgångars': [('olgång', False)],
          'olgångs': [('olgång', False)],
          'olgångs-': [('olgång', False)],
          'oli': [('olia', False)],
          'oli-': [('oli', False)],
          'olian': [('olia', False)],
          'olians': [('olia', False)],
          'olias': [('olia', False)],
          'olibrier': [('olibri', False)],
          'olibrierna': [('olibri', False)],
          'olibriers': [('olibri', False)],
          'olibris': [('olibri', False)],
          'olider': [('olid', False)],
          'oliderna': [('olid', False)],
          'olidernas': [('olid', False)],
          'oliders': [('olid', False)],
          'olids': [('olid', False)],
          'olie': [('olia', False)],
          'olie-': [('olie', False)],
          'oliers': [('olier', False)],
          'oliet': [('olie', False)],
          'oliets': [('olie', False)],
          'olighets': [('olighet', False)],
          'olik': [('olik', False)],
          'olik-': [('olik', False)],
          'oliken': [('olik', False)],
          'olikens': [('olik', False)],
          'oliker': [('olik', False)],
          'olikerna': [('olik', False)],
          'olikernas': [('olik', False)],
          'olikers': [('olik', False)],
          'oliks': [('olik', False)],
          'oliks-': [('olik', False)],
          'olin': [('oli', False)],
          'olin-': [('olin', False)],
          'olina': [('oli', False)],
          'olinas': [('oli', False)],
          'olinen': [('olin', False)],
          'olinens': [('olin', False)],
          'oliner': [('olin', False)],
          'olinerna': [('olin', False)],
          'olinernas': [('olin', False)],
          'oliners': [('olin', False)],
          'olinet': [('olin', False)],
          'olins': [('olin', False)],
          'olins-': [('olin', False)],
          'olion': [('olio', False)],
          'olions': [('olio', False)],
          'olios': [('olio', False)],
          'olis': [('olo', False)],
          'olis-': [('olis', False)],
          'olisen': [('olis', False)],
          'olisens': [('olis', False)],
          'olist': [('olist', False)],
          'olist-': [('olist', False)],
          'olit': [('olit', False)],
          'olit-': [('olit', False)],
          'olitan': [('olitan', False)],
          'oliten': [('olit', False)],
          'olitens': [('olit', False)],
          'oliter': [('olit', False)],
          'oliterna': [('olit', False)],
          'oliternas': [('olit', False)],
          'oliters': [('olit', False)],
          'olitet': [('olitet', False)],
          'olitets': [('olitet', False)],
          'olits': [('olit', False)],
          'olivs': [('oliv', False)],
          'olivs-': [('oliv', False)],
          'olj': [('olja', False)],
          'olj-': [('olja', False)],
          'oljans': [('olja', False)],
          'oljs': [('olja', False)],
          'oljs-': [('olja', False)],
          'olk': [('olka', False)],
          'olk-': [('olka', False)],
          'olkans': [('olka', False)],
          'olkar': [('olkare', False)],
          'olkarna': [('olkare', False)],
          'olkarnas': [('olk', False)],
          'olkets': [('olk', False)],
          'olkor': [('olka', False)],
          'olks': [('olka', False)],
          'olks-': [('olka', False)],
          'oll': [('olle', False)],
          'oll-': [('olle', False)],
          'ollagen': [('ollage', False)],
          'ollandets': [('ollande', False)],
          'ollans': [('olla', True)],
          'ollaps': [('ollaps', False)],
          'ollaps-': [('ollaps', False)],
          'ollar': [('olle', False)],
          'ollar-': [('ollare', False)],
          'ollarna': [('olle', True)],
          'ollarnas': [('olle', True)],
          'ollars': [('olle', False)],
          'olle': [('olle', True), ('olla', True)],
          'olle-': [('olla', True)],
          'ollen': [('olle', True)],
          'ollens': [('olle', True)],
          'oller': [('oller', False)],
          'ollers': [('oller', False)],
          'olletten': [('ollett', False)],
          'olletter': [('ollett', False)],
          'olletterna': [('ollett', False)],
          'olletternas': [('ollett', False)],
          'olletters': [('ollett', False)],
          'olli': [('olli', False)],
          'ollin': [('olli', False)],
          'ollina': [('olli', False)],
          'ollinas': [('olli', False)],
          'ollins': [('olli', False)],
          'ollis-': [('olli', False)],
          'ollit': [('olli', False)],
          'ollits': [('olli', False)],
          'ollmos': [('ollmos', False)],
          'ollmos-': [('ollmos', False)],
          'ollon': [('ollon', True)],
          'ollons': [('ollon', True)],
          'ollos': [('ollo', False)],
          'ollrarna': [('oller', False)],
          'ollrarnas': [('oller', False)],
          'olls': [('olle', False)],
          'olls-': [('olle', True)],
          'olländarnas': [('olländare', False)],
          'olm': [('olm', True)],
          'olm-': [('olm', True)],
          'olman': [('olma', False)],
          'olmans': [('olma', False)],
          'olmar': [('olm', True)],
          'olmarens': [('olmare', False)],
          'olmarna': [('olm', True)],
          'olmarnas': [('olm', True)],
          'olmars': [('olm', True)],
          'olmen': [('olm', True)],
          'olmens': [('olm', True)],
          'olmor': [('olma', False)],
          'olmors': [('olma', False)],
          'olms': [('olm', False)],
          'olms-': [('olm', True)],
          'olningar': [('olning', False)],
          'olningarna': [('olning', False)],
          'olningarnas': [('olning', False)],
          'olningars': [('olning', False)],
          'olnings': [('olning', False)],
          'olnings-': [('olning', False)],
          'olo-': [('olo', False)],
          'olock': [('olock', False)],
          'oloden': [('olod', False)],
          'olodens': [('olod', False)],
          'olog': [('olog', False)],
          'olog-': [('olog', False)],
          'ologen': [('olog', False)],
          'ologens': [('olog', False)],
          'ologer': [('olog', False)],
          'ologerna': [('olog', False)],
          'ologernas': [('olog', False)],
          'ologers': [('olog', False)],
          'ologet': [('ologet', False)],
          'ologets': [('ologet', False)],
          'ologier': [('ologium', False)],
          'ologierna': [('ologium', False)],
          'ologiernas': [('ologi', False)],
          'ologiers': [('ologium', False)],
          'ologiet': [('ologium', False)],
          'ologiets': [('ologium', False)],
          'ologs': [('olog', False)],
          'olok': [('olok', False)],
          'olok-': [('olok', False)],
          'oloks': [('olok', False)],
          'oloks-': [('olok', False)],
          'olon': [('olon', False)],
          'olonen': [('olon', False)],
          'olonens': [('olon', False)],
          'olonier': [('oloni', False)],
          'oloniernas': [('oloni', False)],
          'olons': [('olon', False)],
          'olopp': [('olopp', False)],
          'olopps': [('olopp', False)],
          'olopps-': [('olopp', False)],
          'olor': [('ola', False)],
          'olor-': [('olor', False)],
          'oloren': [('olor', False)],
          'olorens': [('olor', False)],
          'olorna': [('ola', False)],
          'olornas': [('ola', False)],
          'olors': [('ola', False)],
          'olos': [('olos', False)],
          'olos-': [('olos', False)],
          'olot': [('olo', False)],
          'olots': [('olo', False)],
          'olp-': [('olpe', False)],
          'olpar': [('olpe', False)],
          'olparna': [('olpe', False)],
          'olpars': [('olpe', False)],
          'olpe': [('olpe', False)],
          'olpe-': [('olpe', False)],
          'olpen': [('olpe', False)],
          'olpens': [('olpe', False)],
          'olps-': [('olpe', False)],
          'olriken': [('olrike', False)],
          'olrikens': [('olrike', False)],
          'ols': [('ol', False)],
          'ols-': [('ol', False)],
          'olset': [('olset', False)],
          'olsets': [('olset', False)],
          'olsken': [('olsken', False)],
          'olskens-': [('olsken', False)],
          'olskor': [('olska', False)],
          'olskorna': [('olska', False)],
          'olskornas': [('olska', False)],
          'olskors': [('olska', False)],
          'olston': [('olston', False)],
          'olstrar': [('olster', False)],
          'olstrarna': [('olster', False)],
          'olstudie': [('olstudium', False)],
          'olstudier': [('olstudium', False)],
          'olstyrkans': [('olstyrka', False)],
          'olt': [('olt', False)],
          'olt-': [('olta', False)],
          'oltan': [('olta', False)],
          'oltans': [('olta', False)],
          'oltarnas': [('olt', False)],
          'oltets': [('olt', False)],
          'oltorna': [('olta', False)],
          'olts': [('olta', False)],
          'olumnen': [('olumn', False)],
          'olumnens': [('olumn', False)],
          'olust': [('olust', True)],
          'olut': [('olut', False)],
          'olut-': [('olut', False)],
          'olutens': [('olut', False)],
          'oluts': [('olut', False)],
          'oluts-': [('olut', False)],
          'olv': [('olva', False)],
          'olv-': [('olva', False)],
          'olvan': [('olva', False)],
          'olvans': [('olva', False)],
          'olvars': [('olv', False)],
          'olvens': [('olv', False)],
          'olvens-': [('olvens', False)],
          'olver': [('olver', False)],
          'olvers': [('olver', False)],
          'olvind': [('olvind', False)],
          'olvisar': [('olvisare', False)],
          'olvisarna': [('olvisare', False)],
          'olvisarnas': [('olvisare', False)],
          'olvläggar': [('olvläggare', False)],
          'olvläggarna': [('olvläggare', False)],
          'olvläggarnas': [('olvläggare', False)],
          'olvon': [('olvon', True)],
          'olvons': [('olvon', True)],
          'olvs': [('olva', False)],
          'olvs-': [('olva', False)],
          'olvtidens': [('olvtiden', False)],
          'olvägen': [('olväg', False)],
          'olvägens': [('olväg', False)],
          'olymer': [('olym', False)],
          'olymers': [('olym', False)],
          'olyps': [('olyp', False)],
          'olyps-': [('olyp', False)],
          'olys': [('olys', False)],
          'olys-': [('olys', False)],
          'olysen': [('olys', False)],
          'olysens': [('olys', False)],
          'olyt': [('olyt', False)],
          'olyten': [('olyt', False)],
          'olytens': [('olyt', False)],
          'olyts': [('olyt', False)],
          'oländer': [('oland', False)],
          'oländerna': [('oland', False)],
          'oländernas': [('oland', False)],
          'oländers': [('oland', False)],
          'olänkarna': [('olänk', False)],
          'olär': [('olär', False)],
          'olär-': [('olär', False)],
          'olärs': [('olär', False)],
          'olärs-': [('olär', False)],
          'olåns-': [('olån', False)],
          'olåt': [('olåt', False)],
          'olåts': [('olåt', False)],
          'olön': [('olön', False)],
          'om': [('om', False)],
          'om-': [('om', False)],
          'omad': [('omad', False)],
          'omad-': [('omad', False)],
          'omadan': [('omada', False)],
          'omadans': [('omada', False)],
          'omade': [('omada', False)],
          'omade-': [('omada', False)],
          'omads': [('omada', False)],
          'omads-': [('omada', False)],
          'omager': [('omage', False)],
          'omagerna': [('omage', False)],
          'omagernas': [('omage', False)],
          'omagers': [('omage', False)],
          'omak': [('omak', True)],
          'omakar': [('omakare', False)],
          'omakarna': [('omakare', False)],
          'omakarnas': [('omakare', False)],
          'omaks': [('omak', True)],
          'omaks-': [('omak', True)],
          'omalier': [('omali', False)],
          'omalierna': [('omali', False)],
          'omaliernas': [('omalier', False)],
          'omaliers': [('omalier', False)],
          'omalin': [('omali', False)],
          'omalis': [('omali', False)],
          'oman': [('oman', False)],
          'oman-': [('oman', False)],
          'omanden': [('omande', False)],
          'omaner': [('oman', False)],
          'omanerna': [('oman', False)],
          'omanernas': [('oman', False)],
          'omaners': [('oman', False)],
          'omanier': [('omanier', True)],
          'omanierna': [('omanier', True)],
          'omaniernas': [('omanier', True)],
          'omaniers': [('omanier', True)],
          'omannen': [('oman', False)],
          'omannens': [('oman', False)],
          'omanner': [('omanner', False)],
          'omannerna': [('omanner', False)],
          'omannernas': [('omanner', False)],
          'omanners': [('omanner', False)],
          'omans': [('oman', False)],
          'omar': [('om', False)],
          'omar-': [('omare', False)],
          'omare': [('omare', False)],
          'omaren': [('omare', False)],
          'omarna': [('om', False)],
          'omarnas': [('om', False)],
          'omars': [('om', False)],
          'omas': [('oma', False)],
          'omas-': [('oma', False)],
          'omat': [('omat', False)],
          'omaten': [('omat', False)],
          'omatens': [('omat', False)],
          'omatet': [('omat', False)],
          'omatets': [('omat', False)],
          'omatier': [('omati', False)],
          'omatiers': [('omati', False)],
          'omatik': [('omatik', False)],
          'omatik-': [('omatik', False)],
          'omatiks': [('omatik', False)],
          'omatis': [('omati', False)],
          'omatos': [('omatos', False)],
          'omats': [('omat', False)],
          'ombandets': [('ombande', False)],
          'ombar': [('ombare', False)],
          'ombarens': [('ombare', False)],
          'ombarna': [('ombare', False)],
          'ombarnas': [('ombare', False)],
          'ombars': [('omb', False)],
          'omben': [('omben', False)],
          'ombens': [('omben', False)],
          'ombierna': [('ombie', False)],
          'ombiernas': [('ombie', False)],
          'ombiers': [('ombie', False)],
          'ombin': [('ombin', False)],
          'ombins': [('ombi', False)],
          'ombol': [('ombola', False)],
          'ombol-': [('ombola', False)],
          'ombols': [('ombola', False)],
          'ombon': [('ombo', False)],
          'ombons': [('ombo', False)],
          'ombor': [('ombo', False)],
          'omborna': [('ombo', False)],
          'ombornas': [('ombo', False)],
          'ombos': [('ombo', False)],
          'ombosen': [('ombo', False)],
          'ombosens': [('ombo', False)],
          'ombräds-': [('ombräd', False)],
          'omedar': [('omedar', False)],
          'omedars': [('omedar', False)],
          'omedier': [('omedi', False)],
          'omedierna': [('omedi', False)],
          'omediernas': [('omedi', False)],
          'omediers': [('omedi', False)],
          'omel': [('omel', False)],
          'omel-': [('omel', False)],
          'omen': [('omen', True), ('om', True)],
          'omens': [('om', True), ('omen', True)],
          'omens-': [('omen', False)],
          'omentets': [('oment', False)],
          'oments': [('oment', False)],
          'omer': [('om', False)],
          'omerans': [('omerans', False)],
          'omerer': [('omer', False)],
          'omererna': [('omer', False)],
          'omerernas': [('omer', False)],
          'omerers': [('omer', False)],
          'omerna': [('om', False)],
          'omernas': [('om', False)],
          'omers': [('om', False)],
          'omet': [('om', False)],
          'ometen': [('omet', False)],
          'ometens': [('omet', False)],
          'ometerna': [('omet', False)],
          'ometernas': [('omet', False)],
          'ometoden': [('ometod', False)],
          'omets': [('om', False)],
          'omgiften': [('omgifte', True)],
          'omgiftens': [('omgifte', True)],
          'omgiftets': [('omgifte', True)],
          'omgivar': [('omgiv', True)],
          'omgivarna': [('omgiv', True)],
          'omgivarnas': [('omgiv', True)],
          'omiden': [('omid', False)],
          'omiker': [('omik', False)],
          'omikerna': [('omik', False)],
          'omikernas': [('omik', False)],
          'omikers': [('omik', False)],
          'omikron': [('omikron', True)],
          'omikrons': [('omikron', True)],
          'omillen': [('omill', False)],
          'omillens': [('omill', False)],
          'omin': [('omi', False)],
          'omin-': [('omin', False)],
          'omina': [('omen', True)],
          'ominas': [('omen', False)],
          'ominet': [('omen', True)],
          'ominets': [('omen', True)],
          'ominos-': [('omino', False)],
          'omins': [('omi', False)],
          'omins-': [('omin', False)],
          'omiss': [('omiss', False)],
          'omiss-': [('omiss', False)],
          'omissen': [('omiss', False)],
          'omissens': [('omiss', False)],
          'omit': [('omit', False)],
          'omit-': [('omit', False)],
          'omjölk': [('omjölk', False)],
          'omjölk-': [('omjölk', False)],
          'omjölken': [('omjölk', False)],
          'omjölkens': [('omjölk', False)],
          'omjölks': [('omjölk', False)],
          'omjölks-': [('omjölk', False)],
          'omkostnader': [('omkostnad', True), ('omkostnader', True)],
          'omkostnaderna': [('omkostnader', True), ('omkostnad', True)],
          'omkostnadernas': [('omkostnader', True), ('omkostnad', True)],
          'omkostnaders': [('omkostnad', True), ('omkostnader', True)],
          'omkostnads': [('omkostnad', True), ('omkostnader', True)],
          'omkostnads-': [('omkostnader', True), ('omkostnad', True)],
          'omlandet': [('omland', True)],
          'omlandets': [('omland', True)],
          'omman': [('omma', False)],
          'ommar': [('om', False)],
          'ommar-': [('ommar', False)],
          'ommaren': [('ommar', False)],
          'ommarna': [('omme', False)],
          'ommarnas': [('om', False)],
          'ommars': [('om', False)],
          'omme': [('omme', False)],
          'omme-': [('omme', False)],
          'ommen': [('om', False)],
          'ommens': [('om', False)],
          'ommers': [('ommers', False)],
          'ommers-': [('ommers', False)],
          'ommet': [('om', False)],
          'ommets': [('om', False)],
          'ommo': [('ommo', False)],
          'ommo-': [('ommo', False)],
          'omo': [('omo', False)],
          'omock-': [('omocka', False)],
          'omocks': [('omocka', False)],
          'omocks-': [('omocka', False)],
          'omon': [('omon', False)],
          'omoner': [('omon', False)],
          'omonerna': [('omon', False)],
          'omonernas': [('omon', False)],
          'omoners': [('omon', False)],
          'omonier': [('omonier', False)],
          'omonierna': [('omonier', False)],
          'omoniernas': [('omonier', False)],
          'omoniers': [('omonier', False)],
          'omons': [('omon', False)],
          'omons-': [('omoner', False)],
          'omor': [('omor', False)],
          'omor-': [('omor', False)],
          'omorfin': [('omorfi', False)],
          'omorfins': [('omorfi', False)],
          'omors': [('omor', False)],
          'omors-': [('omor', False)],
          'omos': [('omo', False)],
          'omos-': [('omos', False)],
          'omosen': [('omos', False)],
          'omosens': [('omos', False)],
          'ompan': [('ompa', False)],
          'ompans': [('ompa', False)],
          'ompar': [('ompar', False)],
          'omparen': [('ompar', False)],
          'omparnas': [('omp', False)],
          'ompars': [('ompar', False)],
          'ompars-': [('ompars', False)],
          'ompas': [('ompa', False)],
          'omperier': [('omperi', False)],
          'omperierna': [('omperi', False)],
          'omperiet': [('omperi', False)],
          'ompetens': [('ompetens', False)],
          'ompis': [('ompis', False)],
          'omplets': [('omplet', False)],
          'omrarna': [('ommar', False)],
          'omrarnas': [('ommar', False)],
          'omrars': [('ommar', False)],
          'områden': [('område', False)],
          'området': [('område', False)],
          'områdets': [('område', True)],
          'oms': [('oms', True), ('om', True)],
          'oms-': [('oms', True)],
          'omsen': [('oms', True)],
          'omsens': [('oms', True)],
          'omsk': [('omska', False)],
          'omsk-': [('omska', False)],
          'omske': [('omska', False)],
          'omskor': [('omska', False)],
          'omskorna': [('omska', False)],
          'omskornas': [('omska', False)],
          'omskors': [('omska', False)],
          'omst-': [('omst', False)],
          'omställens': [('omställ', False)],
          'omtanken': [('omtanke', True)],
          'omtankens': [('omtanke', True)],
          'omtars': [('omte', False)],
          'omurar': [('omur', False)],
          'omurarna': [('omur', False)],
          'omurarnas': [('omur', False)],
          'omyt': [('omyt', False)],
          'omyts': [('omyt', False)],
          'omän': [('oman', False)],
          'omäns': [('oman', False)],
          'omår': [('omår', False)],
          'omårs': [('omår', False)],
          'omårs-': [('omår', False)],
          'on': [('o', True), ('on', True)],
          'on-': [('on', True)],
          'ona': [('o', True)],
          'onader': [('onad', False)],
          'onaderna': [('onad', False)],
          'onadernas': [('onad', False)],
          'onaders': [('onad', False)],
          'onads': [('onad', False)],
          'onads-': [('onad', False)],
          'onager': [('onager', True)],
          'onagers': [('onager', True)],
          'onagets': [('onage', False)],
          'onal': [('onal', False)],
          'onal-': [('onal', False)],
          'onalen': [('onal', False)],
          'onalens': [('onal', False)],
          'onaler': [('onal', False)],
          'onalerna': [('onal', False)],
          'onalernas': [('onal', False)],
          'onalers': [('onal', False)],
          'onals-': [('onal', False)],
          'onamn': [('onamn', False)],
          'onamn-': [('onamn', False)],
          'onamnen': [('onamn', False)],
          'onamnens': [('onamn', False)],
          'onamns': [('onamn', False)],
          'onamns-': [('onamn', False)],
          'onanden': [('onande', False)],
          'onans': [('onans', False)],
          'onans-': [('onans', False)],
          'onar': [('onare', False)],
          'onar-': [('onare', False)],
          'onaren': [('onare', False)],
          'onarens': [('onare', False)],
          'onarie-': [('onarie', False)],
          'onarier': [('onarie', False)],
          'onarierna': [('onarie', False)],
          'onariernas': [('onarie', False)],
          'onariers': [('onarie', False)],
          'onarna': [('on', False)],
          'onarnas': [('one', False)],
          'onars': [('onar', False)],
          'onas': [('o', True)],
          'onat': [('onat', False)],
          'onat-': [('onat', False)],
          'onaten': [('onat', False)],
          'onatens': [('onat', False)],
          'onater': [('onat', False)],
          'onaterna': [('onat', False)],
          'onaternas': [('onat', False)],
          'onaters': [('onat', False)],
          'onats': [('onat', False)],
          'onats-': [('onat', False)],
          'onautiker': [('onautik', False)],
          'onautikerna': [('onautik', False)],
          'onautikernas': [('onautik', False)],
          'onautikers': [('onautik', False)],
          'oncern': [('oncern', False)],
          'oncerns': [('oncern', False)],
          'onda': [('onda', False)],
          'ondagen': [('ondage', False)],
          'ondagens': [('ondage', False)],
          'ondans': [('onda', False)],
          'ondas': [('onda', False)],
          'onde': [('onde', False)],
          'onde-': [('onde', False)],
          'ondelar': [('ondel', False)],
          'ondelarna': [('ondel', False)],
          'ondelarnas': [('ondel', False)],
          'onden': [('onde', False)],
          'ondena': [('onde', False)],
          'ondenas': [('onde', False)],
          'ondens': [('onde', False)],
          'onder': [('onder', False)],
          'ondernas': [('ond', False)],
          'onders': [('onder', False)],
          'ondes': [('onde', False)],
          'ondes-': [('onde', False)],
          'ondet': [('onde', False)],
          'ondets': [('ond', False)],
          'ondin': [('ondin', False)],
          'ondis-': [('ondis', False)],
          'ondolens': [('ondol', False)],
          'ondon': [('ondo', False)],
          'ondons': [('ondo', False)],
          'ondrarnas': [('onder', False)],
          'ondrin': [('ondri', False)],
          'ondropp': [('ondropp', False)],
          'ondsk': [('ondska', False)],
          'ondsk-': [('ondska', False)],
          'onduen': [('ondue', False)],
          'onduerna': [('ondue', False)],
          'ondus': [('ondus', False)],
          'ondån': [('ondån', False)],
          'ondåns': [('ondån', False)],
          'one': [('ona', False)],
          'one-': [('ona', False)],
          'onen': [('on', False)],
          'onens': [('on', False)],
          'onens-': [('onens', False)],
          'oner': [('on', False)],
          'onerier': [('oneri', False)],
          'onerierna': [('oneri', False)],
          'oneriernas': [('oneri', False)],
          'oneriers': [('oneri', False)],
          'onerna': [('on', False)],
          'onernas': [('on', False)],
          'oners': [('on', False)],
          'onerts': [('onert', False)],
          'onerts-': [('onert', False)],
          'ones': [('ones', False)],
          'ones-': [('ones', False)],
          'onesarnas': [('one', False)],
          'onesen': [('ones', False)],
          'onesens': [('ones', False)],
          'onesier': [('onesier', False)],
          'onesiernas': [('onesier', False)],
          'onesiers': [('onesier', False)],
          'oness': [('onessa', False)],
          'onet': [('on', False)],
          'onetiker': [('onetiker', False)],
          'onetikerna': [('onetiker', False)],
          'onfot': [('onfot', False)],
          'onfälle': [('onfälla', False)],
          'ongar': [('ongare', False)],
          'ongar-': [('ongare', False)],
          'ongarens': [('ongare', False)],
          'ongarna': [('ongare', False)],
          'ongarnas': [('ongare', False)],
          'ongets': [('ong', False)],
          'onglans': [('onglans', False)],
          'onglas': [('onglas', False)],
          'ongon': [('ongo', False)],
          'ongons': [('ongo', False)],
          'ongos': [('ongo', False)],
          'ongångar': [('ongång', False)],
          'ongångarna': [('ongång', False)],
          'oni': [('onia', False)],
          'oni-': [('onia', False)],
          'onie': [('onia', False)],
          'onie-': [('onium', False)],
          'onien': [('onie', False)],
          'oniens': [('onie', False)],
          'onier': [('oni', False)],
          'oniernas': [('oni', False)],
          'oniers': [('onier', False)],
          'onies': [('onie', False)],
          'oniet': [('onium', False)],
          'onika': [('onika', False)],
          'onin-': [('onin', False)],
          'oninen': [('onin', False)],
          'oninens': [('onin', False)],
          'oniner': [('onin', False)],
          'oninerna': [('onin', False)],
          'oninernas': [('onin', False)],
          'oniners': [('onin', False)],
          'oninet': [('onin', False)],
          'oninets': [('onin', False)],
          'onis': [('onis', False)],
          'onis-': [('onis', False)],
          'onisarna': [('onis', False)],
          'onisarnas': [('onis', False)],
          'onisen': [('onis', False)],
          'onisens': [('onis', False)],
          'onisk': [('oniska', False)],
          'onisk-': [('oniska', False)],
          'oniss': [('onissa', False)],
          'onisse': [('onissa', False)],
          'onisse-': [('onissa', False)],
          'onist': [('onist', False)],
          'onit': [('onit', False)],
          'onitens': [('onit', False)],
          'onitet': [('onitet', False)],
          'onitets': [('onitet', False)],
          'onjack-': [('onjack', False)],
          'onjacks': [('onjack', False)],
          'onk': [('onker', False)],
          'onk-': [('onker', False)],
          'onke': [('onke', False)],
          'onke-': [('onke', False)],
          'onken': [('onke', False)],
          'onkens': [('onke', False)],
          'onker': [('onker', False)],
          'onkerna': [('onker', False)],
          'onkernas': [('onker', False)],
          'onkers': [('onker', False)],
          'onkes': [('onke', False)],
          'onkets': [('onk', False)],
          'onks': [('onker', False)],
          'onks-': [('onker', False)],
          'onkulan': [('onkula', False)],
          'onkulans': [('onkula', False)],
          'onkurs': [('onkurs', False)],
          'onkurs-': [('onkurs', False)],
          'onkvisten': [('onkvist', False)],
          'onkvistens': [('onkvist', False)],
          'onkön': [('onkö', False)],
          'onköns': [('onkö', False)],
          'onkös': [('onkö', False)],
          'onlopp': [('onlopp', False)],
          'onlopps': [('onlopp', False)],
          'onlopps-': [('onlopp', False)],
          'onn': [('onn', False)],
          'onn-': [('onn', False)],
          'onnan': [('onna', False)],
          'onnarna': [('onnare', False)],
          'onnarnas': [('onnare', False)],
          'onne': [('onne', False)],
          'onne-': [('onne', False)],
          'onnen': [('onn', False)],
          'onnens': [('on', False)],
          'onnes': [('onne', False)],
          'onnes-': [('onne', False)],
          'onnet': [('on', False)],
          'onnets': [('on', False)],
          'onnier': [('onny', False)],
          'onnierna': [('onny', False)],
          'onniers': [('onny', False)],
          'onns': [('onna', False)],
          'onns-': [('onna', False)],
          'onnyer': [('onny', False)],
          'onnyerna': [('onny', False)],
          'onnyernas': [('onny', False)],
          'onnyers': [('onny', False)],
          'onnäs': [('onnäs', False)],
          'onnäs-': [('onnäs', False)],
          'ono': [('ono', False)],
          'ono-': [('ono', False)],
          'onomen': [('onom', False)],
          'onon': [('ono', False)],
          'onons': [('ono', False)],
          'onor': [('ona', False)],
          'onorna': [('ona', False)],
          'onornas': [('ona', False)],
          'onors': [('ona', False)],
          'onos': [('ono', False)],
          'onos-': [('ono', False)],
          'onosen': [('ono', False)],
          'onosens': [('ono', False)],
          'ons': [('ons', True), ('o', True)],
          'ons-': [('ons', True)],
          'onsarna': [('on', False)],
          'onsarnas': [('on', False)],
          'onsdagar': [('onsdag', False)],
          'onsdagarna': [('onsdag', True)],
          'onsdagarnas': [('onsdag', False)],
          'onsdagars': [('onsdag', False)],
          'onsdags': [('onsdag', False)],
          'onsdags-': [('onsdag', False)],
          'onsen': [('on', False)],
          'onsens': [('on', False)],
          'onset': [('onset', False)],
          'onsets': [('ons', False)],
          'onsetter': [('onsetter', False)],
          'onsetters': [('onsetter', False)],
          'onsflagg-': [('onsflagga', False)],
          'onsflaggs-': [('onsflagga', False)],
          'onsidan': [('onsidan', False)],
          'onsidans': [('onsidan', False)],
          'onsilie': [('onsilium', False)],
          'onsilier': [('onsilium', False)],
          'onsiliers': [('onsilium', False)],
          'onskal': [('onskal', False)],
          'onskal-': [('onskala', False)],
          'onskals': [('onskal', False)],
          'onskals-': [('onskal', False)],
          'onskans': [('onska', False)],
          'onskaps': [('onskap', False)],
          'onskor': [('onska', False)],
          'onskorna': [('onska', False)],
          'onskornas': [('onska', False)],
          'onskors': [('onska', False)],
          'onskurs': [('onskurs', False)],
          'onsor': [('onsor', False)],
          'onsors': [('onsor', False)],
          'onsort': [('onsort', False)],
          'onsorter': [('onsort', False)],
          'onsorterna': [('onsort', False)],
          'onsorternas': [('onsort', False)],
          'onsorters': [('onsort', False)],
          'onsorts': [('onsort', False)],
          'onsorts-': [('onsort', False)],
          'onsskal': [('onsskala', False)],
          'onsskals': [('onsskala', False)],
          'onsskals-': [('onsskala', False)],
          'onsten': [('onst', False)],
          'onstens': [('onst', False)],
          'onställen': [('onställe', False)],
          'onställens': [('onställe', False)],
          'onstället': [('onställe', False)],
          'onsvar': [('onsvara', False)],
          'ont-': [('ont', False)],
          'ontagen': [('ontage', False)],
          'ontagens': [('ontage', False)],
          'ontaget': [('ontage', False)],
          'ontanden': [('ontand', False)],
          'ontandens': [('ontand', False)],
          'ontants': [('ontanter', False)],
          'ontar': [('ont', False)],
          'ontarnas': [('ont', False)],
          'ontax': [('ontaxa', False)],
          'onte': [('onte', False)],
          'onte-': [('onte', False)],
          'ontes': [('onte', False)],
          'ontet': [('ont', True)],
          'ontets': [('ont', True)],
          'ontien': [('onti', False)],
          'ontiens': [('onti', False)],
          'ontinens': [('ontinens', False)],
          'onton': [('onto', False)],
          'ontons': [('onto', False)],
          'ontor': [('ontor', False)],
          'ontorn': [('ontorn', False)],
          'ontorns': [('ontorn', False)],
          'ontors': [('ontor', False)],
          'ontrans': [('ontra', False)],
          'ontrarnas': [('onter', False)],
          'ontras': [('ontra', False)],
          'ontrers': [('onter', False)],
          'ontringarna': [('ontring', False)],
          'ontringarnas': [('ontring', False)],
          'onträden': [('onträd', False)],
          'onträdens': [('onträd', False)],
          'onträdet': [('onträd', False)],
          'onts': [('ont', False)],
          'onurin': [('onuri', False)],
          'onus': [('onus', False)],
          'onus-': [('onus', True)],
          'onvit': [('onvita', False)],
          'onvit-': [('onvita', False)],
          'onvits': [('onvita', False)],
          'onyx': [('onyx', True)],
          'onyx-': [('onyx', True)],
          'onär': [('onär', False)],
          'onär-': [('onär', False)],
          'onärer': [('onär', False)],
          'onärerna': [('onär', False)],
          'onärernas': [('onär', False)],
          'onärers': [('onär', False)],
          'onärs': [('onär', False)],
          'onärs-': [('onär', False)],
          'onäs': [('onäs', False)],
          'onäs-': [('onäs', False)],
          'onäst': [('onäste', False)],
          'onäst-': [('onäste', False)],
          'onäste': [('onäste', False)],
          'onästen': [('onäste', False)],
          'onästens': [('onäste', False)],
          'onästet': [('onäste', False)],
          'onästets': [('onäste', False)],
          'onör': [('onör', False)],
          'onör-': [('onör', False)],
          'onören': [('onör', False)],
          'onörens': [('onör', False)],
          'onörs': [('onör', False)],
          'onörs-': [('onör', False)],
          'ooden': [('ood', False)],
          'oodens': [('ood', False)],
          'oods': [('ood', False)],
          'ooer': [('oo', False)],
          'ooerna': [('oo', False)],
          'ooernas': [('oo', False)],
          'ooers': [('oo', False)],
          'ookan': [('ooka', False)],
          'ookarnas': [('ook', False)],
          'oomen': [('oom', False)],
          'oomens': [('oom', False)],
          'ooms': [('oom', False)],
          'ooms-': [('oom', False)],
          'oon': [('oo', False)],
          'oonas': [('oo', False)],
          'oons': [('oo', False)],
          'ooparnas': [('oop', False)],
          'oor': [('oa', False)],
          'oord': [('oord', False)],
          'oorden': [('oord', False)],
          'oordens': [('oord', False)],
          'oordinat': [('oordinat', False)],
          'oordinat-': [('oordinat', False)],
          'oordinator': [('oordinator', False)],
          'oordinators': [('oordinator', False)],
          'oordinats': [('oordinat', False)],
          'oordinats-': [('oordinat', False)],
          'oords': [('oord', False)],
          'oorganisationen': [('oorganisationen', False)],
          'oorna': [('oo', False)],
          'oornas': [('oo', False)],
          'oors': [('oa', False)],
          'oos': [('oo', False)],
          'oosarna': [('oo', False)],
          'ooter': [('ooter', False)],
          'ooters': [('ooter', False)],
          'ootier': [('ooti', False)],
          'ootierna': [('ooti', False)],
          'ootiernas': [('ooti', False)],
          'ootiers': [('ooti', False)],
          'ootins': [('ooti', False)],
          'oots': [('oo', False)],
          'ootsen': [('oots', False)],
          'ootsens': [('oots', False)],
          'op': [('op', False)],
          'op-': [('op', False)],
          'opagen': [('opag', False)],
          'opagens': [('opag', False)],
          'opager': [('opag', False)],
          'opagerna': [('opag', False)],
          'opagernas': [('opag', False)],
          'opagers': [('opag', False)],
          'opals': [('opal', True)],
          'opals-': [('opal', True)],
          'opan': [('opan', False)],
          'opande': [('opande', False)],
          'opande-': [('opande', False)],
          'opans': [('opan', False)],
          'opar': [('op', False)],
          'opar-': [('opare', False)],
          'oparen': [('opare', False)],
          'oparens': [('opar', False)],
          'opares': [('opare', False)],
          'oparna': [('op', False)],
          'opars': [('op', False)],
          'opars-': [('opar', False)],
          'opas': [('opas', False)],
          'opastor': [('opastor', False)],
          'opastors': [('opastor', False)],
          'opat': [('opat', False)],
          'opat-': [('opat', False)],
          'opaten': [('opat', False)],
          'opatens': [('opat', False)],
          'opater': [('opat', False)],
          'opaters': [('opat', False)],
          'opatiens': [('opati', False)],
          'opatiernas': [('opati', False)],
          'opats': [('opat', False)],
          'opats-': [('opat', False)],
          'opbackar': [('opbacke', False)],
          'opbackarna': [('opbacke', False)],
          'opbackarnas': [('opbacke', False)],
          'ope': [('opa', False)],
          'ope-': [('opa', False)],
          'opelar': [('opelare', False)],
          'opelar-': [('opelare', False)],
          'opellarnas': [('opell', False)],
          'opellen': [('opell', False)],
          'opellens': [('opell', False)],
          'open': [('op', False)],
          'open-': [('open', False)],
          'openen': [('open', False)],
          'openens': [('open', False)],
          'opengar': [('openg', False)],
          'opengarna': [('openg', False)],
          'opengarnas': [('openg', False)],
          'opengars': [('openg', False)],
          'openning': [('openning', False)],
          'openning-': [('openning', False)],
          'openningar': [('openning', False)],
          'openningarna': [('openning', False)],
          'openningarnas': [('openning', False)],
          'openningars': [('openning', False)],
          'opennings': [('openning', False)],
          'opennings-': [('openning', False)],
          'opens': [('op', False)],
          'oper': [('op', False)],
          'operna': [('op', False)],
          'opernas': [('op', False)],
          'opers': [('op', False)],
          'opers-': [('oper', False)],
          'opet': [('op', False)],
          'opets': [('op', False)],
          'opier': [('opier', False)],
          'opierna': [('opier', False)],
          'opiernas': [('opier', False)],
          'opiers': [('opier', False)],
          'opiet': [('opium', True)],
          'opiets': [('opium', True)],
          'opiker': [('opik', False)],
          'opikers': [('opik', False)],
          'opillers': [('opiller', False)],
          'opin': [('opi', False)],
          'opin-': [('opin', False)],
          'opins-': [('opin', False)],
          'opisk': [('opiska', False)],
          'opisk-': [('opiska', False)],
          'oplanet': [('oplan', False)],
          'oplanets': [('oplan', False)],
          'oplin': [('oplin', False)],
          'oplins': [('oplin', False)],
          'oplit': [('oplit', False)],
          'oplit-': [('oplit', False)],
          'oplits': [('oplit', False)],
          'opol': [('opol', False)],
          'opolen': [('opol', False)],
          'opolens': [('opol', False)],
          'opols': [('opol', False)],
          'opols-': [('opol', False)],
          'opondens': [('opond', False)],
          'oponents': [('oponent', False)],
          'oponents-': [('oponent', False)],
          'opor': [('opa', False)],
          'oporna': [('opa', False)],
          'opornas': [('opa', False)],
          'opors': [('opa', False)],
          'oppar-': [('oppare', False)],
          'opparen': [('oppar', False)],
          'opparens': [('oppar', False)],
          'opparna': [('oppare', False)],
          'opparnas': [('opp', False)],
          'oppbackar': [('oppbackare', True)],
          'oppbackarna': [('oppbackare', True)],
          'oppbackarnas': [('oppbackare', True)],
          'oppe': [('oppe', False)],
          'oppe-': [('oppe', False)],
          'opper': [('opp', False)],
          'oppers': [('opper', False)],
          'oppets': [('opp', False)],
          'oppisarna': [('oppis', False)],
          'oppisarnas': [('oppis', False)],
          'opplanden': [('opplande', False)],
          'opplandens': [('opplande', False)],
          'opplandet': [('opplande', False)],
          'opplar': [('opplare', False)],
          'opplarna': [('opplare', False)],
          'opplarnas': [('opplare', False)],
          'opplet': [('oppel', False)],
          'oppris': [('oppris', False)],
          'oppris-': [('oppris', False)],
          'oppås': [('oppåse', False)],
          'oppås-': [('oppåse', False)],
          'oppåsar': [('oppåse', False)],
          'oppåsarna': [('oppåse', False)],
          'oppåsarnas': [('oppåse', False)],
          'oppåsars': [('oppåse', False)],
          'oppåsen': [('oppåse', False)],
          'oppåsens': [('oppåse', False)],
          'opraktik': [('opraktik', False)],
          'opraktik-': [('opraktik', False)],
          'opraktiker': [('opraktiker', False)],
          'opraktikerna': [('opraktiker', False)],
          'opraktikernas': [('opraktiker', False)],
          'opraktikers': [('opraktiker', False)],
          'opraktiks': [('opraktik', False)],
          'opran': [('opra', False)],
          'oprans': [('opra', False)],
          'opras': [('opras', False)],
          'oproblemets': [('oproblem', False)],
          'oprogrammet': [('oprogram', False)],
          'ops': [('op', False)],
          'ops-': [('op', False)],
          'opsar': [('op', False)],
          'opsarna': [('op', False)],
          'opsarnas': [('ops', False)],
          'opsars': [('op', False)],
          'opsdagen': [('opsdag', False)],
          'opsdagens': [('opsdag', False)],
          'opsens': [('ops', False)],
          'opsins': [('opsi', False)],
          'opsis': [('opsis', False)],
          'opsis-': [('opsis', False)],
          'opter': [('opter', False)],
          'opters': [('opter', False)],
          'optris': [('optris', False)],
          'opulas': [('opulas', False)],
          'opuls': [('opula', False)],
          'opuls-': [('opula', False)],
          'opulsar': [('opuls', False)],
          'opulsars': [('opuls', False)],
          'opåkar': [('opåkare', False)],
          'opåkarna': [('opåkare', False)],
          'opåkarnas': [('opåkare', False)],
          'opån': [('opå', False)],
          'opås': [('opå', False)],
          'opås-': [('opå', False)],
          'opåt': [('opå', False)],
          'opåts': [('opå', False)],
          'or': [('or', True)],
          'or-': [('or', False)],
          'oradon': [('orado', False)],
          'oradons': [('orado', False)],
          'oraget': [('oraget', False)],
          'oragets': [('oraget', False)],
          'oragetter': [('oraget', False)],
          'orak': [('orak', False)],
          'orak-': [('orak', False)],
          'oraken': [('orak', False)],
          'orakens': [('orak', False)],
          'oraks': [('orak', False)],
          'oraks-': [('orak', False)],
          'oralier': [('oralier', False)],
          'oraliernas': [('oralier', False)],
          'oraliers': [('oralier', False)],
          'oran': [('oran', False)],
          'oran-': [('oran', False)],
          'orana': [('ora', False)],
          'oranas': [('ora', False)],
          'orande': [('orande', False)],
          'orande-': [('orande', False)],
          'oranden': [('orande', False)],
          'orandens': [('orande', False)],
          'orandet': [('orande', False)],
          'orangen': [('orange', True)],
          'orangens': [('orange', True)],
          'oranger': [('orange', True)],
          'orangerna': [('orange', True)],
          'orangernas': [('orange', True)],
          'orangers': [('orange', True)],
          'orans-': [('orans', False)],
          'orar': [('orare', False)],
          'orar-': [('orar', False)],
          'oraren': [('orar', False)],
          'orarens': [('orar', False)],
          'oraret': [('orar', False)],
          'orarets': [('orar', False)],
          'orarna': [('orare', False)],
          'orars': [('orar', False)],
          'oras-': [('oras', False)],
          'orasen': [('oras', False)],
          'orasens': [('oras', False)],
          'orat': [('orat', False)],
          'oraten': [('orat', False)],
          'oratens': [('orat', False)],
          'orater': [('orat', False)],
          'oraterna': [('orat', False)],
          'oraternas': [('orat', False)],
          'oraters': [('orat', False)],
          'orats': [('orat', False)],
          'oraxen': [('orax', False)],
          'oraxens': [('orax', False)],
          'orben': [('orb', False)],
          'orbet': [('orbet', False)],
          'orbets': [('orbet', False)],
          'orbroder': [('orbror', False)],
          'orbrors': [('orbror', False)],
          'orbrors-': [('orbrorsa', False)],
          'orbröderna': [('orbror', False)],
          'orbröders': [('orbror', False)],
          'ord': [('ord', True)],
          'ord-': [('ord', True)],
          'orda': [('orda', False)],
          'ordan': [('orda', False)],
          'ordans': [('ordan', False)],
          'ordans-': [('ordans', False)],
          'ordar': [('ordare', False)],
          'ordarna': [('ordare', False)],
          'ordarnas': [('ord', False)],
          'ordas': [('orda', False)],
          'orddelar': [('orddelare', True), ('orddel', True)],
          'orddelarna': [('orddelare', True), ('orddel', True)],
          'orddelarnas': [('orddelare', True), ('orddel', True)],
          'orden': [('ord', True), ('orden', True)],
          'ordens': [('ord', True), ('orden', True)],
          'order': [('order', False)],
          'orderna': [('order', False)],
          'ordernas': [('order', True)],
          'orders': [('order', False)],
          'ordets': [('ord', False)],
          'ordians': [('ordia', False)],
          'ordier': [('ordion', False)],
          'ordiernas': [('ordion', False)],
          'ordiers': [('ordion', False)],
          'ordinat': [('ordinata', True)],
          'ordinat-': [('ordinata', True)],
          'ordinator': [('ordinata', True)],
          'ordinators': [('ordinata', True)],
          'ordinats': [('ordinata', True)],
          'ordinats-': [('ordinata', True)],
          'ordnar': [('ordnare', True), ('orden', True)],
          'ordnarna': [('ordnare', True), ('orden', True)],
          'ordnarnas': [('ordnare', True), ('orden', True)],
          'ordomarna': [('ordom', False)],
          'ordrar': [('order', True)],
          'ordrarna': [('order', True)],
          'ordrarnas': [('order', False)],
          'ords': [('ord', True)],
          'ords-': [('ord', True)],
          'ordsböns': [('ordsbön', False)],
          'ore': [('ora', False)],
          'ore-': [('ora', False)],
          'orean': [('orean', False)],
          'oreans': [('orean', False)],
          'oredans': [('oreda', True)],
          'oree': [('oree', False)],
          'oree-': [('oree', False)],
          'oreen': [('oree', False)],
          'oreens': [('oree', False)],
          'oreer': [('oree', False)],
          'oreerna': [('oree', False)],
          'oreernas': [('oree', False)],
          'oreers': [('oree', False)],
          'oremens': [('orem', False)],
          'orems': [('orem', False)],
          'oren': [('or', False)],
          'orens': [('or', False)],
          'orer': [('or', False)],
          'orerna': [('or', False)],
          'orernas': [('or', False)],
          'orers': [('or', False)],
          'ores': [('ores', False)],
          'ores-': [('ores', False)],
          'oresen': [('ores', False)],
          'oresens': [('ores', False)],
          'oret': [('or', False)],
          'oretas': [('oretum', False)],
          'oreterna': [('oret', False)],
          'oreternas': [('oret', False)],
          'oreters': [('oret', False)],
          'orets': [('or', False)],
          'orfader-': [('orfar', False)],
          'orfadern': [('orfar', False)],
          'orfaderns': [('orfar', False)],
          'orfaders': [('orfar', False)],
          'orfar': [('orfar', False)],
          'orfar-': [('orfar', False)],
          'orfis': [('orfi', False)],
          'orflaggs': [('orflagga', False)],
          'orflaggs-': [('orflagga', False)],
          'orfäder': [('orfar', False)],
          'orfäders': [('orfar', False)],
          'organden': [('organde', False)],
          'organisationen': [('organisation', False)],
          'orgers': [('orgers', False)],
          'orgier': [('orgie', True)],
          'orgierna': [('orgie', True)],
          'orgiernas': [('orgie', True)],
          'orgiers': [('orgie', True)],
          'orgskors': [('orgskors', False)],
          'orgsområdets': [('orgsområdet', False)],
          'orhot': [('orhot', False)],
          'orhots': [('orhot', False)],
          'orian': [('oria', False)],
          'orians': [('oria', False)],
          'orias': [('oria', False)],
          'orick-': [('oricka', False)],
          'oricks': [('oricka', False)],
          'oricks-': [('oricka', False)],
          'orid': [('orid', False)],
          'orid-': [('orid', False)],
          'orider': [('orid', False)],
          'oriderna': [('orid', False)],
          'oridernas': [('orid', False)],
          'oriders': [('orid', False)],
          'orie': [('oria', False)],
          'orie-': [('oria', False)],
          'orien': [('ori', False)],
          'oriens': [('oria', False)],
          'orier': [('orium', False)],
          'oriernas': [('ori', False)],
          'ories': [('ory', False)],
          'oriet': [('orium', False)],
          'orighets': [('orighet', False)],
          'orik': [('orik', False)],
          'orik-': [('orik', False)],
          'oriken': [('orik', False)],
          'orikens': [('orik', False)],
          'orikets': [('orike', False)],
          'oriks': [('orik', False)],
          'oriks-': [('orik', False)],
          'orill': [('orilla', False)],
          'orill-': [('orilla', False)],
          'orills': [('orilla', False)],
          'orills-': [('orilla', False)],
          'orin': [('ori', False)],
          'orin-': [('orin', False)],
          'orina': [('orina', False)],
          'orinas': [('orina', False)],
          'oriner': [('orin', False)],
          'orinerna': [('orin', False)],
          'orinernas': [('orin', False)],
          'oriners': [('orin', False)],
          'oringar': [('oring', False)],
          'oringarna': [('oring', False)],
          'oringarnas': [('oring', False)],
          'orinor': [('orina', False)],
          'orinorna': [('orina', False)],
          'orinornas': [('orina', False)],
          'orinors': [('orina', False)],
          'orins': [('orin', False)],
          'orins-': [('orina', False)],
          'orior': [('oria', False)],
          'oris-': [('oria', False)],
          'orisarna': [('oris', False)],
          'orisk': [('orisk', False)],
          'orisk-': [('orisk', False)],
          'oristiker': [('oristiker', False)],
          'oristikerna': [('oristiker', False)],
          'oristikernas': [('oristiker', False)],
          'oristikers': [('oristiker', False)],
          'orit': [('orit', False)],
          'orit-': [('orit', False)],
          'oritans': [('orita', False)],
          'oriter': [('orit', False)],
          'oriterna': [('orit', False)],
          'oritet': [('oritet', False)],
          'oritets': [('oritet', False)],
          'orits': [('orit', False)],
          'orits-': [('orita', False)],
          'orizons': [('orizo', False)],
          'ork': [('ork', True)],
          'ork-': [('ork', True)],
          'orkan': [('orkan', True)],
          'orkans': [('orkan', True)],
          'orkarnas': [('ork', False)],
          'orkas': [('orka', False)],
          'orkets': [('ork', False)],
          'orkors': [('orkors', False)],
          'orl': [('orla', False)],
          'orl-': [('orla', False)],
          'orlandets': [('orlande', False)],
          'orleks': [('orlek', False)],
          'orls': [('orla', False)],
          'orls-': [('orla', False)],
          'ormanden': [('ormande', True)],
          'ormandens': [('ormande', False)],
          'ormar': [('orm', True)],
          'ormarna': [('orm', True)],
          'ormarnas': [('orm', True)],
          'ormen': [('orm', False)],
          'ormoder': [('ormor', False)],
          'ormor': [('ormor', False)],
          'ormors': [('ormor', False)],
          'ormödrarna': [('ormor', False)],
          'ormödrarnas': [('ormor', False)],
          'ormödrars': [('ormor', False)],
          'orn': [('orne', True)],
          'orn-': [('orne', True)],
          'orna': [('a', False)],
          'ornar': [('orne', True)],
          'ornarna': [('orne', True)],
          'ornarnas': [('orne', True)],
          'ornars': [('orne', True)],
          'ornas': [('a', False)],
          'orne': [('orne', True)],
          'orne-': [('orna', False)],
          'ornen': [('orne', True)],
          'ornens': [('orne', True)],
          'ornes': [('orne', True)],
          'ornes-': [('orne', True)],
          'ornets': [('orn', False)],
          'ornister': [('ornist', False)],
          'ornisters': [('ornist', False)],
          'orns': [('orne', True)],
          'orns-': [('orne', True)],
          'oroller': [('oroll', False)],
          'orollerna': [('oroll', False)],
          'orollernas': [('oroll', False)],
          'orollers': [('oroll', False)],
          'orolls': [('oroll', False)],
          'orolls-': [('oroll', False)],
          'oron': [('oro', True)],
          'oron-': [('orona', False)],
          'orona': [('orona', False)],
          'oronas': [('orona', False)],
          'orone': [('orona', False)],
          'orone-': [('orona', False)],
          'orons': [('oro', True)],
          'oropen': [('orop', False)],
          'oropens': [('orop', False)],
          'orops': [('orop', False)],
          'oror': [('oro', True)],
          'ororna': [('oro', True)],
          'orornas': [('oro', True)],
          'orors': [('oro', True)],
          'oros': [('oro', True)],
          'oros-': [('oro', False)],
          'orot': [('orot', False)],
          'oroten': [('orot', False)],
          'orotens': [('orot', False)],
          'orots': [('orot', False)],
          'orots-': [('orot', False)],
          'orov': [('orov', False)],
          'orov-': [('orov', False)],
          'oroven': [('orov', False)],
          'orovs': [('orov', False)],
          'orovs-': [('orov', False)],
          'orpar': [('orpare', False)],
          'orpar-': [('orpare', False)],
          'orparens': [('orpare', False)],
          'orparna': [('orp', False)],
          'orparnas': [('orp', False)],
          'orpars': [('orp', False)],
          'orps-': [('orp', False)],
          'orr': [('orre', False)],
          'orr-': [('orre', False)],
          'orran': [('orra', False)],
          'orrans': [('orran', False)],
          'orrar': [('orre', False)],
          'orrarna': [('orre', False)],
          'orrarnas': [('orre', True)],
          'orrars': [('orre', False)],
          'orre': [('orre', False)],
          'orre-': [('orre', False)],
          'orren': [('orre', False)],
          'orrens': [('orre', False)],
          'orrs': [('orre', False)],
          'orrs-': [('orre', False)],
          'ors': [('or', True)],
          'ors-': [('or', False)],
          'orsan': [('orsa', False)],
          'orsans': [('orsa', False)],
          'orsar': [('orsar', False)],
          'orsaren': [('orsar', False)],
          'orsarna': [('ors', False)],
          'orsarnas': [('ors', False)],
          'orsars': [('orsar', False)],
          'orse': [('orse', False)],
          'orsen': [('ors', False)],
          'orser': [('orso', False)],
          'orserna': [('orso', False)],
          'orsernas': [('orso', False)],
          'orsers': [('orso', False)],
          'orsets': [('ors', False)],
          'orsfasoner': [('orsfasoner', False)],
          'orsfiskarnas': [('orsfisk', False)],
          'orsk': [('orsk', False)],
          'orsk-': [('orsk', False)],
          'orskar': [('orsk', False)],
          'orskarna': [('orsk', False)],
          'orskarnas': [('orskare', False)],
          'orskens': [('orsk', False)],
          'orskiftet': [('orskifte', False)],
          'orskor': [('orska', False)],
          'orskorna': [('orska', False)],
          'orskornas': [('orska', False)],
          'orskors': [('orska', False)],
          'orskot': [('orskot', False)],
          'orskots': [('orskot', False)],
          'orskots-': [('orskot', False)],
          'orson': [('orso', False)],
          'orsons': [('orso', False)],
          'orsor': [('orso', False)],
          'orsorna': [('orso', False)],
          'orsornas': [('orso', False)],
          'orsors': [('orso', False)],
          'orst-': [('orst', False)],
          'orstanden': [('orstande', False)],
          'orstandens': [('orstande', False)],
          'orstarna': [('orst', False)],
          'orstarnas': [('orst', False)],
          'orstars': [('orst', False)],
          'orsten': [('orsten', False)],
          'orstens': [('orsten', True)],
          'orstövlars': [('orstövlar', False)],
          'ort': [('ort', True)],
          'ort-': [('ort', True)],
          'ortagen': [('ortage', False)],
          'ortagens': [('ortage', False)],
          'ortaget': [('ortage', False)],
          'ortan': [('orta', False)],
          'ortar': [('ort', True)],
          'ortar-': [('ortare', False)],
          'ortarens': [('ortare', False)],
          'ortarna': [('ort', True)],
          'ortarnas': [('ort', False)],
          'orte': [('orte', False)],
          'orte-': [('orte', False)],
          'ortegens': [('ortege', False)],
          'orten': [('ort', True)],
          'ortens': [('ort', True)],
          'orter': [('ort', True)],
          'orterna': [('ort', True)],
          'orternas': [('ort', True)],
          'orters': [('ort', True)],
          'ortes': [('ortes', False)],
          'ortet': [('ort', True)],
          'ortets': [('ort', False)],
          'ortiets': [('ortium', False)],
          'ortin': [('orti', False)],
          'ortis': [('ortis', False)],
          'ortits': [('ortit', False)],
          'orton': [('orto', False)],
          'ortons': [('orto', False)],
          'ortron': [('ortron', False)],
          'orts': [('ort', True)],
          'orts-': [('ort', True)],
          'ortsen': [('orts', False)],
          'ortsens': [('orts', False)],
          'ortssamhällena': [('ortsamhälle', False)],
          'ortändar': [('ortände', False)],
          'orum': [('orum', False)],
          'orum-': [('orum', False)],
          'orums': [('orum', False)],
          'orums-': [('orum', False)],
          'orund': [('orund', False)],
          'orund-': [('orund', False)],
          'orunds': [('orund', False)],
          'orunds-': [('orund', False)],
          'orungen': [('orunge', False)],
          'orungens': [('orunge', False)],
          'orus': [('orus', False)],
          'orus-': [('orus', False)],
          'orv': [('orv', True)],
          'orv-': [('orv', True)],
          'orvar': [('orv', False)],
          'orvas': [('orva', False)],
          'orvs': [('orv', True)],
          'orvs-': [('orv', True)],
          'ory': [('ory', False)],
          'ory-': [('ory', False)],
          'orys': [('ory', False)],
          'orän': [('orän', False)],
          'oränden': [('orände', False)],
          'orändens': [('orände', False)],
          'oräns': [('orän', False)],
          'oräns-': [('orän', False)],
          'oråden': [('oråd', False)],
          'orådens': [('oråd', False)],
          'oröst': [('oröst', False)],
          'oröst-': [('oröst', False)],
          'orösten': [('oröst', False)],
          'oröstens': [('oröst', False)],
          'orötter': [('orot', False)],
          'orötterna': [('orot', False)],
          'orötternas': [('orot', False)],
          'orötters': [('orot', False)],
          'os': [('o', True), ('os', True)],
          'os-': [('os', False)],
          'osaiker': [('osaiker', False)],
          'osaikerna': [('osaiker', False)],
          'osaikernas': [('osaiker', False)],
          'osaikers': [('osaiker', False)],
          'osalen': [('osal', False)],
          'osalens': [('osal', False)],
          'osandar': [('osande', False)],
          'osandarna': [('osande', False)],
          'osandarnas': [('osande', False)],
          'osandars': [('osande', False)],
          'osanden': [('osande', False)],
          'osandens': [('osande', False)],
          'osar': [('o', False)],
          'osarnas': [('o', False)],
          'osars': [('o', False)],
          'osat': [('osa', False)],
          'osats-': [('osats', False)],
          'osaxar': [('osaxare', False)],
          'osaxarna': [('osaxare', False)],
          'osaxarnas': [('osaxare', False)],
          'osch': [('osch', False)],
          'osch-': [('osch', False)],
          'oschen': [('osch', False)],
          'oschens': [('osch', False)],
          'oscher': [('osch', False)],
          'oschers': [('osch', False)],
          'ose': [('osa', False)],
          'ose-': [('osa', False)],
          'osed': [('osed', True)],
          'osel': [('osel', False)],
          'osel-': [('osel', False)],
          'osels': [('osel', False)],
          'osen': [('os', False)],
          'osens': [('os', False)],
          'oser': [('os', False)],
          'oser-': [('oser', False)],
          'osern': [('oser', False)],
          'oserna': [('os', False)],
          'osernas': [('os', False)],
          'oserns': [('oser', False)],
          'osers': [('os', False)],
          'oset': [('os', False)],
          'osets': [('os', False)],
          'osetter': [('osett', False)],
          'osetters': [('osett', False)],
          'osex': [('osex', False)],
          'oshet': [('oshet', False)],
          'osi': [('osus', False)],
          'osian': [('osia', False)],
          'osians': [('osia', False)],
          'osid': [('osid', False)],
          'osid-': [('osid', False)],
          'osidans': [('osida', False)],
          'oside': [('osida', False)],
          'oside-': [('osida', False)],
          'osiden': [('osid', False)],
          'osidens': [('osid', False)],
          'osider': [('osid', False)],
          'osiderna': [('osid', False)],
          'osidernas': [('osid', False)],
          'osiders': [('osid', False)],
          'osier': [('osium', False)],
          'osierna': [('osi', False)],
          'osiernas': [('osium', False)],
          'osiers': [('osi', False)],
          'osin': [('osi', False)],
          'osin-': [('osin', False)],
          'osina': [('osus', False)],
          'osinas': [('osus', False)],
          'osinen': [('osin', False)],
          'osinens': [('osin', False)],
          'osiner': [('osin', False)],
          'osinerna': [('osin', False)],
          'osinernas': [('osin', False)],
          'osiners': [('osin', False)],
          'osins': [('osin', False)],
          'osins-': [('osin', False)],
          'osis': [('osis', True)],
          'osita': [('ositum', False)],
          'ositet': [('ositet', False)],
          'ositets': [('ositet', False)],
          'ositiv': [('ositiv', False)],
          'ositiv-': [('ositiv', False)],
          'ositivs': [('ositiv', False)],
          'osits': [('osit', False)],
          'osiv': [('osiva', False)],
          'osiv-': [('osiva', False)],
          'osjukan': [('osjukan', False)],
          'osjukans': [('osjukan', False)],
          'osk': [('oska', False)],
          'osk-': [('oska', False)],
          'oskak': [('oskaka', False)],
          'oskak-': [('oskaka', False)],
          'oskaks': [('oskaka', False)],
          'oskaks-': [('oskaka', False)],
          'oskan': [('oska', False)],
          'oskans': [('oska', False)],
          'oskatte-': [('oskatt', False)],
          'oskatts-': [('oskatt', False)],
          'osken': [('osk', False)],
          'oskens': [('osk', False)],
          'oskets': [('osk', False)],
          'oskidan': [('oskidan', False)],
          'oskidans': [('oskidan', False)],
          'oskiften': [('oskifte', False)],
          'oskiftens': [('oskifte', False)],
          'oskiftet': [('oskifte', False)],
          'oskiftets': [('oskifte', False)],
          'oskon': [('oskon', False)],
          'oskons': [('oskon', False)],
          'oskop': [('oskop', False)],
          'oskop-': [('oskop', False)],
          'oskops': [('oskop', False)],
          'oskops-': [('oskop', False)],
          'oskor': [('oska', False)],
          'oskorna': [('oska', False)],
          'oskornas': [('oska', False)],
          'oskors': [('oska', False)],
          'oskott': [('oskott', False)],
          'oskotten': [('oskott', False)],
          'oskottens': [('oskott', False)],
          'oskrin': [('oskri', False)],
          'oskrins': [('oskri', False)],
          'oskulder': [('oskuld', False)],
          'oskurs': [('oskurs', False)],
          'oskurs-': [('oskurs', False)],
          'oskäll': [('oskälla', False)],
          'oskäll-': [('oskälla', False)],
          'oskälls': [('oskälla', False)],
          'oskälls-': [('oskälla', False)],
          'oslantar': [('oslant', False)],
          'oslantarna': [('oslant', False)],
          'oslantars': [('oslant', False)],
          'osling': [('osling', False)],
          'osling-': [('osling', False)],
          'oslings': [('osling', False)],
          'oslings-': [('osling', False)],
          'oslotts': [('oslott', False)],
          'osläkten': [('osläkte', False)],
          'osläktens': [('osläkte', False)],
          'osläkts': [('osläkte', False)],
          'osläkts-': [('osläkte', False)],
          'osmarna': [('osme', False)],
          'osmarnas': [('osme', False)],
          'osmatt': [('osmatta', False)],
          'osmatt-': [('osmatta', False)],
          'osmatts': [('osmatta', False)],
          'osmatts-': [('osmatta', False)],
          'osme': [('osme', False)],
          'osme-': [('osme', False)],
          'osmen': [('osme', False)],
          'osmens': [('osme', False)],
          'osmes-': [('osme', False)],
          'osmin': [('osmi', False)],
          'osmins': [('osmi', False)],
          'osnits': [('osnit', False)],
          'osnits-': [('osnit', False)],
          'osnäpp': [('osnäppa', False)],
          'osnäpp-': [('osnäppa', False)],
          'osnäpps': [('osnäppa', False)],
          'osnäpps-': [('osnäppa', False)],
          'osnåret': [('osnåret', False)],
          'osnårets': [('osnåret', False)],
          'osomer': [('osom', False)],
          'osomers': [('osom', False)],
          'oson': [('oson', False)],
          'osoner': [('oson', False)],
          'osonerna': [('oson', False)],
          'osonernas': [('oson', False)],
          'osoners': [('oson', False)],
          'osons': [('oson', False)],
          'osor': [('osa', False)],
          'osorna': [('osa', False)],
          'osornas': [('osa', False)],
          'osors': [('osa', False)],
          'osot': [('oso', False)],
          'osots': [('osot', False)],
          'osovar-': [('osovar', False)],
          'osovarens': [('osovar', False)],
          'ospermien': [('ospermi', False)],
          'ospermiens': [('ospermi', False)],
          'ospirator': [('ospirator', False)],
          'ospirators': [('ospirator', False)],
          'ospits': [('ospits', False)],
          'ospån': [('ospån', False)],
          'ospåns': [('ospån', False)],
          'ospåns-': [('ospån', False)],
          'osregionen': [('osregion', False)],
          'osregionens': [('osregion', False)],
          'osringar': [('osring', False)],
          'oss': [('osse', False)],
          'oss-': [('ossa', False)],
          'ossans': [('ossa', False)],
          'ossar': [('osse', False)],
          'ossar-': [('ossare', False)],
          'ossarens': [('ossare', False)],
          'ossarie': [('ossarium', False)],
          'ossarier': [('ossarium', False)],
          'ossariernas': [('ossarium', False)],
          'ossarna': [('oss', False)],
          'ossars': [('osse', False)],
          'ossats': [('ossat', False)],
          'ossats-': [('ossat', False)],
          'osse': [('osse', False)],
          'osse-': [('osse', False)],
          'ossen': [('osse', False)],
          'ossens': [('osse', False)],
          'ossenter': [('ossent', False)],
          'ossenterna': [('ossent', False)],
          'ossenternas': [('ossent', False)],
          'ossenters': [('ossent', False)],
          'osserierna': [('osseri', False)],
          'ossets': [('oss', False)],
          'ossiers': [('ossier', False)],
          'ossins': [('ossi', False)],
          'osslanden': [('osslande', False)],
          'osslandens': [('osslande', False)],
          'osslandet': [('osslande', False)],
          'ost': [('ost', False)],
          'ost-': [('ost', True)],
          'osta': [('osta', False)],
          'osta-': [('osta', False)],
          'ostadge': [('ostadga', False)],
          'ostadge-': [('ostadga', False)],
          'ostadie': [('ostadium', False)],
          'ostadie-': [('ostadium', False)],
          'ostadier': [('ostadium', False)],
          'ostadierna': [('ostadium', False)],
          'ostadiernas': [('ostadium', False)],
          'ostadiers': [('ostadium', False)],
          'ostadiet': [('ostadium', False)],
          'ostadiets': [('ostadium', False)],
          'ostadium': [('ostadium', False)],
          'ostadiums': [('ostadium', False)],
          'ostamenten': [('ostament', False)],
          'ostamentens': [('ostament', False)],
          'ostamentet': [('ostament', False)],
          'ostaments-': [('ostament', False)],
          'ostan': [('ostan', True)],
          'ostans': [('ostan', True)],
          'ostar': [('ost', False)],
          'ostar-': [('ostare', False)],
          'ostarna': [('ost', True)],
          'ostarnas': [('ost', False)],
          'ostars': [('ost', False)],
          'ostas': [('osta', False)],
          'ostator': [('ostata', False)],
          'ostators': [('ostata', False)],
          'oste': [('oste', False)],
          'osteg': [('osteg', False)],
          'osteg-': [('osteg', False)],
          'ostegen': [('osteg', False)],
          'ostegens': [('osteg', False)],
          'ostegs': [('osteg', False)],
          'ostegs-': [('osteg', False)],
          'ostel': [('ostel', False)],
          'ostel-': [('ostel', False)],
          'ostels': [('ostel', False)],
          'ostels-': [('ostel', False)],
          'osten': [('ost', False)],
          'ostens': [('ost', False)],
          'oster': [('oster', False)],
          'osterbroder': [('osterbroder', False)],
          'osterbrodern': [('osterbror', False)],
          'osterbroderns': [('osterbror', False)],
          'osterbroders': [('osterbror', False)],
          'osterbröder': [('osterbror', False)],
          'osterbröderna': [('osterbroder', False)],
          'osterbrödernas': [('osterbror', False)],
          'osterbröders': [('osterbroder', False)],
          'osteri': [('osteria', True)],
          'osteri-': [('osteria', True)],
          'osterie': [('osteria', True)],
          'osterier': [('osteri', False)],
          'osterierna': [('osteri', False)],
          'osteriers': [('osteri', False)],
          'osteriet': [('osteri', False)],
          'osteris': [('osteria', True)],
          'osteris-': [('osteria', True)],
          'osterna': [('oster', False)],
          'osternas': [('oster', False)],
          'osters': [('oster', False)],
          'ostets': [('ost', False)],
          'ostiker': [('ostiker', False)],
          'ostikerna': [('ostiker', False)],
          'ostikernas': [('ostiker', False)],
          'ostikers': [('ostiker', False)],
          'ostol': [('ostol', False)],
          'ostol-': [('ostol', False)],
          'ostols': [('ostol', False)],
          'ostols-': [('ostol', False)],
          'oston': [('oston', False)],
          'ostons': [('oston', False)],
          'ostor': [('osta', False)],
          'ostormarnas': [('ostorm', False)],
          'ostors': [('osta', False)],
          'ostran': [('ostra', True)],
          'ostranden': [('ostrande', False)],
          'ostrandens': [('ostrande', False)],
          'ostrans': [('ostra', True)],
          'ostrar': [('ostrare', False)],
          'ostrarna': [('ostrare', False)],
          'ostrarnas': [('oster', False)],
          'ostriktioner': [('ostriktion', False)],
          'ostriktionernas': [('ostriktion', False)],
          'ostringens': [('ostring', False)],
          'ostron': [('ostron', True)],
          'ostronen': [('ostron', True)],
          'ostronens': [('ostron', True)],
          'ostrons': [('ostron', True)],
          'ostrån': [('ostrån', False)],
          'ostråns': [('ostrån', False)],
          'ostudie': [('ostudie', False)],
          'ostudie-': [('ostudie', False)],
          'ostudier': [('ostudie', False)],
          'ostudierna': [('ostudie', False)],
          'ostudiernas': [('ostudie', False)],
          'ostudiers': [('ostudie', False)],
          'ostycken': [('ostycke', False)],
          'ostyckena': [('ostycke', False)],
          'ostyckenas': [('ostycke', False)],
          'ostyckens': [('ostycke', False)],
          'ostycket': [('ostycke', False)],
          'ostyckets': [('ostycke', False)],
          'oställen': [('oställe', False)],
          'oställens': [('oställe', False)],
          'ostället': [('oställe', False)],
          'oställets': [('oställe', False)],
          'oställningar': [('oställning', False)],
          'oställningarna': [('oställning', False)],
          'oställningarnas': [('oställning', False)],
          'oställningars': [('oställning', False)],
          'oställnings': [('oställning', False)],
          'oställnings-': [('oställning', False)],
          'ostötarnas': [('ostöt', False)],
          'osvans': [('osvans', False)],
          'osvans-': [('osvans', False)],
          'osvensk': [('osvensk', False)],
          'osvensk-': [('osvensk', False)],
          'osyn': [('osyn', False)],
          'osyns': [('osyn', False)],
          'osyre': [('osyra', False)],
          'osyre-': [('osyra', False)],
          'osändarna': [('osändare', False)],
          'osång-': [('osång', False)],
          'osås': [('osås', False)],
          'osås-': [('osås', False)],
          'oséer': [('osé', False)],
          'oséers': [('osé', False)],
          'osögonen': [('osögon', False)],
          'osögonens': [('osögon', False)],
          'osögons': [('osögon', False)],
          'osören': [('osör', False)],
          'osörens': [('osör', False)],
          'ot': [('o', True)],
          'ot-': [('ot', False)],
          'ota': [('otum', False)],
          'otack': [('otack', True)],
          'otacks': [('otack', True)],
          'otacks-': [('otack', True)],
          'otagen': [('otage', False)],
          'otagens': [('otage', False)],
          'otaget': [('otage', False)],
          'otagets': [('otage', False)],
          'otaggar': [('otagg', False)],
          'otaggarna': [('otagg', False)],
          'otaggarnas': [('otagg', False)],
          'otalen': [('otal', False)],
          'otalens': [('otal', False)],
          'otalet': [('otal', False)],
          'otamen': [('otam', False)],
          'otamens': [('otam', False)],
          'otan': [('ota', False)],
          'otana': [('ota', False)],
          'otanas': [('ota', False)],
          'otanden': [('otande', False)],
          'otandens': [('otande', False)],
          'otangenten': [('otangent', False)],
          'otangentens': [('otangent', False)],
          'otans': [('ota', False)],
          'otar': [('ot', False)],
          'otaren': [('otare', False)],
          'otarie': [('otarie', False)],
          'otarie-': [('otarie', False)],
          'otarier': [('otarie', False)],
          'otariernas': [('otarie', False)],
          'otariers': [('otarie', False)],
          'otarna': [('ot', False)],
          'otarnas': [('otare', False)],
          'otars': [('ot', False)],
          'otas': [('otum', False)],
          'otax': [('otax', False)],
          'otax-': [('otax', False)],
          'ote': [('ota', False)],
          'ote-': [('ota', False)],
          'otekniker': [('otekniker', False)],
          'oteknikerna': [('otekniker', False)],
          'oteknikernas': [('otekniker', False)],
          'oteknikers': [('oteknik', False)],
          'otel': [('otel', False)],
          'oteln': [('otel', False)],
          'otelns': [('otel', False)],
          'otels': [('otel', False)],
          'otels-': [('otel', False)],
          'otemet': [('otem', False)],
          'otemets': [('otem', False)],
          'oten': [('ot', False)],
          'otens': [('ot', False)],
          'otens-': [('otens', False)],
          'oter': [('ot', False)],
          'oter-': [('oter', False)],
          'oteranden': [('oterande', False)],
          'oterandens': [('oterande', False)],
          'oterier': [('oterion', False)],
          'oterierna': [('oterion', False)],
          'oteriernas': [('oterion', False)],
          'oteriers': [('oterion', False)],
          'otermer': [('oterm', False)],
          'otermerna': [('oterm', False)],
          'otermernas': [('oterm', False)],
          'otermers': [('oterm', False)],
          'otermin': [('otermi', False)],
          'otermins': [('otermi', False)],
          'otern': [('oter', False)],
          'oterna': [('ot', False)],
          'oternas': [('ot', False)],
          'oterns': [('oter', False)],
          'oters': [('ot', False)],
          'oters-': [('oter', False)],
          'otes': [('otes', False)],
          'otes-': [('otes', False)],
          'otestens': [('otest', False)],
          'otet': [('ot', False)],
          'otets': [('ot', False)],
          'otiden': [('otid', False)],
          'otidens': [('otiden', False)],
          'otider': [('otid', False)],
          'otiders': [('otid', False)],
          'otier': [('otier', False)],
          'otierna': [('otier', False)],
          'otiernas': [('otier', False)],
          'otiers': [('otier', False)],
          'otiet': [('otium', True)],
          'otighets': [('otighet', False)],
          'otik': [('otik', False)],
          'otik-': [('otik', False)],
          'otikana': [('otikum', False)],
          'otikanas': [('otikum', False)],
          'otiks': [('otik', False)],
          'otim': [('otimme', False)],
          'otim-': [('otimme', False)],
          'otimmarna': [('otimme', False)],
          'otin': [('oti', False)],
          'otin-': [('otin', False)],
          'otinens': [('otin', False)],
          'otiner': [('otin', False)],
          'otinerna': [('otin', False)],
          'otinernas': [('otin', False)],
          'otiners': [('otin', False)],
          'otinor': [('otino', False)],
          'otinorna': [('otino', False)],
          'otinornas': [('otino', False)],
          'otinors': [('otino', False)],
          'otins': [('otin', False)],
          'otint-': [('otint', False)],
          'otints': [('otint', False)],
          'otions-': [('otion', False)],
          'otis': [('oti', False)],
          'otit': [('otit', True)],
          'otit-': [('otit', True)],
          'otits': [('otit', True)],
          'otiv': [('otiv', False)],
          'otiv-': [('otiv', False)],
          'otiven': [('otiv', False)],
          'otivens': [('otiv', False)],
          'otivet': [('otiv', False)],
          'otivs': [('otiv', False)],
          'otjack': [('otjacka', False)],
          'otjack-': [('otjacka', False)],
          'otjacks': [('otjacka', False)],
          'otjacks-': [('otjacka', False)],
          'otlar': [('otel', False)],
          'otlarna': [('otel', False)],
          'otlarnas': [('otel', False)],
          'otnötter': [('otnot', False)],
          'otnötterna': [('otnot', False)],
          'otnötternas': [('otnot', False)],
          'otnötters': [('otnot', False)],
          'oto-': [('oto', False)],
          'otom': [('otom', False)],
          'otoms': [('otom', False)],
          'oton': [('oton', False)],
          'otoner': [('oton', False)],
          'otonerna': [('oton', False)],
          'otonernas': [('oton', False)],
          'otonin': [('otonin', False)],
          'otonins': [('otonin', False)],
          'otons': [('oton', False)],
          'otops': [('otop', False)],
          'otor': [('ota', False)],
          'otorer': [('otor', False)],
          'otorerna': [('otor', False)],
          'otorernas': [('otor', False)],
          'otorers': [('otor', False)],
          'otorn': [('otor', False)],
          'otorna': [('ota', False)],
          'otornas': [('ota', False)],
          'otorns': [('otor', False)],
          'otors': [('ota', False)],
          'otos': [('oto', False)],
          'otos-': [('oto', False)],
          'otox': [('otox', False)],
          'otoxen': [('otox', False)],
          'otoxens': [('otox', False)],
          'otrar': [('oter', False)],
          'otrarna': [('oter', False)],
          'otrars': [('oter', False)],
          'otricks': [('otrick', False)],
          'otricks-': [('otrick', False)],
          'otripp-': [('otripp', False)],
          'otripparna': [('otripp', False)],
          'otripps-': [('otripp', False)],
          'otron': [('otro', True)],
          'otrons': [('otro', True)],
          'otros': [('otro', True)],
          'otros-': [('otro', True)],
          'otrum-': [('otrumma', False)],
          'otrums': [('otrumma', False)],
          'oträd': [('oträd', False)],
          'oträd-': [('oträd', False)],
          'oträden': [('oträd', False)],
          'oträdens': [('oträd', False)],
          'oträdet': [('oträd', False)],
          'oträdets': [('oträd', False)],
          'oträds': [('oträd', False)],
          'oträn': [('oträd', False)],
          'oträna': [('oträd', False)],
          'otränas': [('oträd', False)],
          'oträns': [('oträd', False)],
          'ots': [('o', True)],
          'ots-': [('ot', False)],
          'otsaks': [('otsak', False)],
          'otsaks-': [('otsak', False)],
          'otsar': [('ots', False)],
          'otsarnas': [('ots', False)],
          'otsars': [('ots', False)],
          'otsk': [('otska', False)],
          'otsk-': [('otska', False)],
          'otskor': [('otska', False)],
          'otskorna': [('otska', False)],
          'otskornas': [('otska', False)],
          'otskors': [('otska', False)],
          'otsteg': [('otsteg', False)],
          'otströmmen': [('otström', False)],
          'otstudie-': [('otstudie', False)],
          'otstudierna': [('otstudie', False)],
          'otstudiernas': [('otstudie', False)],
          'otstudiers': [('otstudie', False)],
          'otställens': [('otställ', False)],
          'otställets': [('otställ', False)],
          'ottan': [('otta', False)],
          'ottarna': [('ott', False)],
          'otte': [('otta', True)],
          'otte-': [('otta', False)],
          'ottens': [('ott', False)],
          'otter': [('otter', False)],
          'otteriers': [('otteri', False)],
          'otters': [('otter', False)],
          'ottets': [('ott', False)],
          'otti': [('otti', False)],
          'ottighets-': [('ottighet', False)],
          'ottin': [('ottin', False)],
          'ottina': [('otti', False)],
          'ottins': [('ottin', False)],
          'ottis': [('otti', False)],
          'ottis-': [('otti', False)],
          'ottlanden': [('ottlande', False)],
          'ottlandens': [('ottlande', False)],
          'ottlandet': [('ottlande', False)],
          'ottnarna': [('otten', False)],
          'ottnarnas': [('otten', False)],
          'ottnens': [('otten', False)],
          'otto': [('otto', False)],
          'ottpengarna': [('ottpengar', False)],
          'ottrarnas': [('otter', False)],
          'ottre': [('ottra', False)],
          'ottre-': [('ottra', False)],
          'otträden': [('otträd', False)],
          'otträdens': [('otträd', False)],
          'otträdet': [('otträd', False)],
          'ottränas': [('otträd', False)],
          'ottställens': [('ottställe', False)],
          'ottställets': [('ottställe', False)],
          'ottsång': [('ottsånga', False)],
          'ottsångs': [('ottsånga', False)],
          'ottsångs-': [('ottsånga', False)],
          'otum': [('otum', False)],
          'otum-': [('otum', False)],
          'otumen': [('otum', False)],
          'otumens': [('otum', False)],
          'otums': [('otum', False)],
          'otums-': [('otum', False)],
          'otundans': [('otunda', False)],
          'otur-': [('otur', False)],
          'oturer': [('otur', False)],
          'oturerna': [('otur', False)],
          'oturernas': [('otur', False)],
          'oturs': [('otur', False)],
          'oturs-': [('otur', True)],
          'otus': [('otus', False)],
          'otus-': [('otus', False)],
          'otvind': [('otvind', False)],
          'otylen': [('otyl', False)],
          'otylens': [('otyl', False)],
          'otypen': [('otyp', False)],
          'otypens': [('otyp', False)],
          'otyper': [('otyp', False)],
          'otyperna': [('otyp', False)],
          'otypernas': [('otyp', False)],
          'otypers': [('otyp', False)],
          'otäcke': [('otäcka', True)],
          'otändar': [('otände', False)],
          'otändarna': [('otände', False)],
          'otändarnas': [('otände', False)],
          'otände': [('otände', False)],
          'otänger': [('otång', False)],
          'otängers': [('otång', False)],
          'otång': [('otång', False)],
          'otång-': [('otång', False)],
          'otången': [('otång', False)],
          'otångens': [('otång', False)],
          'otångs': [('otång', False)],
          'otångs-': [('otång', False)],
          'ou': [('ou', False)],
          'oucher': [('oucher', False)],
          'oucherna': [('ouche', False)],
          'ouchernas': [('oucher', False)],
          'ouchers': [('ouche', False)],
          'ouer': [('ou', False)],
          'ouerna': [('ou', False)],
          'ouernas': [('ou', False)],
          'ouers': [('ou', False)],
          'ouge': [('ouge', False)],
          'ouge-': [('ouge', False)],
          'ouget': [('ouge', False)],
          'oukis': [('ouki', False)],
          'oukisarnas': [('ouki', False)],
          'oukisen': [('ouki', False)],
          'oukisens': [('ouki', False)],
          'oule': [('oule', False)],
          'oule-': [('oule', False)],
          'oulen': [('oule', False)],
          'oulens': [('oule', False)],
          'oun': [('ou', False)],
          'ound': [('ound', False)],
          'ound-': [('ound', False)],
          'ounds': [('ound', False)],
          'ounds-': [('ound', False)],
          'ounger': [('ounge', False)],
          'oungers': [('ounge', False)],
          'ouns': [('ou', False)],
          'ount': [('ount', False)],
          'ounten': [('ount', False)],
          'ountens': [('ount', False)],
          'ounts-': [('ount', False)],
          'oupe': [('oupe', False)],
          'oupe-': [('oupe', False)],
          'oupen': [('oupe', False)],
          'oupens': [('oupe', False)],
          'ouper': [('oupe', False)],
          'ouperna': [('oupe', False)],
          'oupernas': [('oupe', False)],
          'oupers': [('oupe', False)],
          'oupier': [('oupier', False)],
          'oups': [('oups', False)],
          'ourmandens': [('ourmand', False)],
          'ours-': [('ours', False)],
          'ourser': [('ours', False)],
          'ourserna': [('ours', False)],
          'oursernas': [('ours', False)],
          'oursers': [('ours', False)],
          'ourt': [('ourt', False)],
          'ourt-': [('ourt', False)],
          'ourtaget': [('ourtage', False)],
          'ourtagets': [('ourtage', False)],
          'ourts': [('ourt', False)],
          'ous': [('ou', False)],
          'ouse': [('ouse', False)],
          'ouse-': [('ouse', False)],
          'ousen': [('ouse', False)],
          'ousens': [('ouse', False)],
          'ousin': [('ousin', False)],
          'outarnas': [('out', False)],
          'oute': [('oute', False)],
          'oute-': [('oute', False)],
          'outen': [('oute', False)],
          'outens': [('oute', False)],
          'outerier': [('outerier', False)],
          'outerierna': [('outerier', False)],
          'outeriernas': [('outerier', False)],
          'outerna': [('oute', False)],
          'outernas': [('oute', False)],
          'outrar': [('outer', False)],
          'outrarnas': [('outer', False)],
          'outrars': [('outer', False)],
          'outsarna': [('out', False)],
          'outsarnas': [('out', False)],
          'ov': [('ov', False)],
          'ov-': [('ov', False)],
          'ovak': [('ovak', False)],
          'ovak-': [('ovak', False)],
          'ovaks': [('ovak', False)],
          'ovaks-': [('ovak', False)],
          'oval-': [('oval', True)],
          'ovalen': [('oval', True)],
          'ovalens': [('oval', True)],
          'ovals': [('oval', False)],
          'ovals-': [('oval', False)],
          'ovan': [('ova', False)],
          'ovana': [('ovana', False)],
          'ovane': [('ovana', True)],
          'ovane-': [('ovana', False)],
          'ovans': [('ova', False)],
          'ovar': [('ovare', False)],
          'ovar-': [('ovar', False)],
          'ovaren': [('ovare', False)],
          'ovarens': [('ovar', False)],
          'ovarie': [('ovarium', True)],
          'ovarie-': [('ovarium', True)],
          'ovarierna': [('ovarium', True)],
          'ovariers': [('ovarium', True)],
          'ovarna': [('ov', False)],
          'ovarnas': [('ov', False)],
          'ovars': [('ov', False)],
          'ovarts': [('ovart', False)],
          'ovas': [('ova', False)],
          'ovbitar': [('ovbit', False)],
          'ovbitarna': [('ovbit', False)],
          'ovbitarnas': [('ovbit', False)],
          'ovdags': [('ovdag', False)],
          'ovdar': [('ovdag', False)],
          'ovdarna': [('ovdag', False)],
          'ovdarnas': [('ovdag', False)],
          'ovdars': [('ovdag', False)],
          'ove': [('ova', False)],
          'ove-': [('ova', False)],
          'ovel': [('ovel', False)],
          'ovel-': [('ovel', False)],
          'ovels': [('ovel', False)],
          'ovels-': [('ovel', False)],
          'oven': [('ov', False)],
          'ovender': [('ovend', False)],
          'ovenderna': [('ovend', False)],
          'ovendernas': [('ovend', False)],
          'ovenders': [('ovend', False)],
          'ovens': [('ov', False)],
          'ovens-': [('oven', False)],
          'overande': [('overande', False)],
          'overande-': [('overande', False)],
          'overben': [('overb', False)],
          'overbens': [('overb', False)],
          'overkets': [('overk', False)],
          'overlåtar': [('overlåt', False)],
          'overlåtarnas': [('overlåt', False)],
          'overn': [('over', False)],
          'overna': [('ov', False)],
          'overnas': [('ov', False)],
          'overns': [('over', False)],
          'overs-': [('over', False)],
          'oversarna': [('over', False)],
          'oversarnas': [('over', False)],
          'oversen': [('over', False)],
          'oversens': [('over', False)],
          'ovet': [('ov', False)],
          'ovett': [('ovett', True)],
          'ovetts': [('ovett', True)],
          'ovetts-': [('ovett', True)],
          'ovfiskar': [('ovfisk', False)],
          'ovfiskarna': [('ovfisk', False)],
          'ovie': [('ovie', False)],
          'ovie-': [('ovie', False)],
          'ovien': [('ovie', False)],
          'oviens': [('ovie', False)],
          'ovin': [('ovin', False)],
          'ovind': [('ovind', False)],
          'ovindarnas': [('ovind', False)],
          'ovinds': [('ovind', False)],
          'ovinds-': [('ovind', False)],
          'ovins': [('ovin', False)],
          'ovins-': [('ovin', False)],
          'ovinsten': [('ovinst', False)],
          'ovinstens': [('ovinst', False)],
          'ovip': [('ovipa', False)],
          'ovip-': [('ovipa', False)],
          'ovips': [('ovipa', False)],
          'ovips-': [('ovipa', False)],
          'ovis': [('ovisa', False)],
          'ovis-': [('ovis', False)],
          'ovisa': [('ovisa', False)],
          'ovisar': [('ovis', False)],
          'ovisarna': [('ovis', False)],
          'ovisarnas': [('ovis', False)],
          'ovisars': [('ovis', False)],
          'ovisas': [('ovisa', False)],
          'ovise': [('ovisa', False)],
          'ovisen': [('ovis', False)],
          'ovisens': [('ovis', False)],
          'ovisor': [('ovisa', False)],
          'ovit': [('ovit', False)],
          'ovit-': [('ovit', False)],
          'oviten': [('ovit', False)],
          'ovitens': [('ovit', False)],
          'oviter': [('ovit', False)],
          'oviterna': [('ovit', False)],
          'oviters': [('ovit', False)],
          'ovitet': [('ovitet', False)],
          'ovitets': [('ovitet', False)],
          'ovits': [('ovits', False)],
          'ovits-': [('ovits', False)],
          'ovlar': [('ovel', False)],
          'ovlarna': [('ovel', False)],
          'ovlarnas': [('ovel', False)],
          'ovlars': [('ovel', False)],
          'ovor': [('ova', False)],
          'ovorna': [('ova', False)],
          'ovornas': [('ova', False)],
          'ovors': [('ova', False)],
          'ovrar': [('over', False)],
          'ovrarna': [('over', False)],
          'ovs': [('ov', False)],
          'ovs-': [('ov', False)],
          'ovtidens': [('ovtid', False)],
          'ovägar': [('oväg', False)],
          'ovägarna': [('oväg', False)],
          'ovägarnas': [('oväg', False)],
          'ovägs': [('oväg', False)],
          'ovägs-': [('oväg', False)],
          'ovälden': [('oväld', True)],
          'oväldens': [('oväld', True)],
          'ovärden': [('ovärde', False)],
          'ovärdens': [('ovärde', False)],
          'ovärdet': [('ovärde', False)],
          'oväsendet': [('oväsen', True)],
          'oväsendets': [('oväsen', True)],
          'oväxlar': [('oväxel', False)],
          'oväxlarna': [('oväxel', False)],
          'oväxlarnas': [('oväxel', False)],
          'owan': [('owan', False)],
          'owans': [('owan', False)],
          'owns': [('own', False)],
          'ox': [('oxe', True)],
          'ox-': [('oxe', True)],
          'oxar': [('oxe', True)],
          'oxarna': [('oxe', True)],
          'oxarnas': [('oxe', True)],
          'oxars': [('oxe', True)],
          'oxen': [('oxe', True)],
          'oxens': [('oxe', True)],
          'oxer': [('ox', False)],
          'oxerna': [('ox', False)],
          'oxernas': [('ox', False)],
          'oxers': [('ox', False)],
          'oxin': [('oxi', False)],
          'oxins': [('oxin', False)],
          'oxlar': [('oxel', True)],
          'oxlarna': [('oxel', True)],
          'oxlarnas': [('oxel', True)],
          'oy': [('oy', False)],
          'oy-': [('oy', False)],
          'oyans': [('oya', False)],
          'oyar': [('oy', False)],
          'oyarna': [('oy', False)],
          'oyen': [('oy', False)],
          'oyen-': [('oyen', False)],
          'oyens': [('oyen', False)],
          'oyer': [('oy', False)],
          'oyeren': [('oyer', False)],
          'oyerens': [('oyer', False)],
          'oyerna': [('oy', False)],
          'oyernas': [('oy', False)],
          'oyers': [('oy', False)],
          'oyoten': [('oyot', False)],
          'oyotens': [('oyot', False)],
          'oyoter': [('oyot', False)],
          'oyoterna': [('oyot', False)],
          'oyoternas': [('oyot', False)],
          'oyoters': [('oyot', False)],
          'oys': [('oy', False)],
          'oys-': [('oy', False)],
          'oysarna': [('oy', False)],
          'oysen': [('oy', False)],
          'oysens': [('oy', False)],
          'ozon': [('ozon', True)],
          'ozonen': [('ozon', False)],
          'ozonens': [('ozon', True)],
          'ozons': [('ozon', True)],
          'oägg': [('oägg', False)],
          'oägg-': [('oägg', False)],
          'oäggs': [('oägg', False)],
          'oänd': [('oända', False)],
          'oänd-': [('oända', False)],
          'oändar': [('oände', False)],
          'oänds': [('oända', False)],
          'oänds-': [('oända', False)],
          'oäng': [('oäng', False)],
          'oäng-': [('oäng', False)],
          'oängen': [('oäng', False)],
          'oängens': [('oäng', False)],
          'oänger': [('oäng', False)],
          'oängerna': [('oäng', False)],
          'oängernas': [('oäng', False)],
          'oängers': [('oäng', False)],
          'oänget': [('oäng', False)],
          'oängs': [('oäng', False)],
          'oängs-': [('oäng', False)],
          'oåkar': [('oåkare', False)],
          'oår': [('oår', False)],
          'oårs': [('oår', False)],
          'oårs-': [('oår', False)],
          'oöarna': [('oö', False)],
          'oöde': [('oöde', False)],
          'oöden': [('oöde', False)],
          'oödens': [('oöde', False)],
          'oödet': [('oöde', False)],
          'oögat': [('oöga', False)],
          'oögats': [('oöga', False)],
          'oögonens': [('oöga', False)],
          'oöns': [('oö', False)],
          'oös': [('oö', False)],
          'oös-': [('oö', False)],
          'p': [('p', True)],
          'p-': [('p', True)],
          'p-ins': [('p-in', False)],
          'p3-': [('p3', False)],
          'pH-': [('pH', True)],
          'pa': [('pa', False)],
          'pa-': [('pa', False)],
          'pack': [('packe', True), ('pack', True)],
          'pack-': [('packe', True), ('pack', True)],
          'packar': [('packe', True)],
          'packarna': [('packe', True)],
          'packarnas': [('packe', False)],
          'packars': [('packe', True)],
          'packe': [('packe', True)],
          'packe-': [('packa', False)],
          'packel': [('packel', False)],
          'packel-': [('packel', False)],
          'packen': [('packe', True)],
          'packens': [('packe', True)],
          'packersens': [('packer', False)],
          'packet': [('pack', False)],
          'packets': [('pack', True)],
          'packlandets': [('packlande', False)],
          'packor': [('packa', False)],
          'packorna': [('packa', False)],
          'packornas': [('packa', False)],
          'packors': [('packa', False)],
          'packs': [('packe', True), ('pack', True)],
          'packs-': [('packe', True), ('pack', True)],
          'padar': [('pade', False)],
          'padar-': [('padare', False)],
          'padarna': [('padare', False)],
          'padarnas': [('padare', False)],
          'padars': [('pade', False)],
          'padd': [('padda', True)],
          'padd-': [('padda', False)],
          'padds': [('padda', True)],
          'padds-': [('padda', True)],
          'pade': [('pade', False)],
          'pade-': [('pade', False)],
          'paden': [('pade', False)],
          'padens': [('pade', False)],
          'pader': [('pader', False)],
          'pader-': [('pader', False)],
          'paderna': [('pader', False)],
          'padernas': [('pader', False)],
          'paders': [('pader', False)],
          'pades': [('pade', False)],
          'padets': [('pad', False)],
          'pagats': [('pagat', False)],
          'page': [('page', False)],
          'page-': [('page', False)],
          'pagen': [('page', True)],
          'pagens': [('page', False)],
          'pager': [('page', True)],
          'pagerna': [('page', True)],
          'pagernas': [('page', True)],
          'pagers': [('page', True)],
          'paget': [('page', False)],
          'pagin': [('pagina', True)],
          'pagins': [('pagina', True)],
          'pagnen': [('pagne', False)],
          'pagnens': [('pagne', False)],
          'pajs-': [('paj', False)],
          'pak-': [('pak', False)],
          'pakarnas': [('pak', False)],
          'paket': [('paket', False)],
          'pakets': [('paket', True)],
          'pakistans': [('pakistan', True)],
          'paks': [('pak', False)],
          'paks-': [('pak', False)],
          'pakta': [('paktum', True)],
          'paktana': [('paktum', True)],
          'pakten': [('pakt', True)],
          'pakter': [('pakt', False)],
          'pakters': [('pakt', False)],
          'palats': [('palats', False)],
          'pales': [('pales', False)],
          'pales-': [('pales', False)],
          'pall': [('pall', False)],
          'pall-': [('pall', False)],
          'pallanden': [('pallande', True)],
          'pallandens': [('pallande', True)],
          'pallandet': [('pallande', True)],
          'pallar': [('pall', True)],
          'pallars': [('pall', False)],
          'pallen': [('pall', True)],
          'palls': [('pall', False)],
          'palls-': [('pall', False)],
          'pals': [('pals', True)],
          'pals-': [('pals', True)],
          'palt': [('paltor', True), ('palt', True)],
          'palt-': [('paltor', True), ('palt', True)],
          'paltar': [('palt', False)],
          'paltarna': [('palt', False)],
          'paltarnas': [('palt', False)],
          'palter': [('palt', False)],
          'palterna': [('palt', False)],
          'palternas': [('palt', False)],
          'palters': [('palt', False)],
          'paltorna': [('paltor', True)],
          'palts': [('paltor', True), ('palt', True)],
          'palts-': [('paltor', True), ('palt', True)],
          'pam': [('pam', False)],
          'pam-': [('pam', False)],
          'pamet': [('pam', False)],
          'pamets': [('pam', False)],
          'pamin': [('pamin', False)],
          'pamins': [('pamin', False)],
          'pammen': [('pamm', False)],
          'pammens': [('pamm', False)],
          'pammet': [('pamm', False)],
          'pammets': [('pamm', False)],
          'pamp': [('pamp', False)],
          'pamp-': [('pamp', False)],
          'pampar': [('pamp', False)],
          'pamparna': [('pamp', False)],
          'pampas': [('pampas', True)],
          'pampen': [('pamp', False)],
          'pampens': [('pamp', False)],
          'pamps': [('pamp', True)],
          'pamps-': [('pamp', False)],
          'pams': [('pam', False)],
          'pams-': [('pam', False)],
          'pan': [('pa', False)],
          'pana': [('pa', False)],
          'panaman': [('panama', True), ('panaman', True)],
          'panamans': [('panama', True), ('panaman', True)],
          'panar': [('panare', False)],
          'panarna': [('panare', False)],
          'panas': [('pa', False)],
          'pand': [('panda', True)],
          'pand-': [('panda', True)],
          'pande': [('panda', True)],
          'pande-': [('panda', True)],
          'panden': [('pande', False)],
          'pandens': [('pande', False)],
          'pandets': [('pande', False)],
          'pands': [('panda', True)],
          'pands-': [('panda', True)],
          'panegyriker': [('panegyriker', True), ('panegyrik', True)],
          'panegyrikerna': [('panegyriker', True), ('panegyrik', True)],
          'panegyrikernas': [('panegyriker', True), ('panegyrik', True)],
          'panegyrikers': [('panegyriker', True), ('panegyrik', True)],
          'panens': [('pan', False)],
          'panets': [('pan', False)],
          'pang': [('pang', True)],
          'pang-': [('pang', True)],
          'pangen': [('pang', True)],
          'pangens': [('pang', True)],
          'pangs': [('pang', True)],
          'pangs-': [('pang', True)],
          'pani': [('pani', False)],
          'pani-': [('pani', False)],
          'panier': [('pani', False)],
          'paniers': [('pani', False)],
          'paniet': [('pani', False)],
          'panis': [('pani', False)],
          'panis-': [('pani', False)],
          'panit': [('pani', False)],
          'panjen': [('panj', False)],
          'panjens': [('panj', False)],
          'panjer': [('panj', False)],
          'panjerna': [('panj', False)],
          'panjernas': [('panj', False)],
          'panjers': [('panj', False)],
          'panjon': [('panjon', False)],
          'pankar': [('pankare', False)],
          'pankar-': [('pankare', False)],
          'panke-': [('panka', False)],
          'pankor': [('panka', False)],
          'pankorna': [('panka', True)],
          'pankornas': [('panka', False)],
          'pann': [('panna', True)],
          'pann-': [('panna', True)],
          'pannar': [('pann', False)],
          'pannarna': [('pann', False)],
          'pannarnas': [('pann', False)],
          'pannars': [('pann', False)],
          'panne': [('panna', False)],
          'panne-': [('panna', True)],
          'pannen': [('pann', False)],
          'pannens': [('pann', False)],
          'pannor': [('panna', False)],
          'pannorna': [('panna', False)],
          'pannornas': [('panna', False)],
          'pannors': [('panna', True)],
          'panns': [('panna', True)],
          'panns-': [('panna', True)],
          'pans': [('pa', False)],
          'pans-': [('pan', False)],
          'pansar': [('pansar', True)],
          'pansar-': [('pansar', False)],
          'pansarens': [('pansar', False)],
          'pansarna': [('pansar', False)],
          'pansarnas': [('pansar', False)],
          'pansen': [('pans', False)],
          'pansens': [('pans', False)],
          'panser': [('pans', False)],
          'panserna': [('pans', False)],
          'pansernas': [('pans', False)],
          'pansers': [('pans', False)],
          'pansk': [('panska', False)],
          'pansk-': [('panska', False)],
          'pant': [('pant', False)],
          'panten': [('pant', False)],
          'pantens': [('pant', False)],
          'panter': [('panter', True), ('pant', True)],
          'pantern': [('panter', True)],
          'panterna': [('pant', False)],
          'panternas': [('pant', False)],
          'panterns': [('panter', True)],
          'panters': [('pant', True), ('panter', True)],
          'pantet': [('pant', False)],
          'pantets': [('pant', False)],
          'panträden': [('panträd', False)],
          'panträdens': [('panträd', False)],
          'panträdet': [('panträd', False)],
          'panträdets': [('panträd', False)],
          'pants-': [('pant', False)],
          'paper': [('paper', True)],
          'papers': [('paper', True)],
          'papp-': [('papp', False)],
          'pappe': [('pappa', False)],
          'pappen': [('papp', False)],
          'pappens': [('papp', False)],
          'papper': [('papper', False)],
          'papplåd': [('papplåda', True)],
          'papplåd-': [('papplåda', True)],
          'papplåds': [('papplåda', True)],
          'papplåds-': [('papplåda', True)],
          'papps': [('papp', False)],
          'papps-': [('papp', True)],
          'papuan': [('papuan', True), ('papua', True)],
          'papuans': [('papuan', True), ('papua', True)],
          'par': [('par', True)],
          'par-': [('par', True)],
          'paranden': [('parande', True)],
          'parandens': [('parande', True)],
          'parans': [('parans', False)],
          'parar': [('parare', False)],
          'pararna': [('parare', False)],
          'pararnas': [('parare', False)],
          'pard': [('pard', False)],
          'pard-': [('pard', False)],
          'pardagen': [('pardag', False)],
          'pardagens': [('pardag', False)],
          'pardan': [('pardan', False)],
          'pardans': [('pardans', True)],
          'parden': [('pard', False)],
          'pardens': [('pard', False)],
          'parder': [('pard', False)],
          'parderna': [('pard', False)],
          'pardernas': [('pard', False)],
          'parders': [('pard', False)],
          'pards': [('pard', False)],
          'pards-': [('pard', False)],
          'pare': [('pare', False)],
          'paren': [('par', False)],
          'parens': [('par', True)],
          'pares': [('pares', True)],
          'pari': [('pari', True)],
          'pari-': [('pari', True)],
          'parian': [('parian', True), ('paria', True)],
          'parians': [('parian', True), ('paria', True)],
          'parin': [('parin', False)],
          'paris': [('pari', True)],
          'paris-': [('pari', True)],
          'parit': [('pari', True)],
          'parits': [('pari', True)],
          'parkar': [('park', False)],
          'parkarna': [('park', False)],
          'parkas': [('parkas', True)],
          'parkis': [('parkis', False)],
          'parkurs': [('parkur', False)],
          'parkurs-': [('parkur', False)],
          'parlamentärflagg': [('parlamentärflagga', True), ('parlamentärflagg', True)],
          'parlamentärflaggs': [('parlamentärflagg', True), ('parlamentärflagga', True)],
          'parlamentärflaggs-': [('parlamentärflagg', True), ('parlamentärflagga', True)],
          'parmar': [('parm', False)],
          'parmarnas': [('parm', False)],
          'parna': [('pare', False)],
          'parnas': [('p', False)],
          'parr': [('parre', False)],
          'parr-': [('parre', False)],
          'parren': [('parre', False)],
          'parrens': [('parre', False)],
          'parrs': [('parre', False)],
          'parrs-': [('parre', False)],
          'pars': [('par', False)],
          'pars-': [('par', True)],
          'parsens': [('pars', False)],
          'parser': [('parser', True)],
          'parsers': [('parser', True)],
          'parstens': [('parsten', False)],
          'part': [('part', False)],
          'partan': [('partan', False)],
          'parten': [('part', False)],
          'partens': [('part', False)],
          'parter': [('part', False)],
          'parterna': [('part', False)],
          'parternas': [('part', False)],
          'parters': [('part', False)],
          'partiväsendet': [('partiväsende', True), ('partiväsen', True)],
          'partiväsendets': [('partiväsen', True), ('partiväsende', True)],
          'parts': [('part', False)],
          'parts-': [('part', False)],
          'parv': [('parv', False)],
          'parv-': [('parv', False)],
          'parvar': [('parv', False)],
          'parvarna': [('parv', False)],
          'parvarnas': [('parv', False)],
          'parvars': [('parv', False)],
          'parven': [('parv', False)],
          'parvens': [('parv', False)],
          'parvs': [('parv', False)],
          'parvs-': [('parv', False)],
          'pas': [('pa', False)],
          'pas-': [('pas', False)],
          'pasarna': [('pas', False)],
          'pasarnas': [('pas', False)],
          'pasch': [('pascha', True)],
          'pasch-': [('pascha', True)],
          'paschans': [('pascha', True)],
          'paskor': [('pasko', False)],
          'paskors': [('pasko', False)],
          'pasm': [('pasma', True)],
          'pasm-': [('pasma', True)],
          'pasmer': [('pasm', False)],
          'pasmerna': [('pasm', False)],
          'pasmernas': [('pasm', False)],
          'pasmers': [('pasm', False)],
          'pass': [('pass', False)],
          'passarnas': [('passare', False)],
          'passen': [('pass', False)],
          'passens': [('pass', False)],
          'passet': [('pass', False)],
          'passivets': [('passivum', True)],
          'past': [('pasta', False)],
          'paste': [('pasta', False)],
          'paste-': [('pasta', True)],
          'pastor': [('pasta', True), ('pastor', True)],
          'pastors': [('pastor', True), ('pasta', True)],
          'pat': [('pata', True)],
          'pat-': [('pata', True)],
          'pata': [('pata', True)],
          'patan': [('pata', True)],
          'patas': [('pata', True)],
          'paten': [('paten', True)],
          'patens': [('paten', True)],
          'pater': [('pater', True)],
          'paters': [('pater', True)],
          'patien': [('pati', False)],
          'patiens': [('patiens', True)],
          'patier': [('pati', False)],
          'patierna': [('pati', False)],
          'patiernas': [('patium', False)],
          'patiers': [('pati', False)],
          'patiets': [('patium', False)],
          'patins': [('pati', False)],
          'pation': [('patio', True)],
          'pationen': [('pation', False)],
          'pations': [('patio', True)],
          'patium': [('patium', False)],
          'patiums': [('patium', False)],
          'pator': [('pata', True)],
          'pators': [('pata', True)],
          'patris': [('patris', True)],
          'patron': [('patron', False)],
          'patrons-': [('patron', False)],
          'pats': [('pata', True)],
          'pats-': [('pata', True)],
          'patsen': [('pats', False)],
          'patsens': [('pats', False)],
          'patt': [('patte', True), ('patt', True)],
          'patt-': [('patte', True), ('patt', True)],
          'pattar': [('patte', True)],
          'pattarna': [('patte', True)],
          'pattarnas': [('patte', True)],
          'patte': [('patte', True)],
          'patten': [('patt', True), ('patte', True)],
          'pattens': [('patte', True), ('patt', True)],
          'patter': [('patt', True)],
          'patters': [('patt', True)],
          'patts': [('patte', True), ('patt', True)],
          'patts-': [('patt', True), ('patte', True)],
          'paus': [('paus', False)],
          'paus-': [('paus', False)],
          'pauser': [('paus', False)],
          'pauserna': [('paus', True)],
          'pausernas': [('paus', False)],
          'pausers': [('paus', False)],
          'pav': [('pava', True)],
          'pav-': [('pava', True)],
          'pavan': [('pava', True)],
          'pavanen': [('pavane', True)],
          'pavaner': [('pavane', True)],
          'pavanernas': [('pavane', True)],
          'pavaners': [('pavane', True)],
          'pavanes': [('pavane', True)],
          'pavanes-': [('pavane', True)],
          'pavans': [('pava', True)],
          'pave': [('pava', True)],
          'pave-': [('pava', True)],
          'pavs': [('pava', True)],
          'pavs-': [('pava', True)],
          'pay': [('paya', False)],
          'pay-': [('paya', False)],
          'payan': [('paya', False)],
          'pback': [('pbacke', False)],
          'pback-': [('pbacke', False)],
          'pbackars': [('pbacke', False)],
          'pbacke': [('pbacke', False)],
          'pbacke-': [('pbacke', False)],
          'pbacken': [('pbacke', False)],
          'pbackens': [('pbacke', False)],
          'pbacks': [('pbacke', False)],
          'pbacks-': [('pbacke', False)],
          'pbagg': [('pbagge', False)],
          'pbagg-': [('pbagge', False)],
          'pbaggar': [('pbagge', False)],
          'pbaggarna': [('pbagge', False)],
          'pbaggarnas': [('pbagge', False)],
          'pbaggars': [('pbagge', False)],
          'pbaggen': [('pbagge', False)],
          'pbaggens': [('pbagge', False)],
          'pbaggs': [('pbagge', False)],
          'pbaggs-': [('pbagge', False)],
          'pbandets': [('pband', False)],
          'pbil': [('pbil', False)],
          'pbil-': [('pbil', False)],
          'pbilar': [('pbil', False)],
          'pbilars': [('pbil', False)],
          'pbils': [('pbil', False)],
          'pbils-': [('pbil', False)],
          'pborst': [('pborste', False)],
          'pborst-': [('pborste', False)],
          'pborsten': [('pborste', False)],
          'pborstens': [('pborste', False)],
          'pbot': [('pbot', False)],
          'pbots': [('pbot', False)],
          'pboxar': [('pbox', False)],
          'pboxarna': [('pbox', False)],
          'pboxarnas': [('pbox', False)],
          'pbroder': [('pbroder', False)],
          'pbrodern': [('pbroder', False)],
          'pbroderns': [('pbroder', False)],
          'pbroders': [('pbroder', False)],
          'pbräds': [('pbräda', False)],
          'pbräds-': [('pbräda', False)],
          'pbröder': [('pbroder', False)],
          'pbröderna': [('pbroder', False)],
          'pbrödernas': [('pbroder', False)],
          'pbröders': [('pbroder', False)],
          'pbubbel': [('pbubbla', False)],
          'pbubbel-': [('pbubbla', False)],
          'pbyx': [('pbyxa', False)],
          'pbyx-': [('pbyxa', False)],
          'pbyxornas': [('pbyxa', False)],
          'pbälte': [('pbälte', False)],
          'pbåd': [('pbåd', False)],
          'pbåd-': [('pbåd', False)],
          'pbåden': [('pbåd', False)],
          'pbådens': [('pbåd', False)],
          'pbåds': [('pbåd', False)],
          'pbåds-': [('pbåd', False)],
          'pcentrer': [('pcentrum', False)],
          'pcentrerna': [('pcentrum', False)],
          'pcentrernas': [('pcentrum', False)],
          'pcentrers': [('pcentrum', False)],
          'pcentret': [('pcentrum', False)],
          'pcentrets': [('pcentrum', False)],
          'pdelandet': [('pdelande', False)],
          'pdocks': [('pdocka', False)],
          'pdungen': [('pdunge', False)],
          'pduor': [('pduo', False)],
          'pduorna': [('pduo', False)],
          'pduornas': [('pduo', False)],
          'pdykanden': [('pdykande', False)],
          'pdykandens': [('pdykande', False)],
          'pdyn': [('pdyna', False)],
          'pdyn-': [('pdyna', False)],
          'pdyns': [('pdyna', False)],
          'pdyns-': [('pdyna', False)],
          'pe': [('pe', False)],
          'pe-': [('pe', False)],
          'pecins': [('peci', False)],
          'ped': [('ped', False)],
          'ped-': [('ped', False)],
          'pedans': [('pedans', False)],
          'pedans-': [('pedans', False)],
          'pediens': [('pedi', False)],
          'pedier': [('pedi', False)],
          'pediers': [('pedi', False)],
          'pedins': [('pedi', False)],
          'pedis': [('pedi', False)],
          'peds': [('ped', False)],
          'peds-': [('ped', False)],
          'pegas': [('pegas', True)],
          'pegas-': [('pegas', True)],
          'pejar': [('pejare', False)],
          'pejarna': [('pejare', False)],
          'pejarnas': [('pejare', False)],
          'pek': [('pek', False)],
          'pek-': [('pek', False)],
          'pekar': [('pekare', False)],
          'pekarens': [('pekare', True)],
          'pekarna': [('pekare', False)],
          'pekarnas': [('pekare', False)],
          'peks': [('pek', False)],
          'pekt': [('pekt', False)],
          'pekt-': [('pekt', False)],
          'pekten': [('pekt', False)],
          'pektens': [('pekt', False)],
          'pekter': [('pekt', False)],
          'pekterna': [('pekt', False)],
          'pekternas': [('pekt', False)],
          'pekters': [('pekt', False)],
          'pektet': [('pekt', False)],
          'pektets': [('pekt', False)],
          'pektret': [('pektrum', False)],
          'pekts': [('pekt', False)],
          'pekts-': [('pekt', False)],
          'pelanden': [('pelande', False)],
          'pelandens': [('pelande', False)],
          'pelandets': [('pelande', False)],
          'pelar': [('pelarer', True), ('pelare', True)],
          'pelar-': [('pelarer', True), ('pelare', True)],
          'pelare': [('pelare', False)],
          'pelarens': [('pelare', False)],
          'pelarer': [('pelarer', True)],
          'pelarerna': [('pelarer', True)],
          'pelarernas': [('pelarer', True)],
          'pelarers': [('pelarer', True)],
          'pelares': [('pelare', False)],
          'pelars': [('pelarer', True)],
          'peldar': [('peld', False)],
          'peldarna': [('peld', False)],
          'peldarnas': [('peld', False)],
          'pelinen': [('peline', False)],
          'pelinens': [('peline', False)],
          'peliner': [('peline', False)],
          'pelinerna': [('peline', False)],
          'pelinernas': [('peline', False)],
          'peliners': [('peline', False)],
          'pell': [('pell', False)],
          'pell-': [('pell', False)],
          'pellar': [('pell', False)],
          'pellarna': [('pell', False)],
          'pellarnas': [('pelle', False)],
          'pellars': [('pell', False)],
          'pellen': [('pelle', False)],
          'pellens': [('pelle', False)],
          'peller': [('pell', False)],
          'pellerna': [('pell', False)],
          'pellernas': [('pell', False)],
          'pellers': [('pell', False)],
          'pellet': [('pellet', True)],
          'pellets': [('pellet', True)],
          'pells': [('pell', False)],
          'pells-': [('pell', False)],
          'pelsen': [('pel', False)],
          'pelsens': [('pel', False)],
          'pen': [('pen', True)],
          'pen-': [('pen', True)],
          'pena': [('pe', False)],
          'penar': [('pen', True)],
          'penarna': [('pen', True)],
          'penarnas': [('pen', True)],
          'penars': [('pen', True)],
          'penas': [('pe', False)],
          'penat': [('penater', True)],
          'penat-': [('penater', True)],
          'penater': [('penater', True)],
          'penaterna': [('penater', True)],
          'penaternas': [('penater', True)],
          'penaters': [('penater', True)],
          'penats': [('penater', True)],
          'pendens': [('pendens', False)],
          'pendlar': [('pendel', True), ('pendlare', True)],
          'pendlarna': [('pendel', True), ('pendlare', True)],
          'pendlarnas': [('pendel', True), ('pendlare', True)],
          'pene': [('pene', False)],
          'pene-': [('pene', False)],
          'penen': [('pen', True)],
          'penens': [('pen', True)],
          'penes': [('pene', False)],
          'penes-': [('pene', False)],
          'penet': [('pen', False)],
          'penets': [('pen', False)],
          'peng': [('peng', False)],
          'peng-': [('peng', False)],
          'pengar': [('pengar', True), ('peng', True)],
          'pengarna': [('pengar', True), ('peng', True)],
          'pengarnas': [('pengar', True), ('peng', True)],
          'pengars': [('pengar', True), ('peng', True)],
          'pengs': [('peng', False)],
          'pengs-': [('peng', False)],
          'penheter': [('penhet', False)],
          'penheternas': [('penhet', False)],
          'penheters': [('penhet', False)],
          'penhets': [('penhet', False)],
          'penhets-': [('penhet', False)],
          'penis-': [('penis', True)],
          'penitens': [('penitens', True)],
          'penn': [('penna', True)],
          'penne': [('penna', False)],
          'penne-': [('penna', False)],
          'penning': [('penning', True), ('penningar', True)],
          'penning-': [('penning', True), ('penningar', True)],
          'penningar': [('penning', True), ('penningar', True)],
          'penningarna': [('penningar', True), ('penning', True)],
          'penningarnas': [('penningar', True), ('penning', True)],
          'penningars': [('penning', True), ('penningar', True)],
          'pennings': [('penning', True), ('penningar', True)],
          'pennings-': [('penning', True), ('penningar', True)],
          'pennis-': [('penni', True)],
          'penns': [('penna', False)],
          'pens': [('pen', False)],
          'pens-': [('pen', True)],
          'pensa': [('pensum', True)],
          'pensas': [('pensum', True)],
          'pensen': [('pens', False)],
          'pensens': [('pens', False)],
          'penser': [('pens', False)],
          'penserna': [('pens', False)],
          'pensernas': [('pens', False)],
          'pensers': [('pens', False)],
          'penskaps-': [('penskap', False)],
          'penséer': [('pensé', True), ('penséer', True)],
          'penséerna': [('penséer', True), ('pensé', True)],
          'penséernas': [('penséer', True), ('pensé', True)],
          'penséers': [('pensé', True), ('penséer', True)],
          'pent': [('pent', False)],
          'penten': [('pent', False)],
          'pentens': [('pent', False)],
          'penter': [('pent', False)],
          'penterna': [('pent', False)],
          'penternas': [('pent', False)],
          'penters': [('pent', False)],
          'pents-': [('pent', False)],
          'peon': [('peon', True)],
          'peppar-': [('peppar', False)],
          'pepsin': [('pepsin', True)],
          'pepsins': [('pepsin', True)],
          'per': [('pe', False)],
          'per-': [('per', False)],
          'pera': [('pera', False)],
          'perans': [('pera', False)],
          'perbil': [('perbil', False)],
          'perbils': [('perbil', False)],
          'perbils-': [('perbil', False)],
          'pere': [('pere', False)],
          'pere-': [('pere', False)],
          'peren': [('pere', False)],
          'perens': [('pere', False)],
          'pergen': [('perg', False)],
          'pergens': [('perg', False)],
          'peri': [('peri', False)],
          'peri-': [('peri', False)],
          'perie': [('perium', False)],
          'perie-': [('perium', False)],
          'perier': [('peri', False)],
          'perierna': [('peri', False)],
          'periet': [('peri', False)],
          'peris': [('peri', False)],
          'peris-': [('peri', False)],
          'perit': [('peri', False)],
          'periternas': [('perit', False)],
          'permanens': [('permanens', True)],
          'permer': [('perm', False)],
          'permerna': [('perm', False)],
          'permernas': [('perm', False)],
          'permers': [('perm', False)],
          'permin': [('permi', False)],
          'permis': [('permis', False)],
          'perornas': [('pera', False)],
          'pers': [('pers', True)],
          'pers-': [('pers', True)],
          'persarnas': [('per', False)],
          'persen': [('pers', True)],
          'persens': [('pers', True)],
          'perset': [('pers', True)],
          'perstens': [('persten', False)],
          'pertens': [('pert', False)],
          'perter': [('pert', False)],
          'perters': [('pert', False)],
          'perts': [('pert', False)],
          'perts-': [('pert', False)],
          'pes': [('pe', False)],
          'pes-': [('pe', False)],
          'pesen': [('pe', False)],
          'pesens': [('pe', False)],
          'peson': [('peso', True)],
          'pesons': [('peso', True)],
          'pesor': [('peso', True)],
          'pesornas': [('peso', True)],
          'pesors': [('peso', True)],
          'pessar': [('pessar', True)],
          'pessar-': [('pessar', True)],
          'pessarens': [('pessar', True)],
          'pest-': [('pest', True)],
          'pester': [('pest', False)],
          'pesterna': [('pest', False)],
          'pesternas': [('pest', False)],
          'pesters': [('pest', True)],
          'pestons': [('pesto', True)],
          'pestos': [('pesto', True)],
          'pestos-': [('pesto', True)],
          'pet': [('pet', True)],
          'pet-': [('pet', True)],
          'petan': [('peta', False)],
          'petans': [('peta', False)],
          'petar': [('petare', False)],
          'petarna': [('petare', False)],
          'petarnas': [('pet', False)],
          'petas': [('peta', False)],
          'peten': [('pet', False)],
          'peter': [('peter', False)],
          'peteri': [('peteri', False)],
          'peteri-': [('peteri', False)],
          'peteris': [('peteri', False)],
          'peteris-': [('peteri', False)],
          'peters': [('peter', False)],
          'petets': [('pet', True)],
          'petins': [('peti', False)],
          'petit': [('petita', True), ('petit', True)],
          'petit-': [('petita', True), ('petit', True)],
          'petits': [('petita', True), ('petit', True)],
          'pets': [('pet', True)],
          'pets-': [('pet', True)],
          'petsar': [('pets', False)],
          'petsarna': [('pets', False)],
          'petsarnas': [('pets', False)],
          'petsen': [('pets', False)],
          'petsens': [('pets', False)],
          'petset': [('pets', False)],
          'petsets': [('pets', False)],
          'pett': [('pett', False)],
          'pett-': [('pett', False)],
          'pettar': [('pett', False)],
          'pettars': [('pett', False)],
          'petten': [('pett', False)],
          'petter': [('petter', False)],
          'petterna': [('pett', False)],
          'petternas': [('pett', False)],
          'petters': [('pett', False)],
          'pettiden': [('pettid', False)],
          'pettidens': [('pettid', False)],
          'petts': [('pett', False)],
          'petts-': [('pett', False)],
          'pexar': [('pexare', False)],
          'pexarna': [('pexare', False)],
          'pexarnas': [('pexare', False)],
          'pfasoner': [('pfasoner', False)],
          'pfasonerna': [('pfasoner', False)],
          'pfasonernas': [('pfasoner', False)],
          'pfasoners': [('pfasoner', False)],
          'pfilen': [('pfil', False)],
          'pfilens': [('pfil', False)],
          'pfinnar': [('pfinnare', False)],
          'pfinnarna': [('pfinnare', False)],
          'pfinnarnas': [('pfinnare', False)],
          'pfiskar': [('pfisk', False)],
          'pfiskarna': [('pfisk', False)],
          'pfiskarnas': [('pfisk', False)],
          'pfordringar': [('pfordring', False)],
          'pfordringarna': [('pfordring', False)],
          'pfordringarnas': [('pfordring', False)],
          'pfordringars': [('pfordring', False)],
          'pfots': [('pfot', False)],
          'pfots-': [('pfot', False)],
          'pfyrar': [('pfyr', False)],
          'pfår': [('pfår', False)],
          'pfår-': [('pfår', False)],
          'pfårs': [('pfår', False)],
          'pfårs-': [('pfår', False)],
          'pförsäkringar': [('pförsäkring', False)],
          'pförsäkringarna': [('pförsäkring', False)],
          'pförsäkringarnas': [('pförsäkring', False)],
          'pförsäkringars': [('pförsäkring', False)],
          'pgetterna': [('pget', False)],
          'pgiften': [('pgift', False)],
          'pgiftens': [('pgift', False)],
          'pgifts': [('pgift', False)],
          'pgifts-': [('pgift', False)],
          'pgångar': [('pgång', False)],
          'pgångarna': [('pgång', False)],
          'pgångarnas': [('pgång', False)],
          'phalar': [('phalare', False)],
          'phandlar': [('phandlare', False)],
          'phandlarna': [('phandlare', False)],
          'phandlarnas': [('phandlare', False)],
          'phans': [('phane', False)],
          'phans-': [('phane', False)],
          'phas': [('phas', False)],
          'phasen': [('phas', False)],
          'phasens': [('phas', False)],
          'pheter': [('phet', False)],
          'pheterna': [('phet', False)],
          'pheternas': [('phet', False)],
          'pheters': [('phet', False)],
          'phets': [('phets', False)],
          'phets-': [('phet', False)],
          'phin': [('phi', True)],
          'phins': [('phi', True)],
          'phis-': [('phi', True)],
          'phit': [('phi', True)],
          'phits': [('phi', True)],
          'phonas': [('phona', False)],
          'phone': [('phone', False)],
          'phone-': [('phone', False)],
          'phopar': [('phopare', False)],
          'phoparna': [('phopare', False)],
          'phoparnas': [('phopare', False)],
          'phundars': [('phund', False)],
          'phus': [('phus', False)],
          'phylle': [('phylla', False)],
          'phylle-': [('phylla', False)],
          'phälar': [('phäl', False)],
          'phälarna': [('phäl', False)],
          'phälarnas': [('phäl', False)],
          'phänget': [('phänge', False)],
          'phängets': [('phänge', False)],
          'phäst': [('phäst', False)],
          'phästarnas': [('phäst', False)],
          'phästars': [('phäst', False)],
          'phål': [('phål', False)],
          'phål-': [('phål', False)],
          'phåls': [('phål', False)],
          'phåls-': [('phål', False)],
          'phöns': [('phöns', False)],
          'phöns-': [('phöns', False)],
          'pi': [('pi', False)],
          'pi-': [('pi', False)],
          'piar': [('pi', False)],
          'piarna': [('pi', False)],
          'piarnas': [('pi', False)],
          'piars': [('pi', False)],
          'piaster': [('piaster', True)],
          'piasters': [('piaster', True)],
          'piat': [('piat', False)],
          'piater': [('piat', False)],
          'piaters': [('piat', False)],
          'piats': [('piat', False)],
          'piccolor': [('piccolo', True), ('piccola', True)],
          'piccolorna': [('piccolo', True), ('piccola', True)],
          'piccolornas': [('piccolo', True), ('piccola', True)],
          'piccolors': [('piccolo', True), ('piccola', True)],
          'picen': [('pice', False)],
          'picens': [('pice', False)],
          'picier': [('picier', False)],
          'picierna': [('picier', False)],
          'piciers': [('picier', False)],
          'pick-': [('pick', True)],
          'pickar': [('pick', True)],
          'pickarna': [('pick', True)],
          'pickelsens': [('pickels', True)],
          'picks': [('pick', True)],
          'picks-': [('pick', True)],
          'piden': [('pid', False)],
          'pidens': [('pid', False)],
          'pids': [('pid', False)],
          'pie': [('pia', False)],
          'pie-': [('pia', False)],
          'pien': [('pi', False)],
          'piender': [('piend', False)],
          'piendernas': [('piend', False)],
          'pienders': [('piend', False)],
          'piens': [('pi', False)],
          'pier': [('pi', False)],
          'pierna': [('pi', False)],
          'piernas': [('pi', False)],
          'piers': [('pi', False)],
          'piesarna': [('pie', False)],
          'piesarnas': [('pie', False)],
          'piet': [('pi', True)],
          'piets': [('pi', True)],
          'piffen': [('piff', True)],
          'pig': [('piga', True)],
          'pig-': [('piga', True)],
          'pigan': [('piga', False)],
          'pigg': [('pigg', False)],
          'pigg-': [('pigg', False)],
          'piggarna': [('pigg', False)],
          'piggarnas': [('pigg', False)],
          'piggars': [('pigg', False)],
          'piggen': [('pigg', True)],
          'piggens': [('pigg', False)],
          'piggs': [('pigg', True)],
          'piggs-': [('pigg', False)],
          'pigheter': [('pighet', False)],
          'pigheterna': [('pighet', False)],
          'pigheternas': [('pighet', False)],
          'pigheters': [('pighet', False)],
          'pighets-': [('pighet', False)],
          'pigon': [('pigon', False)],
          'pigons': [('pigon', False)],
          'pigs': [('piga', False)],
          'pigs-': [('piga', False)],
          'pikador': [('pikador', True)],
          'pikadors': [('pikador', True)],
          'pikandens': [('pikande', True)],
          'pikarnas': [('pik', False)],
          'piker': [('piker', False)],
          'pikernas': [('piker', False)],
          'pikers': [('piker', False)],
          'pikets': [('piket', True)],
          'pilandets': [('pilande', False)],
          'pilken': [('pilk', True)],
          'pilkens': [('pilk', True)],
          'pilks': [('pilk', True)],
          'pilks-': [('pilk', True)],
          'pill': [('pill', False)],
          'pill-': [('pill', False)],
          'pillans': [('pillan', False)],
          'pillar': [('pillar', False)],
          'pillar-': [('pillar', False)],
          'pillars': [('pillar', False)],
          'pillen': [('pill', False)],
          'piller': [('piller', True)],
          'piller-': [('piller', False)],
          'pillerna': [('piller', True)],
          'pillernas': [('piller', True)],
          'pillers': [('piller', True)],
          'pillet': [('pill', False)],
          'pillets': [('pill', False)],
          'pillrar': [('pillar', False)],
          'pillrarna': [('pillar', False)],
          'pillrarnas': [('pillar', False)],
          'pillrars': [('pillar', False)],
          'pills': [('pill', True)],
          'pills-': [('pill', False)],
          'pilot': [('pilot', False)],
          'pilt': [('pilt', True)],
          'pilt-': [('pilt', False)],
          'pilts': [('pilt', True)],
          'pilts-': [('pilt', False)],
          'pin': [('pi', True), ('pina', True)],
          'pin-': [('pina', True)],
          'pina': [('pina', True), ('pi', True)],
          'pinandens': [('pinande', True)],
          'pinans': [('pina', True)],
          'pinar': [('pinare', False)],
          'pinar-': [('pinare', False)],
          'pinarens': [('pinare', False)],
          'pinarna': [('pinare', False)],
          'pinas': [('pi', True), ('pina', True)],
          'pindlar': [('pindel', False)],
          'pindlarna': [('pindel', False)],
          'pindlarnas': [('pindel', False)],
          'pinell': [('pinell', False)],
          'pinell-': [('pinell', False)],
          'pinells': [('pinell', False)],
          'pinells-': [('pinell', False)],
          'pinets': [('pin', False)],
          'ping': [('ping', False)],
          'ping-': [('ping', False)],
          'pingar': [('ping', False)],
          'pingarna': [('ping', False)],
          'pingarnas': [('ping', False)],
          'pingars': [('ping', False)],
          'pingel': [('pingel', True), ('pingla', True)],
          'pingel-': [('pingel', True), ('pingla', True)],
          'pingen': [('ping', False)],
          'pingens': [('ping', False)],
          'pinglas': [('pingla', False)],
          'pings': [('ping', False)],
          'pings-': [('ping', False)],
          'pinister': [('pinist', False)],
          'pinisters': [('pinist', False)],
          'pink': [('pink', True)],
          'pinn': [('pinne', False)],
          'pinn-': [('pinne', False)],
          'pinnar': [('pinne', True)],
          'pinnarna': [('pinne', False)],
          'pinnarnas': [('pinne', True)],
          'pinnen': [('pinne', False)],
          'pinnens': [('pinne', True)],
          'pinnet': [('pinn', False)],
          'pinns': [('pinne', True)],
          'pinns-': [('pinne', False)],
          'pins': [('pina', True), ('pi', True)],
          'pins-': [('pina', True)],
          'pion': [('pion', False)],
          'pionen': [('pion', False)],
          'pionens': [('pion', False)],
          'pioner': [('pion', False)],
          'pionerna': [('pion', True)],
          'pionernas': [('pion', False)],
          'pioners': [('pion', False)],
          'pions': [('pion', True)],
          'pior': [('pia', False)],
          'piorna': [('pia', False)],
          'piornas': [('pia', False)],
          'piors': [('pia', False)],
          'pip': [('pipa', True), ('pip', True)],
          'pip-': [('pipa', True), ('pip', True)],
          'pipan': [('pipa', False)],
          'pipans': [('pipa', False)],
          'pipar': [('pip', True), ('pipare', True)],
          'piparna': [('pip', True), ('pipare', True)],
          'piparnas': [('pip', True), ('pipare', True)],
          'pipas': [('pipa', False)],
          'pips': [('pipa', True), ('pip', True)],
          'pips-': [('pipa', True), ('pip', True)],
          'pipstoppar': [('pipstopp', True), ('pipstoppare', True)],
          'pipstopparna': [('pipstoppare', True), ('pipstopp', True)],
          'pipstopparnas': [('pipstoppare', True), ('pipstopp', True)],
          'pir': [('pir', True)],
          'pir-': [('pir', True)],
          'pirar': [('pir', True)],
          'pirarna': [('pir', True)],
          'pirarnas': [('pir', True)],
          'piren': [('pir', True)],
          'pirens': [('pir', True)],
          'pirer': [('pir', False)],
          'pirerna': [('pir', True)],
          'pirernas': [('pir', True)],
          'pirers': [('pir', True)],
          'pires': [('pire', False)],
          'pirin': [('pirin', False)],
          'pirins': [('piri', False)],
          'piris': [('piri', False)],
          'pirk': [('pirk', True), ('pirka', True)],
          'pirk-': [('pirk', True), ('pirka', True)],
          'pirke': [('pirka', True)],
          'pirke-': [('pirka', True)],
          'pirks': [('pirk', True), ('pirka', True)],
          'pirks-': [('pirk', True), ('pirka', True)],
          'pirre': [('pirra', True)],
          'pirre-': [('pirra', True)],
          'pirrs': [('pirra', True)],
          'pirrs-': [('pirra', True)],
          'pirs': [('pir', True)],
          'pirs-': [('pir', True)],
          'pis': [('pi', False)],
          'pis-': [('pi', False)],
          'pisarnas': [('pis', False)],
          'pisk': [('pisk', True), ('piska', True)],
          'pisk-': [('pisk', True), ('piska', True)],
          'piskan': [('piska', False)],
          'piskans': [('piska', False)],
          'piskar': [('piskare', False)],
          'piskarnas': [('piskare', False)],
          'piske': [('piska', False)],
          'piske-': [('piska', False)],
          'pisket': [('pisk', True)],
          'pismerna': [('pism', False)],
          'pismernas': [('pism', False)],
          'piss': [('piss', True)],
          'pisserier': [('pisseri', False)],
          'pisseriernas': [('pisseri', False)],
          'pisseriers': [('pisseri', False)],
          'pist-': [('pist', False)],
          'pistarna': [('pist', False)],
          'pisten': [('pist', True)],
          'pistens': [('pist', False)],
          'pister': [('pist', False)],
          'pisterna': [('pist', False)],
          'pisternas': [('pist', False)],
          'pisters': [('pist', False)],
          'pit': [('pi', False)],
          'pita': [('pita', False)],
          'pitarnas': [('pit', False)],
          'pitas': [('pita', False)],
          'piternas': [('pit', False)],
          'pits': [('pi', True)],
          'pits-': [('pits', False)],
          'pitsen': [('pits', False)],
          'pitsens': [('pits', False)],
          'pitt': [('pitt', True)],
          'pitt-': [('pitt', True)],
          'pittar': [('pitt', False)],
          'pittarna': [('pitt', True)],
          'pitten': [('pitt', False)],
          'pitts': [('pitt', False)],
          'pitts-': [('pitt', True)],
          'pium': [('pium', False)],
          'piums': [('pium', False)],
          'pjut': [('pjut', False)],
          'pjut-': [('pjut', False)],
          'pjuten': [('pjut', False)],
          'pjutens': [('pjut', False)],
          'pjutet': [('pjut', False)],
          'pjutets': [('pjut', False)],
          'pjuts': [('pjut', False)],
          'pjuts-': [('pjut', False)],
          'pjäle-': [('pjäla', False)],
          'pkammar': [('pkammare', False)],
          'pkams': [('pkam', False)],
          'pkams-': [('pkam', False)],
          'pklubb': [('pklubb', False)],
          'pklubbs': [('pklubb', False)],
          'pklubbs-': [('pklubb', False)],
          'pknut': [('pknut', False)],
          'pknuts': [('pknut', False)],
          'pknuts-': [('pknut', False)],
          'pkojs': [('pkojs', False)],
          'pkojs-': [('pkojs', False)],
          'pkok': [('pkok', False)],
          'pkok-': [('pkok', False)],
          'pkoks': [('pkok', False)],
          'pkoks-': [('pkok', False)],
          'pkomst-': [('pkomst', False)],
          'pkonst-': [('pkonst', False)],
          'pkonster': [('pkonst', False)],
          'pkonsterna': [('pkonst', False)],
          'pkonsternas': [('pkonst', False)],
          'pkopp': [('pkoppa', False)],
          'pkopp-': [('pkoppa', False)],
          'pkopps': [('pkoppa', False)],
          'pkopps-': [('pkoppa', False)],
          'pkrafter': [('pkraft', False)],
          'pkrafterna': [('pkraft', False)],
          'pkrafters': [('pkraft', False)],
          'pkrafts': [('pkraft', False)],
          'pkrafts-': [('pkraft', False)],
          'pkrans': [('pkran', False)],
          'pkrans-': [('pkran', False)],
          'pkurs': [('pkurs', False)],
          'pkurs-': [('pkur', False)],
          'pkäng': [('pkänga', False)],
          'pkäng-': [('pkänga', False)],
          'pkängs': [('pkänga', False)],
          'pkängs-': [('pkänga', False)],
          'pkärr': [('pkärra', False)],
          'pkärr-': [('pkärra', False)],
          'pkärrs': [('pkärra', False)],
          'pkärrs-': [('pkärra', False)],
          'pkök-': [('pkök', False)],
          'pköks': [('pkök', False)],
          'pköks-': [('pkök', False)],
          'plack': [('plack', False)],
          'plad': [('plada', False)],
          'plad-': [('plada', False)],
          'plads': [('plada', False)],
          'plads-': [('plada', False)],
          'plag': [('plag', False)],
          'plagans': [('plaga', False)],
          'plage': [('plage', True)],
          'plage-': [('plage', True)],
          'plagen': [('plage', True)],
          'plagens': [('plage', True)],
          'plager': [('plage', True)],
          'plagerna': [('plage', True)],
          'plagernas': [('plage', True)],
          'plagers': [('plage', True)],
          'plaget': [('plag', False)],
          'plagor': [('plaga', False)],
          'plagorna': [('plaga', False)],
          'plagornas': [('plaga', False)],
          'plagors': [('plaga', False)],
          'plags': [('plag', False)],
          'plags-': [('plag', False)],
          'plan': [('plan', False)],
          'plan-': [('plan', False)],
          'planden': [('plande', False)],
          'plandena': [('plande', False)],
          'plandenas': [('plande', False)],
          'plandens': [('plande', False)],
          'plandet': [('plande', False)],
          'plandets': [('pland', False)],
          'plane': [('plan', False)],
          'plane-': [('plan', False)],
          'planer': [('plan', False)],
          'planerna': [('plan', False)],
          'planernas': [('plan', False)],
          'planers': [('plan', False)],
          'planet': [('planet', True), ('plan', True)],
          'planets': [('planet', True), ('plan', True)],
          'plank': [('planka', True), ('plank', True)],
          'plank-': [('plank', True), ('planka', True)],
          'planks': [('planka', True), ('plank', True)],
          'planks-': [('planka', True), ('plank', True)],
          'plans': [('plan', False)],
          'plans-': [('plan', False)],
          'plant': [('planta', False)],
          'plantan': [('planta', False)],
          'plantans': [('planta', False)],
          'plants': [('plants', True), ('planta', True)],
          'plants-': [('plants', True), ('planta', True)],
          'plar': [('plare', False)],
          'plaren': [('plare', False)],
          'plarna': [('plare', False)],
          'plarnas': [('plare', False)],
          'plars-': [('plar', False)],
          'plasmat': [('plasma', False)],
          'plasmats': [('plasma', True)],
          'platan': [('platan', True)],
          'plats': [('plats', False)],
          'plats-': [('plats', False)],
          'platt': [('platta', False)],
          'platt-': [('platta', False)],
          'platte': [('platta', False)],
          'platte-': [('platta', False)],
          'platts': [('platta', False)],
          'platts-': [('platta', False)],
          'pleg': [('plega', False)],
          'pleg-': [('plega', False)],
          'plegans': [('plega', False)],
          'plege': [('plega', False)],
          'plegs': [('plega', False)],
          'plegs-': [('plega', False)],
          'plekar': [('plek', False)],
          'plekarna': [('plek', False)],
          'plekarnas': [('plek', False)],
          'pleken': [('plek', False)],
          'pleks-': [('plek', False)],
          'plekter': [('plekter', True)],
          'plekterna': [('plekter', True)],
          'plekters': [('plekter', True)],
          'plektret': [('plekter', True), ('plektrum', True)],
          'plektrets': [('plektrum', True), ('plekter', True)],
          'plementets': [('plement', False)],
          'plements': [('plement', False)],
          'plena': [('plenum', True)],
          'plenas': [('plenum', False)],
          'pler': [('pel', False)],
          'plerna': [('pel', False)],
          'plers': [('pel', False)],
          'plets-': [('plet', False)],
          'plettens': [('plett', False)],
          'pli': [('pli', True)],
          'pli-': [('pli', True)],
          'pliftar': [('plift', False)],
          'pliftarna': [('plift', False)],
          'pliftarnas': [('plift', False)],
          'pliggar': [('pligg', True)],
          'pliggarna': [('pligg', True)],
          'pliggarnas': [('pligg', True)],
          'plighets': [('plighet', False)],
          'plik': [('plik', False)],
          'plik-': [('plik', False)],
          'plikanden': [('plikand', False)],
          'plikandens': [('plikand', False)],
          'pliken': [('plik', False)],
          'plikens': [('plik', False)],
          'pliker': [('plik', False)],
          'plikerna': [('plik', False)],
          'plikernas': [('plik', False)],
          'plikers': [('plik', False)],
          'pliks': [('plik', False)],
          'pliks-': [('plik', False)],
          'plin': [('pli', True)],
          'plin-': [('plin', False)],
          'plina': [('plina', False)],
          'plinas': [('plina', False)],
          'pline': [('plina', False)],
          'plinen': [('plin', False)],
          'plinens': [('plin', False)],
          'pliner': [('plin', False)],
          'plinerna': [('plin', False)],
          'plinernas': [('plin', False)],
          'pliners': [('plin', False)],
          'plinet': [('plin', False)],
          'plingets': [('pling', True)],
          'plins': [('pli', True)],
          'plins-': [('plin', False)],
          'plint-': [('plint', False)],
          'plints': [('plint', False)],
          'plis': [('pli', True)],
          'plis-': [('plisa', False)],
          'pliss-': [('pliss', False)],
          'plister': [('plister', True)],
          'plisters': [('plister', True)],
          'plit': [('plit', True), ('plita', True)],
          'plit-': [('plita', True), ('plit', True)],
          'plitans': [('plita', True)],
          'pliten': [('plit', False)],
          'plitens': [('plit', False)],
          'pliter': [('plit', False)],
          'pliterna': [('plit', False)],
          'pliternas': [('plit', False)],
          'pliters': [('plit', False)],
          'plits': [('plita', True), ('plit', True)],
          'plits-': [('plita', True), ('plit', True)],
          'plitter': [('plitter', False)],
          'plitter-': [('plitter', False)],
          'plitters': [('plitter', False)],
          'plitters-': [('plitter', False)],
          'plock': [('plock', False)],
          'plockar': [('plockare', False)],
          'plockarna': [('plockare', False)],
          'plockarnas': [('plockare', False)],
          'ploden': [('plod', False)],
          'plodens': [('plod', False)],
          'plog': [('plog', False)],
          'plog-': [('plog', False)],
          'plogar': [('plog', False)],
          'plogarna': [('plog', False)],
          'plogarnas': [('plog', False)],
          'plogars': [('plog', False)],
          'plogen': [('plog', False)],
          'plogens': [('plog', True)],
          'plogs': [('plog', True)],
          'plogs-': [('plog', False)],
          'plom': [('plom', False)],
          'plom-': [('plom', False)],
          'ploms': [('plom', False)],
          'plopp': [('plopp', False)],
          'plopps': [('plopp', False)],
          'plopps-': [('plopp', False)],
          'plott': [('plott', False)],
          'plott-': [('plott', False)],
          'plottens': [('plott', False)],
          'plotter': [('plotter', True)],
          'plotters': [('plotter', True)],
          'plottrarnas': [('plotter', False)],
          'plotts': [('plott', False)],
          'plotts-': [('plott', False)],
          'pluggar': [('pluggare', True), ('plugg', True)],
          'pluggarna': [('pluggare', True), ('plugg', True)],
          'pluggarnas': [('pluggare', True), ('plugg', True)],
          'plundrar': [('plundrare', False)],
          'plundrarna': [('plundrare', False)],
          'plunt': [('plunta', False)],
          'plunts-': [('plunta', True)],
          'plusk': [('pluska', True)],
          'plusk-': [('pluska', True)],
          'plut': [('plut', True)],
          'plut-': [('plut', True)],
          'pluts': [('plut', True)],
          'pluts-': [('plut', True)],
          'pluttarna': [('plutt', False)],
          'pluttarnas': [('plutt', False)],
          'plykts': [('plykta', False)],
          'plymer': [('plym', False)],
          'plymers': [('plym', False)],
          'plys': [('ply', False)],
          'plys-': [('ply', False)],
          'plysch': [('plysch', True)],
          'plysch-': [('plysch', True)],
          'plytets': [('plyte', True)],
          'pläd': [('pläd', True)],
          'pläd-': [('pläd', True)],
          'plädar': [('pläd', True)],
          'pläden': [('pläd', True)],
          'plädens': [('pläd', True)],
          'pläder': [('pläd', True)],
          'pläderna': [('pläd', True)],
          'plädernas': [('pläd', True)],
          'pläders': [('pläd', True)],
          'pläds': [('pläd', True)],
          'pläds-': [('pläd', True)],
          'pländer': [('pland', False)],
          'pländerna': [('pland', False)],
          'pländernas': [('pland', False)],
          'pländers': [('pland', False)],
          'plärk': [('plärka', False)],
          'plärk-': [('plärka', False)],
          'plärks': [('plärka', False)],
          'plärks-': [('plärka', False)],
          'pläsandens': [('pläsande', False)],
          'pläsarna': [('pläsare', False)],
          'pläsarnas': [('pläsare', False)],
          'plåders': [('plåd', False)],
          'plåns': [('plån', True)],
          'plåns-': [('plån', False)],
          'plåt': [('plåt', False)],
          'plåtar': [('plåt', False)],
          'plåtarna': [('plåt', False)],
          'plåts': [('plåt', False)],
          'plöje': [('plöja', False)],
          'plöje-': [('plöja', False)],
          'plös': [('plös', True)],
          'plös-': [('plös', True)],
          'plösar': [('plös', True)],
          'plösen': [('plös', True)],
          'plösens': [('plös', True)],
          'pmajor': [('pmaja', False)],
          'pmajors': [('pmaja', False)],
          'pman': [('pman', False)],
          'pmannens': [('pman', False)],
          'pmask': [('pmask', False)],
          'pmask-': [('pmaska', False)],
          'pmaster': [('pmast', False)],
          'pmasters': [('pmast', False)],
          'pmat': [('pmat', False)],
          'pmaten': [('pmat', False)],
          'pmatens': [('pmat', False)],
          'pmats': [('pmat', False)],
          'pmatt': [('pmatta', False)],
          'pmatt-': [('pmatta', False)],
          'pmatte': [('pmatta', False)],
          'pmatte-': [('pmatta', False)],
          'pmatts': [('pmatta', False)],
          'pmatts-': [('pmatta', False)],
          'pmin': [('pmina', False)],
          'pmin-': [('pmina', False)],
          'pmina': [('pmina', False)],
          'pminors': [('pmina', False)],
          'pmins': [('pmina', False)],
          'pmins-': [('pmina', False)],
          'pmän': [('pman', False)],
          'pmäns': [('pman', False)],
          'pmån': [('pmån', False)],
          'pmånen': [('pmån', False)],
          'pmånens': [('pmån', False)],
          'pmåns': [('pmån', False)],
          'pmåns-': [('pmån', False)],
          'pn': [('p', False)],
          'pnader': [('pnad', False)],
          'pnaderna': [('pnad', False)],
          'pnadernas': [('pnad', False)],
          'pnaders': [('pnad', False)],
          'pnads': [('pnad', False)],
          'pnads-': [('pnad', False)],
          'pnamn': [('pnamn', False)],
          'pnamn-': [('pnamn', False)],
          'pnamnen': [('pnamn', False)],
          'pnamnens': [('pnamn', False)],
          'pnamns': [('pnamn', False)],
          'pnamns-': [('pnamn', False)],
          'pnanden': [('pnande', False)],
          'pnar': [('pnare', False)],
          'pnar-': [('pnare', False)],
          'pnaren': [('pnare', False)],
          'pnarens': [('pnare', False)],
          'pnarna': [('pen', False)],
          'pnarnas': [('pnare', False)],
          'pnars': [('pen', False)],
          'pne-': [('pne', False)],
          'pnet': [('pen', False)],
          'pnets': [('pen', False)],
          'pningsdags': [('pningsdags', False)],
          'pningsdags-': [('pningsdags', False)],
          'pningskurs': [('pningskurs', False)],
          'pningskurs-': [('pningskurs', False)],
          'pnisse': [('pnisse', False)],
          'pnosen': [('pnos', False)],
          'pnot': [('pnot', False)],
          'pnot-': [('pnot', False)],
          'pnots': [('pnot', False)],
          'pns': [('p', False)],
          'pnäs': [('pnäsa', False)],
          'pnäs-': [('pnäsa', False)],
          'po': [('po', False)],
          'po-': [('pa', False)],
          'pock-': [('pock', False)],
          'pocken': [('pock', False)],
          'pockens': [('pock', False)],
          'pocket': [('pock', True), ('pocket', True)],
          'pockets': [('pocket', True), ('pock', True)],
          'pocks': [('pock', True)],
          'pocks-': [('pock', True)],
          'poden': [('pod', False)],
          'podens': [('pod', False)],
          'poders': [('pod', False)],
          'podier': [('podium', True)],
          'podierna': [('podium', True)],
          'podiernas': [('podium', True)],
          'pods': [('pod', False)],
          'pods-': [('pod', False)],
          'poet': [('poet', False)],
          'poets': [('poet', False)],
          'pogrammet': [('pogram', True)],
          'pogrammets': [('pogram', True)],
          'pointer': [('pointer', True)],
          'pointers': [('pointer', True)],
          'pojk': [('pojk', True), ('pojke', True)],
          'pojk-': [('pojk', True), ('pojke', True)],
          'pojkar': [('pojke', False)],
          'pojkarna': [('pojke', False)],
          'pojkarnas': [('pojke', False)],
          'pojkars': [('pojke', False)],
          'pojks': [('pojk', True), ('pojke', True)],
          'pojks-': [('pojk', True), ('pojke', True)],
          'poker': [('poker', True)],
          'pokernas': [('pok', False)],
          'pokers': [('poker', True)],
          'pokondriens': [('pokondri', False)],
          'pokondrier': [('pokondri', False)],
          'pokondrierna': [('pokondri', False)],
          'pokondriers': [('pokondri', False)],
          'pol': [('pol', True)],
          'pol-': [('pol', True)],
          'polar': [('polare', True)],
          'polar-': [('polare', True)],
          'polarens': [('polare', False)],
          'polarna': [('polare', True)],
          'polarnas': [('polare', True)],
          'polars': [('pole', False)],
          'pole': [('pole', False)],
          'polemiker': [('polemiker', True), ('polemik', True)],
          'polemikerna': [('polemiker', True), ('polemik', True)],
          'polemikernas': [('polemiker', True), ('polemik', True)],
          'polemikers': [('polemiker', True), ('polemik', True)],
          'polen': [('pol', True)],
          'polens': [('pol', True)],
          'poles': [('pole', False)],
          'poles-': [('pole', False)],
          'polets': [('pol', False)],
          'polin': [('polin', False)],
          'polis': [('polis', False)],
          'politikerna': [('politiker', False)],
          'pollar': [('pollare', True)],
          'pollarna': [('pollare', True)],
          'pollarnas': [('pollare', True)],
          'pollen': [('pollen', True)],
          'pollens': [('pollen', False)],
          'pologier': [('pologi', False)],
          'pologierna': [('pologi', False)],
          'pologiers': [('pologi', False)],
          'polon': [('polo', False)],
          'polons': [('polo', False)],
          'polos': [('polo', False)],
          'polos-': [('polo', True)],
          'pols': [('pol', True)],
          'pols-': [('pol', True)],
          'polskor': [('polsko', True), ('polska', True)],
          'polskorna': [('polsko', True), ('polska', True)],
          'polskornas': [('polsko', True), ('polska', True)],
          'polskors': [('polsko', True), ('polska', True)],
          'polymer': [('polymer', True)],
          'polymers': [('polymer', True)],
          'pomad': [('pomada', True)],
          'pomad-': [('pomada', True)],
          'pomanier': [('pomani', False)],
          'pomanierna': [('pomani', False)],
          'pomaniernas': [('pomani', False)],
          'pomaniers': [('pomani', False)],
          'pomen': [('pom', False)],
          'pomens': [('pom', False)],
          'pområdets': [('pområde', False)],
          'poms': [('pom', False)],
          'pon': [('po', False)],
          'pona': [('po', False)],
          'ponas': [('po', False)],
          'pond': [('pond', True)],
          'pond-': [('pond', True)],
          'ponden': [('pond', False)],
          'pondens': [('pond', True)],
          'pondet': [('pond', True)],
          'ponds': [('pond', True)],
          'ponds-': [('pond', True)],
          'ponens': [('ponens', False)],
          'pong': [('pong', False)],
          'pong-': [('pong', False)],
          'ponger': [('pong', False)],
          'pongerna': [('pong', False)],
          'pongernas': [('pong', False)],
          'pongers': [('pong', False)],
          'pongs': [('pong', False)],
          'pongs-': [('pong', False)],
          'poni': [('poni', False)],
          'poni-': [('poni', False)],
          'ponien': [('poni', False)],
          'poniens': [('poni', False)],
          'ponierna': [('poni', False)],
          'poniers': [('poni', False)],
          'ponin': [('poni', False)],
          'ponins': [('poni', False)],
          'ponis': [('poni', False)],
          'ponk': [('ponk', False)],
          'ponk-': [('ponk', False)],
          'ponken': [('ponk', False)],
          'ponkens': [('ponk', False)],
          'ponks': [('ponk', False)],
          'pons': [('po', False)],
          'pons-': [('pon', False)],
          'ponsen': [('pons', False)],
          'ponsens': [('pons', False)],
          'pontanden': [('pontande', False)],
          'pontandens': [('pontande', False)],
          'ponter': [('pont', False)],
          'ponters': [('pont', False)],
          'pontet': [('ponte', False)],
          'pontets': [('ponte', False)],
          'ponton': [('ponton', True)],
          'pontons': [('ponton', True)],
          'popp': [('popp', True)],
          'popp-': [('popp', True)],
          'poppen': [('popp', True)],
          'poppens': [('popp', True)],
          'popplar': [('poppel', True)],
          'popplarna': [('poppel', False)],
          'popplarnas': [('poppel', False)],
          'popps': [('popp', True)],
          'popps-': [('popp', True)],
          'por': [('por', False)],
          'pora': [('pora', False)],
          'poran': [('pora', False)],
          'porans': [('pora', False)],
          'poras': [('pora', False)],
          'pord': [('pord', False)],
          'pord-': [('pord', False)],
          'porden': [('pord', False)],
          'pordens': [('pord', False)],
          'pords': [('pord', False)],
          'porgierna': [('porgie', False)],
          'porian': [('porian', False)],
          'porians': [('porian', False)],
          'porl': [('porl', True)],
          'porl-': [('porl', True)],
          'porls': [('porl', True)],
          'porls-': [('porl', True)],
          'poros': [('poros', False)],
          'poros-': [('poros', False)],
          'porr': [('porr', False)],
          'porr-': [('porr', False)],
          'porren': [('porr', False)],
          'porrens': [('porr', False)],
          'porrs': [('porr', False)],
          'porrs-': [('porr', False)],
          'pors': [('por', True), ('pors', True)],
          'pors-': [('pors', True), ('por', True)],
          'port': [('port', False)],
          'port-': [('port', False)],
          'portar': [('port', False)],
          'portarna': [('port', False)],
          'portarnas': [('port', True)],
          'porten': [('port', False)],
          'portens': [('port', False)],
          'porter': [('porter', True)],
          'porterna': [('porter', True)],
          'porternas': [('porter', True)],
          'porters': [('porter', True)],
          'portier': [('portier', True)],
          'portiers': [('portier', True)],
          'ports': [('port', False)],
          'ports-': [('port', False)],
          'pos': [('po', False)],
          'pos-': [('po', False)],
          'pose': [('pose', False)],
          'pose-': [('pose', False)],
          'posen': [('pose', False)],
          'posens': [('pose', True)],
          'poser': [('pose', True)],
          'poserna': [('pose', False)],
          'posernas': [('pose', True)],
          'posers': [('pose', False)],
          'posierna': [('posium', False)],
          'posiers': [('posium', False)],
          'positas': [('positas', False)],
          'positet': [('positum', False)],
          'positets': [('positum', False)],
          'post-': [('post', False)],
          'poster': [('poster', True), ('post', True)],
          'posterna': [('post', False)],
          'posternas': [('post', False)],
          'posters': [('poster', True), ('post', True)],
          'postrar': [('poster', True)],
          'postrarna': [('poster', True)],
          'pot': [('pot', False)],
          'potarnas': [('pot', False)],
          'potens': [('potens', False)],
          'potier': [('poti', False)],
          'potierna': [('poti', False)],
          'potiernas': [('poti', False)],
          'potiers': [('poti', False)],
          'potins': [('poti', False)],
          'pots': [('po', False)],
          'pott': [('potta', True), ('pott', True)],
          'pott-': [('potta', True), ('pott', True)],
          'pottar': [('pott', False)],
          'pottarnas': [('pott', False)],
          'pottars': [('pott', False)],
          'potten': [('pott', False)],
          'potter': [('pott', False)],
          'potterna': [('pott', True)],
          'potternas': [('pott', False)],
          'potters': [('pott', False)],
          'potts': [('potta', True), ('pott', True)],
          'potts-': [('potta', True), ('pott', True)],
          'povar': [('pov', False)],
          'pover': [('pover', False)],
          'povers': [('pover', False)],
          'poxins': [('poxi', False)],
          'poyens': [('poy', False)],
          'ppad': [('ppad', False)],
          'ppad-': [('ppad', False)],
          'ppaden': [('ppad', False)],
          'ppadens': [('ppad', False)],
          'ppader': [('ppad', False)],
          'ppaderna': [('ppad', False)],
          'ppadernas': [('ppad', False)],
          'ppaders': [('ppad', False)],
          'ppads': [('ppad', False)],
          'ppande': [('ppande', False)],
          'ppande-': [('ppande', False)],
          'ppardans': [('ppardan', False)],
          'pparen': [('ppare', False)],
          'pparens': [('ppare', False)],
          'ppares': [('ppare', False)],
          'ppars': [('pp', False)],
          'ppas-': [('ppa', False)],
          'ppastor': [('ppasta', False)],
          'ppastors': [('ppasta', False)],
          'ppat': [('ppa', False)],
          'ppats': [('ppa', False)],
          'ppe': [('ppa', False)],
          'ppe-': [('ppa', False)],
          'ppellen': [('ppell', False)],
          'ppellens': [('ppell', False)],
          'ppelsen': [('ppelse', False)],
          'ppelsens': [('ppelse', False)],
          'ppen': [('pp', False)],
          'ppens': [('pp', False)],
          'pperen': [('pper', False)],
          'pperens': [('pper', False)],
          'pperna': [('pp', False)],
          'ppernas': [('pp', False)],
          'ppers': [('pp', False)],
          'ppers-': [('pper', False)],
          'ppersen': [('pper', False)],
          'ppersens': [('pper', False)],
          'ppet': [('pp', False)],
          'ppet-': [('ppet', False)],
          'ppetar': [('ppet', False)],
          'ppetarna': [('ppet', False)],
          'ppetens': [('ppet', False)],
          'ppets-': [('ppet', False)],
          'pphets': [('pphet', False)],
          'ppie': [('ppie', False)],
          'ppie-': [('ppie', False)],
          'ppien': [('ppie', False)],
          'ppiens': [('ppie', False)],
          'ppier': [('ppy', False)],
          'ppierna': [('ppy', False)],
          'ppiernas': [('ppy', False)],
          'ppiers': [('ppy', False)],
          'ppies': [('ppie', False)],
          'ppiesarna': [('ppy', False)],
          'ppiesarnas': [('ppy', False)],
          'ppiker': [('ppik', False)],
          'ppikerna': [('ppik', False)],
          'ppikernas': [('ppik', False)],
          'ppikers': [('ppik', False)],
          'ppin': [('ppi', False)],
          'ppins': [('ppi', False)],
          'ppis': [('ppis', False)],
          'ppis-': [('ppis', False)],
          'ppisar': [('ppis', False)],
          'ppisarna': [('ppisar', False)],
          'ppisarnas': [('ppisar', False)],
          'ppisars': [('ppis', False)],
          'ppkammar': [('ppkam', False)],
          'ppkurs': [('ppkur', False)],
          'pplage': [('pplaga', False)],
          'pplage-': [('pplaga', False)],
          'pplagen': [('pplag', False)],
          'pplagens': [('pplag', False)],
          'pplager': [('pplager', False)],
          'pplagerna': [('pplager', False)],
          'pplagernas': [('pplager', False)],
          'pplagers': [('pplager', False)],
          'pplanden': [('ppland', False)],
          'pplandens': [('ppland', False)],
          'pplandet': [('ppland', False)],
          'pplandets': [('pplande', False)],
          'pplar-': [('pplare', False)],
          'pplarens': [('pplare', False)],
          'pplars': [('ppel', False)],
          'pplen': [('ppel', False)],
          'pplena': [('pple', False)],
          'pplenas': [('pple', False)],
          'pplens': [('ppel', False)],
          'pplet': [('pple', False)],
          'pplets': [('ppel', False)],
          'pplis': [('pplisa', False)],
          'pplös': [('pplösa', False)],
          'pplös-': [('pplösa', False)],
          'ppnarna': [('ppnare', False)],
          'ppo-': [('ppo', False)],
          'pponents': [('pponent', False)],
          'pponents-': [('pponent', False)],
          'ppor': [('ppa', False)],
          'pporna': [('ppa', False)],
          'ppornas': [('ppa', False)],
          'ppors': [('ppa', False)],
          'pporter': [('pport', False)],
          'pporterna': [('pport', False)],
          'pporternas': [('pport', False)],
          'pporters': [('pporter', False)],
          'pposter': [('ppost', False)],
          'pposters': [('ppost', False)],
          'ppot': [('ppo', False)],
          'ppran': [('ppra', False)],
          'pprans': [('ppra', False)],
          'pprets': [('pper', False)],
          'ppring': [('ppring', False)],
          'ppringar': [('ppring', False)],
          'ppringarnas': [('ppring', False)],
          'pprings': [('ppring', False)],
          'pprings-': [('ppring', False)],
          'ppris': [('ppri', False)],
          'ppris-': [('ppri', False)],
          'pprit': [('ppri', False)],
          'pprits': [('ppri', False)],
          'pprockar': [('pprock', False)],
          'pprockarna': [('pprockare', False)],
          'pprockarnas': [('pprockare', False)],
          'pprogrammet': [('pprogram', False)],
          'ppropen': [('pprop', False)],
          'ppropens': [('pprop', False)],
          'pprops': [('pprop', False)],
          'pprops-': [('pprop', False)],
          'ppror': [('ppra', False)],
          'pprors': [('ppra', False)],
          'pprättar': [('pprättare', False)],
          'pprättarna': [('pprättare', False)],
          'ppsarna': [('pp', False)],
          'ppsen': [('pp', False)],
          'ppskor': [('ppsko', False)],
          'ppskors': [('ppsko', False)],
          'ppslandets': [('ppsland', False)],
          'pptorn': [('pptorn', False)],
          'pptorns': [('pptorn', False)],
          'ppurn': [('ppurna', False)],
          'ppurns': [('ppurna', False)],
          'ppurs': [('ppur', False)],
          'ppys': [('ppy', False)],
          'ppysar': [('ppy', False)],
          'ppysarna': [('ppy', False)],
          'ppysarnas': [('ppy', False)],
          'ppysars': [('ppy', False)],
          'prack': [('pracka', True)],
          'prack-': [('pracka', True)],
          'pracks': [('pracka', True)],
          'pracks-': [('pracka', True)],
          'praden': [('prad', False)],
          'praktik': [('praktik', True)],
          'praktik-': [('praktik', True)],
          'praktiker': [('praktiker', True), ('praktik', True)],
          'praktikerna': [('praktiker', True), ('praktik', True)],
          'praktikernas': [('praktiker', True), ('praktik', True)],
          'praktikers': [('praktik', True), ('praktiker', True)],
          'praktiks': [('praktik', True)],
          'praktiks-': [('praktika', False)],
          'pran-': [('pran', False)],
          'prande': [('prande', False)],
          'prande-': [('prande', False)],
          'pranden': [('prande', False)],
          'prandens': [('prande', False)],
          'prandet': [('prande', False)],
          'prans-': [('pran', False)],
          'prarnas': [('per', False)],
          'pras': [('pra', False)],
          'pras-': [('pras', False)],
          'prasslanden': [('prasslande', True)],
          'prasslandens': [('prasslande', True)],
          'prasslandet': [('prasslande', True)],
          'prat': [('prat', False)],
          'prata': [('prata', True)],
          'praten': [('prat', True)],
          'pratens': [('prat', True)],
          'prator': [('prata', True)],
          'prators': [('prata', True)],
          'prats': [('prat', False)],
          'praxis': [('praxis', True)],
          'pray': [('pray', False)],
          'pray-': [('pray', False)],
          'predans': [('preda', False)],
          'prede': [('preda', False)],
          'preds': [('preda', False)],
          'preds-': [('preda', False)],
          'prej': [('prej', False)],
          'prej-': [('prej', False)],
          'prejs': [('prej', False)],
          'prejs-': [('prej', False)],
          'premie': [('premium', True), ('premie', True)],
          'premie-': [('premium', True), ('premie', True)],
          'premien': [('premie', False)],
          'premiens': [('premie', False)],
          'premier': [('premium', True), ('premie', True)],
          'premierna': [('premium', True), ('premie', True)],
          'premiernas': [('premium', True), ('premie', True)],
          'premiers': [('premium', True), ('premie', True)],
          'premiss': [('premiss', True)],
          'premiss-': [('premiss', False)],
          'pren': [('per', False)],
          'prens': [('per', False)],
          'prep': [('prep', False)],
          'prep-': [('prep', False)],
          'prepet': [('prep', False)],
          'prepets': [('prep', False)],
          'preps': [('prep', False)],
          'preps-': [('prep', False)],
          'prese': [('presa', False)],
          'prese-': [('presa', False)],
          'presens': [('presens', True)],
          'preses': [('preses', True)],
          'preses-': [('preses', True)],
          'pressar': [('pressare', True), ('press', True)],
          'pressarna': [('press', True), ('pressare', True)],
          'pressarnas': [('pressare', True), ('press', True)],
          'pret': [('per', False)],
          'pretanden': [('pretande', False)],
          'pretandens': [('pretande', False)],
          'preterna': [('pret', False)],
          'preternas': [('pret', False)],
          'preters': [('pret', False)],
          'prets': [('pret', False)],
          'prets-': [('pret', False)],
          'pri': [('pri', False)],
          'pri-': [('pri', False)],
          'prick': [('prick', False)],
          'prick-': [('prick', True)],
          'prickar': [('prickare', True), ('prick', True)],
          'prickarna': [('prickare', True), ('prick', True)],
          'prickarnas': [('prickare', True), ('prick', True)],
          'pricks': [('prick', True)],
          'pricks-': [('prick', True)],
          'prien': [('pri', False)],
          'priernas': [('pri', False)],
          'priffen': [('priffe', True)],
          'priffens': [('priffe', True)],
          'prighets': [('prighet', False)],
          'prill': [('prilla', True)],
          'prill-': [('prilla', True)],
          'prills': [('prilla', True)],
          'prills-': [('prilla', True)],
          'prim': [('prim', True)],
          'primer': [('primer', True), ('prim', True)],
          'primers': [('primer', True), ('prim', True)],
          'prims': [('prim', True)],
          'prims-': [('prim', True)],
          'prin': [('pri', False)],
          'pringar': [('pringare', False)],
          'pringarna': [('pring', False)],
          'pringarnas': [('pringare', False)],
          'pringornas': [('pringa', False)],
          'pringors': [('pringa', False)],
          'prins': [('prins', False)],
          'printer': [('printer', False)],
          'printerna': [('printer', False)],
          'printernas': [('printer', False)],
          'printers': [('printer', False)],
          'prior': [('prior', True)],
          'priors': [('prior', True)],
          'priot': [('priot', False)],
          'pris': [('pris', False)],
          'pris-': [('pris', False)],
          'prisarna': [('pris', True)],
          'prisen': [('pris', False)],
          'prisens': [('pris', False)],
          'priser': [('pris', False)],
          'priserna': [('pris', True)],
          'prisernas': [('pris', False)],
          'prisers': [('pris', False)],
          'prismat': [('prisma', True)],
          'prismats': [('prisma', True)],
          'prismer': [('prisma', True)],
          'prismerna': [('prisma', False)],
          'prismernas': [('prisma', True)],
          'prismers': [('prisma', True)],
          'prisse': [('prisse', True)],
          'prisse-': [('prisse', False)],
          'prissen': [('prisse', False)],
          'prissens': [('prisse', False)],
          'prit-': [('prit', False)],
          'priterna': [('prit', False)],
          'privatpraktiker': [('privatpraktiker', True), ('privatpraktik', True)],
          'privatpraktikerna': [('privatpraktiker', True), ('privatpraktik', True)],
          'privatpraktikernas': [('privatpraktiker', True), ('privatpraktik', True)],
          'privatpraktikers': [('privatpraktiker', True), ('privatpraktik', True)],
          'privilegie': [('privilegium', False)],
          'privilegie-': [('privilegium', False)],
          'privilegier': [('privilegium', False)],
          'privilegierna': [('privilegium', True)],
          'privilegiernas': [('privilegium', True)],
          'privilegiers': [('privilegium', False)],
          'problemet': [('problem', True)],
          'problemets': [('problem', True)],
          'processen': [('process', True)],
          'processens': [('process', True)],
          'prock': [('prock', False)],
          'prockets': [('prock', False)],
          'proddar': [('proddare', False)],
          'progen': [('prog', True)],
          'progens': [('prog', True)],
          'proggarna': [('proggare', True)],
          'proggarnas': [('proggare', True)],
          'programmet': [('program', True)],
          'programmets': [('program', True)],
          'prominens': [('prominens', True)],
          'proms': [('proms', True)],
          'proms-': [('proms', True)],
          'pronomens': [('pronomen', False)],
          'propeller': [('propell', True), ('propeller', True)],
          'propellers': [('propell', True), ('propeller', True)],
          'propen': [('propen', True)],
          'propens': [('propen', True)],
          'propparna': [('propp', False)],
          'propparnas': [('propp', False)],
          'propps': [('propp', False)],
          'propps-': [('propp', False)],
          'props': [('props', True)],
          'props-': [('props', False)],
          'proren': [('pror', False)],
          'prorens': [('pror', False)],
          'prorna': [('pra', False)],
          'prornas': [('pra', False)],
          'prors-': [('pror', False)],
          'pros': [('pros', False)],
          'pros-': [('pros', False)],
          'prosor': [('prosa', False)],
          'prosorna': [('prosa', False)],
          'prosornas': [('prosa', False)],
          'prosors': [('prosa', False)],
          'prot': [('prot', False)],
          'proten': [('prot', False)],
          'protens': [('prot', False)],
          'protes': [('protes', True)],
          'protes-': [('protes', False)],
          'prots': [('prot', False)],
          'prots-': [('prot', False)],
          'prov': [('prov', False)],
          'prov-': [('prov', False)],
          'proven': [('prov', False)],
          'provens': [('prov', False)],
          'prover': [('prov', False)],
          'proverna': [('prov', False)],
          'provernas': [('prov', False)],
          'provers': [('prov', False)],
          'provs': [('prov', False)],
          'provs-': [('prov', False)],
          'pruens': [('prue', False)],
          'prull': [('prulle', False)],
          'prull-': [('prulle', False)],
          'prulle': [('prulle', False)],
          'prulle-': [('prulle', False)],
          'prulls': [('prulle', False)],
          'prulls-': [('prulle', False)],
          'prums': [('prum', False)],
          'prums-': [('prum', False)],
          'prund': [('prund', False)],
          'prund-': [('prund', False)],
          'prunds': [('prund', False)],
          'prunds-': [('prund', False)],
          'prunkarnas': [('prunkare', False)],
          'prut': [('prut', False)],
          'prut-': [('prut', True)],
          'pruten': [('prut', False)],
          'prutens': [('prut', False)],
          'pruts': [('prut', True)],
          'pruts-': [('prut', False)],
          'prylen': [('pryl', False)],
          'prylens': [('pryl', False)],
          'pryor': [('pryo', True), ('prya', True)],
          'pryorna': [('pryo', True), ('prya', True)],
          'pryornas': [('pryo', True), ('prya', True)],
          'pryors': [('pryo', True), ('prya', True)],
          'prys-': [('prya', True)],
          'präcke': [('präcke', False)],
          'präcken': [('präcke', False)],
          'präckens': [('präcke', False)],
          'präcket': [('präcke', False)],
          'präckets': [('präcke', False)],
          'prällar': [('prälle', True)],
          'prällars': [('prälle', True)],
          'prällen': [('prälle', True)],
          'prängar': [('prängare', False)],
          'prängarna': [('prängare', False)],
          'prängarnas': [('prängare', False)],
          'pränn': [('pränna', False)],
          'pränn-': [('pränna', False)],
          'pränns': [('pränna', False)],
          'pränns-': [('pränna', False)],
          'prättar': [('prätt', False)],
          'prättarna': [('prätt', False)],
          'prättarnas': [('prättare', False)],
          'prättighets-': [('prättighet', False)],
          'pråk': [('pråk', False)],
          'pråk-': [('pråk', False)],
          'pråkar': [('pråkare', False)],
          'pråkarna': [('pråkare', False)],
          'pråkarnas': [('pråkare', False)],
          'pråken': [('pråk', False)],
          'pråkens': [('pråk', False)],
          'pråks': [('pråk', False)],
          'pråks-': [('pråk', False)],
          'prål': [('prål', True)],
          'prål-': [('prål', True)],
          'pråls': [('prål', True)],
          'pråls-': [('prål', True)],
          'pråm': [('pråm', True)],
          'pråm-': [('pråm', True)],
          'pråms': [('pråm', True)],
          'pråms-': [('pråm', True)],
          'pröjs': [('pröjs', True)],
          'pröjs-': [('pröjs', False)],
          'pröjsarna': [('pröjsare', True)],
          'pröjsarnas': [('pröjsare', True)],
          'prökar': [('prökare', False)],
          'prökarna': [('prökare', False)],
          'prökarnas': [('prökare', False)],
          'pröt': [('pröt', False)],
          'pröt-': [('pröt', False)],
          'pröts': [('pröt', False)],
          'prötter': [('prot', False)],
          'prötterna': [('prot', False)],
          'prötternas': [('prot', False)],
          'prötters': [('prot', False)],
          'ps-': [('ps', False)],
          'psan': [('psan', False)],
          'psanden': [('psande', False)],
          'psandens': [('psande', False)],
          'psans': [('psan', False)],
          'psar': [('ps', False)],
          'psarna': [('ps', False)],
          'psarnas': [('p', False)],
          'psars': [('ps', False)],
          'psats': [('psats', False)],
          'psats-': [('psats', False)],
          'psaxar': [('psax', False)],
          'psaxarna': [('psax', False)],
          'psaxarnas': [('psax', False)],
          'psback': [('psbacke', False)],
          'psbackarna': [('psbacke', False)],
          'psbackarnas': [('psbacke', False)],
          'psbacks': [('psbacke', False)],
          'psdagen': [('psdagen', False)],
          'psdagens': [('psdagen', False)],
          'psdans': [('psdans', False)],
          'psdelar': [('psdel', False)],
          'psdelarna': [('psdel', False)],
          'psdelarnas': [('psdel', False)],
          'psdos': [('psdos', False)],
          'psdos-': [('psdos', False)],
          'psel': [('psel', False)],
          'psel-': [('psel', False)],
          'psels': [('psel', False)],
          'psels-': [('psel', False)],
          'psen': [('ps', False)],
          'psens': [('p', False)],
          'pser': [('ps', False)],
          'pserna': [('ps', False)],
          'psernas': [('ps', False)],
          'psers': [('ps', False)],
          'pset': [('ps', False)],
          'psets': [('ps', False)],
          'psgåvornas': [('psgåva', False)],
          'pshandlarna': [('pshandel', False)],
          'pshandlarnas': [('pshandel', False)],
          'pshots': [('pshot', False)],
          'pshots-': [('pshot', False)],
          'pshotsen': [('pshot', False)],
          'pshotsens': [('pshot', False)],
          'psierna': [('psi', False)],
          'psiers': [('psi', False)],
          'psiet': [('psi', True)],
          'psiets': [('psi', True)],
          'psikten': [('psikt', False)],
          'psiktens': [('psikt', False)],
          'psilon': [('psilon', False)],
          'psilons': [('psilon', False)],
          'psin': [('psi', False)],
          'psin-': [('psin', False)],
          'psinen': [('psin', False)],
          'psinens': [('psin', False)],
          'psiner': [('psin', False)],
          'psinerna': [('psin', False)],
          'psinernas': [('psin', False)],
          'psiners': [('psin', False)],
          'psins': [('psi', True)],
          'psins-': [('psin', False)],
          'psis': [('psi', True)],
          'psis-': [('psi', True)],
          'psit': [('psi', True)],
          'psits': [('psi', True)],
          'psjukan': [('psjuka', False)],
          'psk': [('pska', False)],
          'psk-': [('pska', False)],
          'pskak': [('pskaka', False)],
          'pskak-': [('pskaka', False)],
          'pskaks': [('pskaka', False)],
          'pskaks-': [('pskaka', False)],
          'pskallen': [('pskalle', False)],
          'pskallens': [('pskalle', False)],
          'pskan': [('pska', False)],
          'pskans': [('pska', False)],
          'pskasse-': [('pskassa', False)],
          'psken': [('psken', False)],
          'pskens': [('psken', False)],
          'pskens-': [('psken', False)],
          'pskiften': [('pskift', False)],
          'pskiftens': [('pskift', False)],
          'pskiftet': [('pskift', False)],
          'pskiftets': [('pskift', False)],
          'pskjuts': [('pskjut', False)],
          'pskjuts-': [('pskjut', False)],
          'psklocks': [('psklocka', False)],
          'psklocks-': [('psklocka', False)],
          'psko': [('psko', False)],
          'pskojs': [('pskojs', False)],
          'pskojs-': [('pskojs', False)],
          'pskon': [('psko', False)],
          'pskons': [('psko', False)],
          'pskor': [('pska', False)],
          'pskorna': [('psko', False)],
          'pskornas': [('psko', False)],
          'pskors': [('pskors', False)],
          'pskott': [('pskott', False)],
          'pskotten': [('pskott', False)],
          'pskottens': [('pskott', False)],
          'pskramar': [('pskram', False)],
          'pskramarna': [('pskram', False)],
          'pskrams': [('pskram', False)],
          'pskrev': [('pskreva', False)],
          'pskrev-': [('pskreva', False)],
          'pskrevs': [('pskreva', False)],
          'pskrevs-': [('pskreva', False)],
          'pskris': [('pskris', False)],
          'pskytten': [('pskytt', False)],
          'pskyttens': [('pskytt', False)],
          'pskäll': [('pskälla', False)],
          'pskäll-': [('pskälla', False)],
          'pskälls': [('pskälla', False)],
          'pskälls-': [('pskälla', False)],
          'pslag': [('pslag', False)],
          'pslagan': [('pslagan', False)],
          'pslagans': [('pslagan', False)],
          'pslagar': [('pslagare', False)],
          'pslagarna': [('pslagare', False)],
          'pslagarnas': [('pslagare', False)],
          'pslager': [('pslager', False)],
          'pslagernas': [('pslager', False)],
          'pslagers': [('pslager', False)],
          'pslags': [('pslag', False)],
          'pslags-': [('pslag', False)],
          'pslandet': [('psland', False)],
          'pslar': [('psel', False)],
          'pslarna': [('psel', False)],
          'pslarnas': [('psel', False)],
          'psling': [('psling', False)],
          'pslings': [('psling', False)],
          'pslings-': [('psling', False)],
          'psniffar': [('psniffare', False)],
          'psniffarna': [('psniffare', False)],
          'psniffarnas': [('psniffare', False)],
          'pso-': [('pso', False)],
          'psområdet': [('psområde', False)],
          'pson': [('pso', False)],
          'psoner': [('pson', False)],
          'psonerna': [('pson', False)],
          'psonernas': [('pson', False)],
          'psoners': [('pson', False)],
          'psons': [('pson', False)],
          'pspar': [('pspar', False)],
          'pspars': [('pspar', False)],
          'pspets': [('pspets', False)],
          'pspets-': [('pspets', False)],
          'psportarnas': [('psportare', False)],
          'pspris': [('pspris', False)],
          'pssen': [('pssena', False)],
          'pssena': [('pssena', False)],
          'pssens': [('pssena', False)],
          'pssens-': [('pssena', False)],
          'pstak': [('pstak', False)],
          'pstaken': [('pstak', False)],
          'pstakens': [('pstak', False)],
          'pstaket': [('pstak', False)],
          'pstakets': [('pstak', False)],
          'pstaks': [('pstak', False)],
          'pstaks-': [('pstak', False)],
          'pstammar': [('pstam', False)],
          'pstammarna': [('pstam', False)],
          'pstammarnas': [('pstam', False)],
          'pstans': [('pstad', False)],
          'pstarter': [('pstart', False)],
          'pstarterna': [('pstart', False)],
          'pstarternas': [('pstart', False)],
          'pstarters': [('pstart', False)],
          'pstavarna': [('pstav', False)],
          'psteg': [('pstege', False)],
          'psteg-': [('pstege', False)],
          'pstegen': [('psteg', False)],
          'pstegens': [('pstege', False)],
          'pstegs': [('psteg', False)],
          'pstegs-': [('pstege', False)],
          'pstekar': [('pstek', False)],
          'pstekarna': [('pstek', False)],
          'pstekarnas': [('pstek', False)],
          'psten': [('psten', False)],
          'pstens': [('psten', False)],
          'pster': [('pster', False)],
          'psters': [('pster', False)],
          'pstick': [('psticka', False)],
          'pstick-': [('pstick', False)],
          'psticks': [('pstick', False)],
          'psticks-': [('psticka', False)],
          'pstrarnas': [('pster', False)],
          'pstråk': [('pstråk', False)],
          'pstråk-': [('pstråk', False)],
          'pstråken': [('pstråk', False)],
          'pstråkens': [('pstråk', False)],
          'pstråks': [('pstråk', False)],
          'pstråks-': [('pstråk', False)],
          'pstup': [('pstup', False)],
          'pstup-': [('pstup', False)],
          'pstups': [('pstup', False)],
          'pstups-': [('pstup', False)],
          'pstycken': [('pstycke', False)],
          'pstyckena': [('pstycke', False)],
          'pstyckenas': [('pstycke', False)],
          'pstyckens': [('pstycke', False)],
          'pstycket': [('pstycke', False)],
          'pstyckets': [('pstycke', False)],
          'pstycks': [('pstycke', False)],
          'pstyrkan': [('pstyrka', False)],
          'pstyrke': [('pstyrka', False)],
          'pställanden': [('pställande', False)],
          'pställandena': [('pställande', False)],
          'pställandenas': [('pställande', False)],
          'pställandens': [('pställande', False)],
          'pställningar': [('pställning', False)],
          'pställningarna': [('pställning', False)],
          'pställningarnas': [('pställning', False)],
          'pställningars': [('pställning', False)],
          'pställnings': [('pställning', False)],
          'pställnings-': [('pställning', False)],
          'pstövlars': [('pstövel', False)],
          'psugar': [('psug', False)],
          'psupar': [('psupare', False)],
          'psuparna': [('psupare', False)],
          'psuparnas': [('psupare', False)],
          'psval': [('psval', False)],
          'psvalen': [('psval', False)],
          'psvalens': [('psval', False)],
          'psvals': [('psval', False)],
          'psvals-': [('psval', False)],
          'psvar': [('psvara', False)],
          'psvensk': [('psvenska', False)],
          'psvensk-': [('psvenska', False)],
          'psving': [('psving', False)],
          'psving-': [('psving', False)],
          'psvingen': [('psving', False)],
          'psvärmen': [('psvärme', False)],
          'psvärmens': [('psvärme', False)],
          'psyns': [('psyn', False)],
          'psyre': [('psyra', False)],
          'psyre-': [('psyra', False)],
          'psäkringar': [('psäkring', False)],
          'psäkringars': [('psäkring', False)],
          'psås': [('psås', False)],
          'psås-': [('psås', False)],
          'psåt': [('psåt', False)],
          'psåt-': [('psåt', False)],
          'psåten': [('psåt', False)],
          'psåtens': [('psåt', False)],
          'psåts': [('psåt', False)],
          'psåts-': [('psåt', False)],
          'psömmar': [('psöm', False)],
          'psömmarna': [('psöm', False)],
          'psömmarnas': [('psöm', False)],
          'pt': [('pt', False)],
          'pt-': [('pt', False)],
          'ptafsar': [('ptafsare', False)],
          'ptafsarna': [('ptafsare', False)],
          'ptafsarnas': [('ptafsare', False)],
          'ptaget': [('ptag', False)],
          'ptalens': [('ptal', False)],
          'ptan': [('ptan', False)],
          'ptan-': [('ptan', False)],
          'ptana': [('ptum', False)],
          'ptanas': [('ptum', False)],
          'ptans': [('pta', False)],
          'ptans-': [('ptans', False)],
          'ptants': [('ptant', False)],
          'ptarie': [('ptarie', False)],
          'ptarie-': [('ptarie', False)],
          'ptarier': [('ptarie', False)],
          'ptariernas': [('ptarie', False)],
          'ptariers': [('ptarie', False)],
          'pte': [('pta', False)],
          'pte-': [('pta', False)],
          'ptekniker': [('pteknik', False)],
          'pteknikerna': [('pteknik', False)],
          'pteknikernas': [('pteknik', False)],
          'pteknikers': [('pteknik', False)],
          'pten': [('pt', False)],
          'ptens': [('pt', False)],
          'ptens-': [('pten', False)],
          'pter': [('pt', False)],
          'pter-': [('pter', False)],
          'pteranden': [('pterande', False)],
          'pterandens': [('pterande', False)],
          'ptern': [('pter', False)],
          'pterna': [('pt', False)],
          'pternas': [('pt', False)],
          'pterns': [('pter', False)],
          'pters': [('pt', False)],
          'pters-': [('pter', False)],
          'ptet': [('pt', False)],
          'ptets': [('pt', False)],
          'pthet': [('pthet', False)],
          'pthets': [('pthet', False)],
          'ptiden': [('ptid', False)],
          'ptider': [('ptid', False)],
          'ptiders': [('ptid', False)],
          'ptier': [('ptier', False)],
          'ptierna': [('ptier', False)],
          'ptiernas': [('ptier', False)],
          'ptiers': [('ptier', False)],
          'ptik': [('ptik', False)],
          'ptik-': [('ptik', False)],
          'ptiks': [('ptik', False)],
          'ptiks-': [('ptik', False)],
          'ptilen': [('ptil', False)],
          'ptilens': [('ptil', False)],
          'ptillhörighets': [('ptillhörighet', False)],
          'ptillhörighets-': [('ptillhörighet', False)],
          'ptim': [('ptima', False)],
          'ptim-': [('ptima', False)],
          'ptima': [('ptimum', False)],
          'ptiman': [('ptima', False)],
          'ptimas': [('ptimum', False)],
          'ptime': [('ptima', False)],
          'ptime-': [('ptima', False)],
          'ptims': [('ptima', False)],
          'ptims-': [('ptima', False)],
          'ptions-': [('ption', False)],
          'ptippar': [('ptipp', False)],
          'ptipparna': [('ptipp', False)],
          'ptipparnas': [('ptipp', False)],
          'ptisteriets': [('ptisterium', False)],
          'ptit': [('ptit', False)],
          'ptit-': [('ptit', False)],
          'ptits': [('ptit', False)],
          'pto-': [('pto', False)],
          'ptom-': [('ptom', False)],
          'ptoms': [('ptom', False)],
          'pton': [('pto', False)],
          'ptons': [('pto', False)],
          'ptopparnas': [('ptopp', False)],
          'ptops': [('ptop', False)],
          'ptops-': [('ptop', False)],
          'ptopsarna': [('ptop', False)],
          'ptopsarnas': [('ptop', False)],
          'ptopsen': [('ptop', False)],
          'ptopsens': [('ptop', False)],
          'ptor': [('pta', False)],
          'ptorer': [('ptor', False)],
          'ptorerna': [('ptor', False)],
          'ptorernas': [('ptor', False)],
          'ptorers': [('ptor', False)],
          'ptorn': [('ptor', False)],
          'ptorna': [('pta', False)],
          'ptornas': [('pta', False)],
          'ptorns': [('ptor', False)],
          'ptors': [('pta', False)],
          'ptos': [('pto', False)],
          'ptot': [('ptot', False)],
          'ptots': [('ptot', False)],
          'ptrar': [('pter', False)],
          'ptrarna': [('pter', False)],
          'ptrars': [('pter', False)],
          'ptren': [('pter', False)],
          'ptrets': [('pter', False)],
          'ptricks': [('ptrick', False)],
          'ptricks-': [('ptrick', False)],
          'ptrier': [('ptri', False)],
          'ptrierna': [('ptri', False)],
          'ptriers': [('ptri', False)],
          'ptrins': [('ptri', False)],
          'ptrycken': [('ptryck', False)],
          'ptryckens': [('ptryck', False)],
          'ptrycket': [('ptryck', False)],
          'ptryckets': [('ptryck', False)],
          'ptrycks': [('ptryck', False)],
          'ptrycks-': [('ptryck', False)],
          'pträde': [('pträde', False)],
          'pträden': [('pträde', False)],
          'pträdens': [('pträde', False)],
          'pträdet': [('pträde', False)],
          'pträdets': [('pträde', False)],
          'pträds': [('pträde', False)],
          'pträds-': [('pträde', False)],
          'pträn': [('pträ', False)],
          'pträna': [('pträ', False)],
          'ptränas': [('pträ', False)],
          'pträns': [('pträ', False)],
          'pträt': [('pträ', False)],
          'pträts': [('pträ', False)],
          'pts': [('pt', False)],
          'pts-': [('pt', False)],
          'ptum': [('ptum', False)],
          'ptum-': [('ptum', False)],
          'ptumen': [('ptum', False)],
          'ptumens': [('ptum', False)],
          'ptums': [('ptum', False)],
          'ptun': [('ptu', False)],
          'ptuns': [('ptu', False)],
          'ptur-': [('ptur', False)],
          'pturer': [('ptur', False)],
          'pturerna': [('ptur', False)],
          'pturernas': [('ptur', False)],
          'pturers': [('ptur', False)],
          'pturs': [('ptur', False)],
          'ptus': [('ptus', False)],
          'ptus-': [('ptus', False)],
          'ptut': [('ptu', False)],
          'ptuts': [('ptu', False)],
          'ptänger': [('ptång', False)],
          'ptängers': [('ptång', False)],
          'ptåg': [('ptåg', False)],
          'ptågs': [('ptåg', False)],
          'ptågs-': [('ptåg', False)],
          'ptång': [('ptång', False)],
          'ptång-': [('ptång', False)],
          'ptången': [('ptång', False)],
          'ptångens': [('ptång', False)],
          'ptångs': [('ptång', False)],
          'puas': [('pua', False)],
          'puck': [('puck', True)],
          'puck-': [('puck', True)],
          'puckar': [('puck', True), ('puckare', True)],
          'puckarna': [('puck', True), ('puckare', True)],
          'puckarnas': [('puckare', True), ('puck', True)],
          'puckel': [('puckel', True)],
          'puckel-': [('puckel', True)],
          'pucklar': [('puckel', True)],
          'pucklarnas': [('puckel', True)],
          'pucklet': [('puckel', True)],
          'pucklets': [('puckel', True)],
          'pucks': [('puck', True)],
          'pucks-': [('puck', True)],
          'pudel-': [('pudel', False)],
          'puder': [('puder', True)],
          'puders': [('puder', True)],
          'puff': [('puff', False)],
          'puff-': [('puff', True)],
          'puffar': [('puff', False)],
          'puffarna': [('puff', True)],
          'puffs': [('puff', False)],
          'puffs-': [('puff', True)],
          'puk': [('puka', True), ('puke', True)],
          'puk-': [('puke', True), ('puka', True)],
          'pukan': [('puka', True)],
          'pukar': [('puke', True)],
          'pukarna': [('puke', True)],
          'pukarnas': [('puke', True)],
          'pukars': [('puke', True)],
          'pukas': [('puka', True)],
          'puke': [('puke', True), ('puka', True)],
          'puken': [('puke', True)],
          'pukens': [('puke', True)],
          'puks': [('puke', True), ('puka', True)],
          'puks-': [('puka', True), ('puke', True)],
          'pul': [('pula', False)],
          'pul-': [('pula', False)],
          'pula': [('pula', False)],
          'pulan': [('pula', False)],
          'pulans': [('pula', False)],
          'pulens': [('pulens', False)],
          'pulk': [('pulka', True)],
          'pulk-': [('pulka', False)],
          'pulkan': [('pulka', False)],
          'pulkors': [('pulka', False)],
          'pulks': [('pulka', False)],
          'pulks-': [('pulka', True)],
          'pull': [('pulla', True)],
          'pull-': [('pulla', False)],
          'pulle': [('pulla', False)],
          'pulle-': [('pulla', True)],
          'pullen': [('pull', False)],
          'puller': [('pull', False)],
          'pullerna': [('pull', False)],
          'pullernas': [('pull', False)],
          'pullers': [('pull', False)],
          'pulls': [('pulla', False)],
          'pulls-': [('pulla', True)],
          'pulps': [('pulpa', False)],
          'puls': [('puls', False)],
          'puls-': [('puls', False)],
          'pulsar': [('puls', True), ('pulsar', True)],
          'pulsars': [('puls', True), ('pulsar', True)],
          'pult-': [('pult', False)],
          'pulten': [('pult', False)],
          'pultens': [('pult', False)],
          'pulter': [('pult', True)],
          'pults': [('pult', False)],
          'pults-': [('pult', True)],
          'puman': [('puma', True)],
          'pumors': [('puma', True)],
          'pump': [('pumpa', True), ('pump', True)],
          'pump-': [('pump', True), ('pumpa', True)],
          'pumpor': [('pumpa', False)],
          'pumporna': [('pumpa', False)],
          'pumpornas': [('pumpa', False)],
          'pumpors': [('pumpa', False)],
          'pumps': [('pumpa', True), ('pumps', True), ('pump', True)],
          'pumps-': [('pumpa', True), ('pump', True)],
          'pun': [('pun', False)],
          'puncharnas': [('punch', True)],
          'pund': [('pund', False)],
          'pund-': [('pund', False)],
          'pundarnas': [('pundare', True)],
          'punds': [('pund', True)],
          'punds-': [('pund', False)],
          'pung': [('pung', True)],
          'pung-': [('pung', True)],
          'pungar': [('pung', False)],
          'pungarna': [('pung', False)],
          'pungarnas': [('pung', True)],
          'pungars': [('pung', False)],
          'pungen': [('pung', False)],
          'pungens': [('pung', False)],
          'pungs': [('pung', False)],
          'pungs-': [('pung', False)],
          'punk': [('punk', True)],
          'punk-': [('punk', True)],
          'punkar': [('punkare', True)],
          'punkarna': [('punkare', True)],
          'punken': [('punk', True)],
          'punkens': [('punk', True)],
          'punks': [('punk', True)],
          'punks-': [('punk', True)],
          'puns': [('puns', True)],
          'puns-': [('puns', True)],
          'purin': [('purin', False)],
          'purn': [('pur', False)],
          'purnas': [('purna', False)],
          'purne': [('purna', False)],
          'purns': [('pur', False)],
          'purs': [('purs', False)],
          'purt': [('purt', False)],
          'purt-': [('purt', False)],
          'purts': [('purt', False)],
          'purts-': [('purt', False)],
          'pusarnas': [('pus', False)],
          'puss': [('puss', False)],
          'pussar': [('puss', False)],
          'pussars': [('puss', False)],
          'pussel': [('pussel', False)],
          'pussel-': [('pussel', False)],
          'pussen': [('puss', True)],
          'pussens': [('puss', False)],
          'pusskalas': [('pusskalas', True)],
          'pust-': [('pust', False)],
          'pustarna': [('pust', False)],
          'put': [('puta', False)],
          'put-': [('puta', False)],
          'putan': [('puta', False)],
          'putarnas': [('put', False)],
          'puts': [('puta', True), ('puts', True)],
          'puts-': [('puta', True), ('puts', True)],
          'putsanden': [('putsande', False)],
          'putsandens': [('putsande', True)],
          'putsarnas': [('putsare', False)],
          'putsen': [('puts', False)],
          'putsens': [('puts', False)],
          'putt': [('putte', True), ('putt', True)],
          'putt-': [('putte', True), ('putt', True)],
          'puttar': [('putte', True), ('putt', True)],
          'puttarna': [('putte', True), ('putt', True)],
          'puttarnas': [('putte', True), ('putt', True)],
          'puttars': [('putt', True), ('putte', True)],
          'putten': [('putte', True), ('putt', True)],
          'puttens': [('putte', True), ('putt', True)],
          'putter': [('putter', True)],
          'putters': [('putter', True)],
          'putti': [('putto', True)],
          'puttina': [('putto', True)],
          'puttis': [('putto', True)],
          'putts': [('putte', True), ('putt', True)],
          'putts-': [('putte', True), ('putt', True)],
          'pvadar': [('pvad', False)],
          'pvadarna': [('pvad', False)],
          'pvadarnas': [('pvad', False)],
          'pvana': [('pvana', False)],
          'pvanas': [('pvana', False)],
          'pvane-': [('pvana', False)],
          'pvanors': [('pvana', False)],
          'pvant': [('pvante', False)],
          'pvant-': [('pvante', False)],
          'pvantarna': [('pvante', False)],
          'pvante-': [('pvante', False)],
          'pvanten': [('pvante', False)],
          'pvantens': [('pvante', False)],
          'pvants': [('pvante', False)],
          'pvants-': [('pvante', False)],
          'pverben': [('pverb', False)],
          'pverbens': [('pverb', False)],
          'pvind': [('pvind', False)],
          'pvinds': [('pvind', False)],
          'pvinds-': [('pvind', False)],
          'pving': [('pvinge', False)],
          'pving-': [('pvinge', False)],
          'pvingar': [('pvinge', False)],
          'pvingarna': [('pvinge', False)],
          'pvingarnas': [('pvinge', False)],
          'pvingars': [('pvinge', False)],
          'pvingen': [('pvinge', False)],
          'pvingens': [('pvinge', False)],
          'pvings': [('pvinge', False)],
          'pvings-': [('pvinge', False)],
          'pviol': [('pviol', False)],
          'pviol-': [('pviol', False)],
          'pviols': [('pviol', False)],
          'pviols-': [('pviol', False)],
          'pvisa': [('pvisa', False)],
          'pvisas': [('pvisa', False)],
          'pvise': [('pvisa', False)],
          'pvägar': [('pväg', False)],
          'pvägarna': [('pväg', False)],
          'pvägarnas': [('pväg', False)],
          'pvägs': [('pväg', False)],
          'pvärden': [('pvärde', False)],
          'pvärdens': [('pvärde', False)],
          'pvärmar': [('pvärmare', False)],
          'pvärmarna': [('pvärmare', False)],
          'pvärmarnas': [('pvärmare', False)],
          'pväsendet': [('pväsen', False)],
          'pväsendets': [('pväsen', False)],
          'pxen': [('pix', True)],
          'pxens': [('pix', True)],
          'pxet': [('pix', True)],
          'pxets': [('pix', True)],
          'py': [('py', False)],
          'pyans': [('pya', False)],
          'pyckets': [('pycke', True)],
          'pye': [('pya', False)],
          'pye-': [('pya', False)],
          'pyer': [('py', False)],
          'pyerna': [('py', False)],
          'pyernas': [('py', False)],
          'pyers': [('py', False)],
          'pyn': [('py', False)],
          'pyns': [('py', False)],
          'pynt': [('pynt', True)],
          'pyntarna': [('pynt', True)],
          'pyntet': [('pynt', True)],
          'pynts-': [('pynt', True)],
          'pyor': [('pya', False)],
          'pyorna': [('pya', False)],
          'pyornas': [('pya', False)],
          'pyre': [('pyre', True)],
          'pyren': [('pyre', True), ('pyren', True)],
          'pyrens': [('pyre', True), ('pyren', True)],
          'pyrer': [('pyrus', False)],
          'pyrerna': [('pyrus', False)],
          'pyrernas': [('pyrus', False)],
          'pyrers': [('pyr', False)],
          'pyret': [('pyre', True)],
          'pyrets': [('pyre', True)],
          'pyrol': [('pyrola', True)],
          'pyrol-': [('pyrola', True)],
          'pyrols': [('pyrola', True)],
          'pyrs': [('pyre', True)],
          'pyrs-': [('pyre', True)],
          'pys': [('pys', True)],
          'pysar': [('pys', True)],
          'pysarna': [('pys', True)],
          'pysarnas': [('pys', True)],
          'pysars': [('pys', True)],
          'pyt': [('pyt', False)],
          'pyt-': [('pyt', False)],
          'pyts': [('pyts', True)],
          'pyts-': [('pyts', True)],
          'pytsanden': [('pytsande', True)],
          'pytsandens': [('pytsande', True)],
          'pytt': [('pytt', True)],
          'pytt-': [('pytt', True)],
          'pytten': [('pytt', True)],
          'pyttens': [('pytt', True)],
          'pytts': [('pytt', True)],
          'pytts-': [('pytt', True)],
          'päck': [('päck', False)],
          'päck-': [('päck', False)],
          'päcket': [('päck', False)],
          'päcks': [('päck', False)],
          'päcks-': [('päck', False)],
          'pägar': [('pägare', False)],
          'pägarnas': [('pägare', False)],
          'päll': [('päll', False)],
          'päll-': [('päll', False)],
          'pällar': [('päll', True)],
          'pällars': [('päll', False)],
          'pällen': [('päll', False)],
          'pälls': [('päll', False)],
          'pälls-': [('päll', False)],
          'päls-': [('päls', False)],
          'pälsar': [('päls', False)],
          'pälsarna': [('päls', False)],
          'pälsen': [('päls', False)],
          'pälsens': [('päls', False)],
          'pänd': [('pända', False)],
          'pänd-': [('pända', False)],
          'pändar': [('pände', False)],
          'pändarna': [('pände', False)],
          'pänds': [('pända', False)],
          'pänds-': [('pända', False)],
          'pänger': [('pång', False)],
          'pängers': [('pång', False)],
          'pänn': [('pänn', False)],
          'pänn-': [('pänn', False)],
          'pänner': [('pann', False)],
          'pännerna': [('pann', False)],
          'pännernas': [('pann', False)],
          'pänners': [('pann', False)],
          'pänns': [('pänn', False)],
          'päns': [('päns', False)],
          'päns-': [('päns', False)],
          'pärk': [('pärk', True)],
          'pärk-': [('pärk', True)],
          'pärken': [('pärk', True)],
          'pärkens': [('pärk', True)],
          'pärks': [('pärk', True)],
          'pärks-': [('pärk', True)],
          'pärmar': [('pärm', False)],
          'pärmarna': [('pärm', False)],
          'pärmarnas': [('pärm', True)],
          'pärmens': [('pärm', False)],
          'pärr': [('pärr', False)],
          'pärr-': [('pärr', False)],
          'pärrs-': [('pärr', False)],
          'pärs': [('pärs', True), ('pär', True)],
          'pärs-': [('pärs', True), ('pär', True)],
          'pärt': [('pärta', True), ('pärt', True)],
          'pärt-': [('pärta', True), ('pärt', True)],
          'pärter': [('pärt', True)],
          'pärterna': [('pärt', True)],
          'pärternas': [('pärt', True)],
          'pärters': [('pärt', True)],
          'pärts': [('pärt', True), ('pärta', True)],
          'pärts-': [('pärt', True), ('pärta', True)],
          'päsk': [('päsk', True)],
          'päsk-': [('päsk', True)],
          'päskar': [('päsk', True)],
          'päskarna': [('päsk', True)],
          'päskars': [('päsk', True)],
          'pätt': [('pätta', False)],
          'pätt-': [('pätta', False)],
          'pätte': [('pätta', False)],
          'pätte-': [('pätta', False)],
          'pätts': [('pätta', False)],
          'pätts-': [('pätta', False)],
          'på': [('på', False)],
          'på-': [('på', False)],
          'påar': [('påare', False)],
          'påarna': [('påare', False)],
          'påarnas': [('påare', False)],
          'pågarnas': [('påg', True)],
          'påkar': [('påk', False)],
          'påkarna': [('påk', True)],
          'påkarnas': [('påk', False)],
          'pål': [('påle', False)],
          'pål-': [('påle', False)],
          'pålar': [('påle', True)],
          'pålarna': [('påle', True)],
          'pålarnas': [('påle', False)],
          'pålars': [('påle', True)],
          'påle': [('påle', False)],
          'påle-': [('påle', False)],
          'pålen': [('påle', False)],
          'pålens': [('påle', False)],
          'pållar': [('pålle', True)],
          'pållarnas': [('pålle', True)],
          'pålle': [('pålle', True)],
          'pålle-': [('pålle', True)],
          'pållens': [('pålle', True)],
          'påls': [('påle', True)],
          'påls-': [('påle', True)],
          'påna': [('på', False)],
          'pånas': [('på', False)],
          'påne-': [('påna', False)],
          'pång': [('pång', False)],
          'pång-': [('pång', False)],
          'pångar': [('pång', False)],
          'pångarna': [('pång', False)],
          'pångarnas': [('pång', False)],
          'pångars': [('pång', False)],
          'pången': [('pång', False)],
          'pångens': [('pång', False)],
          'pångs': [('pång', False)],
          'pånk': [('pånk', False)],
          'pånk-': [('pånk', False)],
          'pånks': [('pånk', False)],
          'pånor': [('påna', False)],
          'pånornas': [('påna', False)],
          'påns': [('på', False)],
          'pår': [('pår', False)],
          'pår-': [('pår', False)],
          'pårs': [('pår', False)],
          'pårs-': [('pår', False)],
          'pås': [('påse', False)],
          'pås-': [('påse', False)],
          'påsar': [('påse', True)],
          'påsarna': [('påse', False)],
          'påsarnas': [('påse', False)],
          'påsars': [('påse', False)],
          'påse': [('påse', False)],
          'påse-': [('påse', False)],
          'påsen': [('påse', False)],
          'påsens': [('påse', False)],
          'påsk': [('påsk', True)],
          'påsk-': [('påsk', True)],
          'påt': [('påt', True)],
          'påts': [('påt', True)],
          'påvar': [('påve', True)],
          'påvarna': [('påve', False)],
          'påvars': [('påve', False)],
          'påve': [('påve', True)],
          'påve-': [('påve', True)],
          'påven': [('påve', False)],
          'påvens': [('påve', False)],
          'péerna': [('pé', False)],
          'péernas': [('pé', False)],
          'pögat': [('pöga', False)],
          'pögats': [('pöga', False)],
          'pögonen': [('pöga', False)],
          'pögonens': [('pöga', False)],
          'pök': [('pöke', False)],
          'pök-': [('pöke', False)],
          'pöke': [('pöke', False)],
          'pöken': [('pöke', False)],
          'pökens': [('pöke', False)],
          'pöket': [('pöke', False)],
          'pökets': [('pöke', False)],
          'pöks': [('pöke', False)],
          'pöks-': [('pöke', False)],
          'pöls': [('pölsa', True), ('pöl', True)],
          'pöls-': [('pölsa', True), ('pöl', True)],
          'pön': [('pö', False)],
          'pöna': [('pö', False)],
          'pönas': [('pö', False)],
          'pöns': [('pö', False)],
          'pören': [('pör', False)],
          'pörens': [('pör', False)],
          'pörten': [('pörte', True)],
          'pörtens': [('pörte', True)],
          'pörtets': [('pörte', True)],
          'pörts': [('pörte', True)],
          'pörts-': [('pörte', True)],
          'pös': [('pös', True)],
          'pös-': [('pös', True)],
          'pöset': [('pös', True)],
          'pösets': [('pös', True)],
          'pöt': [('pö', False)],
          'pöts': [('pö', False)],
          'qaber': [('qab', False)],
          'qabers': [('qab', False)],
          'qatarier': [('qatarier', True)],
          'qatariernas': [('qatarier', True)],
          'qatariers': [('qatarier', True)],
          'quen': [('que', False)],
          'quer': [('que', False)],
          'querna': [('que', False)],
          'quets': [('quet', False)],
          'quis': [('quis', False)],
          'quis-': [('quis', False)],
          'r': [('r', True)],
          'r-': [('r', True)],
          'ra': [('ra', False)],
          'ra-': [('ra', False)],
          'rabb': [('rabb', False)],
          'rabb-': [('rabb', False)],
          'rabbarna': [('rabb', False)],
          'rabbarnas': [('rabb', False)],
          'rabbars': [('rabb', False)],
          'rabbe': [('rabba', False)],
          'rabbens': [('rabb', False)],
          'rabbin': [('rabbin', True), ('rabbi', True)],
          'rabbins': [('rabbin', True), ('rabbi', True)],
          'rabbis': [('rabbis', True), ('rabbi', True)],
          'rabbs': [('rabba', False)],
          'rabbs-': [('rabb', False)],
          'raber': [('rab', False)],
          'rabers': [('rab', False)],
          'rabil': [('rabil', False)],
          'racen': [('race', False)],
          'racens': [('racen', False)],
          'racer': [('racer', False)],
          'racerna': [('racer', True)],
          'racernas': [('racer', True)],
          'racers': [('racer', True)],
          'rack': [('racka', True), ('rack', True)],
          'rack-': [('rack', True), ('racka', True)],
          'rackar': [('rackare', True), ('rack', True)],
          'rackarna': [('rackare', True), ('rack', True)],
          'rackarnas': [('rackare', True), ('rack', True)],
          'rackars': [('rack', False)],
          'racke': [('racka', False)],
          'racke-': [('racka', False)],
          'racken': [('rack', False)],
          'rackens': [('rack', False)],
          'racker': [('rack', False)],
          'rackers': [('rack', False)],
          'rackersen': [('rackers', False)],
          'racket': [('rack', True), ('racket', True)],
          'rackets': [('racket', True), ('rack', True)],
          'rackor': [('racka', False)],
          'rackorna': [('racka', False)],
          'rackornas': [('racka', False)],
          'rackors': [('racka', False)],
          'racks': [('rack', True), ('racka', True)],
          'racks-': [('racka', True), ('rack', True)],
          'radar': [('radar', True)],
          'radar-': [('radar', True)],
          'radarna': [('radare', False)],
          'radarnas': [('radare', False)],
          'radars': [('radar', True)],
          'radd-': [('radda', True)],
          'rade': [('rad', False)],
          'rade-': [('rade', False)],
          'raden': [('rad', True)],
          'radena': [('rade', False)],
          'radenas': [('rade', False)],
          'radens': [('rad', True)],
          'rades': [('rade', False)],
          'radet': [('rade', False)],
          'radets': [('rad', False)],
          'radier': [('radie', False)],
          'radierna': [('radie', True)],
          'radiernas': [('radie', False)],
          'radiers': [('radie', False)],
          'radiet': [('radium', True)],
          'radiets': [('radium', True)],
          'radions': [('radio', False)],
          'radium': [('radium', True)],
          'radiums': [('radium', True)],
          'radon': [('radon', True)],
          'radons': [('radon', True)],
          'rador': [('rado', False)],
          'radorna': [('rado', False)],
          'radornas': [('rado', False)],
          'radors': [('rador', False)],
          'rados-': [('rado', False)],
          'radosen': [('rado', False)],
          'rads': [('rad', True)],
          'rads-': [('rad', True)],
          'radsdomar': [('radsdomare', False)],
          'radsdomarna': [('radsdomare', False)],
          'radsdomarnas': [('radsdomare', False)],
          'raff': [('raff', False)],
          'raff-': [('raff', False)],
          'raffar': [('raff', False)],
          'raffarna': [('raff', False)],
          'raffen': [('raff', False)],
          'raffer': [('raff', False)],
          'raffers': [('raff', False)],
          'raffet': [('raff', False)],
          'raffets': [('raff', False)],
          'raffs': [('raff', False)],
          'raffs-': [('raff', False)],
          'rafier': [('rafi', False)],
          'rafierna': [('rafi', False)],
          'rafiernas': [('rafi', False)],
          'rafiers': [('rafi', False)],
          'rafiet': [('rafi', False)],
          'rafs': [('rafs', False)],
          'rafs-': [('rafs', False)],
          'rag': [('raga', True)],
          'rag-': [('raga', True)],
          'ragar': [('ragare', False)],
          'ragar-': [('ragare', False)],
          'ragarna': [('rage', False)],
          'ragarnas': [('rage', False)],
          'ragars': [('rage', False)],
          'ragat': [('ragata', True)],
          'ragat-': [('ragata', True)],
          'ragats': [('ragata', True)],
          'ragats-': [('ragata', True)],
          'rage': [('raga', True)],
          'rage-': [('raga', True)],
          'ragen': [('rage', False)],
          'ragens': [('rage', False)],
          'raget': [('rage', False)],
          'ragets': [('rag', False)],
          'ragetter': [('ragett', False)],
          'ragetterna': [('raget', False)],
          'ragetternas': [('raget', False)],
          'ragetters': [('raget', False)],
          'ragg': [('ragg', True)],
          'ragg-': [('ragg', False)],
          'raggar': [('raggare', True)],
          'raggarna': [('raggare', True)],
          'raggarnas': [('raggare', True)],
          'raggars': [('ragg', False)],
          'raggen': [('ragg', True)],
          'raggens': [('ragg', False)],
          'raggs-': [('ragg', True)],
          'ragon': [('ragon', False)],
          'ragons': [('ragon', False)],
          'ragor': [('raga', True)],
          'ragors': [('raga', True)],
          'rags': [('raga', True)],
          'rags-': [('raga', True)],
          'ragun': [('ragu', True)],
          'raguns': [('ragu', True)],
          'ragus': [('ragu', True)],
          'ragvägar': [('ragväg', False)],
          'ragvägarna': [('ragväg', False)],
          'ragvägarnas': [('ragväg', False)],
          'raids': [('raid', False)],
          'raids-': [('raid', False)],
          'rainer': [('rain', False)],
          'rainerna': [('rain', False)],
          'rainernas': [('rain', False)],
          'rainers': [('rain', False)],
          'raj': [('raja', True)],
          'raj-': [('raja', True)],
          'rajans': [('raja', True)],
          'rajas': [('raja', False)],
          'rajor': [('raja', True)],
          'rajs': [('raja', True)],
          'rajs-': [('raja', True)],
          'rak': [('raka', True)],
          'rak-': [('raka', True)],
          'raka': [('raka', False)],
          'rakan': [('raka', True)],
          'rakans': [('raka', True)],
          'rakar': [('rake', False)],
          'rakarna': [('rake', False)],
          'rakars': [('rake', False)],
          'rakas': [('raka', False)],
          'rake': [('raka', True)],
          'raken': [('rake', False)],
          'rakens': [('rake', False)],
          'rakes': [('rake', False)],
          'raket': [('raket', False)],
          'rakets': [('raket', True)],
          'rakors': [('raka', True)],
          'rakos-': [('rakos', False)],
          'rakrits': [('rakrit', False)],
          'raks': [('raka', True)],
          'raks-': [('raka', True)],
          'raktan': [('raktan', False)],
          'raktans': [('raktan', False)],
          'raktat': [('raktat', False)],
          'raktats': [('raktat', False)],
          'rakter': [('rakt', False)],
          'rakters': [('rakt', False)],
          'raktorer': [('raktor', False)],
          'raktorers': [('raktor', False)],
          'raktur': [('raktur', False)],
          'raktur-': [('raktur', False)],
          'rakturs': [('raktur', False)],
          'ralbas': [('ralbas', False)],
          'ralet': [('ral', False)],
          'ralets': [('ral', False)],
          'ralie': [('ralia', False)],
          'ralie-': [('ralia', False)],
          'ralier': [('ral', False)],
          'ralierna': [('ralier', False)],
          'raliernas': [('ral', False)],
          'raliers': [('ral', False)],
          'ralin': [('ralin', False)],
          'ralis': [('ralis', False)],
          'ralj': [('ralj', False)],
          'ralj-': [('ralj', False)],
          'raljans': [('raljans', True)],
          'raljen': [('ralj', False)],
          'raljens': [('ralj', False)],
          'raljer': [('ralj', False)],
          'raljerna': [('ralj', False)],
          'raljernas': [('ralj', False)],
          'raljers': [('ralj', False)],
          'raljs': [('ralj', False)],
          'raljs-': [('ralj', False)],
          'rall': [('rall', False)],
          'rall-': [('rall', False)],
          'rallagen': [('rallag', False)],
          'rallan': [('ralla', False)],
          'rallanden': [('rallande', False)],
          'rallandens': [('rallande', False)],
          'rallandet': [('rallande', False)],
          'rallar': [('rallare', True), ('rall', True)],
          'rallarna': [('rall', True), ('rallare', True)],
          'rallarnas': [('rallare', True), ('rall', True)],
          'rallars': [('rall', False)],
          'ralle': [('ralla', False)],
          'ralle-': [('ralla', False)],
          'rallen': [('rall', False)],
          'raller': [('rall', False)],
          'rallerna': [('rall', False)],
          'rallernas': [('rall', False)],
          'rallers': [('rall', False)],
          'rallor': [('ralla', False)],
          'rallorna': [('ralla', False)],
          'rallornas': [('ralla', False)],
          'ralls': [('rall', False)],
          'ralls-': [('rall', False)],
          'rallöns': [('rallö', False)],
          'rals': [('ral', False)],
          'rals-': [('ral', False)],
          'ram': [('ram', False)],
          'ram-': [('ram', False)],
          'raman': [('rama', False)],
          'raman-': [('ramaner', False)],
          'ramaner': [('ramaner', False)],
          'ramanerna': [('ramaner', False)],
          'ramanernas': [('ramaner', False)],
          'ramaners': [('ramaner', False)],
          'ramans': [('rama', False)],
          'ramans-': [('raman', False)],
          'ramar': [('ram', True)],
          'ramarna': [('ram', True)],
          'ramarnas': [('ram', False)],
          'ramas-': [('rama', False)],
          'ramat': [('rama', False)],
          'ramaten': [('ramaten', False)],
          'ramats': [('rama', False)],
          'ramb': [('ramb', False)],
          'ramb-': [('ramb', False)],
          'ramben': [('ramb', False)],
          'rambens': [('ramb', False)],
          'rambs': [('ramb', False)],
          'rambs-': [('ramb', False)],
          'ramel': [('ramla', False)],
          'ramel-': [('ramla', False)],
          'ramenten': [('rament', False)],
          'ramentens': [('rament', False)],
          'ramentet': [('rament', False)],
          'raments-': [('rament', False)],
          'ramers': [('ram', False)],
          'ramet': [('ram', False)],
          'rameter': [('rameter', False)],
          'rameters': [('rameter', False)],
          'ramets': [('ram', False)],
          'ramin': [('rami', False)],
          'ramins': [('ramin', False)],
          'ramlandet': [('ramlande', True)],
          'ramlandets': [('ramlande', True)],
          'ramlarnas': [('ramlare', False)],
          'rammarna': [('ramm', True)],
          'rammars': [('ramm', True)],
          'rammen': [('ramm', True)],
          'rammens': [('ramm', True)],
          'rammer': [('ram', False)],
          'rammernas': [('ram', False)],
          'ramp': [('ramp', False)],
          'ramp-': [('ramp', False)],
          'ramparnas': [('rampare', False)],
          'rampen': [('ramp', False)],
          'rampens': [('ramp', False)],
          'ramps': [('ramp', False)],
          'ramps-': [('ramp', True)],
          'rams': [('ramsa', True), ('ram', True), ('rams', True)],
          'rams-': [('ram', True), ('ramsa', True), ('rams', True)],
          'ran': [('rana', True)],
          'ran-': [('rana', True)],
          'rana': [('rana', True)],
          'ranan': [('rana', True)],
          'ranans': [('rana', True)],
          'ranarna': [('ran', False)],
          'ranarnas': [('ran', False)],
          'ranas': [('rana', True)],
          'rancen': [('ranc', False)],
          'rancens': [('ranc', False)],
          'rand': [('rand', False)],
          'rand-': [('rand', False)],
          'randa': [('randum', False)],
          'randans': [('randans', False)],
          'randar': [('rand', False)],
          'randarna': [('rande', False)],
          'randarnas': [('rand', False)],
          'randars': [('rand', False)],
          'randas': [('randum', False)],
          'randen': [('rand', False)],
          'randens': [('rand', False)],
          'rander': [('rand', False)],
          'randers': [('rand', False)],
          'randets': [('rande', False)],
          'randflat': [('randflate', False)],
          'rands': [('rand', False)],
          'rands-': [('rand', False)],
          'ranens': [('ran', False)],
          'ranets': [('ran', False)],
          'rang': [('rang', False)],
          'rang-': [('rang', False)],
          'rangen': [('rang', False)],
          'rangens': [('rang', True)],
          'ranger': [('ranger', True)],
          'rangerna': [('rang', False)],
          'rangernas': [('rang', False)],
          'rangers': [('ranger', True)],
          'rangs': [('rang', False)],
          'rangs-': [('rang', True)],
          'rani': [('rani', False)],
          'rani-': [('rani', False)],
          'ranie': [('ranium', False)],
          'ranier': [('ranier', False)],
          'ranierna': [('ranier', False)],
          'raniernas': [('ranium', False)],
          'raniers': [('ranium', False)],
          'raniets': [('ranium', False)],
          'ranis': [('rani', False)],
          'ranits': [('ranit', False)],
          'rank': [('ranka', True)],
          'rank-': [('ranka', True)],
          'rankar': [('rankare', False)],
          'rankar-': [('rankare', False)],
          'rankarna': [('rankare', False)],
          'rankarnas': [('rank', False)],
          'rankars': [('rank', False)],
          'ranke': [('ranka', False)],
          'ranke-': [('ranka', False)],
          'ranken': [('rank', False)],
          'rankens': [('rank', False)],
          'ranker': [('rank', False)],
          'rankerna': [('rank', False)],
          'rankernas': [('rank', False)],
          'rankers': [('rank', False)],
          'rankor': [('ranka', False)],
          'rankorna': [('ranka', False)],
          'rankornas': [('ranka', False)],
          'ranks': [('ranka', True)],
          'ranks-': [('ranka', True)],
          'ranmälningar': [('ranmälning', False)],
          'ranmälningarna': [('ranmälning', False)],
          'ranmälningarnas': [('ranmälning', False)],
          'ranmälningars': [('ranmälning', False)],
          'rannars': [('ranne', False)],
          'rannen': [('rann', False)],
          'rannens': [('ranne', False)],
          'ranner': [('rann', False)],
          'rannerna': [('rann', False)],
          'rannernas': [('rann', False)],
          'ranners': [('rann', False)],
          'rannit': [('ranni', False)],
          'rannits': [('ranni', False)],
          'ranns': [('rann', False)],
          'ranor': [('rana', False)],
          'ranorna': [('rana', True)],
          'ranornas': [('rana', True)],
          'ranors': [('rana', True)],
          'rans': [('rana', True)],
          'rans-': [('rana', True)],
          'ransar': [('rans', False)],
          'ransarna': [('rans', False)],
          'ransars': [('rans', False)],
          'ransen': [('rans', False)],
          'ransens': [('rans', False)],
          'ranser': [('rans', False)],
          'ranserna': [('rans', False)],
          'ransernas': [('rans', False)],
          'ransers': [('rans', False)],
          'ransk': [('ranska', False)],
          'ransk-': [('ranska', False)],
          'ranskarna': [('ranskare', False)],
          'ranstalter': [('ranstalt', False)],
          'ranstalterna': [('ranstalt', False)],
          'ranstalternas': [('ranstalt', False)],
          'ranstalters': [('ranstalt', False)],
          'ranstalts': [('ranstalt', False)],
          'ranstalts-': [('ranstalt', False)],
          'rant': [('rant', False)],
          'ranten': [('rant', False)],
          'rantens': [('rant', False)],
          'ranter': [('rant', False)],
          'ranterna': [('rant', False)],
          'ranternas': [('rant', False)],
          'ranters': [('rant', False)],
          'rantierna': [('ranti', False)],
          'rantin': [('ranti', False)],
          'rantins': [('ranti', False)],
          'rantis': [('ranti', False)],
          'rants-': [('rant', False)],
          'rap': [('rap', False)],
          'rap-': [('rap', True)],
          'rapan': [('rapa', False)],
          'rapans': [('rapa', False)],
          'rapar': [('rapar', False)],
          'raparen': [('rapar', False)],
          'raparens': [('rapare', False)],
          'raparna': [('rapare', False)],
          'raparnas': [('rapare', False)],
          'rapars': [('rapar', False)],
          'rapas': [('rapa', False)],
          'rapats': [('rapat', False)],
          'rapats-': [('rapat', False)],
          'rape': [('rape', False)],
          'rape-': [('rape', False)],
          'rapen': [('rap', True)],
          'rapens': [('rap', True)],
          'rapet': [('rap', True)],
          'rapets': [('rap', False)],
          'rapets-': [('rapets', False)],
          'rapis': [('rapi', False)],
          'rapp': [('rapp', False)],
          'rapp-': [('rapp', False)],
          'rappar': [('rapp', True), ('rappare', True)],
          'rapparna': [('rappare', True), ('rapp', True)],
          'rapparnas': [('rappare', True), ('rapp', True)],
          'rappars': [('rapp', True)],
          'rappe': [('rappa', False)],
          'rappen': [('rapp', False)],
          'rappens': [('rapp', False)],
          'rapps': [('rapp', False)],
          'rapps-': [('rapp', False)],
          'raps': [('rap', True), ('raps', True)],
          'raps-': [('rap', True), ('raps', True)],
          'rar': [('er', False)],
          'rar-': [('rare', False)],
          'rardagen': [('rardag', False)],
          'rardagens': [('rardag', False)],
          'rare': [('rare', False)],
          'rare-': [('rare', False)],
          'raren': [('rare', False)],
          'rarens': [('rare', False)],
          'rares': [('rare', False)],
          'rares-': [('rare', False)],
          'raret': [('rare', False)],
          'rarets': [('rare', False)],
          'rarian': [('raria', False)],
          'rarians': [('raria', False)],
          'rarie': [('rarium', False)],
          'rarie-': [('rarium', False)],
          'rarier': [('rarium', False)],
          'rarierna': [('rarium', False)],
          'rariernas': [('rarium', False)],
          'rariers': [('rarium', False)],
          'raris': [('raria', False)],
          'raris-': [('raria', False)],
          'rarmar': [('rarm', False)],
          'rarmarna': [('rarm', False)],
          'rarmarnas': [('rarm', False)],
          'rarna': [('er', False)],
          'rarnas': [('rare', False)],
          'rars': [('er', False)],
          'rart': [('rart', False)],
          'rarten': [('rart', False)],
          'rartens': [('rart', False)],
          'rarter': [('rart', False)],
          'rarterna': [('rart', False)],
          'rarternas': [('rart', False)],
          'rarters': [('rart', False)],
          'rarv': [('rarv', False)],
          'rarven': [('rarv', False)],
          'rarvens': [('rarv', False)],
          'rarvs': [('rarv', False)],
          'rarvs-': [('rarv', False)],
          'ras': [('ras', True)],
          'ras-': [('ras', True)],
          'rasan': [('rasa', False)],
          'rasans': [('rasa', False)],
          'rasarna': [('ra', False)],
          'rasarnas': [('ra', False)],
          'raschan': [('raschan', False)],
          'rasen': [('ras', True)],
          'rasens': [('ras', True)],
          'raseri': [('raseri', False)],
          'raseri-': [('raseri', True)],
          'raserierna': [('raseri', False)],
          'rasier': [('rasi', False)],
          'rasierna': [('rasi', False)],
          'rasiernas': [('rasier', False)],
          'rasiers': [('rasier', False)],
          'rasins': [('rasi', False)],
          'rasis': [('rasi', False)],
          'rask': [('rask', False)],
          'rask-': [('rask', False)],
          'rasket': [('rask', False)],
          'raskets': [('rask', False)],
          'rasm': [('rasm', False)],
          'rasm-': [('rasm', False)],
          'raspars': [('rasp', True)],
          'raspet': [('rasp', True)],
          'raspets': [('rasp', True)],
          'rass': [('rass', False)],
          'rassar': [('rasse', False)],
          'rassarna': [('rasse', False)],
          'rassarnas': [('rasse', False)],
          'rassen': [('rasse', True)],
          'rassens': [('rasse', True)],
          'rasslanden': [('rasslande', True)],
          'rasslandens': [('rasslande', True)],
          'rasslandet': [('rasslande', True)],
          'rasslandets': [('rasslande', False)],
          'rasslen': [('rassel', False)],
          'rasslens': [('rassel', False)],
          'rast-': [('rast', False)],
          'rastar': [('rast', False)],
          'rastarna': [('rast', False)],
          'rasten': [('rast', True)],
          'rastens': [('rast', True)],
          'raster': [('raster', True), ('rast', True)],
          'rasterna': [('raster', True), ('rast', True)],
          'rasternas': [('raster', True), ('rast', True)],
          'rasters': [('raster', True), ('rast', True)],
          'rastis': [('rasti', False)],
          'rat': [('ra', False)],
          'rata': [('ratum', False)],
          'ratan': [('rata', False)],
          'ratana': [('ratum', False)],
          'ratanas': [('rata', False)],
          'ratar': [('ratare', False)],
          'ratar-': [('ratare', False)],
          'ratarens': [('ratare', False)],
          'ratarna': [('ratare', False)],
          'ratarnas': [('ratare', False)],
          'ratars': [('rat', False)],
          'ratas': [('rata', False)],
          'rate': [('rate', False)],
          'rate-': [('rate', True)],
          'raten': [('rate', True)],
          'ratens': [('rate', True)],
          'rater': [('rate', True)],
          'raterna': [('rate', True)],
          'raternas': [('rate', True)],
          'raters': [('rate', True)],
          'rates': [('rate', True)],
          'rates-': [('rate', True)],
          'ratiden': [('ratiden', False)],
          'ratien': [('rati', False)],
          'ratiens': [('rati', False)],
          'ratier': [('rati', False)],
          'ratierna': [('rati', False)],
          'ratiernas': [('rati', False)],
          'ratin': [('ratin', False)],
          'ratins': [('rati', False)],
          'ration': [('ration', False)],
          'rationen': [('ration', False)],
          'rations': [('ration', False)],
          'rationsdags': [('rationsdag', False)],
          'rationsdags-': [('rationsdag', False)],
          'rativets': [('rativ', False)],
          'raton': [('raton', False)],
          'ratons': [('raton', False)],
          'rator': [('rator', False)],
          'rators': [('rator', False)],
          'ratos': [('rato', False)],
          'ratris': [('ratris', False)],
          'rats': [('ra', False)],
          'rats-': [('rat', False)],
          'ratsarna': [('rats', False)],
          'ratsars': [('rats', False)],
          'ratsen': [('rats', False)],
          'ratsens': [('rats', False)],
          'ratt': [('ratt', False)],
          'ratt-': [('ratt', True)],
          'rattan': [('ratta', False)],
          'rattans': [('ratta', False)],
          'rattar': [('ratt', False)],
          'rattarna': [('ratt', True)],
          'rattarnas': [('ratt', True)],
          'rattars': [('ratt', False)],
          'ratte': [('ratta', False)],
          'ratten': [('ratt', False)],
          'rattet': [('ratt', False)],
          'ratts': [('ratt', False)],
          'ratts-': [('ratt', False)],
          'raut': [('raut', False)],
          'rauten': [('raut', False)],
          'rautens': [('raut', False)],
          'rauts': [('raut', False)],
          'ravan': [('ravan', False)],
          'ravanden': [('ravande', False)],
          'ravandens': [('ravande', False)],
          'ravanens': [('ravan', False)],
          'ravanerna': [('ravan', False)],
          'ravans': [('ravan', False)],
          'ravarna': [('rav', False)],
          'ravars': [('rave', False)],
          'rave': [('rave', False)],
          'rave-': [('rave', False)],
          'raven': [('rave', False)],
          'ravens': [('rave', False)],
          'ravernas': [('rav', False)],
          'ravers-': [('ravers', False)],
          'ravet': [('rav', False)],
          'ravets': [('rav', False)],
          'ravin': [('ravin', True)],
          'ravins': [('ravin', False)],
          'ravis': [('ravis', False)],
          'ravis-': [('ravis', False)],
          'ravor': [('ravor', False)],
          'ravors': [('ravor', False)],
          'raxen': [('raxen', False)],
          'raxens': [('raxen', False)],
          'raxis': [('raxi', False)],
          'ray': [('raya', False)],
          'ray-': [('raya', False)],
          'rayan': [('raya', False)],
          'rays': [('ray', False)],
          'rays-': [('ray', False)],
          'rb': [('rb', False)],
          'rb-': [('rb', False)],
          'rback': [('rback', False)],
          'rback-': [('rback', False)],
          'rbackar': [('rback', False)],
          'rbackarna': [('rback', False)],
          'rbackarnas': [('rback', False)],
          'rbackars': [('rback', False)],
          'rbacken': [('rback', False)],
          'rbackens': [('rback', False)],
          'rbacks': [('rback', False)],
          'rbacks-': [('rback', False)],
          'rbagar': [('rbag', False)],
          'rbagarna': [('rbag', False)],
          'rbagarnas': [('rbag', False)],
          'rbagg': [('rbagge', False)],
          'rbagg-': [('rbagge', False)],
          'rbaggar': [('rbagge', False)],
          'rbaggarna': [('rbagge', False)],
          'rbaggarnas': [('rbagge', False)],
          'rbaggars': [('rbagge', False)],
          'rbaggen': [('rbagge', False)],
          'rbaggens': [('rbagge', False)],
          'rbaggs': [('rbagge', False)],
          'rbaggs-': [('rbagge', False)],
          'rbal': [('rbal', False)],
          'rbalen': [('rbal', False)],
          'rbalens': [('rbal', False)],
          'rbals': [('rbal', False)],
          'rbals-': [('rbal', False)],
          'rban': [('rban', False)],
          'rban-': [('rban', False)],
          'rbanan': [('rbana', False)],
          'rbanans': [('rbana', False)],
          'rbandets': [('rband', False)],
          'rbane': [('rbana', False)],
          'rbane-': [('rbana', False)],
          'rbaner': [('rban', False)],
          'rbaners': [('rban', False)],
          'rbans': [('rban', False)],
          'rbar': [('rbar', False)],
          'rbarens': [('rbar', False)],
          'rbariet': [('rbarium', False)],
          'rbariets': [('rbari', False)],
          'rbarnsmoder': [('rbarnsmor', False)],
          'rbarnsmoder-': [('rbarnsmor', False)],
          'rbarnsmödrar': [('rbarnsmor', False)],
          'rbarnsmödrarna': [('rbarnsmor', False)],
          'rbarnsmödrarnas': [('rbarnsmor', False)],
          'rbarnsmödrars': [('rbarnsmor', False)],
          'rbars': [('rbar', False)],
          'rbas': [('rbas', False)],
          'rbasar': [('rbas', False)],
          'rbasars': [('rbas', False)],
          'rbel': [('rbel', False)],
          'rbel-': [('rbel', False)],
          'rbels': [('rbel', False)],
          'rbels-': [('rbel', False)],
          'rben': [('rben', False)],
          'rben-': [('rbena', False)],
          'rbens': [('rb', False)],
          'rbens-': [('rben', False)],
          'rberis': [('rberis', False)],
          'rberis-': [('rberis', False)],
          'rberna': [('rb', False)],
          'rbernas': [('rb', False)],
          'rbet-': [('rbet', False)],
          'rbetar': [('rbetare', False)],
          'rbetarna': [('rbetare', False)],
          'rbetarnas': [('rbetare', False)],
          'rbete': [('rbeta', False)],
          'rbeten': [('rbet', False)],
          'rbetens': [('rbet', False)],
          'rbetets': [('rbete', False)],
          'rbets': [('rbete', False)],
          'rbets-': [('rbete', False)],
          'rbevis': [('rbevis', False)],
          'rbi': [('rbia', False)],
          'rbi-': [('rbia', False)],
          'rbian': [('rbia', False)],
          'rbians': [('rbia', False)],
          'rbias': [('rbia', False)],
          'rbie': [('rbia', False)],
          'rbie-': [('rbia', False)],
          'rbiet': [('rbium', False)],
          'rbiets': [('rbium', False)],
          'rbil': [('rbil', False)],
          'rbil-': [('rbil', False)],
          'rbilar': [('rbil', False)],
          'rbilars': [('rbil', False)],
          'rbils': [('rbil', False)],
          'rbils-': [('rbil', False)],
          'rbin': [('rbin', False)],
          'rbiner': [('rbin', False)],
          'rbinerna': [('rbin', False)],
          'rbinernas': [('rbin', False)],
          'rbiners': [('rbin', False)],
          'rbins': [('rbin', False)],
          'rbis': [('rbia', False)],
          'rbit': [('rbit', False)],
          'rbits': [('rbit', False)],
          'rbits-': [('rbit', False)],
          'rblernas': [('rbel', False)],
          'rblom': [('rblomma', False)],
          'rblom-': [('rblomma', False)],
          'rbloms': [('rblomma', False)],
          'rbloms-': [('rblomma', False)],
          'rbläck': [('rbläck', False)],
          'rbläck-': [('rbläck', False)],
          'rbläcks': [('rbläck', False)],
          'rbläcks-': [('rbläck', False)],
          'rboj': [('rboj', False)],
          'rboj-': [('rboj', False)],
          'rbojar': [('rboj', False)],
          'rbojars': [('rboj', False)],
          'rbojs': [('rboj', False)],
          'rbojs-': [('rboj', False)],
          'rbol': [('rbol', False)],
          'rbol-': [('rbol', False)],
          'rbolaget': [('rbolag', False)],
          'rbolen': [('rbol', False)],
          'rbolens': [('rbol', False)],
          'rbols': [('rbol', False)],
          'rbomb': [('rbomb', False)],
          'rbomber': [('rbomb', False)],
          'rbomberna': [('rbomb', False)],
          'rbombernas': [('rbomb', False)],
          'rbombers': [('rbomb', False)],
          'rbombs': [('rbomb', False)],
          'rbombs-': [('rbomb', False)],
          'rbon': [('rbon', False)],
          'rbond': [('rbonde', False)],
          'rbond-': [('rbonde', False)],
          'rbondens': [('rbonde', False)],
          'rbons': [('rbon', False)],
          'rbor': [('rbo', False)],
          'rborgar': [('rborg', False)],
          'rborgarna': [('rborg', False)],
          'rborgarnas': [('rborg', False)],
          'rborgen': [('rborg', False)],
          'rborgens': [('rborg', False)],
          'rbors': [('rbo', False)],
          'rborst': [('rborste', False)],
          'rborst-': [('rborste', False)],
          'rborsten': [('rborste', False)],
          'rborstens': [('rborste', False)],
          'rboxar': [('rbox', False)],
          'rboxarna': [('rbox', False)],
          'rboxarnas': [('rbox', False)],
          'rbranden': [('rbrand', False)],
          'rbrandens': [('rbrand', False)],
          'rbre': [('rbre', False)],
          'rbrena': [('rbre', False)],
          'rbrenas': [('rbre', False)],
          'rbrens': [('rbre', False)],
          'rbrodern': [('rbror', False)],
          'rbroderns': [('rbror', False)],
          'rbroders': [('rbror', False)],
          'rbroms': [('rbroms', False)],
          'rbromsar': [('rbroms', False)],
          'rbromsarna': [('rbroms', False)],
          'rbromsarnas': [('rbroms', False)],
          'rbror': [('rbror', False)],
          'rbrors-': [('rbror', False)],
          'rbrs-': [('rbre', False)],
          'rbrytar': [('rbrytare', False)],
          'rbrytarna': [('rbrytare', False)],
          'rbrytarnas': [('rbrytare', False)],
          'rbräck': [('rbräcka', False)],
          'rbräck-': [('rbräcka', False)],
          'rbräcks': [('rbräcka', False)],
          'rbräcks-': [('rbräcka', False)],
          'rbräds': [('rbräda', False)],
          'rbräds-': [('rbräda', False)],
          'rbråk': [('rbråk', False)],
          'rbråks': [('rbråk', False)],
          'rbråks-': [('rbråk', False)],
          'rbröder': [('rbror', False)],
          'rbrödernas': [('rbror', False)],
          'rbs': [('rb', False)],
          'rbs-': [('rb', False)],
          'rbuggen': [('rbug', False)],
          'rbuggens': [('rbug', False)],
          'rbut': [('rbut', False)],
          'rbuts': [('rbut', False)],
          'rbyx': [('rbyxa', False)],
          'rbyx-': [('rbyxa', False)],
          'rbyxorna': [('rbyxa', False)],
          'rbyxornas': [('rbyxa', False)],
          'rbäcken': [('rbäck', False)],
          'rbäckens': [('rbäcken', False)],
          'rbälte': [('rbälte', False)],
          'rbärs': [('rbär', False)],
          'rbärs-': [('rbär', False)],
          'rbåg': [('rbåge', False)],
          'rbåg-': [('rbåge', False)],
          'rbågs': [('rbåge', False)],
          'rbågs-': [('rbåge', False)],
          'rbön-': [('rböna', False)],
          'rböne': [('rböna', False)],
          'rböne-': [('rböna', False)],
          'rböns': [('rböna', False)],
          'rböns-': [('rböna', False)],
          'rcell': [('rcell', False)],
          'rcenter': [('rcenter', False)],
          'rcentrer': [('rcentrum', False)],
          'rcentrerna': [('rcentrum', False)],
          'rcentrernas': [('rcentrum', False)],
          'rcentrers': [('rcentrum', False)],
          'rcentret': [('rcenter', False)],
          'rcentrets': [('rcenter', False)],
          'rcer': [('rce', False)],
          'rcis': [('rcis', False)],
          'rcis-': [('rcis', False)],
          'rcor': [('rca', False)],
          'rcorna': [('rca', False)],
          'rcornas': [('rca', False)],
          'rd': [('rd', False)],
          'rd-': [('rd', False)],
          'rda': [('rde', False)],
          'rda-': [('rde', False)],
          'rdagar': [('rdag', False)],
          'rdagarna': [('rdag', False)],
          'rdagarnas': [('rdag', False)],
          'rdagars': [('rdag', False)],
          'rdagen': [('rdag', False)],
          'rdagens': [('rdag', False)],
          'rdags': [('rdag', False)],
          'rdags-': [('rdag', False)],
          'rdanden': [('rdande', False)],
          'rdandens': [('rdande', False)],
          'rdaren': [('rdare', False)],
          'rdars': [('rd', False)],
          'rdas-': [('rdas', False)],
          'rdaten': [('rdat', False)],
          'rdatens': [('rdat', False)],
          'rdator': [('rdator', False)],
          'rdators': [('rdator', False)],
          'rdats': [('rdat', False)],
          'rdbits': [('rdbi', False)],
          'rdborr': [('rdborr', False)],
          'rdborr-': [('rdborr', False)],
          'rdborrar': [('rdborr', False)],
          'rdborrarna': [('rdborr', False)],
          'rdborrarnas': [('rdborr', False)],
          'rdborrars': [('rdborr', False)],
          'rdborren': [('rdborr', False)],
          'rdborrens': [('rdborr', False)],
          'rdborrs': [('rdborr', False)],
          'rdborrs-': [('rdborr', False)],
          'rddans': [('rddans', False)],
          'rddelar': [('rddel', False)],
          'rddelarna': [('rddel', False)],
          'rddelarnas': [('rddel', False)],
          'rde': [('rda', False)],
          'rde-': [('rda', False)],
          'rdeg': [('rdeg', False)],
          'rdegs-': [('rdeg', False)],
          'rdel': [('rdel', False)],
          'rdelandet': [('rdelande', False)],
          'rdelars': [('rdel', False)],
          'rdels': [('rdel', False)],
          'rdels-': [('rdel', False)],
          'rden': [('rd', False)],
          'rdens': [('rd', False)],
          'rdens-': [('rden', False)],
          'rder': [('rd', False)],
          'rder-': [('rder', False)],
          'rderits': [('rderi', False)],
          'rdern': [('rder', False)],
          'rderna': [('rd', False)],
          'rdernas': [('rd', False)],
          'rderns': [('rder', False)],
          'rders': [('rd', False)],
          'rders-': [('rder', False)],
          'rdet': [('rd', False)],
          'rdian': [('rdia', False)],
          'rdians': [('rdian', False)],
          'rdie': [('rdie', False)],
          'rdie-': [('rdie', False)],
          'rdien': [('rdie', False)],
          'rdiens': [('rdie', False)],
          'rdier': [('rdi', False)],
          'rdierna': [('rdion', False)],
          'rdiernas': [('rdier', False)],
          'rdiers': [('rdier', False)],
          'rdies': [('rdie', False)],
          'rdiet': [('rdion', False)],
          'rdiets': [('rdion', False)],
          'rdin': [('rdin', False)],
          'rdinar': [('rdinare', False)],
          'rdinar-': [('rdinare', False)],
          'rdinaren': [('rdinare', False)],
          'rdinarens': [('rdinare', False)],
          'rding': [('rding', False)],
          'rding-': [('rding', False)],
          'rdingar': [('rding', False)],
          'rdingarna': [('rding', False)],
          'rdingarnas': [('rding', False)],
          'rdingars': [('rding', False)],
          'rdingen': [('rding', False)],
          'rdingens': [('rding', False)],
          'rdings': [('rding', False)],
          'rdings-': [('rding', False)],
          'rdins': [('rdin', False)],
          'rdions': [('rdion', False)],
          'rdis': [('rdis', False)],
          'rdisan': [('rdisan', False)],
          'rdisans': [('rdisan', False)],
          'rdisk': [('rdiska', False)],
          'rdisk-': [('rdiska', False)],
          'rdiskar': [('rdisk', False)],
          'rdiskarna': [('rdisk', False)],
          'rdiskarnas': [('rdisk', False)],
          'rdivan': [('rdiva', False)],
          'rdivans': [('rdiva', False)],
          'rdjävlar': [('rdjävul', False)],
          'rdjävlarna': [('rdjävul', False)],
          'rdjävlarnas': [('rdjävul', False)],
          'rdjävlars': [('rdjävul', False)],
          'rdlar': [('rdel', False)],
          'rdlarna': [('rdel', False)],
          'rdlarnas': [('rdel', False)],
          'rdlars': [('rdel', False)],
          'rdmåns': [('rdmån', False)],
          'rdock-': [('rdocka', False)],
          'rdocks': [('rdocka', False)],
          'rdogen': [('rdog', False)],
          'rdogens': [('rdog', False)],
          'rdomar': [('rdom', False)],
          'rdomarnas': [('rdom', False)],
          'rdomen': [('rdom', False)],
          'rdon': [('rdon', False)],
          'rdon-': [('rdon', False)],
          'rdonnans': [('rdonnans', False)],
          'rdons': [('rdon', False)],
          'rdons-': [('rdon', False)],
          'rdor': [('rda', False)],
          'rdorna': [('rda', False)],
          'rdornas': [('rda', False)],
          'rdors': [('rda', False)],
          'rdramer': [('rdrama', False)],
          'rdramerna': [('rdrama', False)],
          'rdramernas': [('rdrama', False)],
          'rdrars': [('rder', False)],
          'rdricks': [('rdricka', False)],
          'rdricks-': [('rdricka', False)],
          'rdriv': [('rdriv', False)],
          'rdriv-': [('rdriv', False)],
          'rdriven': [('rdriv', False)],
          'rdrivens': [('rdriv', False)],
          'rdrivs': [('rdriv', False)],
          'rdrivs-': [('rdriv', False)],
          'rdroppar': [('rdroppar', False)],
          'rdropparna': [('rdroppar', False)],
          'rdropparnas': [('rdroppar', False)],
          'rdroppars': [('rdroppar', False)],
          'rdropps': [('rdroppar', False)],
          'rdropps-': [('rdroppar', False)],
          'rdrotens': [('rdrot', False)],
          'rdrots': [('rdrot', False)],
          'rdrots-': [('rdrot', False)],
          'rdrömmar': [('rdröm', False)],
          'rdrömmarna': [('rdröm', False)],
          'rdrömmarnas': [('rdröm', False)],
          'rds': [('rd', False)],
          'rds-': [('rd', False)],
          'rdsarna': [('rd', False)],
          'rdsarnas': [('rd', False)],
          'rdsbön': [('rdsbön', False)],
          'rdsböns': [('rdsböna', False)],
          'rdsböns-': [('rdsbön', False)],
          'rdsdagar': [('rdsdag', False)],
          'rdsdagarna': [('rdsdag', False)],
          'rdsdagarnas': [('rdsdag', False)],
          'rdsdagars': [('rdsdag', False)],
          'rdsdags': [('rdsdag', False)],
          'rdsdags-': [('rdsdag', False)],
          'rdsen': [('rd', False)],
          'rdsens': [('rd', False)],
          'rdsken': [('rdsken', False)],
          'rdskens': [('rdsken', False)],
          'rdskotts': [('rdskott', False)],
          'rdskrafter': [('rdskraft', False)],
          'rdskrafterna': [('rdskraft', False)],
          'rdskrafternas': [('rdskraft', False)],
          'rdskrafters': [('rdskraft', False)],
          'rdskrafts': [('rdskraft', False)],
          'rdskrafts-': [('rdskraft', False)],
          'rdslanden': [('rdslande', False)],
          'rdslandens': [('rdslande', False)],
          'rdslandet': [('rdslande', False)],
          'rdslandets': [('rdsland', False)],
          'rdstalets': [('rdstalet', False)],
          'rdsuparna': [('rdsup', False)],
          'rdsuparnas': [('rdsup', False)],
          'rdsvar': [('rdsvar', False)],
          'rdsverket': [('rdsverk', False)],
          'rdträn': [('rdträd', False)],
          'rdträns': [('rdträd', False)],
          'rdu': [('rdu', False)],
          'rdu-': [('rdu', False)],
          'rdubblar': [('rdubbel', False)],
          'rdubblarna': [('rdubbel', False)],
          'rdubblarnas': [('rdubbel', False)],
          'rdull': [('rdull', False)],
          'rdulls': [('rdull', False)],
          'rdungen': [('rdunge', False)],
          'rduns': [('rdun', False)],
          'rduns-': [('rdun', False)],
          'rduor': [('rduo', False)],
          'rduorna': [('rduo', False)],
          'rduors': [('rduo', False)],
          'rdus': [('rdu', False)],
          'rdvägens': [('rdväg', False)],
          'rdyrken': [('rdyrke', False)],
          'rdyrkens': [('rdyrke', False)],
          'rdängar': [('rdängare', False)],
          'rdängarna': [('rdängare', False)],
          'rdåligheter': [('rdålighet', False)],
          'rdåligheterna': [('rdålighet', False)],
          'rdåligheternas': [('rdålighet', False)],
          'rdåligheters': [('rdålighet', False)],
          'rdålighets': [('rdålighet', False)],
          'rdålighets-': [('rdålighet', False)],
          're': [('re', False)],
          're-': [('re', False)],
          'realen': [('reale', True), ('real', True)],
          'realens': [('reale', True), ('real', True)],
          'rean': [('rea', True)],
          'reans': [('rea', True)],
          'rear': [('re', False)],
          'rearna': [('re', False)],
          'reas': [('rea', True)],
          'reasen': [('reas', False)],
          'reasens': [('reas', False)],
          'reaser': [('reas', False)],
          'reaserna': [('reas', False)],
          'reasernas': [('reas', False)],
          'reasers': [('reas', False)],
          'rebror': [('rebror', False)],
          'reck': [('reck', False)],
          'reck-': [('reck', False)],
          'recken': [('reck', False)],
          'reckens': [('reck', False)],
          'recks': [('reck', False)],
          'recks-': [('reck', False)],
          'red': [('reda', False)],
          'red-': [('reda', False)],
          'redan': [('reda', False)],
          'redans': [('reda', True)],
          'redans-': [('redans', False)],
          'redar': [('redare', False)],
          'redar-': [('redare', True)],
          'redarens': [('redare', True)],
          'redarna': [('redare', False)],
          'redd': [('redd', False)],
          'redd-': [('redd', False)],
          'redds': [('redd', False)],
          'redds-': [('redd', False)],
          'rede': [('rede', False)],
          'rede-': [('reda', False)],
          'reden': [('rede', False)],
          'redens': [('rede', False)],
          'redes': [('rede', True)],
          'redes-': [('rede', False)],
          'redet': [('rede', True)],
          'redets': [('rede', True)],
          'redon': [('redo', False)],
          'redons': [('redo', False)],
          'reds': [('rede', True)],
          'reds-': [('rede', True)],
          'ree': [('rea', False)],
          'ree-': [('rea', False)],
          'reen': [('re', False)],
          'reens': [('re', False)],
          'reer': [('re', False)],
          'reerna': [('re', False)],
          'reernas': [('re', False)],
          'reers': [('re', False)],
          'reffekterna': [('reffekt', False)],
          'regalen': [('regale', True), ('regal', True)],
          'regalens': [('regale', True), ('regal', True)],
          'regales': [('regale', True)],
          'regals': [('regal', True), ('regale', True)],
          'regals-': [('regale', True), ('regal', True)],
          'regatt': [('regatta', True)],
          'regatt-': [('regatta', True)],
          'regatts': [('regatta', True)],
          'regatts-': [('regatta', True)],
          'regerna': [('reg', False)],
          'regernas': [('reg', False)],
          'regionen': [('region', False)],
          'regionens': [('region', False)],
          'regis': [('regi', True)],
          'regs': [('reg', False)],
          'regångar': [('regångare', False)],
          'regångarna': [('regångare', False)],
          'rejar': [('rejare', False)],
          'rejarna': [('rejare', False)],
          'rejarnas': [('rejare', False)],
          'rejden': [('rejd', False)],
          'rejdens': [('rejd', False)],
          'rejkar': [('rejkare', False)],
          'rejkarnas': [('rejkare', False)],
          'rejor': [('rej', False)],
          'rejorna': [('rej', False)],
          'rejornas': [('rej', False)],
          'rejors': [('rej', False)],
          'rek': [('rek', True)],
          'rek-': [('rek', False)],
          'reker': [('rek', False)],
          'rekers': [('rek', False)],
          'reket': [('rek', True)],
          'rekets': [('rek', True)],
          'reks': [('rek', True)],
          'reks-': [('rek', True)],
          'rektiven': [('rektiv', False)],
          'rektivens': [('rektiv', False)],
          'relar-': [('relare', False)],
          'relare': [('relare', False)],
          'relarens': [('relare', False)],
          'relares': [('relare', False)],
          'reldar': [('reld', False)],
          'reldarna': [('reld', False)],
          'reldarnas': [('reld', False)],
          'relers': [('rel', False)],
          'religionskritiker': [('religionskritiker', True), ('religionskritik', True)],
          'religionskritikerna': [('religionskritiker', True), ('religionskritik', True)],
          'religionskritikernas': [('religionskritiker', True), ('religionskritik', True)],
          'religionskritikers': [('religionskritiker', True), ('religionskritik', True)],
          'relikens': [('relik', True)],
          'rell': [('rell', False)],
          'rell-': [('rell', False)],
          'rellan': [('rella', False)],
          'rellen': [('rell', False)],
          'reller': [('rell', False)],
          'rellerna': [('rell', False)],
          'rellernas': [('rell', False)],
          'rellers': [('rell', False)],
          'rells': [('rell', False)],
          'rells-': [('rell', False)],
          'rem': [('rem', False)],
          'rem-': [('rem', False)],
          'reman': [('rema', False)],
          'remans': [('rema', False)],
          'remen': [('rem', True)],
          'remens': [('rem', True)],
          'rementen': [('rement', False)],
          'rementens': [('rement', False)],
          'rementet': [('rement', False)],
          'rements-': [('rement', False)],
          'remer': [('reme', False)],
          'remerna': [('reme', False)],
          'remernas': [('reme', False)],
          'remers': [('reme', False)],
          'remien': [('remi', False)],
          'remiens': [('remi', False)],
          'remier': [('remi', True)],
          'remierna': [('remi', True)],
          'remiernas': [('remi', True)],
          'remiers': [('remi', True)],
          'remis': [('remis', True), ('remi', True)],
          'remiss': [('remissa', True), ('remiss', True)],
          'remiss-': [('remissa', True), ('remiss', True)],
          'remits': [('remit', False)],
          'remmar': [('remmare', True), ('rem', True)],
          'remmarna': [('remmare', True), ('rem', True)],
          'remmarnas': [('remmare', True), ('rem', True)],
          'rems': [('rem', True), ('remsa', True)],
          'rems-': [('rem', True), ('remsa', True)],
          'ren': [('ren', True), ('r', True)],
          'rena': [('re', False)],
          'renans': [('rena', False)],
          'renar': [('ren', True)],
          'renar-': [('renare', False)],
          'renarens': [('renare', False)],
          'renarna': [('ren', True)],
          'renarnas': [('ren', False)],
          'renas': [('re', False)],
          'renat-': [('renat', True)],
          'renats-': [('renat', True)],
          'renbeten': [('renbete', True)],
          'renbetens': [('renbete', True)],
          'renbetet': [('renbete', True)],
          'renbetets': [('renbete', True)],
          'renda': [('rendum', False)],
          'rendas': [('rendum', False)],
          'renden': [('rend', False)],
          'rendens': [('rend', False)],
          'render': [('rend', False)],
          'renderna': [('rend', False)],
          'renders': [('rend', False)],
          'rendets': [('rende', False)],
          'renet': [('ren', False)],
          'renets': [('ren', False)],
          'renheter': [('renhet', False)],
          'renheterna': [('renhet', True)],
          'renheternas': [('renhet', False)],
          'renheters': [('renhet', False)],
          'renhets': [('renhet', False)],
          'renhets-': [('renhet', False)],
          'reni': [('reni', False)],
          'reni-': [('reni', False)],
          'renien': [('reni', False)],
          'reniens': [('reni', False)],
          'reniernas': [('reni', False)],
          'reniers': [('reni', False)],
          'renis': [('reni', False)],
          'renn': [('renn', False)],
          'renn-': [('renn', False)],
          'rennen': [('renn', False)],
          'rennens': [('renn', False)],
          'renner': [('renn', False)],
          'rennerna': [('renn', False)],
          'rennernas': [('renn', False)],
          'renners': [('renn', False)],
          'renns': [('renn', False)],
          'rens': [('r', True), ('ren', True)],
          'rens-': [('ren', True)],
          'rensanden': [('rensande', False)],
          'rensandens': [('rensande', True)],
          'rensarnas': [('rensare', False)],
          'rensen': [('rens', False)],
          'rensens': [('rens', False)],
          'renser': [('rens', False)],
          'renserna': [('rens', False)],
          'rensernas': [('rens', False)],
          'rensers': [('rens', False)],
          'rent': [('rent', False)],
          'renten': [('rent', False)],
          'rentens': [('rent', False)],
          'renter': [('rent', False)],
          'renterna': [('rent', False)],
          'renternas': [('rent', False)],
          'renters': [('rent', False)],
          'rentes': [('rentes', False)],
          'rentes-': [('rentes', False)],
          'rentier': [('rentier', True)],
          'rentiers': [('rentier', True)],
          'rents-': [('rent', False)],
          'reoler': [('reol', True)],
          'reolerna': [('reol', True)],
          'reolernas': [('reol', True)],
          'reolers': [('reol', True)],
          'reon': [('reon', False)],
          'reons': [('reo', False)],
          'reor': [('rea', False)],
          'reorden': [('reorden', False)],
          'reordens': [('reorden', False)],
          'reorna': [('rea', False)],
          'reornas': [('rea', True)],
          'reors': [('rea', True)],
          'rep': [('repa', True), ('rep', True)],
          'rep-': [('repa', True), ('rep', True)],
          'repan': [('repa', True)],
          'repans': [('repa', True)],
          'repe': [('repa', True), ('repe', True)],
          'repe-': [('repe', True), ('repa', True)],
          'repen': [('rep', True)],
          'repens': [('rep', False)],
          'repet': [('repe', True), ('rep', True)],
          'repets': [('repe', True), ('rep', True)],
          'repp': [('repp', False)],
          'repp-': [('repp', False)],
          'reppen': [('repp', False)],
          'reppens': [('repp', False)],
          'repps': [('repp', False)],
          'repps-': [('repp', False)],
          'reps': [('repa', True), ('rep', True)],
          'reps-': [('repa', True), ('rep', True)],
          'repände': [('repända', True), ('repände', True)],
          'repände-': [('repände', True), ('repända', True)],
          'rer': [('er', False)],
          'rer-': [('rer', False)],
          'rerare': [('rerare', False)],
          'rerares': [('rerare', False)],
          'rerarna': [('rerare', False)],
          'rerarnas': [('rerare', False)],
          'reri': [('reri', False)],
          'reri-': [('reri', False)],
          'rerier': [('reri', False)],
          'rerierna': [('reri', False)],
          'reriers': [('reri', False)],
          'reriet': [('reri', False)],
          'reris': [('reri', False)],
          'reris-': [('reri', False)],
          'rerit': [('reri', False)],
          'rerna': [('er', False)],
          'rernas': [('er', False)],
          'reron': [('rero', False)],
          'rerons': [('rero', False)],
          'reror': [('rero', False)],
          'rerorna': [('rero', False)],
          'rerornas': [('rero', False)],
          'rerors': [('rero', False)],
          'reros': [('rero', False)],
          'reros-': [('rero', False)],
          'rers': [('re', False)],
          'rers-': [('rer', False)],
          'res': [('re', False)],
          'res-': [('re', False)],
          'resan': [('resa', False)],
          'resans': [('resa', False)],
          'resar': [('rese', True)],
          'resarna': [('rese', True)],
          'resarnas': [('rese', True)],
          'resars': [('rese', True)],
          'rese': [('rese', True), ('resa', True)],
          'rese-': [('rese', True), ('resa', True)],
          'researcher': [('research', True), ('researcher', True)],
          'researcherna': [('research', True), ('researcher', True)],
          'researchernas': [('research', True), ('researcher', True)],
          'researchers': [('research', True), ('researcher', True)],
          'resen': [('rese', True)],
          'resens': [('rese', True)],
          'reses': [('rese', True)],
          'reses-': [('rese', True)],
          'resier': [('resi', False)],
          'resiernas': [('resi', False)],
          'resiers': [('resi', False)],
          'resis': [('resi', False)],
          'resits': [('resi', False)],
          'reslagar': [('reslag', False)],
          'reslagarna': [('reslag', False)],
          'reslagarnas': [('reslag', False)],
          'resorna': [('resa', False)],
          'ress': [('ress', False)],
          'ressar': [('ress', False)],
          'ressaren': [('ressare', False)],
          'ressars': [('ress', False)],
          'ressen': [('ress', False)],
          'ressena': [('resse', False)],
          'ressens': [('ress', False)],
          'resser': [('ress', False)],
          'resserna': [('ress', False)],
          'ressernas': [('ress', False)],
          'ressers': [('ress', False)],
          'resset': [('resse', False)],
          'ressets': [('resse', False)],
          'rest-': [('rest', True)],
          'restans': [('resta', False)],
          'restarnas': [('restare', False)],
          'resten': [('rest', False)],
          'rester': [('rest', False)],
          'resterna': [('rest', False)],
          'resternas': [('rest', False)],
          'resters': [('rest', False)],
          'restilens': [('restil', False)],
          'restons': [('resto', False)],
          'restors': [('resta', False)],
          'restos': [('resto', False)],
          'restriktioner': [('restriktion', True)],
          'restriktionerna': [('restriktion', True)],
          'restriktionernas': [('restriktion', True)],
          'restriktioners': [('restriktion', True)],
          'restriktions': [('restriktion', True)],
          'restriktions-': [('restriktion', False)],
          'resurs': [('resurs', True)],
          'resurs-': [('resurs', True)],
          'resurser': [('resurs', True)],
          'resurserna': [('resurs', False)],
          'resursernas': [('resurs', False)],
          'resursers': [('resurs', True)],
          'resvärden': [('resvärd', False)],
          'resvärdens': [('resvärd', False)],
          'ret': [('r', True)],
          'reta': [('retum', False)],
          'retagen': [('retag', False)],
          'retagens': [('retag', False)],
          'retaget': [('retag', False)],
          'retagets': [('retag', False)],
          'retan': [('reta', False)],
          'retana': [('retum', False)],
          'retanas': [('retum', False)],
          'retanden': [('retande', True)],
          'retandens': [('retande', True)],
          'retans': [('reta', False)],
          'retar': [('retare', False)],
          'retarna': [('retare', False)],
          'retarnas': [('ret', False)],
          'retas': [('reta', False)],
          'reten': [('ret', False)],
          'retens': [('ret', False)],
          'reter': [('ret', False)],
          'reterna': [('reter', False)],
          'reternas': [('reter', False)],
          'reters': [('reter', False)],
          'retets': [('ret', False)],
          'retiden': [('retiden', False)],
          'retikerna': [('retiker', False)],
          'retikers': [('retiker', False)],
          'retin': [('retin', False)],
          'retor': [('retor', False)],
          'retors': [('retor', True)],
          'reträdens': [('reträde', False)],
          'reträdets': [('reträde', False)],
          'rets': [('r', True)],
          'retsar': [('rets', False)],
          'retsarna': [('rets', False)],
          'retsarnas': [('rets', False)],
          'retsen': [('rets', False)],
          'retsens': [('rets', False)],
          'retslopp': [('retslopp', False)],
          'retslopps': [('retslopp', False)],
          'retslopps-': [('retslopp', False)],
          'rett': [('rett', False)],
          'rett-': [('rett', False)],
          'retten': [('rett', False)],
          'retter': [('rett', False)],
          'retterna': [('rett', False)],
          'retternas': [('rett', False)],
          'retters': [('rett', False)],
          'rettlandet': [('rettland', False)],
          'rettor': [('retto', False)],
          'rettorna': [('retto', False)],
          'rettornas': [('retto', False)],
          'rettors': [('retto', False)],
          'retts': [('rett', False)],
          'retts-': [('rett', False)],
          'retylen': [('retylen', False)],
          'retylens': [('retylen', False)],
          'rev': [('rev', True), ('reva', True)],
          'rev-': [('reva', True), ('rev', True)],
          'revar': [('rev', True)],
          'revar-': [('revare', False)],
          'revarna': [('rev', True)],
          'revarnas': [('rev', True)],
          'revars': [('rev', False)],
          'reve': [('reva', True)],
          'reven': [('rev', True)],
          'revens': [('rev', True)],
          'rever': [('rever', False)],
          'revers': [('revers', False)],
          'revers-': [('revers', False)],
          'revets': [('rev', False)],
          'revisor': [('revisor', False)],
          'revlars': [('revel', True)],
          'revs': [('reva', True), ('rev', True)],
          'revs-': [('reva', True), ('rev', True)],
          'rexin': [('rexi', False)],
          'rexins': [('rexi', False)],
          'rf': [('rf', False)],
          'rf-': [('rf', False)],
          'rfader': [('rfar', False)],
          'rfader-': [('rfader', False)],
          'rfadern': [('rfader', False)],
          'rfaderns': [('rfader', False)],
          'rfaders': [('rfader', False)],
          'rfaders-': [('rfar', False)],
          'rfar-': [('rfare', False)],
          'rfare': [('rfara', False)],
          'rfarmar': [('rfarmare', False)],
          'rfarmarna': [('rfarmare', False)],
          'rfarmarnas': [('rfarmare', False)],
          'rfarna': [('rf', False)],
          'rfars': [('rfar', False)],
          'rfars-': [('rfar', False)],
          'rfasan': [('rfasan', False)],
          'rfasans': [('rfasan', False)],
          'rfasonerna': [('rfason', False)],
          'rfasonernas': [('rfason', False)],
          'rfasoners': [('rfason', False)],
          'rfat': [('rfat', False)],
          'rfats': [('rfat', False)],
          'rfekt': [('rfektum', False)],
          'rfekt-': [('rfektum', False)],
          'rfekten': [('rfektum', False)],
          'rfektens': [('rfektum', False)],
          'rfekter': [('rfektum', False)],
          'rfekternas': [('rfektum', False)],
          'rfekters': [('rfektum', False)],
          'rfekts': [('rfektum', False)],
          'rfel': [('rfel', False)],
          'rfels': [('rfel', False)],
          'rfels-': [('rfel', False)],
          'rfem': [('rfem', False)],
          'rfem-': [('rfem', False)],
          'rfems': [('rfem', False)],
          'rfen': [('rf', False)],
          'rfens': [('rf', False)],
          'rfer': [('rf', False)],
          'rferna': [('rf', False)],
          'rfernas': [('rf', False)],
          'rfers': [('rf', False)],
          'rfilar': [('rfil', False)],
          'rfilarna': [('rfil', False)],
          'rfilarnas': [('rfil', False)],
          'rfilen': [('rfil', False)],
          'rfilens': [('rfil', False)],
          'rfinans': [('rfinans', False)],
          'rfinans-': [('rfinans', False)],
          'rfink': [('rfink', False)],
          'rfink-': [('rfink', False)],
          'rfinks': [('rfink', False)],
          'rfinks-': [('rfink', False)],
          'rfis': [('rfis', False)],
          'rfis-': [('rfis', False)],
          'rfiskarnas': [('rfisk', False)],
          'rfjäll': [('rfjäll', False)],
          'rfjälls': [('rfjäll', False)],
          'rfjälls-': [('rfjäll', False)],
          'rflagg': [('rflagga', False)],
          'rflagg-': [('rflagga', False)],
          'rflor': [('rflor', False)],
          'rflor-': [('rflor', False)],
          'rflors': [('rflor', False)],
          'rflors-': [('rflor', False)],
          'rflottar': [('rflotte', False)],
          'rflottarna': [('rflotte', False)],
          'rflottarnas': [('rflotte', False)],
          'rflotte': [('rflotta', False)],
          'rflyt': [('rfly', False)],
          'rflyts': [('rfly', False)],
          'rfläck': [('rfläck', False)],
          'rfläck-': [('rfläcka', False)],
          'rfläcks': [('rfläcka', False)],
          'rfläcks-': [('rfläcka', False)],
          'rflödet': [('rflöd', False)],
          'rflödets': [('rflöd', False)],
          'rfolierna': [('rfolie', False)],
          'rfos': [('rfos', False)],
          'rfos-': [('rfos', False)],
          'rfots': [('rfot', False)],
          'rfots-': [('rfot', False)],
          'rframställningar': [('rframställning', False)],
          'rframställningarna': [('rframställning', False)],
          'rframställningarnas': [('rframställning', False)],
          'rframställningars': [('rframställning', False)],
          'rfräknar': [('rfräken', False)],
          'rfräknarna': [('rfräken', False)],
          'rfräknarnas': [('rfräken', False)],
          'rfräknars': [('rfräken', False)],
          'rfrågan': [('rfrågan', False)],
          'rfrågans': [('rfrågan', False)],
          'rfs': [('rf', False)],
          'rfs-': [('rf', False)],
          'rftets': [('rft', False)],
          'rfyrar': [('rfyr', False)],
          'rfyrarnas': [('rfyr', False)],
          'rfäder': [('rfader', False)],
          'rfäderna': [('rfar', False)],
          'rfädernas': [('rfar', False)],
          'rfäders': [('rfader', False)],
          'rfången': [('rfånge', False)],
          'rfångens': [('rfånge', False)],
          'rförar': [('rförare', False)],
          'rförarna': [('rförare', False)],
          'rförarnas': [('rförare', False)],
          'rfören': [('rföre', False)],
          'rförens': [('rföre', False)],
          'rförlust': [('rförluster', False)],
          'rförlust-': [('rförluster', False)],
          'rförluster': [('rförluster', False)],
          'rförlusterna': [('rförluster', False)],
          'rförlusternas': [('rförluster', False)],
          'rförlusters': [('rförluster', False)],
          'rförs': [('rföre', False)],
          'rförs-': [('rföre', False)],
          'rförsäkringar': [('rförsäkring', False)],
          'rförsäkringarna': [('rförsäkring', False)],
          'rförsäkringarnas': [('rförsäkring', False)],
          'rförsäkringars': [('rförsäkring', False)],
          'rg': [('rg', False)],
          'rg-': [('rg', False)],
          'rgal': [('rgal', False)],
          'rgal-': [('rgal', False)],
          'rgalen': [('rgal', False)],
          'rgalens': [('rgal', False)],
          'rgaller': [('rgaller', False)],
          'rgallerna': [('rgaller', False)],
          'rgallernas': [('rgaller', False)],
          'rgallers': [('rgaller', False)],
          'rgals': [('rgal', False)],
          'rgals-': [('rgal', False)],
          'rgaltarnas': [('rgalt', False)],
          'rgan': [('rgan', False)],
          'rganden': [('rgand', False)],
          'rgandens': [('rgande', False)],
          'rgans': [('rgan', False)],
          'rgans-': [('rgan', False)],
          'rgar': [('rg', False)],
          'rgarden': [('rgarde', False)],
          'rgardens': [('rgarde', False)],
          'rgaren': [('rgare', False)],
          'rgarna': [('rg', False)],
          'rgarnas': [('rg', False)],
          'rgars': [('rg', False)],
          'rgas': [('rgas', False)],
          'rgasernas': [('rgas', False)],
          'rgasers': [('rgas', False)],
          'rgate': [('rgata', False)],
          'rgate-': [('rgata', False)],
          'rgatids': [('rgatider', False)],
          'rgatids-': [('rgatider', False)],
          'rgator': [('rgata', False)],
          'rgators': [('rgata', False)],
          'rgats': [('rgata', False)],
          'rgdags': [('rgdag', False)],
          'rge': [('rg', False)],
          'rge-': [('rg', False)],
          'rgel': [('rgel', False)],
          'rgel-': [('rgel', False)],
          'rgelsen': [('rgelse', False)],
          'rgelsens': [('rgelse', False)],
          'rgen': [('rg', False)],
          'rgen-': [('rgen', False)],
          'rgens': [('rg', False)],
          'rgens-': [('rgen', False)],
          'rger': [('rg', False)],
          'rgeriernas': [('rgeri', False)],
          'rgerna': [('rg', False)],
          'rgernas': [('rg', False)],
          'rgers': [('rg', False)],
          'rget': [('rg', False)],
          'rgets': [('rg', False)],
          'rgetten': [('rgette', False)],
          'rgglans': [('rgglans', False)],
          'rghandlar': [('rghandel', False)],
          'rghets': [('rghet', False)],
          'rgie': [('rgie', False)],
          'rgie-': [('rgie', False)],
          'rgien': [('rgie', False)],
          'rgiens': [('rgie', False)],
          'rgiernas': [('rgi', False)],
          'rgiften': [('rgift', False)],
          'rgiftens': [('rgift', False)],
          'rgifts': [('rgift', False)],
          'rgifts-': [('rgift', False)],
          'rgin': [('rgi', False)],
          'rgin-': [('rgin', False)],
          'rgine': [('rgine', False)],
          'rgine-': [('rgine', False)],
          'rginen': [('rgine', False)],
          'rginens': [('rgine', False)],
          'rginer': [('rgine', False)],
          'rginerna': [('rgine', False)],
          'rginers': [('rgine', False)],
          'rgins': [('rgi', False)],
          'rgis': [('rgis', False)],
          'rgis-': [('rgis', False)],
          'rgivar': [('rgivare', False)],
          'rgivarna': [('rgivare', False)],
          'rgivarnas': [('rgivare', False)],
          'rglandet': [('rgland', False)],
          'rglandets': [('rgland', False)],
          'rglar': [('rgel', False)],
          'rglarna': [('rgel', False)],
          'rglarnas': [('rgel', False)],
          'rglars': [('rgel', False)],
          'rglasögon': [('rglasögon', False)],
          'rglasögonen': [('rglasögon', False)],
          'rglasögonens': [('rglasögon', False)],
          'rglasögons': [('rglasögon', False)],
          'rglen': [('rgel', False)],
          'rglens': [('rgel', False)],
          'rgnar': [('rgon', False)],
          'rgnarna': [('rgon', False)],
          'rgnars': [('rgon', False)],
          'rgo': [('rgo', False)],
          'rgo-': [('rgo', False)],
          'rgods': [('rgods', False)],
          'rgods-': [('rgods', False)],
          'rgolan': [('rgola', False)],
          'rgolans': [('rgola', False)],
          'rgolor': [('rgola', False)],
          'rgolorna': [('rgola', False)],
          'rgolornas': [('rgola', False)],
          'rgolors': [('rgola', False)],
          'rgon': [('rgon', False)],
          'rgonen': [('rgon', False)],
          'rgonens': [('rgon', False)],
          'rgonierna': [('rgonia', False)],
          'rgoniers': [('rgonia', False)],
          'rgons': [('rgon', False)],
          'rgrums': [('rgrum', False)],
          'rgrums-': [('rgrum', False)],
          'rgrynet': [('rgryn', False)],
          'rgrynets': [('rgryn', False)],
          'rgs': [('rg', False)],
          'rgs-': [('rg', False)],
          'rgskalas': [('rgskala', False)],
          'rgskals-': [('rgskala', False)],
          'rgskor': [('rgska', False)],
          'rgskorna': [('rgska', False)],
          'rgskornas': [('rgska', False)],
          'rgskors': [('rgska', False)],
          'rgskostnader': [('rgskostnad', False)],
          'rgskostnaderna': [('rgskostnad', False)],
          'rgskostnadernas': [('rgskostnad', False)],
          'rgskostnaders': [('rgskostnad', False)],
          'rgskostnads': [('rgskostnad', False)],
          'rgskostnads-': [('rgskostnad', False)],
          'rgsområdet': [('rgsområdet', False)],
          'rgsområdets': [('rgsområde', False)],
          'rgsregionen': [('rgsregionen', False)],
          'rgsregionens': [('rgsregionen', False)],
          'rgunge': [('rgunge', False)],
          'rgunge-': [('rgunge', False)],
          'rgäng': [('rgäng', False)],
          'rgängen': [('rgäng', False)],
          'rgängens': [('rgäng', False)],
          'rgänget': [('rgäng', False)],
          'rgängets': [('rgäng', False)],
          'rgängs': [('rgäng', False)],
          'rgängs-': [('rgäng', False)],
          'rgångar': [('rgång', False)],
          'rgångarna': [('rgång', False)],
          'rgångarnas': [('rgång', False)],
          'rgås': [('rgås', False)],
          'rgås-': [('rgås', False)],
          'rgåsar': [('rgås', False)],
          'rgåsarna': [('rgås', False)],
          'rgåsarnas': [('rgås', False)],
          'rgåsars': [('rgås', False)],
          'rgåsen': [('rgås', False)],
          'rgåsens': [('rgås', False)],
          'rgåve-': [('rgåva', False)],
          'rgåvors': [('rgåva', False)],
          'rgömme': [('rgömme', False)],
          'rgöms-': [('rgömme', False)],
          'rhaken': [('rhake', False)],
          'rhakens': [('rhake', False)],
          'rhalar': [('rhalare', False)],
          'rhalv': [('rhalv', False)],
          'rhalv-': [('rhalv', False)],
          'rhalvor': [('rhalv', False)],
          'rhalvorna': [('rhalv', False)],
          'rhalvornas': [('rhalv', False)],
          'rhalvors': [('rhalv', False)],
          'rhalvs': [('rhalv', False)],
          'rhalvs-': [('rhalv', False)],
          'rhandlar': [('rhandlare', False)],
          'rhandlarna': [('rhandlare', False)],
          'rhandlarnas': [('rhandlare', False)],
          'rhands': [('rhand', False)],
          'rhands-': [('rhand', False)],
          'rhans-': [('rhane', False)],
          'rheter': [('rhet', False)],
          'rheterna': [('rhet', False)],
          'rheternas': [('rhet', False)],
          'rheters': [('rhet', False)],
          'rhets': [('rhet', False)],
          'rhets-': [('rhet', False)],
          'rhimlen': [('rhimmel', False)],
          'rhimlens': [('rhimlen', False)],
          'rhistoriker': [('rhistoriker', False)],
          'rhistorikerna': [('rhistoriker', False)],
          'rhistorikernas': [('rhistoriker', False)],
          'rhistorikers': [('rhistoriker', False)],
          'rhon': [('rho', True)],
          'rhona': [('rho', True)],
          'rhonas': [('rho', True)],
          'rhone': [('rhona', False)],
          'rhons': [('rho', True)],
          'rhopar': [('rhop', False)],
          'rhoparna': [('rhop', False)],
          'rhos': [('rho', True)],
          'rhos-': [('rho', True)],
          'rhosen': [('rhos', False)],
          'rhosens': [('rhos', False)],
          'rhoser': [('rhos', False)],
          'rhoserna': [('rhos', False)],
          'rhosernas': [('rhos', False)],
          'rhosers': [('rhos', False)],
          'rhost': [('rhosta', False)],
          'rhost-': [('rhosta', False)],
          'rhot': [('rho', True)],
          'rhots': [('rho', True)],
          'rhundars': [('rhund', False)],
          'rhus': [('rhus', False)],
          'rhuv': [('rhuv', False)],
          'rhuve': [('rhuva', False)],
          'rhuven': [('rhuv', False)],
          'rhuvens': [('rhuv', False)],
          'rhuvs': [('rhuv', False)],
          'rhuvs-': [('rhuv', False)],
          'rhyfs': [('rhyfs', False)],
          'rhyfs-': [('rhyfs', False)],
          'rhytt': [('rhytt', False)],
          'rhytt-': [('rhytt', False)],
          'rhytts': [('rhytt', False)],
          'rhytts-': [('rhytt', False)],
          'rhäll': [('rhäll', False)],
          'rhälls': [('rhäll', False)],
          'rhälls-': [('rhäll', False)],
          'rhängen': [('rhänge', False)],
          'rhängens': [('rhänge', False)],
          'rhänget': [('rhänge', False)],
          'rhängets': [('rhänge', False)],
          'rhängs': [('rhänge', False)],
          'rhängs-': [('rhänge', False)],
          'rhästarnas': [('rhäst', False)],
          'rhästars': [('rhäst', False)],
          'rhåg': [('rhåga', False)],
          'rhåg-': [('rhåga', False)],
          'rhågs': [('rhåga', False)],
          'rhågs-': [('rhåga', False)],
          'rhål': [('rhål', False)],
          'rhål-': [('rhål', False)],
          'rhåls': [('rhål', False)],
          'rhåls-': [('rhål', False)],
          'rhögskolans': [('rhögskola', False)],
          'rhökar': [('rhök', False)],
          'rhökarna': [('rhök', False)],
          'rhökarnas': [('rhök', False)],
          'rhölje': [('rhölje', False)],
          'rhöns': [('rhöns', False)],
          'rhöns-': [('rhöns', False)],
          'rhörn': [('rhörn', False)],
          'rhörn-': [('rhörn', False)],
          'rhörns': [('rhörn', False)],
          'rhörns-': [('rhörn', False)],
          'ri': [('ria', True), ('ri', True)],
          'ri-': [('ria', True), ('ri', True)],
          'rialen': [('rial', False)],
          'rialens': [('rial', False)],
          'rialet': [('rial', False)],
          'rialets': [('rial', False)],
          'rian': [('ria', True)],
          'rian-': [('rian', False)],
          'riana': [('ria', False)],
          'rianas': [('riana', False)],
          'rianden': [('riande', True)],
          'riandens': [('riande', True)],
          'riander': [('riander', False)],
          'rianders': [('riander', False)],
          'rians': [('ria', True)],
          'rians-': [('rians', False)],
          'riaren': [('riare', False)],
          'rias': [('ria', True)],
          'rias-': [('rias', False)],
          'riat': [('riat', False)],
          'riats': [('riat', False)],
          'ribb': [('ribb', True), ('ribba', True)],
          'ribb-': [('ribb', True), ('ribba', True)],
          'ribbe': [('ribba', True)],
          'ribbe-': [('ribba', False)],
          'ribbens': [('ribb', True)],
          'ribbs': [('ribb', True), ('ribba', True)],
          'ribbs-': [('ribb', True), ('ribba', True)],
          'ribien': [('ribi', False)],
          'ribiens': [('ribi', False)],
          'ribis': [('ribi', False)],
          'ricier': [('ricier', False)],
          'ricierna': [('ricier', False)],
          'riciers': [('ricier', False)],
          'rick': [('ricka', False)],
          'rick-': [('rick', False)],
          'rickar': [('rick', False)],
          'rickarna': [('rick', False)],
          'rickarnas': [('rickare', False)],
          'rickats': [('ricka', False)],
          'ricket': [('rick', False)],
          'rickets': [('ricket', False)],
          'ricks': [('rick', False)],
          'ricks-': [('rick', False)],
          'ricksens': [('ricks', False)],
          'ridar': [('ridare', False)],
          'ridarna': [('ridare', False)],
          'ridarnas': [('ridare', False)],
          'riden': [('rid', False)],
          'ridens': [('rid', False)],
          'ridin': [('ridin', False)],
          'ridins': [('ridi', False)],
          'ridis': [('ridi', False)],
          'ridor': [('ridor', False)],
          'ridors': [('ridor', False)],
          'rids': [('rid', False)],
          'rids-': [('rid', False)],
          'ridsdomar': [('ridsdomare', False)],
          'ridsdomarna': [('ridsdomare', False)],
          'ridsdomarnas': [('ridsdomare', False)],
          'rie': [('ria', True)],
          'rie-': [('ria', True)],
          'rien': [('ri', True)],
          'rienas': [('rie', False)],
          'riens': [('ri', False)],
          'rier': [('ri', False)],
          'rierna': [('ri', False)],
          'riers': [('ri', False)],
          'riesen': [('ries', False)],
          'riesens': [('ries', False)],
          'riet': [('ri', False)],
          'rietiden': [('rietid', False)],
          'riets': [('ri', True)],
          'riffen': [('riff', False)],
          'riffens': [('riff', True)],
          'riffer': [('riff', False)],
          'riffers': [('riff', False)],
          'rifflar': [('riffel', False)],
          'rifflarna': [('riffel', False)],
          'rifflarnas': [('riffel', False)],
          'rift': [('rift', False)],
          'rift-': [('rift', False)],
          'riften': [('rift', False)],
          'riftens': [('rift', False)],
          'rifts': [('rift', False)],
          'rifts-': [('rift', False)],
          'rigan': [('riga', False)],
          'rigar': [('rigare', False)],
          'rigarna': [('rigare', False)],
          'rigarnas': [('rigare', False)],
          'riger': [('rig', False)],
          'rigernas': [('rig', False)],
          'rigets': [('rig', False)],
          'rigg': [('rigg', False)],
          'rigg-': [('rigg', False)],
          'riggar': [('rigg', True)],
          'riggarna': [('rigg', True)],
          'riggarnas': [('rigg', False)],
          'riggars': [('rigg', False)],
          'riggen': [('rigg', False)],
          'riggens': [('rigg', False)],
          'riggs': [('rigg', True)],
          'riggs-': [('rigg', False)],
          'righeter': [('righet', False)],
          'righeterna': [('righet', False)],
          'righeternas': [('righet', False)],
          'righeters': [('righet', False)],
          'righets-': [('righet', False)],
          'rik': [('rika', False)],
          'rik-': [('rika', False)],
          'rika': [('rika', False)],
          'rikan': [('rika', False)],
          'rikandens': [('rikande', False)],
          'rikans': [('rika', False)],
          'rikar': [('rikare', False)],
          'rikarna': [('rike', False)],
          'rikarnas': [('rik', False)],
          'rikars': [('rike', False)],
          'rikas': [('rika', False)],
          'rikativ': [('rikativa', False)],
          'rikativ-': [('rikativa', False)],
          'rikativs': [('rikativa', False)],
          'rikativs-': [('rikativa', False)],
          'rikator': [('rikator', False)],
          'rikators': [('rikator', False)],
          'rike': [('rike', False)],
          'rike-': [('rike', False)],
          'riken': [('rike', False)],
          'rikens': [('rike', False)],
          'riker': [('riker', False)],
          'rikerna': [('riker', False)],
          'rikernas': [('riker', False)],
          'rikers': [('riker', False)],
          'riket': [('rike', True)],
          'rikets': [('rike', True)],
          'rikin': [('rikin', False)],
          'riks': [('riks', True), ('rike', True)],
          'riks-': [('riks', True), ('rike', True)],
          'riksrös': [('riksröse', True), ('riksrös', True)],
          'riksrös-': [('riksröse', True), ('riksrös', True)],
          'riksrösen': [('riksrös', True), ('riksröse', True)],
          'riksrösens': [('riksrös', True), ('riksröse', True)],
          'riksröset': [('riksrös', True), ('riksröse', True)],
          'riksrösets': [('riksrös', True), ('riksröse', True)],
          'riktarnas': [('riktare', False)],
          'rikten': [('rikt', False)],
          'riktens': [('rikt', False)],
          'riktet': [('rikt', False)],
          'riktions-': [('riktion', False)],
          'rikts': [('rikt', False)],
          'rikts-': [('rikt', False)],
          'rilanden': [('riland', False)],
          'rilandens': [('riland', False)],
          'rilandet': [('riland', False)],
          'rilandets': [('riland', False)],
          'rilans': [('rilans', False)],
          'rilegiernas': [('rilegium', False)],
          'rilj': [('rilj', False)],
          'rilj-': [('rilj', False)],
          'riljans': [('riljans', False)],
          'riljen': [('rilj', False)],
          'riljens': [('rilj', False)],
          'riljs': [('rilj', False)],
          'rill': [('rill', False)],
          'rillan': [('rilla', False)],
          'rillar': [('rill', False)],
          'rillarna': [('rillare', False)],
          'rillarnas': [('rillare', False)],
          'rillars': [('rill', False)],
          'rille': [('rilla', False)],
          'rille-': [('rilla', False)],
          'rillen': [('rill', False)],
          'riller': [('rill', False)],
          'riller-': [('riller', False)],
          'rillerna': [('rill', False)],
          'rillernas': [('rill', False)],
          'rillers': [('rill', False)],
          'rillor': [('rilla', False)],
          'rillorna': [('rilla', False)],
          'rillornas': [('rilla', False)],
          'rillors': [('rilla', False)],
          'rillrar': [('riller', False)],
          'rills': [('rill', False)],
          'rills-': [('rill', False)],
          'rim': [('rim', True)],
          'rim-': [('rim', True)],
          'rimanden': [('rimand', False)],
          'rimas': [('rimas', False)],
          'rimbor': [('rimba', False)],
          'rimborna': [('rimba', False)],
          'rimbornas': [('rimba', False)],
          'rimer': [('rim', False)],
          'rimers': [('rim', False)],
          'rimmar': [('rimmare', True)],
          'rimmarna': [('rimmare', True)],
          'rimme': [('rimma', False)],
          'rimme-': [('rimma', False)],
          'rimmers': [('rimmer', False)],
          'rims': [('rim', True)],
          'rimturs': [('rimturs', True)],
          'rin': [('ri', True)],
          'rina': [('ri', False)],
          'rinandens': [('rinande', False)],
          'rinans': [('rina', False)],
          'rinar': [('rinare', False)],
          'rinar-': [('rinare', False)],
          'rinarens': [('rinare', False)],
          'rinarna': [('rinare', False)],
          'rinas': [('ri', False)],
          'rind': [('rind', False)],
          'rind-': [('rind', False)],
          'rindar': [('rind', False)],
          'rindarna': [('rind', False)],
          'rinder': [('rind', False)],
          'rinderna': [('rind', False)],
          'rindernas': [('rind', False)],
          'rinders': [('rind', False)],
          'rinds': [('rind', False)],
          'rinds-': [('rind', False)],
          'rinets': [('rin', False)],
          'ring': [('ring', False)],
          'ring-': [('ring', False)],
          'ringar': [('ringare', True), ('ring', True)],
          'ringarna': [('ringare', True), ('ring', True)],
          'ringarnas': [('ringare', True), ('ring', True)],
          'ringars': [('ring', False)],
          'ringe': [('ringa', False)],
          'ringe-': [('ringa', False)],
          'ringen': [('ring', False)],
          'ringens': [('ring', False)],
          'ringet': [('ring', True)],
          'ringlas': [('ringla', False)],
          'ringor': [('ringa', False)],
          'ringorna': [('ringa', False)],
          'ringornas': [('ringo', False)],
          'ringors': [('ringo', False)],
          'ringrävar': [('ringräv', True)],
          'ringrävarna': [('ringräv', True)],
          'ringrävarnas': [('ringräv', True)],
          'rings': [('ring', False)],
          'rings-': [('ring', False)],
          'ringsdags': [('ringsdag', False)],
          'ringsdags-': [('ringsdag', False)],
          'ringsfång': [('ringsfång', False)],
          'ringsfången': [('ringsfång', False)],
          'ringsfångs-': [('ringsfång', False)],
          'ringskasse': [('ringskassa', False)],
          'ringskostnader': [('ringskostnad', False)],
          'ringskostnaderna': [('ringskostnad', False)],
          'ringskostnadernas': [('ringskostnad', False)],
          'ringskostnaders': [('ringskostnad', False)],
          'ringskostnads': [('ringskostnad', False)],
          'ringskostnads-': [('ringskostnad', False)],
          'ringsställens': [('ringsställe', False)],
          'ringsvägar': [('ringsväg', False)],
          'ringsvägarna': [('ringsväg', False)],
          'ringsvägarnas': [('ringsväg', False)],
          'ringsvägars': [('ringsväg', False)],
          'ringsvägs': [('ringsväg', False)],
          'ringsvägs-': [('ringsväg', False)],
          'rinier': [('rinier', False)],
          'rinierna': [('rinier', False)],
          'rink': [('rink', False)],
          'rinkar': [('rink', True)],
          'rinkarna': [('rink', True)],
          'rinkarnas': [('rink', True)],
          'rinkars': [('rink', False)],
          'rinks': [('rink', False)],
          'rinnar': [('rinnare', False)],
          'rinnarnas': [('rinnare', False)],
          'rinne': [('rinna', False)],
          'rinne-': [('rinna', False)],
          'rinons': [('rino', False)],
          'rinos': [('rino', False)],
          'rins': [('ri', False)],
          'rins-': [('rins', False)],
          'rinstans': [('rinstans', False)],
          'rint': [('rint', False)],
          'rinter': [('rint', False)],
          'rintern': [('rinter', False)],
          'rinterna': [('rint', False)],
          'rinternas': [('rint', False)],
          'rinterns': [('rinter', False)],
          'rinters': [('rint', False)],
          'rinträden': [('rinträde', False)],
          'rinträdet': [('rinträde', False)],
          'rints-': [('rint', False)],
          'riol': [('riol', False)],
          'riol-': [('riol', False)],
          'rioler': [('riol', False)],
          'riolerna': [('riol', False)],
          'riolernas': [('riol', False)],
          'riolers': [('riol', False)],
          'riolet': [('riol', False)],
          'riolets': [('riolet', False)],
          'riols': [('riol', False)],
          'rion': [('rion', False)],
          'rionen': [('rion', False)],
          'rionens': [('rion', False)],
          'rioner': [('rion', False)],
          'rionerna': [('rion', False)],
          'rionernas': [('rion', False)],
          'rioners': [('rion', False)],
          'rions': [('rio', False)],
          'rior': [('ria', True)],
          'riorna': [('ria', False)],
          'riornas': [('ria', False)],
          'riors': [('ria', False)],
          'rios': [('riosa', False)],
          'rios-': [('riosa', False)],
          'riosana': [('riosum', False)],
          'riosanas': [('riosum', False)],
          'riot': [('rio', False)],
          'riots': [('riot', False)],
          'rip': [('ripa', False)],
          'rip-': [('ripa', False)],
          'ripan': [('ripa', True)],
          'ripans': [('ripa', True)],
          'riparnas': [('rip', False)],
          'ripas': [('ripa', True)],
          'riplanet': [('riplan', False)],
          'rippe': [('rippa', False)],
          'rippe-': [('rippa', False)],
          'rippen': [('ripp', False)],
          'rippens': [('ripp', False)],
          'ripperna': [('ripp', False)],
          'rippernas': [('ripp', False)],
          'rippers': [('ripp', False)],
          'rippet': [('ripp', False)],
          'rippets': [('ripp', False)],
          'ripplar': [('rippel', False)],
          'ripplarna': [('rippel', False)],
          'ripplarnas': [('rippel', False)],
          'rips': [('rips', True), ('ripa', True)],
          'rips-': [('rips', True), ('ripa', True)],
          'riptor': [('ripta', False)],
          'riptors': [('ripta', False)],
          'rirer': [('rir', False)],
          'rirerna': [('rir', False)],
          'rirernas': [('rir', False)],
          'rirers': [('rir', False)],
          'ris': [('ria', True), ('ri', True), ('ris', True)],
          'ris-': [('ria', True), ('ri', True), ('ris', True)],
          'risans': [('risans', False)],
          'risarnas': [('ris', False)],
          'risationen': [('risation', False)],
          'rise': [('rise', False)],
          'rise-': [('rise', False)],
          'risen': [('ris', True)],
          'risens': [('ris', True)],
          'riser': [('rise', False)],
          'riserna': [('rise', False)],
          'risernas': [('rise', False)],
          'risers': [('rise', False)],
          'risk': [('riska', True), ('risk', True)],
          'risk-': [('riska', True), ('risk', True)],
          'riskan': [('riska', False)],
          'riskans': [('riska', False)],
          'riskare': [('riskara', False)],
          'riske': [('riska', False)],
          'riske-': [('riska', False)],
          'rismat': [('rismat', False)],
          'rismats': [('rismat', False)],
          'rismer': [('rism', False)],
          'rismerna': [('rism', False)],
          'rismernas': [('rism', False)],
          'rismers': [('rism', False)],
          'riss-': [('rissa', False)],
          'rissarna': [('risse', False)],
          'rissarnas': [('risse', False)],
          'risse': [('rissa', False)],
          'risse-': [('rissa', False)],
          'rissel': [('rissel', False)],
          'rissel-': [('rissel', True)],
          'rissen': [('riss', False)],
          'rissens': [('riss', False)],
          'risslan': [('rissla', False)],
          'risslans': [('rissla', False)],
          'risslar': [('rissel', False)],
          'risslarna': [('rissel', False)],
          'risslarnas': [('rissel', False)],
          'rist-': [('rist', False)],
          'ristan': [('ristad', False)],
          'ristans': [('ristad', False)],
          'ristar': [('rist', True)],
          'ristarna': [('rist', False)],
          'ristarnas': [('rist', True)],
          'risten': [('rist', False)],
          'ristens': [('rist', False)],
          'rister': [('rist', False)],
          'risterna': [('rist', False)],
          'risternas': [('rist', False)],
          'risters': [('rist', False)],
          'ristik': [('ristik', False)],
          'ristik-': [('ristik', False)],
          'ristiker': [('ristik', False)],
          'ristikerna': [('ristik', False)],
          'ristikernas': [('ristik', False)],
          'ristikers': [('ristik', False)],
          'ristiks': [('ristik', False)],
          'rit': [('rit', True)],
          'rit-': [('rit', True)],
          'rita': [('rita', False)],
          'ritan': [('rita', False)],
          'ritans': [('ritan', False)],
          'ritar': [('ritare', False)],
          'ritar-': [('ritare', False)],
          'ritarens': [('ritare', True)],
          'ritarna': [('ritare', True)],
          'ritarnas': [('ritare', True)],
          'ritas': [('rita', False)],
          'riter': [('rit', True)],
          'riterier': [('riterium', False)],
          'riteriernas': [('riterium', False)],
          'riteriets': [('riterium', False)],
          'riterna': [('rit', True)],
          'riternas': [('rit', False)],
          'riters': [('rit', True)],
          'ritet': [('rit', False)],
          'ritets': [('rit', False)],
          'ritis': [('ritis', False)],
          'ritorierna': [('ritorium', False)],
          'ritoriernas': [('ritorium', False)],
          'ritoriers': [('ritorium', False)],
          'ritoriets': [('ritorium', False)],
          'rits': [('rit', True), ('rits', True)],
          'rits-': [('rits', True), ('rit', True)],
          'ritsar': [('rits', False)],
          'ritsarna': [('rits', False)],
          'ritsen': [('rits', False)],
          'ritsens': [('rits', False)],
          'ritt': [('ritt', False)],
          'ritt-': [('ritt', False)],
          'ritten': [('ritt', False)],
          'ritter': [('ritt', False)],
          'ritter-': [('ritter', False)],
          'ritterna': [('ritt', False)],
          'ritternas': [('ritt', False)],
          'ritters': [('ritt', False)],
          'rittlar': [('rittel', False)],
          'rittlarna': [('rittel', False)],
          'rittlarnas': [('rittel', False)],
          'ritts': [('ritt', False)],
          'ritts-': [('ritt', False)],
          'rium': [('rium', False)],
          'riums': [('rium', False)],
          'riv': [('riv', True)],
          'riv-': [('riv', True)],
          'rivar-': [('rivara', False)],
          'rivarna': [('rivare', False)],
          'rivarnas': [('rivare', False)],
          'rivets': [('riv', False)],
          'rivlins': [('rivlina', False)],
          'rivs': [('riv', True)],
          'rivs-': [('riv', True)],
          'rixar': [('rixare', False)],
          'rixarna': [('rixare', False)],
          'rixarnas': [('rixare', False)],
          'rizon': [('rizo', False)],
          'rizons': [('rizon', False)],
          'rizor': [('rizo', False)],
          'rizorna': [('rizo', False)],
          'rizornas': [('rizo', False)],
          'rizors': [('rizo', False)],
          'rjack': [('rjacka', False)],
          'rjack-': [('rjacka', False)],
          'rjacks': [('rjacka', False)],
          'rjacks-': [('rjacka', False)],
          'rjan': [('rja', False)],
          'rjar': [('rjar', False)],
          'rjaren': [('rjare', False)],
          'rjarnas': [('rjare', False)],
          'rjars': [('rj', False)],
          'rje': [('rja', False)],
          'rje-': [('rja', False)],
          'rjen': [('rj', False)],
          'rjens': [('rj', False)],
          'rjet': [('rj', False)],
          'rjor': [('rja', False)],
          'rjorna': [('rja', False)],
          'rjornas': [('rja', False)],
          'rjors': [('rja', False)],
          'rjos': [('rjo', False)],
          'rjungen': [('rjunge', False)],
          'rjungens': [('rjunge', False)],
          'rjöns': [('rjöns', False)],
          'rk': [('rk', False)],
          'rk-': [('rk', False)],
          'rkad': [('rkad', False)],
          'rkad-': [('rkad', False)],
          'rkadens': [('rkad', False)],
          'rkader': [('rkad', False)],
          'rkaders': [('rkad', False)],
          'rkads': [('rkad', False)],
          'rkads-': [('rkad', False)],
          'rkal': [('rkal', False)],
          'rkal-': [('rkal', False)],
          'rkals': [('rkal', False)],
          'rkals-': [('rkal', False)],
          'rkammar': [('rkammare', False)],
          'rkampar': [('rkamp', False)],
          'rkamparna': [('rkamp', False)],
          'rkamparnas': [('rkamp', False)],
          'rkan-': [('rkan', False)],
          'rkanden': [('rkande', False)],
          'rkans-': [('rkan', False)],
          'rkar': [('rk', False)],
          'rkar-': [('rkare', False)],
          'rkare': [('rkare', False)],
          'rkaren': [('rkare', False)],
          'rkarens': [('rkare', False)],
          'rkarna': [('rk', False)],
          'rkarnas': [('rkare', False)],
          'rkars': [('rk', False)],
          'rkart': [('rkarta', False)],
          'rkart-': [('rkarta', False)],
          'rkarts': [('rkarta', False)],
          'rkarts-': [('rkarta', False)],
          'rkas-': [('rkas', False)],
          'rkasar': [('rkas', False)],
          'rkasarna': [('rkas', False)],
          'rkasarnas': [('rkas', False)],
          'rkasars': [('rkas', False)],
          'rkasen': [('rkas', False)],
          'rkasens': [('rkas', False)],
          'rkass': [('rkass', False)],
          'rkass-': [('rkass', False)],
          'rkasse': [('rkassa', False)],
          'rkasse-': [('rkasse', False)],
          'rkassen': [('rkasse', False)],
          'rkassens': [('rkass', False)],
          'rkat': [('rkat', False)],
          'rkatens': [('rkat', False)],
          'rkatet': [('rkat', False)],
          'rkatets': [('rkat', False)],
          'rkats': [('rkat', False)],
          'rkats-': [('rkat', False)],
          'rkatte-': [('rkatta', False)],
          'rkatten': [('rkatt', False)],
          'rkattens': [('rkatt', False)],
          'rke': [('rka', False)],
          'rke-': [('rka', False)],
          'rkek': [('rkek', False)],
          'rkek-': [('rkek', False)],
          'rkel': [('rkel', False)],
          'rkel-': [('rkel', False)],
          'rkels': [('rkel', False)],
          'rkels-': [('rkel', False)],
          'rkelsen': [('rkelse', False)],
          'rkelsens': [('rkelse', False)],
          'rken': [('rk', False)],
          'rkens': [('rk', False)],
          'rker': [('rk', False)],
          'rkerits': [('rkeri', False)],
          'rkerna': [('rk', False)],
          'rkernas': [('rk', False)],
          'rkers': [('rk', False)],
          'rket': [('rk', False)],
          'rkets': [('rke', False)],
          'rkhamrarna': [('rkhammare', False)],
          'rkhamrarnas': [('rkhammare', False)],
          'rkhamrars': [('rkhammare', False)],
          'rkhan': [('rkha', False)],
          'rkhandlar': [('rkhandlare', False)],
          'rkhans': [('rkha', False)],
          'rkhas': [('rkha', False)],
          'rkikarnas': [('rkikare', False)],
          'rkills': [('rkille', False)],
          'rkin': [('rki', False)],
          'rkis': [('rkis', False)],
          'rkis-': [('rkis', False)],
          'rkisarnas': [('rkis', False)],
          'rkisen': [('rkis', False)],
          'rkisens': [('rkis', False)],
          'rkist': [('rkist', False)],
          'rkistan': [('rkista', False)],
          'rkistans': [('rkista', False)],
          'rkiv': [('rkiv', False)],
          'rkiv-': [('rkiv', False)],
          'rkivs': [('rkiv', False)],
          'rklan': [('rklan', False)],
          'rklandets': [('rklande', False)],
          'rklans': [('rklan', False)],
          'rklar': [('rkel', False)],
          'rklarna': [('rkel', False)],
          'rklarnas': [('rkel', False)],
          'rklars': [('rkel', False)],
          'rklas': [('rkla', False)],
          'rklernas': [('rkel', False)],
          'rklin': [('rklina', False)],
          'rklin-': [('rklina', False)],
          'rkling': [('rklinga', False)],
          'rkling-': [('rklinga', False)],
          'rklings': [('rklinga', False)],
          'rklings-': [('rkling', False)],
          'rklink': [('rklinka', False)],
          'rklink-': [('rklinka', False)],
          'rklinks': [('rklinka', False)],
          'rklinks-': [('rklinka', False)],
          'rklipp': [('rklipp', False)],
          'rklipp-': [('rklipp', False)],
          'rklipps': [('rklipp', False)],
          'rklipps-': [('rklipp', False)],
          'rklister': [('rklist', False)],
          'rklisters': [('rklist', False)],
          'rklock': [('rklocka', False)],
          'rklor': [('rkla', False)],
          'rklorna': [('rkla', False)],
          'rklornas': [('rkla', False)],
          'rklors': [('rkla', False)],
          'rklubb': [('rklubb', False)],
          'rklubbs': [('rklubb', False)],
          'rklubbs-': [('rklubb', False)],
          'rkluddar': [('rkludd', False)],
          'rkluddarna': [('rkludd', False)],
          'rkluddarnas': [('rkludd', False)],
          'rklyvar': [('rklyvare', False)],
          'rklyvarna': [('rklyvare', False)],
          'rklyvarnas': [('rklyvare', False)],
          'rklädes': [('rkläder', False)],
          'rklädes-': [('rkläde', False)],
          'rkläds': [('rkläde', False)],
          'rkläds-': [('rkläde', False)],
          'rkne-': [('rkna', False)],
          'rkningar': [('rkning', False)],
          'rkningarna': [('rkning', False)],
          'rkningarnas': [('rkning', False)],
          'rkningars': [('rkning', False)],
          'rknings': [('rkning', False)],
          'rknings-': [('rkning', False)],
          'rknippe': [('rknippe', False)],
          'rknippe-': [('rknippe', False)],
          'rknut': [('rknut', False)],
          'rknuts': [('rknut', False)],
          'rknuts-': [('rknut', False)],
          'rknät': [('rknät', False)],
          'rknäts': [('rknä', False)],
          'rko': [('rka', False)],
          'rko-': [('rka', False)],
          'rkoj': [('rkoj', False)],
          'rkoj-': [('rkoj', False)],
          'rkojs': [('rkoj', False)],
          'rkojs-': [('rkoj', False)],
          'rkom': [('rkom', False)],
          'rkom-': [('rkom', False)],
          'rkoman': [('rkoman', False)],
          'rkomans': [('rkoman', False)],
          'rkomet': [('rkom', False)],
          'rkomets': [('rkom', False)],
          'rkoms': [('rkom', False)],
          'rkomst-': [('rkomst', False)],
          'rkon': [('rkona', False)],
          'rkon-': [('rkona', False)],
          'rkona': [('rkona', False)],
          'rkonas': [('rkona', False)],
          'rkons': [('rkona', False)],
          'rkons-': [('rkona', False)],
          'rkonst-': [('rkonst', False)],
          'rkonster': [('rkonst', False)],
          'rkonsterna': [('rkonst', False)],
          'rkonsternas': [('rkonst', False)],
          'rkonsters': [('rkonst', False)],
          'rkor': [('rka', False)],
          'rkorna': [('rka', False)],
          'rkornas': [('rka', False)],
          'rkors': [('rka', False)],
          'rkors-': [('rkors', False)],
          'rkos': [('rkos', False)],
          'rkos-': [('rkos', False)],
          'rkoster': [('rkost', False)],
          'rkosters': [('rkost', False)],
          'rkostnader': [('rkostnad', False)],
          'rkostnaderna': [('rkostnad', False)],
          'rkostnadernas': [('rkostnad', False)],
          'rkostnads-': [('rkostnad', False)],
          'rkott': [('rkotte', False)],
          'rkott-': [('rkott', False)],
          'rkottar': [('rkott', False)],
          'rkottarna': [('rkott', False)],
          'rkottarnas': [('rkott', False)],
          'rkottars': [('rkotte', False)],
          'rkotten': [('rkotte', False)],
          'rkottens': [('rkott', False)],
          'rkotts': [('rkott', False)],
          'rkotts-': [('rkott', False)],
          'rkovor': [('rkova', False)],
          'rkovorna': [('rkova', False)],
          'rkovornas': [('rkova', False)],
          'rkovors': [('rkova', False)],
          'rkrafter': [('rkraft', False)],
          'rkrafterna': [('rkraft', False)],
          'rkrafternas': [('rkraft', False)],
          'rkrafters': [('rkraft', False)],
          'rkrafts': [('rkraft', False)],
          'rkrafts-': [('rkraft', False)],
          'rkramar': [('rkramare', False)],
          'rkramarna': [('rkramare', False)],
          'rkramarnas': [('rkramare', False)],
          'rkranks-': [('rkrank', False)],
          'rkrans': [('rkrans', False)],
          'rkrans-': [('rkrans', False)],
          'rkrater': [('rkrater', False)],
          'rkrets': [('rker', False)],
          'rkrets-': [('rkrets', False)],
          'rkris': [('rkris', False)],
          'rkris-': [('rkris', False)],
          'rkritiker': [('rkritiker', False)],
          'rkritikerna': [('rkritiker', False)],
          'rkritikernas': [('rkritiker', False)],
          'rkritikers': [('rkritiker', False)],
          'rkronan': [('rkrona', False)],
          'rkronans': [('rkrona', False)],
          'rkrons-': [('rkrona', False)],
          'rkrull': [('rkrulla', False)],
          'rkrull-': [('rkrulla', False)],
          'rkrulle-': [('rkrulla', False)],
          'rkrulls': [('rkrulla', False)],
          'rkrulls-': [('rkrulla', False)],
          'rkräks': [('rkräk', False)],
          'rkräm': [('rkräm', False)],
          'rks': [('rk', False)],
          'rks-': [('rk', False)],
          'rksaker': [('rksaker', False)],
          'rksakerna': [('rksaker', False)],
          'rksakernas': [('rksaker', False)],
          'rksakers': [('rksaker', False)],
          'rksbygget': [('rksbygge', False)],
          'rksopp': [('rksopp', False)],
          'rksopp-': [('rksopp', False)],
          'rksopps-': [('rksopp', False)],
          'rktorn': [('rktorn', False)],
          'rktorns': [('rktorn', False)],
          'rkulin': [('rkulin', False)],
          'rkulin-': [('rkulin', False)],
          'rkulinen': [('rkulin', False)],
          'rkulinens': [('rkulin', False)],
          'rkuliner': [('rkulin', False)],
          'rkulinerna': [('rkulin', False)],
          'rkulinernas': [('rkulin', False)],
          'rkuliners': [('rkulin', False)],
          'rkulinet': [('rkulin', False)],
          'rkulins': [('rkulin', False)],
          'rkull': [('rkulla', False)],
          'rkull-': [('rkulla', False)],
          'rkulle': [('rkulla', False)],
          'rkulls': [('rkulla', False)],
          'rkulls-': [('rkulla', False)],
          'rkulor': [('rkula', False)],
          'rkulorna': [('rkula', False)],
          'rkulornas': [('rkula', False)],
          'rkulors': [('rkula', False)],
          'rkultarnas': [('rkult', False)],
          'rkungar': [('rkunge', False)],
          'rkungarna': [('rkunge', False)],
          'rkungarnas': [('rkunge', False)],
          'rkungars': [('rkunge', False)],
          'rkungen': [('rkunge', False)],
          'rkungens': [('rkunge', False)],
          'rkunskaper': [('rkunskaper', False)],
          'rkunskaperna': [('rkunskaper', False)],
          'rkunskapernas': [('rkunskaper', False)],
          'rkunskapers': [('rkunskaper', False)],
          'rkunskaps': [('rkunskap', False)],
          'rkunskaps-': [('rkunskaper', False)],
          'rkur': [('rkur', False)],
          'rkurv': [('rkurva', False)],
          'rkurv-': [('rkurva', False)],
          'rkurvor': [('rkurva', False)],
          'rkurvorna': [('rkurva', False)],
          'rkurvornas': [('rkurva', False)],
          'rkurvors': [('rkurva', False)],
          'rkurvs': [('rkurva', False)],
          'rkurvs-': [('rkurva', False)],
          'rkus': [('rkus', False)],
          'rkus-': [('rkus', False)],
          'rkusar': [('rkus', False)],
          'rkusarna': [('rkus', False)],
          'rkusarnas': [('rkus', False)],
          'rkusars': [('rkus', False)],
          'rkusen': [('rkus', False)],
          'rkusens': [('rkus', False)],
          'rkvarter': [('rkvarter', False)],
          'rkvarters': [('rkvarter', False)],
          'rkvarts': [('rkvart', False)],
          'rkvarts-': [('rkvart', False)],
          'rkvärden': [('rkvärd', False)],
          'rkvärdens': [('rkvärd', False)],
          'rkäk': [('rkäke', False)],
          'rkäk-': [('rkäke', False)],
          'rkäks': [('rkäke', False)],
          'rkäks-': [('rkäke', False)],
          'rkäll': [('rkälla', False)],
          'rkäll-': [('rkälla', False)],
          'rkämparnas': [('rkämpe', False)],
          'rkäng': [('rkänga', False)],
          'rkäng-': [('rkänga', False)],
          'rkängs': [('rkänga', False)],
          'rkängs-': [('rkänga', False)],
          'rkärr': [('rkärra', False)],
          'rkärr-': [('rkärra', False)],
          'rkärrs': [('rkärra', False)],
          'rkärrs-': [('rkärra', False)],
          'rkättar': [('rkätte', False)],
          'rkättarna': [('rkätte', False)],
          'rkättarnas': [('rkätte', False)],
          'rkår': [('rkår', False)],
          'rkåren': [('rkår', False)],
          'rkårens': [('rkår', False)],
          'rkårs': [('rkår', False)],
          'rkårs-': [('rkår', False)],
          'rköks': [('rkök', False)],
          'rköks-': [('rkök', False)],
          'rkör': [('rkör', False)],
          'rkör-': [('rkör', False)],
          'rkörs': [('rkör', False)],
          'rkörs-': [('rkör', False)],
          'rl': [('rl', False)],
          'rl-': [('rl', False)],
          'rlack': [('rlack', False)],
          'rlad': [('rlada', False)],
          'rlad-': [('rlada', False)],
          'rlads': [('rlada', False)],
          'rlads-': [('rlada', False)],
          'rlag': [('rlag', False)],
          'rlag-': [('rlaga', False)],
          'rlagans': [('rlaga', False)],
          'rlagarna': [('rlag', False)],
          'rlage': [('rlaga', False)],
          'rlage-': [('rlaga', False)],
          'rlagen': [('rlag', False)],
          'rlagens': [('rlag', False)],
          'rlaget': [('rlag', False)],
          'rlagor': [('rlaga', False)],
          'rlagorna': [('rlaga', False)],
          'rlagornas': [('rlaga', False)],
          'rlagors': [('rlaga', False)],
          'rlags': [('rlag', False)],
          'rlags-': [('rlag', False)],
          'rlamp-': [('rlampa', False)],
          'rlamps': [('rlampa', False)],
          'rlamps-': [('rlampa', False)],
          'rlan': [('rla', False)],
          'rlanden': [('rlande', False)],
          'rlandena': [('rlande', False)],
          'rlandenas': [('rlande', False)],
          'rlandens': [('rlande', False)],
          'rlandet': [('rlande', False)],
          'rlandets': [('rland', False)],
          'rlans': [('rla', False)],
          'rlar': [('rl', False)],
          'rlarna': [('rl', False)],
          'rlarnas': [('rl', False)],
          'rlars': [('rl', False)],
          'rlarv': [('rlarv', False)],
          'rlarver': [('rlarv', False)],
          'rlarvers': [('rlarv', False)],
          'rlarvs': [('rlarv', False)],
          'rlarvs-': [('rlarv', False)],
          'rlatan': [('rlatan', False)],
          'rlav': [('rlav', False)],
          'rlav-': [('rlav', False)],
          'rlavar': [('rlav', False)],
          'rlavarna': [('rlav', False)],
          'rlavarnas': [('rlav', False)],
          'rlavars': [('rlav', False)],
          'rlaven': [('rlav', False)],
          'rlavens': [('rlav', False)],
          'rlavs': [('rlav', False)],
          'rlavs-': [('rlav', False)],
          'rle': [('rla', False)],
          'rle-': [('rla', False)],
          'rleg': [('rleg', False)],
          'rlegens': [('rleg', False)],
          'rleget': [('rleg', False)],
          'rlegets': [('rleg', False)],
          'rlegs': [('rleg', False)],
          'rlegs-': [('rleg', False)],
          'rlek': [('rlek', False)],
          'rlek-': [('rleka', False)],
          'rlekar': [('rlek', False)],
          'rlekarna': [('rlek', False)],
          'rlekarnas': [('rlek', False)],
          'rleke-': [('rleka', False)],
          'rleken': [('rlek', False)],
          'rlekens': [('rlek', False)],
          'rleks-': [('rlek', False)],
          'rlemos': [('rlemo', False)],
          'rlen': [('rl', False)],
          'rlens': [('rl', False)],
          'rlessens': [('rless', False)],
          'rlet': [('rl', False)],
          'rlets': [('rl', False)],
          'rlev': [('rleva', False)],
          'rlev-': [('rleva', False)],
          'rleve': [('rleva', False)],
          'rleve-': [('rleva', False)],
          'rlevs': [('rleva', False)],
          'rlevs-': [('rleva', False)],
          'rligans': [('rliga', False)],
          'rligens': [('rlig', False)],
          'rliggarna': [('rliggare', False)],
          'rlighets': [('rlighet', False)],
          'rlik-': [('rlike', False)],
          'rlikanden': [('rlikande', False)],
          'rlin': [('rlina', False)],
          'rlin-': [('rlina', False)],
          'rlina': [('rlina', False)],
          'rlinas': [('rlina', False)],
          'rline': [('rlina', False)],
          'rlins': [('rlins', False)],
          'rlins-': [('rlina', False)],
          'rlitan': [('rlitan', False)],
          'rlivs': [('rliv', False)],
          'rlivs-': [('rliv', False)],
          'rln': [('rl', False)],
          'rlns': [('rl', False)],
          'rlock': [('rlock', False)],
          'rlog': [('rlog', False)],
          'rlog-': [('rlog', False)],
          'rlogen': [('rlog', False)],
          'rlogens': [('rlog', False)],
          'rlogs': [('rlog', False)],
          'rlogs-': [('rlog', False)],
          'rlom-': [('rlom', False)],
          'rlommen': [('rlom', False)],
          'rlommens': [('rlom', False)],
          'rloms': [('rlom', False)],
          'rlopp': [('rlopp', False)],
          'rlopps': [('rlopp', False)],
          'rlopps-': [('rlopp', False)],
          'rlor': [('rla', False)],
          'rlorna': [('rla', False)],
          'rlornas': [('rla', False)],
          'rlors': [('rla', False)],
          'rlossar-': [('rlossare', False)],
          'rlossarens': [('rlossare', False)],
          'rlossarnas': [('rlossare', False)],
          'rlov': [('rlov', False)],
          'rlov-': [('rlov', False)],
          'rloven': [('rlov', False)],
          'rlovens': [('rlov', False)],
          'rlovs': [('rlov', False)],
          'rlovs-': [('rlov', False)],
          'rls': [('rl', False)],
          'rls-': [('rl', False)],
          'rlsarna': [('rl', False)],
          'rlsen': [('rl', False)],
          'rlsens': [('rl', False)],
          'rluck-': [('rlucka', False)],
          'rlucks': [('rlucka', False)],
          'rlut': [('rlut', False)],
          'rlutarna': [('rlut', False)],
          'rluts': [('rlut', False)],
          'rluts-': [('rlut', False)],
          'rlyftarnas': [('rlyft', False)],
          'rlykt': [('rlykta', False)],
          'rlykt-': [('rlykta', False)],
          'rlykts': [('rlykta', False)],
          'rläggar': [('rläggare', False)],
          'rläggarna': [('rläggare', False)],
          'rläggarnas': [('rläggare', False)],
          'rländar': [('rländare', False)],
          'rländarna': [('rländare', False)],
          'rländer': [('rland', False)],
          'rländerna': [('rland', False)],
          'rländernas': [('rland', False)],
          'rländers': [('rland', False)],
          'rlärk': [('rlärka', False)],
          'rlärk-': [('rlärka', False)],
          'rlärks': [('rlärka', False)],
          'rlärks-': [('rlärka', False)],
          'rlåns': [('rlån', False)],
          'rlåns-': [('rlån', False)],
          'rlås': [('rlås', False)],
          'rlåt': [('rlåt', False)],
          'rlåts': [('rlåt', False)],
          'rlön': [('rlön', False)],
          'rlösarna': [('rlösare', False)],
          'rlösarnas': [('rlösare', False)],
          'rlöss': [('rlus', False)],
          'rlössen': [('rlus', False)],
          'rlössens': [('rlus', False)],
          'rm': [('rm', False)],
          'rm-': [('rm', False)],
          'rmadan': [('rmada', False)],
          'rmadans': [('rmada', False)],
          'rmade': [('rmada', False)],
          'rmade-': [('rmada', False)],
          'rmak': [('rmak', False)],
          'rmak-': [('rmak', False)],
          'rmakar': [('rmakare', False)],
          'rmakarna': [('rmakare', False)],
          'rmakarnas': [('rmakare', False)],
          'rmaken': [('rmak', False)],
          'rmakens': [('rmak', False)],
          'rmaks': [('rmak', False)],
          'rmaks-': [('rmak', False)],
          'rmaliernas': [('rmalier', False)],
          'rmaliers': [('rmalier', False)],
          'rmalins': [('rmalin', False)],
          'rman': [('rman', False)],
          'rman-': [('rman', False)],
          'rmanden': [('rmande', False)],
          'rmaner': [('rman', False)],
          'rmanerna': [('rman', False)],
          'rmanernas': [('rman', False)],
          'rmaners': [('rman', False)],
          'rmanets': [('rmanet', False)],
          'rmannen': [('rman', False)],
          'rmannens': [('rman', False)],
          'rmans': [('rman', False)],
          'rmar': [('rm', False)],
          'rmar-': [('rmare', False)],
          'rmare': [('rmare', False)],
          'rmaren': [('rmare', False)],
          'rmarginaler': [('rmarginal', False)],
          'rmarginalerna': [('rmarginal', False)],
          'rmarginalernas': [('rmarginal', False)],
          'rmarginalers': [('rmarginal', False)],
          'rmarna': [('rm', False)],
          'rmarnas': [('rm', False)],
          'rmars': [('rm', False)],
          'rmas': [('rma', False)],
          'rmas-': [('rma', False)],
          'rmask': [('rmask', False)],
          'rmask-': [('rmask', False)],
          'rmaster': [('rmast', False)],
          'rmasters': [('rmast', False)],
          'rmat': [('rmat', False)],
          'rmaten': [('rmat', False)],
          'rmatens': [('rmat', False)],
          'rmatet': [('rmat', False)],
          'rmatets': [('rmat', False)],
          'rmatos': [('rmatos', False)],
          'rmats': [('rmat', False)],
          'rmatt': [('rmatta', False)],
          'rmatt-': [('rmatta', False)],
          'rmatte': [('rmatta', False)],
          'rmatte-': [('rmatta', False)],
          'rmatten': [('rmatte', False)],
          'rmatts': [('rmatta', False)],
          'rmatts-': [('rmatta', False)],
          'rmbanden': [('rmband', False)],
          'rmbandens': [('rmband', False)],
          'rmbandet': [('rmband', False)],
          'rmben': [('rmben', False)],
          'rmbens': [('rmben', False)],
          'rmbon': [('rmbo', False)],
          'rmbons': [('rmbo', False)],
          'rmborst-': [('rmborst', False)],
          'rmborsten': [('rmborst', False)],
          'rmborstens': [('rmborst', False)],
          'rmbos': [('rmbo', False)],
          'rmbräd': [('rmbräda', False)],
          'rmbräden': [('rmbräde', False)],
          'rmbrädens': [('rmbräde', False)],
          'rmbräds': [('rmbräda', False)],
          'rme': [('rma', False)],
          'rme-': [('rma', False)],
          'rmediers': [('rmedium', False)],
          'rmedis': [('rmedis', False)],
          'rmel': [('rmel', False)],
          'rmel-': [('rmel', False)],
          'rmeliten': [('rmelit', False)],
          'rmelitens': [('rmelit', False)],
          'rmenisk': [('rmeniska', False)],
          'rmenisk-': [('rmeniska', False)],
          'rmens': [('rm', False)],
          'rmentets': [('rment', False)],
          'rments': [('rment', False)],
          'rmer': [('rm', False)],
          'rmerit': [('rmeri', False)],
          'rmerits': [('rmeri', False)],
          'rmerna': [('rm', False)],
          'rmernas': [('rm', False)],
          'rmers': [('rm', False)],
          'rmes': [('rme', False)],
          'rmes-': [('rmes', False)],
          'rmet': [('rm', False)],
          'rmeten': [('rmet', False)],
          'rmetens': [('rmet', False)],
          'rmeter': [('rmet', False)],
          'rmeterna': [('rmet', False)],
          'rmeternas': [('rmet', False)],
          'rmeters': [('rmet', False)],
          'rmetoden': [('rmetod', False)],
          'rmetodens': [('rmetod', False)],
          'rmetter': [('rmetter', False)],
          'rmetters': [('rmetter', False)],
          'rmgiftet': [('rmgift', False)],
          'rmie': [('rmie', False)],
          'rmie-': [('rmie', False)],
          'rmier': [('rmie', False)],
          'rmierna': [('rmie', False)],
          'rmiernas': [('rmie', False)],
          'rmiers': [('rmie', False)],
          'rmies': [('rmie', False)],
          'rmil': [('rmil', False)],
          'rmilar': [('rmil', False)],
          'rmilarna': [('rmil', False)],
          'rmilarnas': [('rmil', False)],
          'rmils': [('rmil', False)],
          'rmils-': [('rmil', False)],
          'rmin-': [('rmin', False)],
          'rminalen': [('rminal', False)],
          'rminalens': [('rminal', False)],
          'rminens': [('rmin', False)],
          'rminet': [('rmin', False)],
          'rminister': [('rminister', False)],
          'rministers': [('rminister', False)],
          'rmins': [('rmin', False)],
          'rmins-': [('rmin', False)],
          'rmis-': [('rmis', False)],
          'rmisarna': [('rmis', False)],
          'rmister': [('rmist', False)],
          'rmisters': [('rmist', False)],
          'rmit': [('rmit', False)],
          'rmit-': [('rmit', False)],
          'rmittens': [('rmittens', False)],
          'rmjölk': [('rmjölk', False)],
          'rmjölk-': [('rmjölk', False)],
          'rmjölken': [('rmjölk', False)],
          'rmjölkens': [('rmjölk', False)],
          'rmjölks': [('rmjölk', False)],
          'rmjölks-': [('rmjölk', False)],
          'rmlar': [('rmel', False)],
          'rmlarna': [('rmel', False)],
          'rmlarnas': [('rmel', False)],
          'rmlars': [('rmel', False)],
          'rmoder': [('rmoder', False)],
          'rmoder-': [('rmor', False)],
          'rmodern': [('rmor', False)],
          'rmoderns': [('rmor', False)],
          'rmoders': [('rmor', False)],
          'rmoders-': [('rmor', False)],
          'rmodet': [('rmode', False)],
          'rmodets': [('rmode', False)],
          'rmods': [('rmod', False)],
          'rmods-': [('rmod', False)],
          'rmon': [('rmon', False)],
          'rmoner': [('rmon', False)],
          'rmonerna': [('rmon', False)],
          'rmonernas': [('rmon', False)],
          'rmoners': [('rmon', False)],
          'rmons': [('rmon', False)],
          'rmor': [('rma', False)],
          'rmor-': [('rmor', False)],
          'rmoran': [('rmoran', False)],
          'rmorans': [('rmoran', False)],
          'rmorna': [('rma', False)],
          'rmornas': [('rma', False)],
          'rmors': [('rma', False)],
          'rmors-': [('rmor', False)],
          'rmos': [('rmos', False)],
          'rmos-': [('rmos', False)],
          'rmosarna': [('rmos', False)],
          'rmosen': [('rmos', False)],
          'rmosens': [('rmos', False)],
          'rmoss': [('rmossa', False)],
          'rmoss-': [('rmossa', False)],
          'rmosse': [('rmossa', False)],
          'rms': [('rm', False)],
          'rms-': [('rm', False)],
          'rmsanden': [('rmsand', False)],
          'rmsandens': [('rmsand', False)],
          'rmslås': [('rmslå', False)],
          'rmslås-': [('rmslå', False)],
          'rmsten': [('rmsten', False)],
          'rmstens': [('rmsten', False)],
          'rmulans': [('rmula', False)],
          'rmurar': [('rmur', False)],
          'rmurarna': [('rmur', False)],
          'rmurarnas': [('rmur', False)],
          'rmurr': [('rmurre', False)],
          'rmurr-': [('rmurre', False)],
          'rmurrs': [('rmurre', False)],
          'rmurrs-': [('rmurre', False)],
          'rmus': [('rmus', False)],
          'rmut': [('rmut', False)],
          'rmut-': [('rmut', False)],
          'rmuts': [('rmut', False)],
          'rmygg': [('rmygga', False)],
          'rmygg-': [('rmygga', False)],
          'rmyggs': [('rmygga', False)],
          'rmyggs-': [('rmygga', False)],
          'rmynt': [('rmynt', False)],
          'rmynts': [('rmynt', False)],
          'rmynts-': [('rmynt', False)],
          'rmyr': [('rmyra', False)],
          'rmyr-': [('rmyra', False)],
          'rmyrs': [('rmyra', False)],
          'rmyrs-': [('rmyra', False)],
          'rmys': [('rmys', False)],
          'rmys-': [('rmys', False)],
          'rmyt': [('rmyt', False)],
          'rmyts': [('rmyt', False)],
          'rmälningar': [('rmälning', False)],
          'rmälningarna': [('rmälning', False)],
          'rmälningarnas': [('rmälning', False)],
          'rmälningars': [('rmälning', False)],
          'rmän': [('rman', False)],
          'rmäns': [('rman', False)],
          'rmån': [('rmån', False)],
          'rmån-': [('rmån', False)],
          'rmånen': [('rmån', False)],
          'rmånens': [('rmån', False)],
          'rmåns': [('rmåne', False)],
          'rmåns-': [('rmån', False)],
          'rmödrar': [('rmor', False)],
          'rmödrarna': [('rmoder', False)],
          'rmödrarnas': [('rmoder', False)],
          'rmödrars': [('rmoder', False)],
          'rmör': [('rmör', False)],
          'rmörn': [('rmörn', False)],
          'rmörns': [('rmörn', False)],
          'rmörs': [('rmör', False)],
          'rmöss': [('rmössa', False)],
          'rn-': [('rn', False)],
          'rna': [('rna', False)],
          'rnack': [('rnacka', False)],
          'rnack-': [('rnacke', False)],
          'rnackarnas': [('rnacke', False)],
          'rnacke': [('rnacke', False)],
          'rnacken': [('rnacke', False)],
          'rnackens': [('rnacke', False)],
          'rnacks': [('rnacka', False)],
          'rnacks-': [('rnacka', False)],
          'rnader': [('rnad', False)],
          'rnaderna': [('rnad', False)],
          'rnadernas': [('rnad', False)],
          'rnaders': [('rnad', False)],
          'rnads': [('rnad', False)],
          'rnads-': [('rnad', False)],
          'rnal': [('rnal', False)],
          'rnal-': [('rnal', False)],
          'rnalen': [('rnal', False)],
          'rnalens': [('rnal', False)],
          'rnaler': [('rnal', False)],
          'rnalerna': [('rnal', False)],
          'rnalernas': [('rnal', False)],
          'rnalers': [('rnal', False)],
          'rnals-': [('rnal', False)],
          'rnamn': [('rnamn', False)],
          'rnamn-': [('rnamn', False)],
          'rnamnen': [('rnamn', False)],
          'rnamnens': [('rnamn', False)],
          'rnamns': [('rnamn', False)],
          'rnamns-': [('rnamn', False)],
          'rnanden': [('rnande', False)],
          'rnap-': [('rnap', False)],
          'rnapen': [('rnap', False)],
          'rnapens': [('rnap', False)],
          'rnaps': [('rnap', False)],
          'rnaps-': [('rnap', False)],
          'rnar-': [('rnare', False)],
          'rnaren': [('rnare', False)],
          'rnarens': [('rnare', False)],
          'rnars': [('rn', False)],
          'rnas': [('rna', False)],
          'rnassen': [('rnass', False)],
          'rnassens': [('rnass', False)],
          'rnat': [('rnat', False)],
          'rnat-': [('rnat', False)],
          'rnaten': [('rnat', False)],
          'rnatens': [('rnat', False)],
          'rnater': [('rnat', False)],
          'rnaterna': [('rnat', False)],
          'rnaternas': [('rnat', False)],
          'rnaters': [('rnat', False)],
          'rnatron': [('rnatro', False)],
          'rnatrons': [('rnatro', False)],
          'rnats': [('rnat', False)],
          'rnats-': [('rnat', False)],
          'rnattens': [('rnatt', False)],
          'rndelar': [('rndel', False)],
          'rndelarna': [('rndel', False)],
          'rndelarnas': [('rndel', False)],
          'rndos': [('rndos', False)],
          'rne': [('rna', False)],
          'rnedos': [('rnedos', False)],
          'rnedos-': [('rnedos', False)],
          'rnekar': [('rnekare', False)],
          'rnekarna': [('rnek', False)],
          'rnekarnas': [('rnek', False)],
          'rnen': [('rn', False)],
          'rnens': [('rn', False)],
          'rnerna': [('rn', False)],
          'rnernas': [('rn', False)],
          'rnesen': [('rnes', False)],
          'rnesens': [('rnes', False)],
          'rnet': [('rn', False)],
          'rnetikernas': [('rnetik', False)],
          'rnetikers': [('rnetik', False)],
          'rnglans': [('rnglans', False)],
          'rniden': [('rnide', False)],
          'rnidens': [('rnide', False)],
          'rnids': [('rnide', False)],
          'rniet': [('rnium', False)],
          'rnin': [('rnin', False)],
          'rnin-': [('rnin', False)],
          'rninen': [('rnin', False)],
          'rninens': [('rnin', False)],
          'rniner': [('rnin', False)],
          'rninerna': [('rnin', False)],
          'rninernas': [('rnin', False)],
          'rniners': [('rnin', False)],
          'rnins': [('rnin', False)],
          'rnis': [('rnis', False)],
          'rnis-': [('rnis', False)],
          'rnisen': [('rnis', False)],
          'rnisens': [('rnis', False)],
          'rnisk': [('rniska', False)],
          'rnisk-': [('rniska', False)],
          'rniss': [('rnissa', False)],
          'rnisse': [('rnissa', False)],
          'rnisse-': [('rnissa', False)],
          'rnist': [('rnist', False)],
          'rnit': [('rnit', False)],
          'rnits-': [('rnit', False)],
          'rnklorna': [('rnklo', False)],
          'rnklornas': [('rnklo', False)],
          'rnklors': [('rnklo', False)],
          'rnklädes': [('rnkläder', False)],
          'rnkors': [('rnkors', False)],
          'rnkulls': [('rnkulle', False)],
          'rnkulls-': [('rnkulle', False)],
          'rnnäs': [('rnnäsa', False)],
          'rno': [('rno', False)],
          'rno-': [('rno', False)],
          'rnon': [('rno', False)],
          'rnona': [('rno', False)],
          'rnonas': [('rno', False)],
          'rnons': [('rno', False)],
          'rnor': [('rna', False)],
          'rnorna': [('rna', False)],
          'rnornas': [('rna', False)],
          'rnors': [('rna', False)],
          'rnos': [('rno', False)],
          'rnos-': [('rno', False)],
          'rnot': [('rno', False)],
          'rnots': [('rno', False)],
          'rnriken': [('rnrike', False)],
          'rnrikens': [('rnrike', False)],
          'rnringar': [('rnring', False)],
          'rnringars': [('rnring', False)],
          'rns-': [('rn', False)],
          'rnsaks': [('rnsak', False)],
          'rnsaks-': [('rnsak', False)],
          'rnshaken': [('rnshake', False)],
          'rnshakens': [('rnshake', False)],
          'rnskat': [('rnskata', False)],
          'rnskats': [('rnskata', False)],
          'rnsko-': [('rnsko', False)],
          'rnskåp': [('rnskåp', False)],
          'rnskåps': [('rnskåp', False)],
          'rnskåps-': [('rnskåp', False)],
          'rnsparens': [('rnspar', False)],
          'rntanden': [('rntand', False)],
          'rntandens': [('rntand', False)],
          'rntorn': [('rntorn', False)],
          'rntorns': [('rntorn', False)],
          'rnungar': [('rnunge', False)],
          'rnungarna': [('rnunge', False)],
          'rnungarnas': [('rnunge', False)],
          'rnungars': [('rnunge', False)],
          'rnungen': [('rnunge', False)],
          'rnungens': [('rnunge', False)],
          'rnus': [('rnus', False)],
          'rnus-': [('rnus', False)],
          'rnys': [('rny', False)],
          'rnys-': [('rny', False)],
          'rnäs': [('rnäs', False)],
          'rnäs-': [('rnäs', False)],
          'rnäste': [('rnäste', False)],
          'rnäste-': [('rnäste', False)],
          'rnästen': [('rnäste', False)],
          'rnästens': [('rnäste', False)],
          'rnästet': [('rnäste', False)],
          'rnästets': [('rnäste', False)],
          'rnåret': [('rnår', False)],
          'rnårets': [('rnår', False)],
          'rnör': [('rnör', False)],
          'rnör-': [('rnör', False)],
          'rnören': [('rnör', False)],
          'rnörens': [('rnör', False)],
          'rnörs': [('rnör', False)],
          'rnörs-': [('rnör', False)],
          'rnötter': [('rnöt', False)],
          'rnötterna': [('rnöt', False)],
          'ro': [('ro', False)],
          'ro-': [('ro', True)],
          'roar': [('ro', False)],
          'roars': [('ro', False)],
          'roben': [('robe', True), ('rob', True)],
          'robens': [('robe', True), ('rob', True)],
          'rober': [('robe', True), ('rob', True)],
          'roberna': [('robe', True), ('rob', True)],
          'robernas': [('robe', True), ('rob', True)],
          'robers': [('robe', True), ('rob', True)],
          'rock': [('rock', True)],
          'rock-': [('rock', False)],
          'rockan': [('rocka', True)],
          'rockans': [('rocka', True)],
          'rockar': [('rockare', True), ('rock', True)],
          'rockarna': [('rockare', True), ('rock', True)],
          'rockarnas': [('rockare', True), ('rock', True)],
          'rocken': [('rock', False)],
          'rockens': [('rock', False)],
          'rocket': [('rock', False)],
          'rocks': [('rock', False)],
          'rocks-': [('rock', False)],
          'rod': [('roda', False)],
          'rod-': [('roda', False)],
          'rodan': [('roda', False)],
          'roddar': [('roddare', True)],
          'roddarna': [('roddare', True)],
          'roddarnas': [('roddare', True)],
          'roddars': [('rodd', False)],
          'rodds': [('rodd', False)],
          'rodds-': [('rodd', False)],
          'rode': [('roda', False)],
          'rodel': [('rodel', True)],
          'rodel-': [('rodel', True)],
          'roden': [('rod', False)],
          'rodens': [('rod', False)],
          'roder': [('roder', False)],
          'roderna': [('roder', False)],
          'rodernas': [('roder', True)],
          'roders': [('roder', False)],
          'rodiers': [('rodi', False)],
          'rodiker': [('rodiker', False)],
          'rodikerna': [('rodiker', False)],
          'rodikernas': [('rodiker', False)],
          'rodikers': [('rodiker', False)],
          'rodis': [('rodi', False)],
          'rodlar': [('rodel', True)],
          'rodlarna': [('rodel', True)],
          'rodlarnas': [('rodel', True)],
          'rods': [('roda', False)],
          'rods-': [('roda', False)],
          'roen': [('ro', True)],
          'roens': [('ro', True)],
          'roer': [('ro', False)],
          'roerna': [('ro', False)],
          'roernas': [('ro', False)],
          'roers': [('ro', False)],
          'roffarnas': [('roffare', True)],
          'rofficerare': [('rofficer', False)],
          'rofficerares': [('rofficer', False)],
          'rofficerarna': [('rofficer', False)],
          'rofficerarnas': [('rofficer', False)],
          'roffs': [('roffs', False)],
          'roffs-': [('roffs', False)],
          'roffset': [('roffs', False)],
          'roffsets': [('roffs', False)],
          'rogans': [('rogans', False)],
          'rogansen': [('rogans', False)],
          'rogansens': [('rogans', False)],
          'rogats': [('rogat', False)],
          'rogen-': [('rogener', False)],
          'rogener': [('rogener', False)],
          'rogenerna': [('rogen', False)],
          'rogenernas': [('rogener', False)],
          'rogeners': [('rogener', False)],
          'rogens': [('rogen', False)],
          'roggar': [('roggare', False)],
          'roggarna': [('rogg', False)],
          'roggarnas': [('rogg', False)],
          'rogrammet': [('rogram', False)],
          'rogrammets': [('rogram', False)],
          'roinen': [('roin', False)],
          'roinens': [('roin', False)],
          'roinet': [('roin', False)],
          'rokammar': [('rokam', False)],
          'rokans': [('rokan', False)],
          'rokar-': [('rokar', False)],
          'rokaren': [('rokar', False)],
          'rokarnas': [('rok', False)],
          'roke': [('roke', False)],
          'roke-': [('roke', False)],
          'roken': [('roke', False)],
          'rokens': [('roke', False)],
          'roket': [('roket', False)],
          'rokets': [('roket', False)],
          'rokien': [('roki', False)],
          'rokiens': [('roki', False)],
          'rolandet': [('roland', False)],
          'rolandets': [('roland', False)],
          'rolar': [('rolare', False)],
          'rolar-': [('rolare', False)],
          'rolarens': [('rolare', False)],
          'rolarna': [('rolare', False)],
          'rolarnas': [('rolare', False)],
          'rolder': [('rold', False)],
          'rolders': [('rold', False)],
          'rolets': [('rol', False)],
          'rolin': [('rolin', False)],
          'roll': [('roll', False)],
          'roll-': [('roll', False)],
          'rollar': [('roll', True)],
          'rollarna': [('roll', True)],
          'rollarnas': [('roll', True)],
          'rollars': [('roll', True)],
          'rollen': [('roll', False)],
          'rollens': [('roll', False)],
          'roller': [('roller', True), ('roll', True)],
          'rollerna': [('roller', True), ('roll', True)],
          'rollernas': [('roller', True), ('roll', True)],
          'rollers': [('roller', True), ('roll', True)],
          'rolls': [('rolls', True), ('roll', True)],
          'rolls-': [('rolls', True), ('roll', True)],
          'rologiernas': [('rologium', False)],
          'rols-': [('rola', False)],
          'romans': [('roman', True), ('romans', True)],
          'romans-': [('romans', True)],
          'romar': [('romare', True)],
          'romarna': [('romare', True)],
          'romarnas': [('romare', True)],
          'romb': [('romb', True)],
          'romb-': [('romb', False)],
          'romben': [('romb', False)],
          'rombens': [('romb', False)],
          'romber': [('romb', True)],
          'romberna': [('romb', True)],
          'rombernas': [('romb', True)],
          'rombers': [('romb', False)],
          'rombins': [('rombin', False)],
          'rombon': [('rombon', False)],
          'rombons': [('rombon', False)],
          'rombos': [('rombos', False)],
          'rombosen': [('rombos', False)],
          'rombosens': [('rombos', False)],
          'rombs': [('romb', False)],
          'rombs-': [('romb', False)],
          'romel': [('romla', False)],
          'romel-': [('romla', False)],
          'romen': [('rom', False)],
          'romens': [('rom', False)],
          'rometer': [('rometer', False)],
          'rometerna': [('rometer', False)],
          'rometernas': [('rometer', False)],
          'rometers': [('rometer', False)],
          'romillen': [('romille', False)],
          'romillens': [('romille', False)],
          'romin': [('romin', False)],
          'rominens': [('romin', False)],
          'rominet': [('romin', False)],
          'rominets': [('romin', False)],
          'romins': [('romin', False)],
          'romlandet': [('romlande', False)],
          'romlandets': [('romlande', False)],
          'rommarna': [('rom', False)],
          'rområdets': [('rområde', False)],
          'roms': [('rom', True)],
          'roms-': [('rom', True)],
          'romsen': [('roms', False)],
          'romsens': [('roms', False)],
          'ron': [('ro', False)],
          'ron-': [('ron', False)],
          'rona': [('ro', True)],
          'ronan': [('rona', False)],
          'ronans': [('rona', False)],
          'ronas': [('ro', False)],
          'rond': [('rond', True)],
          'rond-': [('rond', True)],
          'ronde': [('ronda', False)],
          'ronde-': [('ronda', False)],
          'ronden': [('rond', False)],
          'rondens': [('rond', False)],
          'ronder': [('rond', False)],
          'ronders': [('rond', False)],
          'rondor': [('ronda', False)],
          'rondors': [('ronda', False)],
          'ronds': [('rond', False)],
          'ronds-': [('rond', False)],
          'ronen': [('ra', False)],
          'ronens': [('ra', False)],
          'rones': [('rone', False)],
          'rong': [('rong', False)],
          'rong-': [('rong', False)],
          'ronger': [('rong', False)],
          'rongerna': [('rong', False)],
          'rongernas': [('rong', False)],
          'rongers': [('rong', False)],
          'rongs': [('rong', False)],
          'rongs-': [('rong', False)],
          'roni': [('roni', False)],
          'roni-': [('roni', False)],
          'ronien': [('roni', False)],
          'roniens': [('roni', False)],
          'ronierna': [('roni', False)],
          'roniers': [('roni', False)],
          'ronik': [('ronika', False)],
          'ronik-': [('ronika', False)],
          'roniker': [('roniker', False)],
          'ronikerna': [('roniker', False)],
          'ronikernas': [('roniker', False)],
          'ronikers': [('roniker', False)],
          'roniks': [('ronika', False)],
          'roniks-': [('ronika', False)],
          'ronin': [('roni', False)],
          'ronins': [('roni', False)],
          'ronis': [('roni', False)],
          'ronnen': [('ronne', False)],
          'ronnens': [('ronne', False)],
          'ronnet': [('ronne', False)],
          'ronnets': [('ronne', False)],
          'ronomen': [('ronomen', False)],
          'ronomens': [('ronom', False)],
          'rons': [('ro', False)],
          'rons-': [('rona', False)],
          'ronsen': [('rons', False)],
          'ronsens': [('rons', False)],
          'ronset': [('rons', False)],
          'ronskal-': [('ronskal', False)],
          'rontanden': [('rontande', False)],
          'rontandens': [('rontande', False)],
          'ronter': [('ront', False)],
          'ronters': [('ront', False)],
          'ronton': [('ronton', False)],
          'rontons': [('ronton', False)],
          'ropar': [('ropare', False)],
          'ropar-': [('ropare', True)],
          'roparen': [('ropare', True)],
          'roparens': [('ropare', False)],
          'roparna': [('ropare', False)],
          'roparnas': [('ropare', True)],
          'ropars': [('ropar', False)],
          'ropen': [('rop', True)],
          'ropens': [('rop', True)],
          'ropin': [('ropin', False)],
          'ropp': [('ropp', False)],
          'ropp-': [('ropp', False)],
          'roppar': [('ropp', False)],
          'roppars': [('ropp', False)],
          'roppen': [('ropp', False)],
          'roppens': [('ropp', False)],
          'roppås': [('roppås', False)],
          'roppås-': [('roppås', False)],
          'roppåsar': [('roppås', False)],
          'roppåsarna': [('roppås', False)],
          'roppåsarnas': [('roppås', False)],
          'roppåsars': [('roppås', False)],
          'roppåsen': [('roppås', False)],
          'roppåsens': [('roppås', False)],
          'rops': [('rop', True)],
          'rops-': [('rop', True)],
          'ropsen': [('rops', False)],
          'ror': [('ro', True)],
          'rord': [('rord', False)],
          'rord-': [('rord', False)],
          'rorden': [('rord', False)],
          'rordens': [('rord', False)],
          'rordnar': [('rorden', False)],
          'rordnarna': [('rorden', False)],
          'rordnarnas': [('rorden', False)],
          'rordrar': [('rorder', False)],
          'rords': [('rord', False)],
          'rore': [('rore', False)],
          'rore-': [('rore', False)],
          'rores': [('rore', False)],
          'rormar': [('rorm', False)],
          'rormarna': [('rorm', False)],
          'rormarnas': [('rorm', False)],
          'rorn': [('ror', False)],
          'rorna': [('ro', False)],
          'rornas': [('ro', True)],
          'rorns': [('ror', False)],
          'rors': [('ro', False)],
          'rorse': [('rorsa', False)],
          'rorson': [('rorson', False)],
          'rorsons': [('rorson', False)],
          'rorsor': [('rorsa', False)],
          'rorsorna': [('rorsa', False)],
          'rorsornas': [('rorsa', False)],
          'rorsors': [('rorsa', False)],
          'rorten': [('rort', False)],
          'rortens': [('rort', False)],
          'rorternas': [('rort', False)],
          'rorters': [('rort', False)],
          'rorts': [('rort', False)],
          'rorts-': [('rort', False)],
          'rortssamhällena': [('rortssamhälle', False)],
          'ros': [('ros', True), ('ro', True)],
          'ros-': [('ros', True), ('ro', True)],
          'rosa': [('rosa', False)],
          'rosan': [('rosa', False)],
          'rosans': [('rosa', False)],
          'rosas': [('rosa', False)],
          'rosats': [('rosats', False)],
          'roschen': [('roschen', False)],
          'roschens': [('roschen', False)],
          'rosin': [('rosin', False)],
          'rosk': [('rosk', False)],
          'rosk-': [('rosk', False)],
          'rosor': [('ros', False)],
          'rosorna': [('ros', True)],
          'rosornas': [('ros', False)],
          'rosors': [('ros', False)],
          'ross': [('ross', False)],
          'ross-': [('ross', False)],
          'rossar': [('ross', False)],
          'rossaren': [('rossare', False)],
          'rossarna': [('rossare', False)],
          'rossarnas': [('ross', False)],
          'rossars': [('ross', False)],
          'rossats': [('rossats', False)],
          'rossats-': [('rossats', False)],
          'rosse': [('rossa', False)],
          'rosse-': [('rossa', False)],
          'rossen': [('ross', False)],
          'rossens': [('ross', False)],
          'rost-': [('rost', False)],
          'rostarna': [('rost', False)],
          'rosteri': [('rosteri', False)],
          'rosteri-': [('rosteri', False)],
          'rosteris': [('rosteri', False)],
          'rosteris-': [('rosteri', False)],
          'rostrar': [('roster', False)],
          'rostrarna': [('roster', False)],
          'rot': [('ro', True), ('rot', True)],
          'rotar': [('rote', False)],
          'rotarna': [('rote', False)],
          'rotarnas': [('rote', True)],
          'rotars': [('rote', True)],
          'rote': [('rote', False)],
          'rote-': [('rote', True)],
          'roteknikers': [('rotekniker', False)],
          'roten': [('rot', True), ('rote', True)],
          'rotens': [('rote', True), ('rot', True)],
          'rotes': [('rote', True)],
          'rotes-': [('rote', False)],
          'rotidens': [('rotid', False)],
          'rotin': [('rotin', False)],
          'rotor': [('rotor', True)],
          'rotors': [('rotor', True)],
          'rotron': [('rotron', False)],
          'rotrons': [('rotron', False)],
          'rots': [('rot', True), ('rots', True), ('ro', True)],
          'rots-': [('rot', True), ('rots', True)],
          'rotsen': [('rots', False)],
          'rotsens': [('rots', True)],
          'rott': [('rott', False)],
          'rott-': [('rott', False)],
          'rottar': [('rott', False)],
          'rottarna': [('rottare', False)],
          'rottarnas': [('rott', False)],
          'rottars': [('rott', False)],
          'rotten': [('rott', False)],
          'rotter': [('rott', False)],
          'rotter-': [('rotter', False)],
          'rotterna': [('rott', False)],
          'rotternas': [('rott', False)],
          'rotters': [('rott', False)],
          'rottrar': [('rotter', False)],
          'rottrarna': [('rotter', False)],
          'rotts': [('rott', False)],
          'rotts-': [('rott', False)],
          'rotände-': [('rotände', True)],
          'router': [('router', True), ('route', True)],
          'routers': [('router', True), ('route', True)],
          'rov': [('rova', True), ('rov', True)],
          'rov-': [('rova', True), ('rov', True)],
          'rovar-': [('rovare', False)],
          'rovarens': [('rovare', False)],
          'rovarna': [('rovare', False)],
          'rovarnas': [('rovare', False)],
          'rove': [('rova', True)],
          'rove-': [('rova', True)],
          'roven': [('rov', True)],
          'rovens': [('rov', True)],
          'rover': [('rove', False)],
          'roverna': [('rove', False)],
          'rovernas': [('rove', False)],
          'rovers': [('rove', False)],
          'rovers-': [('rovers', False)],
          'roversen': [('rovers', False)],
          'roversens': [('rovers', False)],
          'rovins': [('rovins', False)],
          'rovins-': [('rovins', False)],
          'rovs': [('rov', True), ('rova', True)],
          'rovs-': [('rova', True), ('rov', True)],
          'rox': [('roxe', False)],
          'roxar': [('roxe', False)],
          'roxars': [('roxe', False)],
          'roxen': [('roxe', False)],
          'roxens': [('roxe', False)],
          'roxin': [('roxin', False)],
          'rozons': [('rozon', False)],
          'rp': [('rp', False)],
          'rp-': [('rp', False)],
          'rpack': [('rpack', False)],
          'rpacken': [('rpack', False)],
          'rpackens': [('rpack', False)],
          'rpacks': [('rpack', False)],
          'rpacks-': [('rpack', False)],
          'rpakets': [('rpaket', False)],
          'rpalt': [('rpalt', False)],
          'rpalt-': [('rpalt', False)],
          'rpalts': [('rpalt', False)],
          'rpalts-': [('rpalt', False)],
          'rpande': [('rpande', False)],
          'rpande-': [('rpande', False)],
          'rpanter': [('rpant', False)],
          'rpanters': [('rpant', False)],
          'rpar-': [('rpar', False)],
          'rparen': [('rpare', False)],
          'rparens': [('rpar', False)],
          'rpares': [('rpare', False)],
          'rpars-': [('rpar', False)],
          'rpastor': [('rpasta', False)],
          'rpastors': [('rpasta', False)],
          'rpation': [('rpation', False)],
          'rpations': [('rpation', False)],
          'rpator': [('rpator', False)],
          'rpators': [('rpator', False)],
          'rpe': [('rpa', False)],
          'rpe-': [('rpa', False)],
          'rpelar': [('rpelare', False)],
          'rpelar-': [('rpelare', False)],
          'rpen': [('rp', False)],
          'rpenen': [('rpen', False)],
          'rpenens': [('rpen', False)],
          'rpeng': [('rpengar', False)],
          'rpeng-': [('rpengar', False)],
          'rpengar': [('rpeng', False)],
          'rpengarna': [('rpeng', False)],
          'rpengarnas': [('rpengar', False)],
          'rpengars': [('rpengar', False)],
          'rpengs': [('rpengar', False)],
          'rpengs-': [('rpengar', False)],
          'rpenning': [('rpenning', False)],
          'rpenning-': [('rpenning', False)],
          'rpenningar': [('rpenning', False)],
          'rpenningarna': [('rpenning', False)],
          'rpenningarnas': [('rpenning', False)],
          'rpenningars': [('rpenning', False)],
          'rpennings': [('rpenning', False)],
          'rpennings-': [('rpenning', False)],
          'rpens': [('rp', False)],
          'rpens-': [('rpen', False)],
          'rper': [('rp', False)],
          'rperna': [('rp', False)],
          'rpernas': [('rp', False)],
          'rpers': [('rp', False)],
          'rpes': [('rpes', False)],
          'rpes-': [('rpes', False)],
          'rpesen': [('rpes', False)],
          'rpesens': [('rpes', False)],
          'rpet': [('rp', False)],
          'rpets': [('rp', False)],
          'rphets': [('rphet', False)],
          'rpiller': [('rpiller', False)],
          'rpillers': [('rpiller', False)],
          'rpinnarnas': [('rpinne', False)],
          'rpinnens': [('rpinne', False)],
          'rpinns': [('rpinne', False)],
          'rpisk': [('rpiska', False)],
          'rpisk-': [('rpiska', False)],
          'rpits': [('rpi', False)],
          'rplandets': [('rplande', False)],
          'rplanet': [('rplan', False)],
          'rplanets': [('rplan', False)],
          'rplank': [('rplank', False)],
          'rplank-': [('rplank', False)],
          'rplanks': [('rplank', False)],
          'rplanks-': [('rplank', False)],
          'rplar-': [('rplare', False)],
          'rplarens': [('rplare', False)],
          'rpo': [('rpa', False)],
          'rpointer': [('rpoint', False)],
          'rpointers': [('rpoint', False)],
          'rpojk': [('rpojke', False)],
          'rpojk-': [('rpojke', False)],
          'rpojks': [('rpojke', False)],
          'rpojks-': [('rpojke', False)],
          'rpor': [('rpa', False)],
          'rporna': [('rpa', False)],
          'rpornas': [('rpa', False)],
          'rpors': [('rpa', False)],
          'rportarnas': [('rport', False)],
          'rposter': [('rpost', False)],
          'rposters': [('rpost', False)],
          'rpraktiker': [('rpraktik', False)],
          'rpraktikerna': [('rpraktik', False)],
          'rpraktikernas': [('rpraktik', False)],
          'rpraktikers': [('rpraktik', False)],
          'rpraktiks': [('rpraktik', False)],
          'rpraktiks-': [('rpraktik', False)],
          'rpremie': [('rpremie', False)],
          'rpressar': [('rpress', False)],
          'rpressarna': [('rpress', False)],
          'rpressarnas': [('rpress', False)],
          'rpret': [('rpret', False)],
          'rprocessen': [('rprocessen', False)],
          'rprocessens': [('rprocessen', False)],
          'rprogrammet': [('rprogram', False)],
          'rprättar': [('rprättare', False)],
          'rprättarna': [('rprättare', False)],
          'rps': [('rp', False)],
          'rps-': [('rpa', False)],
          'rpstick-': [('rpsticka', False)],
          'rpsticks': [('rpsticka', False)],
          'rpull': [('rpulla', False)],
          'rpump': [('rpump', False)],
          'rpumps': [('rpump', False)],
          'rpumps-': [('rpump', False)],
          'rpuns': [('rpun', False)],
          'rpuns-': [('rpun', False)],
          'rpurs': [('rpur', False)],
          'rputs': [('rputs', False)],
          'rputs-': [('rputs', False)],
          'rr': [('rr', False)],
          'rr-': [('rr', False)],
          'rrak': [('rrak', False)],
          'rrak-': [('rrak', False)],
          'rrake': [('rraka', False)],
          'rraken': [('rrak', False)],
          'rrakens': [('rrak', False)],
          'rraks': [('rrak', False)],
          'rraks-': [('rrak', False)],
          'rran': [('rran', False)],
          'rran-': [('rran', False)],
          'rrana': [('rra', False)],
          'rranas': [('rra', False)],
          'rrande': [('rrande', False)],
          'rrande-': [('rrande', False)],
          'rranden': [('rrande', False)],
          'rrandens': [('rrande', False)],
          'rrandet': [('rrande', False)],
          'rrans': [('rra', False)],
          'rrar': [('rr', False)],
          'rrarna': [('rr', False)],
          'rrarnas': [('rr', False)],
          'rrars': [('rr', False)],
          'rras': [('rra', False)],
          'rras-': [('rras', False)],
          'rrasen': [('rras', False)],
          'rrasens': [('rras', False)],
          'rrassen': [('rrass', False)],
          'rrassens': [('rrass', False)],
          'rrasslanden': [('rrassland', False)],
          'rrasslandens': [('rrassland', False)],
          'rrasslandet': [('rrassland', False)],
          'rrasslandets': [('rrassland', False)],
          'rrata': [('rrata', False)],
          'rratana': [('rrata', False)],
          'rre': [('rra', False)],
          'rre-': [('rra', False)],
          'rredan': [('rredag', False)],
          'rredans': [('rredag', False)],
          'rreman': [('rreman', False)],
          'rremans': [('rreman', False)],
          'rremiss': [('rremiss', False)],
          'rremiss-': [('rremiss', False)],
          'rremmar': [('rrem', False)],
          'rremmarna': [('rrem', False)],
          'rremmarnas': [('rrem', False)],
          'rrems': [('rremsa', False)],
          'rrems-': [('rrem', False)],
          'rren': [('rr', False)],
          'rrenar': [('rren', False)],
          'rrenarna': [('rren', False)],
          'rrenden': [('rrende', False)],
          'rrendens': [('rrende', False)],
          'rrens': [('rr', False)],
          'rrens-': [('rrens', False)],
          'rrep': [('rrep', False)],
          'rrepet': [('rrep', False)],
          'rrepets': [('rrep', False)],
          'rreps': [('rrep', False)],
          'rreps-': [('rrep', False)],
          'rrer': [('rr', False)],
          'rrerna': [('rr', False)],
          'rrernas': [('rr', False)],
          'rrers': [('rr', False)],
          'rrese': [('rresa', False)],
          'rrese-': [('rresa', False)],
          'rresurs-': [('rresurs', False)],
          'rret': [('rr', False)],
          'rrets': [('rr', False)],
          'rrev': [('rreva', False)],
          'rrev-': [('rreva', False)],
          'rrevens': [('rrev', False)],
          'rrevs': [('rrev', False)],
          'rrevs-': [('rreva', False)],
          'rrfiskar': [('rrfisk', False)],
          'rrfiskarna': [('rrfisk', False)],
          'rrhake': [('rrhake', False)],
          'rrhake-': [('rrhake', False)],
          'rrhimlen': [('rrhimlen', False)],
          'rrhos': [('rrhos', False)],
          'rrhos-': [('rrhos', False)],
          'rri': [('rri', False)],
          'rri-': [('rri', False)],
          'rrier': [('rrier', False)],
          'rrierna': [('rrier', False)],
          'rriernas': [('rrier', False)],
          'rriers': [('rrier', False)],
          'rrighets': [('rrighet', False)],
          'rrikarna': [('rrikare', False)],
          'rrikarnas': [('rrikare', False)],
          'rriket': [('rrike', False)],
          'rrill-': [('rrill', False)],
          'rrin': [('rrin', False)],
          'rrin-': [('rrin', False)],
          'rriner': [('rrin', False)],
          'rrinerna': [('rrin', False)],
          'rrinernas': [('rrin', False)],
          'rriners': [('rrin', False)],
          'rringar': [('rring', False)],
          'rringarna': [('rring', False)],
          'rringarnas': [('rring', False)],
          'rrins': [('rrin', False)],
          'rris': [('rris', False)],
          'rris-': [('rris', False)],
          'rrisarna': [('rris', False)],
          'rrisk': [('rrisk', False)],
          'rrisk-': [('rrisk', False)],
          'rrit': [('rrit', False)],
          'rrit-': [('rrit', False)],
          'rriter': [('rrit', False)],
          'rrits': [('rrit', False)],
          'rrklädes-': [('rrkläder', False)],
          'rrkläds': [('rrkläder', False)],
          'rrkläds-': [('rrkläder', False)],
          'rrn': [('rr', False)],
          'rrns': [('rr', False)],
          'rrock': [('rrock', False)],
          'rrockan': [('rrocka', False)],
          'rrockar': [('rrock', False)],
          'rrockarna': [('rrock', False)],
          'rrockarnas': [('rrock', False)],
          'rroller': [('rroll', False)],
          'rrollerna': [('rroll', False)],
          'rrollernas': [('rroll', False)],
          'rrollers': [('rroll', False)],
          'rrolls': [('rroll', False)],
          'rrolls-': [('rroll', False)],
          'rromans': [('rroman', False)],
          'rron': [('rron', False)],
          'rronen': [('rron', False)],
          'rronens': [('rron', False)],
          'rrons': [('rron', False)],
          'rropen': [('rrop', False)],
          'rropens': [('rrop', False)],
          'rrops': [('rrop', False)],
          'rror': [('rra', False)],
          'rrorna': [('rra', False)],
          'rrornas': [('rra', False)],
          'rrors': [('rra', False)],
          'rros': [('rros', False)],
          'rros-': [('rros', False)],
          'rrot': [('rrot', False)],
          'rroten': [('rrot', False)],
          'rrotens': [('rrot', False)],
          'rrots': [('rrot', False)],
          'rrots-': [('rrot', False)],
          'rrs-': [('rr', False)],
          'rrsken': [('rrsken', False)],
          'rrsträck': [('rrsträck', False)],
          'rrsträcks': [('rrsträck', False)],
          'rrsträcks-': [('rrsträck', False)],
          'rrträn': [('rrträd', False)],
          'rrtränas': [('rrträd', False)],
          'rrtändarna': [('rrtändare', False)],
          'rrtändarnas': [('rrtändare', False)],
          'rrull': [('rrulle', False)],
          'rrull-': [('rrulle', False)],
          'rrullarna': [('rrulle', False)],
          'rrulle': [('rrulle', False)],
          'rrulle-': [('rrulle', False)],
          'rrulls': [('rrulle', False)],
          'rrulls-': [('rrulle', False)],
          'rrum-': [('rrum', False)],
          'rrums-': [('rrum', False)],
          'rrund': [('rrund', False)],
          'rrund-': [('rrund', False)],
          'rrunds': [('rrund', False)],
          'rrunds-': [('rrund', False)],
          'rrus': [('rrus', False)],
          'rrusk': [('rrusk', False)],
          'rrusk-': [('rrusk', False)],
          'rry': [('rry', False)],
          'rry-': [('rry', False)],
          'rrys': [('rry', False)],
          'rräds': [('rräd', False)],
          'rräds-': [('rräd', False)],
          'rrämne': [('rrämne', False)],
          'rrämne-': [('rrämne', False)],
          'rrättar': [('rrättare', False)],
          'rrättarnas': [('rrättare', False)],
          'rräv': [('rräv', False)],
          'rrävarnas': [('rräv', False)],
          'rrävs': [('rräv', False)],
          'rrävs-': [('rräv', False)],
          'rråden': [('rråd', False)],
          'rrådens': [('rråd', False)],
          'rrådet': [('rråd', False)],
          'rrågen': [('rråg', False)],
          'rrågens': [('rråg', False)],
          'rrål': [('rrål', False)],
          'rrål-': [('rrål', False)],
          'rrålar': [('rrål', False)],
          'rrålarna': [('rrål', False)],
          'rrålarnas': [('rrål', False)],
          'rrålars': [('rrål', False)],
          'rrålens': [('rrål', False)],
          'rråls': [('rrål', False)],
          'rråls-': [('rrål', False)],
          'rrån': [('rrå', False)],
          'rröst': [('rröst', False)],
          'rröst-': [('rröst', False)],
          'rrösten': [('rröst', False)],
          'rröstens': [('rröst', False)],
          'rs': [('r', True)],
          'rs-': [('rs', False)],
          'rsage': [('rsaga', False)],
          'rsage-': [('rsaga', False)],
          'rsago': [('rsaga', False)],
          'rsago-': [('rsaga', False)],
          'rsaker': [('rsak', False)],
          'rsakerna': [('rsak', False)],
          'rsakernas': [('rsak', False)],
          'rsakers': [('rsak', False)],
          'rsalen': [('rsal', False)],
          'rsalens': [('rsal', False)],
          'rsalet': [('rsal', False)],
          'rsamhällena': [('rsamhälle', False)],
          'rsanden': [('rsande', False)],
          'rsandens': [('rsande', False)],
          'rsar': [('rs', False)],
          'rsar-': [('rsar', False)],
          'rsaren': [('rsare', False)],
          'rsarens': [('rsar', False)],
          'rsarnas': [('r', False)],
          'rsars': [('rs', False)],
          'rsars-': [('rsar', False)],
          'rsat': [('rsa', False)],
          'rsats': [('rsats', False)],
          'rsats-': [('rsats', False)],
          'rsaxar': [('rsax', False)],
          'rsaxarna': [('rsax', False)],
          'rsaxarnas': [('rsax', False)],
          'rsback': [('rsbacke', False)],
          'rsbackarna': [('rsbacke', False)],
          'rsbackarnas': [('rsbacke', False)],
          'rsbacks': [('rsbacke', False)],
          'rsbit': [('rsbit', False)],
          'rsblom': [('rsblom', False)],
          'rsblom-': [('rsblom', False)],
          'rsbloms': [('rsblom', False)],
          'rsbloms-': [('rsblom', False)],
          'rsböns': [('rsbön', False)],
          'rscentrers': [('rscentrum', False)],
          'rscentret': [('rscentrum', False)],
          'rscentrets': [('rscentrum', False)],
          'rsch': [('rsch', False)],
          'rsch-': [('rsch', False)],
          'rschen': [('rsch', False)],
          'rschens': [('rsch', False)],
          'rscher': [('rsch', False)],
          'rschers': [('rsch', False)],
          'rsdos': [('rsdos', False)],
          'rsdos-': [('rsdos', False)],
          'rse': [('rsa', False)],
          'rse-': [('rsa', False)],
          'rseffekt': [('rseffekt', False)],
          'rseffekt-': [('rseffekt', False)],
          'rseffekter': [('rseffekt', False)],
          'rseffekternas': [('rseffekt', False)],
          'rseffekters': [('rseffekt', False)],
          'rseffekts': [('rseffekt', False)],
          'rseffekts-': [('rseffekt', False)],
          'rsel': [('rsel', False)],
          'rsel-': [('rsel', False)],
          'rselen': [('rsele', False)],
          'rselens': [('rsele', False)],
          'rsels': [('rsel', False)],
          'rsels-': [('rsel', False)],
          'rsemestrar': [('rsemester', False)],
          'rsemestrarna': [('rsemester', False)],
          'rsemestrarnas': [('rsemester', False)],
          'rsens': [('rs', False)],
          'rser': [('rs', False)],
          'rser-': [('rser', False)],
          'rserier': [('rserie', False)],
          'rserierna': [('rserie', False)],
          'rseriernas': [('rserie', False)],
          'rsern': [('rser', False)],
          'rserna': [('rs', False)],
          'rsernas': [('rs', False)],
          'rserns': [('rser', False)],
          'rsers': [('rs', False)],
          'rsers-': [('rser', False)],
          'rset': [('rs', False)],
          'rsetter': [('rsett', False)],
          'rsetters': [('rsett', False)],
          'rsex-': [('rsex', False)],
          'rsfadern': [('rsfar', False)],
          'rsfaders': [('rsfar', False)],
          'rsfars': [('rsfar', False)],
          'rsfars-': [('rsfar', False)],
          'rsfasoner': [('rsfason', False)],
          'rsfasonerna': [('rsfasoner', False)],
          'rsfasonernas': [('rsfasoner', False)],
          'rsfasoners': [('rsfasoner', False)],
          'rsfiskar': [('rsfisk', False)],
          'rsfiskarna': [('rsfisk', False)],
          'rsfiskarnas': [('rsfiskare', False)],
          'rsflagg': [('rsflagga', False)],
          'rsflaggs': [('rsflagga', False)],
          'rsfäder': [('rsfar', False)],
          'rsfäderna': [('rsfar', False)],
          'rsfäders': [('rsfar', False)],
          'rsförsäkringars': [('rsförsäkring', False)],
          'rsgatan': [('rsgata', False)],
          'rsgåvornas': [('rsgåva', False)],
          'rshandlarna': [('rshandel', False)],
          'rshandlarnas': [('rshandel', False)],
          'rshet': [('rshet', False)],
          'rshytts-': [('rshytt', False)],
          'rsidan': [('rsida', False)],
          'rsidans': [('rsida', False)],
          'rside': [('rsida', False)],
          'rside-': [('rsida', False)],
          'rsides': [('rsida', False)],
          'rsie': [('rsia', False)],
          'rsie-': [('rsia', False)],
          'rsik': [('rsika', False)],
          'rsik-': [('rsika', False)],
          'rsikan': [('rsikan', False)],
          'rsikans': [('rsikan', False)],
          'rsike': [('rsika', False)],
          'rsiks': [('rsika', False)],
          'rsiks-': [('rsika', False)],
          'rsikten': [('rsikte', False)],
          'rsiktens': [('rsikte', False)],
          'rsimon': [('rsimon', False)],
          'rsimons': [('rsimon', False)],
          'rsims': [('rsim', False)],
          'rsims-': [('rsim', False)],
          'rsin': [('rsiner', False)],
          'rsiner': [('rsiner', False)],
          'rsins': [('rsiner', False)],
          'rsitet': [('rsitet', False)],
          'rsitets': [('rsitet', False)],
          'rsiv': [('rsiv', False)],
          'rsiv-': [('rsiv', False)],
          'rsiven': [('rsiv', False)],
          'rsivens': [('rsiv', False)],
          'rsiver': [('rsiv', False)],
          'rsiverna': [('rsiv', False)],
          'rsivernas': [('rsiv', False)],
          'rsivers': [('rsiv', False)],
          'rsivs': [('rsiv', False)],
          'rsjukan': [('rsjuka', False)],
          'rsk': [('rska', False)],
          'rsk-': [('rska', False)],
          'rskal': [('rskala', False)],
          'rskal-': [('rskala', False)],
          'rskall': [('rskall', False)],
          'rskallen': [('rskalle', False)],
          'rskallens': [('rskall', False)],
          'rskalls': [('rskall', False)],
          'rskalls-': [('rskall', False)],
          'rskals': [('rskala', False)],
          'rskals-': [('rskala', False)],
          'rskan': [('rska', False)],
          'rskans': [('rska', False)],
          'rskaps-': [('rskap', False)],
          'rskar': [('rskare', False)],
          'rskar-': [('rskare', False)],
          'rskare': [('rskare', False)],
          'rskare-': [('rskara', False)],
          'rskarens': [('rskare', False)],
          'rskarna': [('rskare', False)],
          'rskars': [('rsk', False)],
          'rskasse': [('rskasse', False)],
          'rskatts-': [('rskatt', False)],
          'rskeden': [('rskede', False)],
          'rskedens': [('rskede', False)],
          'rsken': [('rsk', False)],
          'rskens': [('rsken', False)],
          'rskens-': [('rsken', False)],
          'rskid': [('rskid', False)],
          'rskids': [('rskid', False)],
          'rskids-': [('rskid', False)],
          'rskiften': [('rskifte', False)],
          'rskiftens': [('rskift', False)],
          'rskiftet': [('rskift', False)],
          'rskiftets': [('rskifte', False)],
          'rsklanden': [('rsklande', False)],
          'rsklandens': [('rsklande', False)],
          'rsko': [('rsko', False)],
          'rskonst': [('rskonst', False)],
          'rskor': [('rsko', False)],
          'rskorna': [('rsko', False)],
          'rskornas': [('rsko', False)],
          'rskors': [('rsko', False)],
          'rskot-': [('rskota', False)],
          'rskott': [('rskott', False)],
          'rskotten': [('rskott', False)],
          'rskottens': [('rskott', False)],
          'rskotts-': [('rskott', False)],
          'rskrak-': [('rskrake', False)],
          'rskrakar': [('rskrake', False)],
          'rskrakarna': [('rskrake', False)],
          'rskrakarnas': [('rskrake', False)],
          'rskraken': [('rskrake', False)],
          'rskraks-': [('rskrake', False)],
          'rskrank': [('rskrank', False)],
          'rskrank-': [('rskrank', False)],
          'rskranks': [('rskrank', False)],
          'rskranks-': [('rskrank', False)],
          'rskrin': [('rskri', False)],
          'rskrins': [('rskri', False)],
          'rskris': [('rskris', False)],
          'rskräms': [('rskräm', False)],
          'rskräms-': [('rskräm', False)],
          'rskull': [('rskull', False)],
          'rskullar': [('rskull', False)],
          'rskullarna': [('rskull', False)],
          'rskullarnas': [('rskull', False)],
          'rskullars': [('rskull', False)],
          'rskullen': [('rskull', False)],
          'rskullens': [('rskull', False)],
          'rskulls': [('rskull', False)],
          'rskulls-': [('rskull', False)],
          'rskulor': [('rskula', False)],
          'rskulorna': [('rskula', False)],
          'rskulornas': [('rskula', False)],
          'rskulors': [('rskula', False)],
          'rskurs': [('rskurs', False)],
          'rskurs-': [('rskurs', False)],
          'rskytten': [('rskytt', False)],
          'rskyttens': [('rskytt', False)],
          'rskär': [('rskär', False)],
          'rskär-': [('rskär', False)],
          'rskärmar': [('rskärm', False)],
          'rskärmarna': [('rskärm', False)],
          'rskärmarnas': [('rskärm', False)],
          'rskärs': [('rskär', False)],
          'rskärs-': [('rskär', False)],
          'rskärv': [('rskärva', False)],
          'rskärv-': [('rskärva', False)],
          'rskärve': [('rskärva', False)],
          'rskärvs': [('rskärva', False)],
          'rskärvs-': [('rskärva', False)],
          'rskötar': [('rskötare', False)],
          'rskötarna': [('rskötare', False)],
          'rskötarnas': [('rskötare', False)],
          'rslag': [('rslag', False)],
          'rslagar': [('rslagare', False)],
          'rslagarna': [('rslagare', False)],
          'rslagarnas': [('rslagare', False)],
          'rslager': [('rslager', False)],
          'rslagernas': [('rslager', False)],
          'rslagers': [('rslager', False)],
          'rslags': [('rslag', False)],
          'rslags-': [('rslag', False)],
          'rslams': [('rslam', False)],
          'rslams-': [('rslam', False)],
          'rslan': [('rsla', False)],
          'rslandets': [('rslande', False)],
          'rslans': [('rsla', False)],
          'rslantar': [('rslant', False)],
          'rslantars': [('rslant', False)],
          'rslants-': [('rslant', False)],
          'rslar': [('rsel', False)],
          'rslarna': [('rsel', False)],
          'rslarnas': [('rsel', False)],
          'rslarv': [('rslarv', False)],
          'rslarv-': [('rslarv', False)],
          'rslarvs': [('rslarv', False)],
          'rslas': [('rsla', False)],
          'rsle': [('rsle', False)],
          'rsle-': [('rsle', False)],
          'rslid': [('rslida', False)],
          'rslid-': [('rslida', False)],
          'rslids': [('rslida', False)],
          'rslids-': [('rslida', False)],
          'rsling': [('rsling', False)],
          'rslings': [('rsling', False)],
          'rslings-': [('rsling', False)],
          'rslipar': [('rslipare', False)],
          'rsliparna': [('rslipare', False)],
          'rsliparnas': [('rslipare', False)],
          'rslopp': [('rslopp', False)],
          'rslopps': [('rslopp', False)],
          'rslopps-': [('rslopp', False)],
          'rslotts': [('rslott', False)],
          'rsläkten': [('rsläkt', False)],
          'rsläktens': [('rsläkt', False)],
          'rsläkts': [('rsläkt', False)],
          'rsläng': [('rsläng', False)],
          'rslängs': [('rsläng', False)],
          'rslån': [('rslå', False)],
          'rslåns': [('rslå', False)],
          'rsmatt': [('rsmatt', False)],
          'rsmatts-': [('rsmatt', False)],
          'rsmoder': [('rsmor', False)],
          'rsmoder-': [('rsmor', False)],
          'rsmor': [('rsmor', False)],
          'rsmors': [('rsmor', False)],
          'rsmäll': [('rsmäll', False)],
          'rsmäll-': [('rsmäll', False)],
          'rsmällar': [('rsmäll', False)],
          'rsmällarna': [('rsmäll', False)],
          'rsmällarnas': [('rsmäll', False)],
          'rsmälls': [('rsmäll', False)],
          'rsmälls-': [('rsmäll', False)],
          'rsmödrar': [('rsmor', False)],
          'rsmödrarna': [('rsmor', False)],
          'rsmödrarnas': [('rsmor', False)],
          'rsmödrars': [('rsmor', False)],
          'rsnacks': [('rsnack', False)],
          'rsnacks-': [('rsnack', False)],
          'rsnäpp': [('rsnäppa', False)],
          'rsnäpp-': [('rsnäppa', False)],
          'rsnäpps': [('rsnäppa', False)],
          'rsnäpps-': [('rsnäppa', False)],
          'rsnärje': [('rsnärja', False)],
          'rso-': [('rso', False)],
          'rsområdet': [('rsområde', False)],
          'rson': [('rson', False)],
          'rsonar': [('rsonare', False)],
          'rsonar-': [('rsonare', False)],
          'rsonarnas': [('rsonare', False)],
          'rsoner': [('rson', False)],
          'rsonerna': [('rson', False)],
          'rsonernas': [('rson', False)],
          'rsoners': [('rson', False)],
          'rsons': [('rson', False)],
          'rsopp': [('rsoppa', False)],
          'rsopp-': [('rsoppa', False)],
          'rsopps': [('rsoppa', False)],
          'rsopps-': [('rsoppa', False)],
          'rsor': [('rsa', False)],
          'rsorna': [('rsa', False)],
          'rsornas': [('rsa', False)],
          'rsors': [('rsa', False)],
          'rspad': [('rspade', False)],
          'rspad-': [('rspade', False)],
          'rspads': [('rspade', False)],
          'rspads-': [('rspade', False)],
          'rspasch': [('rspascha', False)],
          'rspasch-': [('rspascha', False)],
          'rspektiven': [('rspektiv', False)],
          'rspektivens': [('rspektiv', False)],
          'rspeng': [('rspeng', False)],
          'rspeng-': [('rspeng', False)],
          'rspengar': [('rspeng', False)],
          'rspengarna': [('rspeng', False)],
          'rspengarnas': [('rspeng', False)],
          'rspengars': [('rspeng', False)],
          'rspengs': [('rspeng', False)],
          'rspengs-': [('rspeng', False)],
          'rspets': [('rspets', False)],
          'rspets-': [('rspets', False)],
          'rspisar': [('rspis', False)],
          'rspisarna': [('rspis', False)],
          'rspisarnas': [('rspis', False)],
          'rspol-': [('rspole', False)],
          'rspolar': [('rspole', False)],
          'rspolen': [('rspole', False)],
          'rspolens': [('rspole', False)],
          'rsportar': [('rsport', False)],
          'rsportarna': [('rsport', False)],
          'rspring': [('rspringa', False)],
          'rspring-': [('rspringa', False)],
          'rsprings': [('rspringa', False)],
          'rsprings-': [('rspringa', False)],
          'rspris': [('rspris', False)],
          'rsprit': [('rsprit', False)],
          'rsprits': [('rsprit', False)],
          'rsprits-': [('rsprit', False)],
          'rsproblemet': [('rsproblemet', False)],
          'rsproblemets': [('rsproblemet', False)],
          'rsprut': [('rspruta', False)],
          'rsprut-': [('rspruta', False)],
          'rspruts': [('rspruta', False)],
          'rspruts-': [('rspruta', False)],
          'rspännen': [('rspänne', False)],
          'rspännens': [('rspänne', False)],
          'rspån': [('rspån', False)],
          'rspåns': [('rspån', False)],
          'rspåns-': [('rspån', False)],
          'rsraster': [('rsraster', False)],
          'rsrasterna': [('rsrast', False)],
          'rsrasternas': [('rsraster', False)],
          'rsrasters': [('rsraster', False)],
          'rsringar': [('rsring', False)],
          'rsråns': [('rsrå', False)],
          'rsskiften': [('rsskifte', False)],
          'rsskiftens': [('rsskifte', False)],
          'rsskiftet': [('rsskift', False)],
          'rsskiftets': [('rsskift', False)],
          'rsspinnar': [('rsspinnare', False)],
          'rsspinnarna': [('rsspinnare', False)],
          'rsspinnarnas': [('rsspinnare', False)],
          'rssylt-': [('rssylt', False)],
          'rssylts': [('rssylt', False)],
          'rssylts-': [('rssylt', False)],
          'rst': [('rst', False)],
          'rstackar': [('rstack', False)],
          'rstackarna': [('rstack', False)],
          'rstackarnas': [('rstack', False)],
          'rstadie': [('rstadium', False)],
          'rstadie-': [('rstadium', False)],
          'rstadier': [('rstadium', False)],
          'rstadierna': [('rstadium', False)],
          'rstadiernas': [('rstadium', False)],
          'rstadiers': [('rstadium', False)],
          'rstadiet': [('rstadium', False)],
          'rstadiets': [('rstadium', False)],
          'rstadium': [('rstadium', False)],
          'rstadiums': [('rstadium', False)],
          'rstagets': [('rstag', False)],
          'rstalets': [('rstal', False)],
          'rstammar': [('rstam', False)],
          'rstammarna': [('rstam', False)],
          'rstammarnas': [('rstam', False)],
          'rstanden': [('rstand', False)],
          'rstandens': [('rstand', False)],
          'rstans': [('rstad', False)],
          'rstans-': [('rstans', False)],
          'rstar': [('rste', False)],
          'rstar-': [('rstare', False)],
          'rstarna': [('rste', False)],
          'rstarnas': [('rste', False)],
          'rstars': [('rste', False)],
          'rstarter': [('rstart', False)],
          'rstarterna': [('rstart', False)],
          'rstarternas': [('rstart', False)],
          'rstarters': [('rstart', False)],
          'rstavarna': [('rstav', False)],
          'rste': [('rste', False)],
          'rste-': [('rste', False)],
          'rsteg': [('rsteg', False)],
          'rsteg-': [('rstege', False)],
          'rstegen': [('rsteg', False)],
          'rstegens': [('rsteg', False)],
          'rstegs': [('rsteg', False)],
          'rstegs-': [('rsteg', False)],
          'rstekar': [('rstek', False)],
          'rstekarna': [('rstek', False)],
          'rstekarnas': [('rstek', False)],
          'rstens': [('rsten', False)],
          'rstets': [('rst', False)],
          'rstick': [('rstick', False)],
          'rstick-': [('rstick', False)],
          'rsticks': [('rstick', False)],
          'rsticks-': [('rstick', False)],
          'rstol': [('rstol', False)],
          'rstol-': [('rstol', False)],
          'rstols': [('rstol', False)],
          'rstols-': [('rstol', False)],
          'rstormarnas': [('rstorm', False)],
          'rstripp': [('rstripp', False)],
          'rstripp-': [('rstripp', False)],
          'rstripps': [('rstripp', False)],
          'rstripps-': [('rstripp', False)],
          'rsträck': [('rsträcka', False)],
          'rsträck-': [('rsträcka', False)],
          'rsträcks': [('rsträcka', False)],
          'rsträcks-': [('rsträcka', False)],
          'rsträna': [('rsträd', False)],
          'rstränas': [('rsträd', False)],
          'rstråk': [('rstråk', False)],
          'rstråk-': [('rstråk', False)],
          'rstråken': [('rstråk', False)],
          'rstråkens': [('rstråk', False)],
          'rstråks': [('rstråk', False)],
          'rstråks-': [('rstråk', False)],
          'rstrån': [('rstrå', False)],
          'rstråns': [('rstrå', False)],
          'rstråt': [('rstråt', False)],
          'rstråts': [('rstrå', False)],
          'rstubb': [('rstubb', False)],
          'rstubben': [('rstubb', False)],
          'rstubbens': [('rstubb', False)],
          'rstubbs': [('rstubb', False)],
          'rstubbs-': [('rstubb', False)],
          'rstudie': [('rstudie', False)],
          'rstudie-': [('rstudium', False)],
          'rstudier': [('rstudie', False)],
          'rstudierna': [('rstudie', False)],
          'rstudiernas': [('rstudie', False)],
          'rstudiers': [('rstudium', False)],
          'rstump': [('rstump', False)],
          'rstump-': [('rstump', False)],
          'rstumps': [('rstump', False)],
          'rstumps-': [('rstump', False)],
          'rstuns': [('rstu', False)],
          'rstup': [('rstup', False)],
          'rstup-': [('rstup', False)],
          'rstups': [('rstup', False)],
          'rstups-': [('rstup', False)],
          'rstur': [('rstu', False)],
          'rsturs': [('rstu', False)],
          'rstycken': [('rstycke', False)],
          'rstyckena': [('rstycke', False)],
          'rstyckenas': [('rstycke', False)],
          'rstyckens': [('rstycke', False)],
          'rstycket': [('rstycke', False)],
          'rstyckets': [('rstycke', False)],
          'rstycks': [('rstycke', False)],
          'rstyren': [('rstyre', False)],
          'rstyrens': [('rstyre', False)],
          'rstyret': [('rstyre', False)],
          'rstyrkan': [('rstyrka', False)],
          'rstyrke': [('rstyrka', False)],
          'rställanden': [('rställande', False)],
          'rställandena': [('rställande', False)],
          'rställandenas': [('rställande', False)],
          'rställandens': [('rställande', False)],
          'rställen': [('rställe', False)],
          'rställens': [('rställe', False)],
          'rstället': [('rställe', False)],
          'rställets': [('rställe', False)],
          'rställningar': [('rställning', False)],
          'rställningarna': [('rställning', False)],
          'rställningarnas': [('rställning', False)],
          'rställningars': [('rställning', False)],
          'rställnings': [('rställning', False)],
          'rställnings-': [('rställning', False)],
          'rständer': [('rstand', False)],
          'rständerna': [('rstand', False)],
          'rständernas': [('rstand', False)],
          'rständers': [('rstand', False)],
          'rstäv': [('rstäv', False)],
          'rstäv-': [('rstäv', False)],
          'rstävs': [('rstäv', False)],
          'rstävs-': [('rstäv', False)],
          'rstörar': [('rstörare', False)],
          'rstörarna': [('rstörare', False)],
          'rstörarnas': [('rstörare', False)],
          'rstötarnas': [('rstöt', False)],
          'rstövel': [('rstövlar', False)],
          'rstövel-': [('rstövlar', False)],
          'rstövels': [('rstövlar', False)],
          'rstövels-': [('rstövlar', False)],
          'rstövlar': [('rstövlar', False)],
          'rstövlarna': [('rstövlar', False)],
          'rstövlarnas': [('rstövlar', False)],
          'rstövlars': [('rstövel', False)],
          'rsvak-': [('rsvaka', False)],
          'rsvaks-': [('rsvaka', False)],
          'rsval': [('rsval', False)],
          'rsvalen': [('rsval', False)],
          'rsvalens': [('rsval', False)],
          'rsvals': [('rsval', False)],
          'rsvals-': [('rsval', False)],
          'rsvanor': [('rsvana', False)],
          'rsvanorna': [('rsvana', False)],
          'rsvanornas': [('rsvana', False)],
          'rsvanors': [('rsvana', False)],
          'rsvans': [('rsvans', False)],
          'rsvans-': [('rsvans', False)],
          'rsvar': [('rsvar', False)],
          'rsvarar': [('rsvarare', False)],
          'rsvararna': [('rsvarare', False)],
          'rsvararnas': [('rsvarare', False)],
          'rsvennen': [('rsven', False)],
          'rsvennens': [('rsven', False)],
          'rsvensk': [('rsvensk', False)],
          'rsvensk-': [('rsvensk', False)],
          'rsverken': [('rsverk', False)],
          'rsverkens': [('rsverk', False)],
          'rsverket': [('rsverk', False)],
          'rsverks': [('rsverk', False)],
          'rsverks-': [('rsverk', False)],
          'rsvindlar': [('rsvindel', False)],
          'rsvindlarna': [('rsvindel', False)],
          'rsvindlarnas': [('rsvindel', False)],
          'rsving': [('rsving', False)],
          'rsvingarnas': [('rsving', False)],
          'rsvägens': [('rsväg', False)],
          'rsvärmar': [('rsvärmare', False)],
          'rsvärmarna': [('rsvärmare', False)],
          'rsvärmarnas': [('rsvärmare', False)],
          'rsväsendet': [('rsväsen', False)],
          'rsyn': [('rsyn', False)],
          'rsyns': [('rsyn', False)],
          'rsyre': [('rsyra', False)],
          'rsyre-': [('rsyra', False)],
          'rsysslornas': [('rsyssla', False)],
          'rsäden': [('rsäd', False)],
          'rsädens': [('rsäd', False)],
          'rsädes': [('rsäd', False)],
          'rsäds': [('rsäd', False)],
          'rsäds-': [('rsäd', False)],
          'rsäkringar': [('rsäkring', False)],
          'rsäkringars': [('rsäkring', False)],
          'rsändar': [('rsändare', False)],
          'rsändarna': [('rsändare', False)],
          'rsås': [('rsås', False)],
          'rsås-': [('rsås', False)],
          'rsåt': [('rsåte', False)],
          'rsåt-': [('rsåte', False)],
          'rsåtar': [('rsåte', False)],
          'rsåtarna': [('rsåte', False)],
          'rsåtarnas': [('rsåte', False)],
          'rsåtars': [('rsåte', False)],
          'rsåten': [('rsåt', False)],
          'rsåtens': [('rsåte', False)],
          'rsåts': [('rsåt', False)],
          'rsåts-': [('rsåt', False)],
          'rsömmar': [('rsöm', False)],
          'rsömmarna': [('rsöm', False)],
          'rsömmarnas': [('rsöm', False)],
          'rt': [('rt', False)],
          'rt-': [('rt', False)],
          'rtack': [('rtacka', False)],
          'rtack-': [('rtacka', False)],
          'rtacks': [('rtacka', False)],
          'rtacks-': [('rtacka', False)],
          'rtagen': [('rtag', False)],
          'rtagens': [('rtag', False)],
          'rtaget': [('rtag', False)],
          'rtagets': [('rtage', False)],
          'rtak': [('rtak', False)],
          'rtaken': [('rtak', False)],
          'rtaket': [('rtak', False)],
          'rtaktiker': [('rtaktik', False)],
          'rtaktikerna': [('rtaktik', False)],
          'rtaktikernas': [('rtaktik', False)],
          'rtaktikers': [('rtaktik', False)],
          'rtalandena': [('rtalande', False)],
          'rtalandenas': [('rtalande', False)],
          'rtalandens': [('rtalande', False)],
          'rtalar': [('rtalare', False)],
          'rtalar-': [('rtalare', False)],
          'rtalaren': [('rtalare', False)],
          'rtalarens': [('rtalare', False)],
          'rtalen': [('rtal', False)],
          'rtalens': [('rtal', False)],
          'rtaler': [('rtal', False)],
          'rtalerna': [('rtal', False)],
          'rtalernas': [('rtal', False)],
          'rtalers': [('rtal', False)],
          'rtalet': [('rtal', False)],
          'rtan-': [('rtan', False)],
          'rtana': [('rta', False)],
          'rtanas': [('rta', False)],
          'rtanden': [('rtande', False)],
          'rtandens': [('rtande', False)],
          'rtangenten': [('rtangent', False)],
          'rtangentens': [('rtangent', False)],
          'rtanke-': [('rtanke', False)],
          'rtanken': [('rtanke', False)],
          'rtankens': [('rtanke', False)],
          'rtanker': [('rtanker', False)],
          'rtankerna': [('rtanker', False)],
          'rtankernas': [('rtanker', False)],
          'rtankers': [('rtanker', False)],
          'rtans': [('rta', False)],
          'rtants': [('rtant', False)],
          'rtar': [('rt', False)],
          'rtar-': [('rtar', False)],
          'rtaren': [('rtare', False)],
          'rtarens': [('rtar', False)],
          'rtarna': [('rt', False)],
          'rtars': [('rt', False)],
          'rtbit': [('rtbit', False)],
          'rte': [('rta', False)],
          'rte-': [('rta', False)],
          'rteg': [('rteg', False)],
          'rtegars': [('rteg', False)],
          'rtegen': [('rtege', False)],
          'rtegens': [('rteg', False)],
          'rtegerna': [('rtege', False)],
          'rtekniker': [('rteknik', False)],
          'rteknikerna': [('rteknik', False)],
          'rteknikernas': [('rteknik', False)],
          'rteknikers': [('rteknik', False)],
          'rtel': [('rtel', False)],
          'rteln': [('rtel', False)],
          'rtelns': [('rtel', False)],
          'rtels': [('rtel', False)],
          'rtels-': [('rtel', False)],
          'rten': [('rt', False)],
          'rtenn': [('rten', False)],
          'rtenns': [('rten', False)],
          'rtens': [('rt', False)],
          'rtens-': [('rtens', False)],
          'rter': [('rt', False)],
          'rter-': [('rter', False)],
          'rteranden': [('rterande', False)],
          'rterandens': [('rterande', False)],
          'rterit': [('rterit', False)],
          'rteriter': [('rterit', False)],
          'rteriterna': [('rterit', False)],
          'rteriters': [('rterit', False)],
          'rtermer': [('rterm', False)],
          'rtermerna': [('rterm', False)],
          'rtermernas': [('rterm', False)],
          'rtermers': [('rterm', False)],
          'rtermin': [('rtermin', False)],
          'rtern': [('rter', False)],
          'rterna': [('rt', False)],
          'rternas': [('rt', False)],
          'rterns': [('rter', False)],
          'rters': [('rt', False)],
          'rters-': [('rter', False)],
          'rtes': [('rte', False)],
          'rtestens': [('rtest', False)],
          'rtet': [('rt', False)],
          'rteters': [('rtet', False)],
          'rteverket': [('rteverket', False)],
          'rtfiskarna': [('rtfisk', False)],
          'rthet': [('rthet', False)],
          'rthets': [('rthet', False)],
          'rtick': [('rticka', False)],
          'rtick-': [('rticka', False)],
          'rticks': [('rticka', False)],
          'rticks-': [('rticka', False)],
          'rtiden': [('rtid', False)],
          'rtider': [('rtid', False)],
          'rtiderna': [('rtid', False)],
          'rtiders': [('rtid', False)],
          'rtie': [('rtium', False)],
          'rtie-': [('rtium', False)],
          'rtiet': [('rtium', False)],
          'rtiets': [('rti', False)],
          'rtigar': [('rtig', False)],
          'rtigarna': [('rtig', False)],
          'rtigarnas': [('rtig', False)],
          'rtigen': [('rtig', False)],
          'rtigens': [('rtig', False)],
          'rtighets': [('rtighet', False)],
          'rtik': [('rtik', False)],
          'rtiker': [('rtik', False)],
          'rtikerna': [('rtik', False)],
          'rtikernas': [('rtik', False)],
          'rtikers': [('rtik', False)],
          'rtilen': [('rtil', False)],
          'rtilens': [('rtil', False)],
          'rtimans': [('rtiman', False)],
          'rtina': [('rtina', False)],
          'rtiner': [('rtin', False)],
          'rtinerna': [('rtin', False)],
          'rtinernas': [('rtin', False)],
          'rtiners': [('rtin', False)],
          'rtinorna': [('rtina', False)],
          'rtins': [('rti', False)],
          'rtions-': [('rtion', False)],
          'rtis': [('rti', False)],
          'rtis-': [('rtis', False)],
          'rtisteriet': [('rtisteri', False)],
          'rtit': [('rtit', False)],
          'rtit-': [('rtit', False)],
          'rtits': [('rti', False)],
          'rtittar': [('rtittare', False)],
          'rtittarna': [('rtittare', False)],
          'rtittarnas': [('rtittare', False)],
          'rtkulan': [('rtkula', False)],
          'rtkulans': [('rtkula', False)],
          'rtlandets': [('rtlande', False)],
          'rtlar': [('rtel', False)],
          'rtlarna': [('rtel', False)],
          'rtlarnas': [('rtel', False)],
          'rtler': [('rtler', False)],
          'rtlerna': [('rtler', False)],
          'rtlers': [('rtler', False)],
          'rtnar': [('rten', False)],
          'rtnarna': [('rten', False)],
          'rto-': [('rto', False)],
          'rtoar': [('rtoar', False)],
          'rtoars': [('rtoar', False)],
          'rtolkar': [('rtolk', False)],
          'rtolkarna': [('rtolk', False)],
          'rtolkarnas': [('rtolk', False)],
          'rtomten': [('rtomt', False)],
          'rtomtens': [('rtomt', False)],
          'rton': [('rton', False)],
          'rtoner': [('rton', False)],
          'rtonerna': [('rton', False)],
          'rtonernas': [('rton', False)],
          'rtons': [('rton', False)],
          'rtopparnas': [('rtopp', False)],
          'rtor': [('rta', False)],
          'rtorier': [('rtorium', False)],
          'rtork': [('rtork', False)],
          'rtork-': [('rtork', False)],
          'rtorkarnas': [('rtork', False)],
          'rtorna': [('rta', False)],
          'rtornas': [('rta', False)],
          'rtors': [('rta', False)],
          'rtorv': [('rtorv', False)],
          'rtorvs': [('rtorv', False)],
          'rtorvs-': [('rtorv', False)],
          'rtos': [('rto', False)],
          'rtox-': [('rtoxe', False)],
          'rtramp': [('rtramp', False)],
          'rtramp-': [('rtramp', False)],
          'rtramps': [('rtramp', False)],
          'rtramps-': [('rtramp', False)],
          'rtran': [('rtran', False)],
          'rtran-': [('rtran', False)],
          'rtrans': [('rtran', False)],
          'rtrans-': [('rtran', False)],
          'rtrapp': [('rtrappa', False)],
          'rtrapp-': [('rtrappa', False)],
          'rtrapps': [('rtrappa', False)],
          'rtrapps-': [('rtrappa', False)],
          'rtrar': [('rter', False)],
          'rtrarna': [('rter', False)],
          'rtrars': [('rter', False)],
          'rtratt': [('rtratt', False)],
          'rtratts': [('rtratt', False)],
          'rtratts-': [('rtratt', False)],
          'rtrav': [('rtrav', False)],
          'rtravs': [('rtrav', False)],
          'rtravs-': [('rtrav', False)],
          'rtret': [('rtret', False)],
          'rtretanden': [('rtretande', False)],
          'rtretandens': [('rtretande', False)],
          'rtrets': [('rtret', False)],
          'rtrevs': [('rtreva', False)],
          'rtricks': [('rtrick', False)],
          'rtricks-': [('rtrick', False)],
          'rtritar': [('rtritare', False)],
          'rtritarna': [('rtritare', False)],
          'rtritarnas': [('rtritare', False)],
          'rtron': [('rtro', False)],
          'rtron-': [('rtron', False)],
          'rtrons': [('rtron', False)],
          'rtros': [('rtro', False)],
          'rtros-': [('rtro', False)],
          'rtrots': [('rtrot', False)],
          'rtrots-': [('rtrot', False)],
          'rtrycken': [('rtryck', False)],
          'rtryckens': [('rtryck', False)],
          'rtrycket': [('rtryck', False)],
          'rtryckets': [('rtryck', False)],
          'rtrycks': [('rtryck', False)],
          'rtrycks-': [('rtryck', False)],
          'rträd': [('rträd', False)],
          'rträd-': [('rträd', False)],
          'rträden': [('rträd', False)],
          'rträdens': [('rträd', False)],
          'rträdet': [('rträd', False)],
          'rträdets': [('rträd', False)],
          'rträds': [('rträd', False)],
          'rträn': [('rträ', False)],
          'rträna': [('rträd', False)],
          'rtränas': [('rträ', False)],
          'rträns': [('rträd', False)],
          'rträt': [('rträ', False)],
          'rträts': [('rträ', False)],
          'rts': [('rt', False)],
          'rts-': [('rt', False)],
          'rtsar': [('rts', False)],
          'rtsarna': [('rt', False)],
          'rtsarnas': [('rt', False)],
          'rtsars': [('rts', False)],
          'rtsen': [('rt', False)],
          'rtsens': [('rt', False)],
          'rtskeden': [('rtsked', False)],
          'rtskedens': [('rtsked', False)],
          'rtskjuts': [('rtskjut', False)],
          'rtspads-': [('rtspade', False)],
          'rtte': [('rtte', False)],
          'rtte-': [('rtte', False)],
          'rttet': [('rtte', False)],
          'rttidens': [('rttid', False)],
          'rtug': [('rtug', False)],
          'rtullar': [('rtull', False)],
          'rtullarna': [('rtull', False)],
          'rtullarnas': [('rtull', False)],
          'rtuna': [('rtuna', False)],
          'rtunas': [('rtuna', False)],
          'rtur': [('rtur', False)],
          'rturer': [('rtur', False)],
          'rturerna': [('rtur', False)],
          'rturernas': [('rtur', False)],
          'rturs': [('rtur', False)],
          'rturs-': [('rtur', False)],
          'rtut': [('rtut', False)],
          'rtut-': [('rtut', False)],
          'rtuts': [('rtuta', False)],
          'rtuts-': [('rtuta', False)],
          'rtvind': [('rtvind', False)],
          'rtvägen': [('rtväg', False)],
          'rtvägens': [('rtväg', False)],
          'rtypen': [('rtyp', False)],
          'rtypens': [('rtyp', False)],
          'rtyper': [('rtyp', False)],
          'rtypernas': [('rtyp', False)],
          'rtypers': [('rtyp', False)],
          'rtyr': [('rtyr', False)],
          'rtyr-': [('rtyr', False)],
          'rtyren': [('rtyr', False)],
          'rtyrens': [('rtyr', False)],
          'rtyrer': [('rtyr', False)],
          'rtyrerna': [('rtyr', False)],
          'rtyrernas': [('rtyr', False)],
          'rtyrers': [('rtyr', False)],
          'rtyrs': [('rtyr', False)],
          'rtyrs-': [('rtyr', False)],
          'rtändar': [('rtändare', False)],
          'rtändarna': [('rtände', False)],
          'rtändarnas': [('rtände', False)],
          'rtänger': [('rtång', False)],
          'rtängernas': [('rtång', False)],
          'rtängers': [('rtång', False)],
          'rtäpp': [('rtäppa', False)],
          'rtäpps-': [('rtäppa', False)],
          'rtåg': [('rtåg', False)],
          'rtågs': [('rtåg', False)],
          'rtågs-': [('rtåg', False)],
          'rtång': [('rtång', False)],
          'rtång-': [('rtång', False)],
          'rtången': [('rtång', False)],
          'rtångens': [('rtång', False)],
          'rtångs': [('rtång', False)],
          'rtår': [('rtå', False)],
          'rtårs': [('rtå', False)],
          'ru': [('ru', False)],
          'ru-': [('ra', False)],
          'ruan': [('ruan', False)],
          'ruans': [('ruan', False)],
          'ruar': [('ru', False)],
          'ruarna': [('ru', False)],
          'ruars': [('ru', False)],
          'rubb': [('rubba', False)],
          'rubbarna': [('rubb', False)],
          'rubbarnas': [('rubb', False)],
          'rubbars': [('rubb', False)],
          'rubbe': [('rubba', False)],
          'rubbe-': [('rubba', False)],
          'rubbel': [('rubbel', False)],
          'rubbel-': [('rubbel', False)],
          'rubbens': [('rubb', False)],
          'rubbet': [('rubbet', True)],
          'rubbets': [('rubbet', True)],
          'rubbor': [('rubba', False)],
          'rubborna': [('rubba', False)],
          'rubbornas': [('rubba', False)],
          'rubbors': [('rubba', False)],
          'rubbs-': [('rubba', False)],
          'ruben': [('ruben', False)],
          'rubens': [('ruben', False)],
          'rubilar': [('rubil', False)],
          'ruck': [('ruck', False)],
          'ruck-': [('ruck', False)],
          'ruckar': [('ruck', False)],
          'ruckarna': [('ruck', False)],
          'ruckel': [('ruckel', False)],
          'ruckel-': [('ruckel', True)],
          'rucklarna': [('rucklare', True)],
          'rucklen': [('ruckel', True)],
          'rucklens': [('ruckel', True)],
          'rucklet': [('ruckel', True)],
          'rucklets': [('ruckel', False)],
          'rucks': [('ruck', False)],
          'rucks-': [('ruck', False)],
          'rud': [('ruda', True)],
          'rud-': [('ruda', True)],
          'rudan': [('ruda', True)],
          'rudanden': [('rudand', False)],
          'rudandens': [('rudand', False)],
          'rudans': [('ruda', True)],
          'rudel-': [('rudel', False)],
          'rudens': [('rudens', False)],
          'ruds': [('ruda', True)],
          'ruds-': [('ruda', True)],
          'ruen': [('rue', False)],
          'ruens': [('ruens', False)],
          'ruettens': [('ruett', False)],
          'ruetters': [('ruett', False)],
          'ruff': [('ruff', False)],
          'ruff-': [('ruff', True)],
          'ruffar': [('ruff', False)],
          'ruffarna': [('ruff', True)],
          'ruffs': [('ruff', False)],
          'ruffs-': [('ruff', True)],
          'rufs': [('rufs', False)],
          'rug': [('ruga', False)],
          'rugets': [('rug', False)],
          'rugg-': [('rugge', False)],
          'ruggar': [('rugge', True)],
          'ruggarna': [('rugge', True)],
          'ruggarnas': [('rugge', False)],
          'ruggens': [('rugge', True)],
          'rugs': [('ruga', False)],
          'ruiden': [('ruid', False)],
          'ruidens': [('ruid', False)],
          'ruider': [('ruid', False)],
          'ruiderna': [('ruid', False)],
          'ruidernas': [('ruid', False)],
          'ruiders': [('ruid', False)],
          'ruins': [('ruin', False)],
          'ruk': [('ruka', False)],
          'ruk-': [('ruka', False)],
          'rukan': [('ruka', False)],
          'rukar': [('rukare', False)],
          'rukarna': [('rukare', False)],
          'rukas': [('ruka', False)],
          'ruks': [('ruka', False)],
          'ruks-': [('ruka', False)],
          'rukt': [('rukt', False)],
          'rukt-': [('rukt', False)],
          'ruktans': [('ruktan', False)],
          'ruktans-': [('ruktan', False)],
          'rukter': [('rukt', False)],
          'rukterna': [('rukt', False)],
          'rukternas': [('rukt', False)],
          'rukters': [('rukt', False)],
          'rukts': [('rukt', False)],
          'rukts-': [('rukt', False)],
          'rulans': [('rulans', False)],
          'rularna': [('rul', False)],
          'rulens': [('rulens', False)],
          'rulinets': [('rulin', False)],
          'rull': [('rulle', True), ('rulla', True)],
          'rull-': [('rulla', True), ('rulle', True)],
          'rullar': [('rulle', True)],
          'rullarna': [('rulle', True)],
          'rullarnas': [('rulle', False)],
          'rullbräde': [('rullbräda', True), ('rullbräde', True)],
          'rulle': [('rulle', True), ('rulla', True)],
          'rulle-': [('rulla', False)],
          'rullen': [('rulle', False)],
          'rullens': [('rulle', False)],
          'ruller': [('rull', False)],
          'rullerna': [('rull', False)],
          'rullernas': [('rull', False)],
          'rullers': [('rull', False)],
          'rulls': [('rulla', True), ('rulle', True)],
          'rulls-': [('rulla', True), ('rulle', True)],
          'rulsar': [('ruls', False)],
          'rulsars': [('ruls', False)],
          'rult': [('rulta', True)],
          'rulte': [('rulta', True)],
          'rults': [('rulta', True)],
          'rults-': [('rulta', True)],
          'rum': [('rum', True)],
          'ruman': [('ruma', False)],
          'rumbas': [('rumba', True)],
          'rumbor': [('rumba', True)],
          'rumborna': [('rumba', True)],
          'rumbornas': [('rumba', True)],
          'rumlar': [('rumlare', True)],
          'rumlarna': [('rumlare', True)],
          'rumlarnas': [('rumlare', True)],
          'rumlet': [('rummel', True)],
          'rumlets': [('rummel', False)],
          'rummar': [('rummare', False)],
          'rummarna': [('rummare', False)],
          'rumme': [('rumma', False)],
          'rumme-': [('rumma', False)],
          'rummis': [('rummis', False)],
          'rummis-': [('rummis', False)],
          'rumpor': [('rumpa', False)],
          'rumporna': [('rumpa', True)],
          'rumpornas': [('rumpa', False)],
          'rumpors': [('rumpa', False)],
          'rums': [('rum', True)],
          'rums-': [('rum', True)],
          'rumset': [('rums', False)],
          'rumsets': [('rumset', False)],
          'rumän': [('rumän', True)],
          'rumäns': [('rumän', True)],
          'run': [('runa', True)],
          'run-': [('runa', False)],
          'runanden': [('runand', False)],
          'rund': [('runda', True)],
          'rund-': [('runda', True)],
          'rundan': [('runda', False)],
          'rundans': [('runda', True)],
          'rundans-': [('rundan', False)],
          'rundarnas': [('rundare', False)],
          'runder': [('rund', False)],
          'runderna': [('rund', False)],
          'runders': [('rund', False)],
          'rundier': [('rundier', False)],
          'rundierna': [('rundier', False)],
          'rundiernas': [('rundier', False)],
          'rundiers': [('rundier', False)],
          'runds': [('runda', True)],
          'runds-': [('runda', True)],
          'rung': [('rung', False)],
          'rung-': [('rung', False)],
          'rungen': [('rung', False)],
          'rungens': [('rung', False)],
          'rungs': [('rung', False)],
          'rungs-': [('rung', False)],
          'runk': [('runk', True)],
          'runk-': [('runk', False)],
          'runkar': [('runkare', True)],
          'runkarna': [('runkare', True)],
          'runkarnas': [('runkare', True)],
          'runkars': [('runk', False)],
          'runke': [('runka', False)],
          'runke-': [('runka', False)],
          'runken': [('runk', False)],
          'runkens': [('runk', True)],
          'runks': [('runk', True)],
          'runks-': [('runk', True)],
          'runnar': [('runnare', True)],
          'runnarna': [('runnare', True)],
          'runnarnas': [('runnare', True)],
          'runnen': [('runn', False)],
          'runnens': [('runn', False)],
          'runns': [('runn', False)],
          'runns-': [('runn', False)],
          'runs': [('runa', False)],
          'runs-': [('runa', False)],
          'runsten': [('runsten', True)],
          'runstens': [('runsten', True)],
          'runt': [('runt', False)],
          'runtar': [('runte', False)],
          'runtarnas': [('runte', False)],
          'runten': [('runt', False)],
          'runtens': [('runt', False)],
          'runts-': [('runt', False)],
          'rup': [('rupe', False)],
          'rup-': [('rupe', False)],
          'rupar': [('rupe', False)],
          'ruparna': [('rupe', False)],
          'ruparnas': [('rupe', False)],
          'rupars': [('rupe', False)],
          'rupe': [('rupe', False)],
          'rupen': [('rupe', False)],
          'rupens': [('rupe', False)],
          'rupiers': [('rupie', True)],
          'rupp': [('rupp', False)],
          'rupp-': [('rupp', False)],
          'rupps': [('rupp', False)],
          'rupps-': [('rupp', False)],
          'rups': [('rupe', False)],
          'rups-': [('rupe', False)],
          'rur': [('ru', False)],
          'rurna': [('ru', False)],
          'rurnas': [('ru', False)],
          'rurs': [('ru', False)],
          'rus': [('rus', True)],
          'rus-': [('rus', True)],
          'rusar': [('rusare', False)],
          'rusar-': [('rusare', False)],
          'rusarens': [('rusare', False)],
          'rusarnas': [('rus', False)],
          'rusk': [('ruska', True), ('rusk', True)],
          'rusk-': [('ruska', True), ('rusk', True)],
          'ruske': [('ruska', False)],
          'ruske-': [('ruska', False)],
          'rusken': [('rusk', False)],
          'ruskens': [('rusk', False)],
          'ruskor': [('ruska', False)],
          'ruskorna': [('ruska', False)],
          'ruskornas': [('ruska', False)],
          'ruskors': [('ruska', False)],
          'russ': [('russ', True)],
          'russen': [('russ', False)],
          'russens': [('russ', False)],
          'russins': [('russin', False)],
          'rust-': [('rust', False)],
          'rustar': [('rustare', True)],
          'rustarnas': [('rustare', True)],
          'ruster': [('rust', False)],
          'rusterna': [('rust', False)],
          'rusternas': [('rust', False)],
          'rusters': [('rust', False)],
          'rut': [('ruta', False)],
          'rut-': [('ruta', False)],
          'rutan': [('ruta', False)],
          'rutarnas': [('rut', False)],
          'ruten': [('ruten', True)],
          'rutens': [('ruten', True)],
          'ruter': [('ruter', True)],
          'ruterna': [('ruter', True)],
          'ruternas': [('ruter', True)],
          'ruters': [('ruter', True)],
          'rutets': [('rut', False)],
          'rutin': [('rutin', False)],
          'ruts': [('ruta', True)],
          'ruts-': [('ruta', False)],
          'rutsar': [('ruts', False)],
          'rutsarna': [('ruts', False)],
          'rutsen': [('ruts', False)],
          'rutsens': [('ruts', False)],
          'rutt': [('rutt', False)],
          'rutt-': [('rutt', False)],
          'ruttar': [('rutt', False)],
          'ruttars': [('rutt', False)],
          'rutte': [('rutta', False)],
          'rutten': [('rutt', False)],
          'rutter': [('rutt', False)],
          'rutters': [('rutt', False)],
          'rutts': [('rutt', False)],
          'rutts-': [('rutt', False)],
          'ruv': [('ruva', False)],
          'ruv-': [('ruva', False)],
          'ruvs': [('ruva', False)],
          'ruvs-': [('ruva', False)],
          'rvafältet': [('rvafältet', False)],
          'rvakar': [('rvakare', False)],
          'rvakarna': [('rvakare', False)],
          'rvakarnas': [('rvakare', False)],
          'rval': [('rval', False)],
          'rval-': [('rval', False)],
          'rvalarna': [('rval', False)],
          'rvalars': [('rval', False)],
          'rvalen': [('rval', False)],
          'rvalens': [('rval', False)],
          'rvallar': [('rvall', False)],
          'rvallarna': [('rvall', False)],
          'rvallarnas': [('rvall', False)],
          'rvalls-': [('rvall', False)],
          'rvals-': [('rval', False)],
          'rvan': [('rva', False)],
          'rvana': [('rvana', False)],
          'rvans': [('rva', False)],
          'rvans-': [('rvans', False)],
          'rvant': [('rvant', False)],
          'rvant-': [('rvant', False)],
          'rvantarna': [('rvante', False)],
          'rvante': [('rvante', False)],
          'rvante-': [('rvante', False)],
          'rvants': [('rvant', False)],
          'rvants-': [('rvante', False)],
          'rvaran': [('rvara', False)],
          'rvarans': [('rvara', False)],
          'rvaren': [('rvare', False)],
          'rvarens': [('rvar', False)],
          'rvarna': [('rv', False)],
          'rvarnas': [('rv', False)],
          'rvars': [('rv', False)],
          'rvas': [('rvas', False)],
          'rvas-': [('rvas', False)],
          'rvasen': [('rvas', False)],
          'rvasens': [('rvas', False)],
          'rvat': [('rvat', False)],
          'rvat-': [('rvat', False)],
          'rvats': [('rvat', False)],
          'rvats-': [('rvat', False)],
          'rve': [('rva', False)],
          'rve-': [('rva', False)],
          'rveck': [('rvecka', False)],
          'rveck-': [('rvecka', False)],
          'rvecks': [('rvecka', False)],
          'rvecks-': [('rvecka', False)],
          'rvel': [('rvel', False)],
          'rvel-': [('rvel', False)],
          'rvels': [('rvel', False)],
          'rvels-': [('rvel', False)],
          'rven': [('rv', False)],
          'rvens': [('rv', False)],
          'rverande': [('rverande', False)],
          'rverande-': [('rverande', False)],
          'rvern': [('rver', False)],
          'rverna': [('rv', False)],
          'rvernas': [('rv', False)],
          'rverns': [('rver', False)],
          'rvers-': [('rver', False)],
          'rvet': [('rv', False)],
          'rvett': [('rvett', False)],
          'rvett-': [('rvett', False)],
          'rvetten': [('rvett', False)],
          'rvettens': [('rvett', False)],
          'rvetts': [('rvett', False)],
          'rvetts-': [('rvett', False)],
          'rvgas': [('rvgas', False)],
          'rvgas-': [('rvgas', False)],
          'rvgaser': [('rvgas', False)],
          'rvigg': [('rvigg', False)],
          'rvigg-': [('rvigg', False)],
          'rviggar': [('rvigg', False)],
          'rviggarna': [('rvigg', False)],
          'rviggarnas': [('rvigg', False)],
          'rviggars': [('rvigg', False)],
          'rviggen': [('rvigg', False)],
          'rviggens': [('rvigg', False)],
          'rviggs': [('rvigg', False)],
          'rviggs-': [('rvigg', False)],
          'rvin': [('rvin', False)],
          'rvin-': [('rvin', False)],
          'rvind': [('rvind', False)],
          'rvinds': [('rvind', False)],
          'rvinds-': [('rvind', False)],
          'rving': [('rvinge', False)],
          'rving-': [('rvinge', False)],
          'rvingar': [('rvinge', False)],
          'rvingarna': [('rvinge', False)],
          'rvingarnas': [('rvinge', False)],
          'rvingars': [('rvinge', False)],
          'rvingen': [('rvinge', False)],
          'rvingens': [('rvinge', False)],
          'rvings': [('rvinge', False)],
          'rvings-': [('rvinge', False)],
          'rvins': [('rvin', False)],
          'rvins-': [('rvin', False)],
          'rvinsten': [('rvinst', False)],
          'rvinstens': [('rvinst', False)],
          'rvinter': [('rvinter', False)],
          'rvinters': [('rvinter', False)],
          'rviol': [('rviol', False)],
          'rviol-': [('rviol', False)],
          'rviols': [('rviol', False)],
          'rviols-': [('rviol', False)],
          'rvipp': [('rvippa', False)],
          'rvipp-': [('rvippa', False)],
          'rvipps': [('rvippa', False)],
          'rvipps-': [('rvippa', False)],
          'rvisa': [('rvisa', False)],
          'rvisar': [('rvisare', False)],
          'rvisarna': [('rvisare', False)],
          'rvisarnas': [('rvisare', False)],
          'rvisas': [('rvisa', False)],
          'rvisch': [('rvisch', False)],
          'rvisch-': [('rvisch', False)],
          'rvise': [('rvisa', False)],
          'rvisen': [('rvis', False)],
          'rvisens': [('rvis', False)],
          'rvisor': [('rvisa', False)],
          'rvisors': [('rvisa', False)],
          'rvisser': [('rvisser', False)],
          'rvisserna': [('rvisser', False)],
          'rvissernas': [('rvisser', False)],
          'rvissers': [('rvisser', False)],
          'rvlandet': [('rvland', False)],
          'rvlandets': [('rvland', False)],
          'rvlar': [('rvel', False)],
          'rvlarna': [('rvel', False)],
          'rvlarnas': [('rvel', False)],
          'rvlars': [('rvel', False)],
          'rvlingen': [('rvling', False)],
          'rvlingens': [('rvling', False)],
          'rvmoss': [('rvmosse', False)],
          'rvmoss-': [('rvmosse', False)],
          'rvo': [('rvo', False)],
          'rvo-': [('rvo', False)],
          'rvons': [('rvo', False)],
          'rvor': [('rva', False)],
          'rvorna': [('rva', False)],
          'rvornas': [('rva', False)],
          'rvors': [('rva', False)],
          'rvot': [('rvo', False)],
          'rvrar': [('rver', False)],
          'rvrarna': [('rver', False)],
          'rvreden': [('rvred', False)],
          'rvredens': [('rvred', False)],
          'rvren': [('rvår', False)],
          'rvrens': [('rvår', False)],
          'rvret': [('rvår', False)],
          'rvrets': [('rvår', False)],
          'rvungen': [('rvunge', False)],
          'rvungens': [('rvunge', False)],
          'rvägar': [('rväg', False)],
          'rvägarna': [('rväg', False)],
          'rvägarnas': [('rväg', False)],
          'rvägars': [('rväg', False)],
          'rvägen': [('rväg', False)],
          'rvägs': [('rväg', False)],
          'rvägs-': [('rväg', False)],
          'rvälden': [('rvälde', False)],
          'rväldens': [('rvälde', False)],
          'rvändarnas': [('rvände', False)],
          'rvärden': [('rvärde', False)],
          'rvärdens': [('rvärde', False)],
          'rvärdet': [('rvärde', False)],
          'rvärmar': [('rvärmare', False)],
          'rvärmarna': [('rvärmare', False)],
          'rvärmarnas': [('rvärmare', False)],
          'rväsendet': [('rväsen', False)],
          'rväsendets': [('rväsen', False)],
          'rväxlar': [('rväxel', False)],
          'rväxlarna': [('rväxel', False)],
          'rväxlarnas': [('rväxel', False)],
          'rvågar': [('rvåg', False)],
          'rvågarna': [('rvåg', False)],
          'rvårdar': [('rvårdare', False)],
          'rvårdarna': [('rvårdare', False)],
          'rvårdarnas': [('rvårdare', False)],
          'ry': [('rya', True)],
          'ry-': [('rya', True)],
          'ryans': [('rya', False)],
          'ryck': [('ryck', True)],
          'ryck-': [('ryck', False)],
          'ryckarnas': [('ryckare', False)],
          'rycke': [('rycka', False)],
          'rycke-': [('rycka', False)],
          'rycken': [('ryck', False)],
          'ryckens': [('ryck', False)],
          'rycket': [('ryck', False)],
          'ryckets': [('ryck', True)],
          'ryckningar': [('ryckning', False)],
          'ryckningarna': [('ryckning', False)],
          'ryckningarnas': [('ryckning', False)],
          'ryckningars': [('ryckning', False)],
          'rycknings': [('ryckning', False)],
          'rycknings-': [('ryckning', False)],
          'rycks': [('ryck', False)],
          'rycks-': [('ryck', False)],
          'rydd-': [('rydda', False)],
          'rye': [('rya', True)],
          'rye-': [('rya', True)],
          'ryer': [('ry', False)],
          'ryerna': [('ry', False)],
          'ryernas': [('ry', False)],
          'ryers': [('ry', False)],
          'ryferna': [('ryferna', False)],
          'ryfernas': [('ryferna', False)],
          'ryg': [('ryga', False)],
          'ryg-': [('ryga', False)],
          'rygg': [('rygg', False)],
          'rygg-': [('rygg', False)],
          'ryggar': [('rygg', True)],
          'ryggarna': [('rygg', False)],
          'ryggarnas': [('rygg', False)],
          'ryggars': [('rygg', False)],
          'rygge': [('rygga', False)],
          'ryggen': [('rygg', False)],
          'ryggens': [('rygg', False)],
          'ryggs': [('rygg', False)],
          'ryggs-': [('rygg', False)],
          'rygs': [('ryga', False)],
          'rygs-': [('ryga', False)],
          'ryhets-': [('ryhet', False)],
          'ryk': [('ryk', False)],
          'rykandens': [('rykande', True)],
          'rykar': [('rykare', False)],
          'rykarna': [('rykare', False)],
          'ryker': [('ryker', False)],
          'rykers': [('ryker', False)],
          'rykets': [('ryk', False)],
          'ryks-': [('ryk', False)],
          'rykt': [('rykt', True)],
          'rykt-': [('rykt', True)],
          'rykten': [('rykt', True), ('rykte', True)],
          'ryktens': [('rykt', True), ('rykte', True)],
          'rykts': [('rykt', True)],
          'rykts-': [('rykt', True)],
          'rylarna': [('ryl', False)],
          'rylen': [('rylen', False)],
          'rylens': [('rylen', False)],
          'ryll': [('ryll', False)],
          'ryll-': [('ryll', False)],
          'ryllandet': [('ryllande', False)],
          'ryllen': [('ryll', False)],
          'ryller': [('ryll', False)],
          'ryllerna': [('ryllis', False)],
          'ryllernas': [('ryll', False)],
          'ryllers': [('ryllis', False)],
          'rylls': [('ryll', False)],
          'rylls-': [('ryll', False)],
          'rymmens': [('rymme', False)],
          'rymmet': [('rymme', False)],
          'rymtar': [('rymtare', False)],
          'ryn': [('ry', False)],
          'ryn-': [('ryne', False)],
          'ryna': [('ry', False)],
          'rynas': [('ry', False)],
          'ryne': [('ryne', False)],
          'ryne-': [('ryne', False)],
          'rynen': [('ryne', False)],
          'rynens': [('ryne', False)],
          'rynes': [('ryne', False)],
          'rynet': [('ryne', False)],
          'rynk': [('rynka', True)],
          'rynk-': [('rynka', False)],
          'rynke': [('rynka', False)],
          'rynks': [('rynka', True)],
          'rynks-': [('rynka', False)],
          'rynne': [('rynna', False)],
          'rynne-': [('rynna', False)],
          'rynns': [('rynna', False)],
          'ryns': [('ry', False)],
          'ryns-': [('ryne', False)],
          'ryor': [('rya', False)],
          'ryorna': [('rya', True)],
          'ryornas': [('rya', False)],
          'ryors': [('rya', True)],
          'ryot': [('ryo', False)],
          'ryoten': [('ryot', False)],
          'ryotens': [('ryot', False)],
          'ryoter': [('ryot', False)],
          'ryoterna': [('ryot', False)],
          'ryoternas': [('ryot', False)],
          'ryoters': [('ryot', False)],
          'ryots': [('ryo', False)],
          'ryparna': [('rypare', False)],
          'ryperit': [('ryperi', False)],
          'rypets': [('ryp', False)],
          'rypin': [('rypin', False)],
          'ryps': [('ryps', True)],
          'ryps-': [('ryps', True)],
          'rys': [('rya', False)],
          'rys-': [('rya', True)],
          'rysar': [('rysare', True)],
          'rysarna': [('rysare', False)],
          'rysarnas': [('rysare', True)],
          'rysars': [('rys', False)],
          'ryssar': [('ryss', False)],
          'ryssarna': [('ryss', True)],
          'ryssarnas': [('ryss', True)],
          'ryt': [('ryt', False)],
          'rytar': [('rytare', False)],
          'rytarna': [('rytare', False)],
          'ryte': [('ryte', False)],
          'rytets': [('ryt', False)],
          'ryts': [('ryt', False)],
          'ryttarna': [('ryttare', False)],
          'ryttarnas': [('ryttare', False)],
          'ryx': [('ryx', False)],
          'ryx-': [('ryx', False)],
          'rz': [('rz', False)],
          'rz-': [('rz', False)],
          'rzon': [('rzo', False)],
          'rzons': [('rzo', False)],
          'räbb-': [('räbba', False)],
          'räck': [('räcka', True), ('räck', True)],
          'räck-': [('räcka', True), ('räck', True)],
          'räckar': [('räck', False)],
          'räckarna': [('räck', False)],
          'räckarnas': [('räckare', False)],
          'räcke': [('räcke', True), ('räcka', True)],
          'räcken': [('räcke', True), ('räck', True)],
          'räckens': [('räcke', True), ('räck', True)],
          'räcket': [('räcke', True), ('räck', True)],
          'räckets': [('räck', True), ('räcke', True)],
          'räcks': [('räcka', True), ('räck', True)],
          'räcks-': [('räcka', True), ('räck', True)],
          'räd': [('räd', True)],
          'räd-': [('räd', True)],
          'rädar': [('rädare', False)],
          'rädarna': [('rädare', False)],
          'rädd': [('rädd', False)],
          'rädd-': [('rädde', False)],
          'räddar': [('räddare', False)],
          'räddarna': [('räddare', False)],
          'räddarnas': [('räddare', False)],
          'rädden': [('rädd', False)],
          'räddens': [('rädd', False)],
          'rädds': [('rädd', False)],
          'rädds-': [('rädd', False)],
          'räde': [('räde', False)],
          'räden': [('räd', True)],
          'rädens': [('räd', True)],
          'räder': [('räd', True)],
          'räderna': [('räd', False)],
          'rädernas': [('räd', False)],
          'räders': [('räd', True)],
          'rädes': [('räde', False)],
          'rädes-': [('räde', False)],
          'rädet': [('räde', False)],
          'räds': [('räd', True)],
          'räfs-': [('räfsa', False)],
          'räfte': [('räfta', False)],
          'rägel-': [('rägel', False)],
          'rägg': [('rägg', False)],
          'rägg-': [('rägg', False)],
          'räggs': [('rägg', False)],
          'räggs-': [('rägg', False)],
          'räk': [('räka', True)],
          'räk-': [('räka', True)],
          'räkarna': [('räkare', False)],
          'räken': [('räk', False)],
          'räkens': [('räk', False)],
          'räkenskaps': [('räkenskaper', True), ('räkenskap', True)],
          'räkenskaps-': [('räkenskap', True), ('räkenskaper', True)],
          'räkets': [('räk', False)],
          'räklarna': [('räkel', True)],
          'räknar': [('räknare', False)],
          'räknarna': [('räknare', True)],
          'räknarnas': [('räknare', True)],
          'räknars': [('räken', False)],
          'räknen': [('räkne', False)],
          'räkors': [('räka', True)],
          'räks': [('räka', True)],
          'räks-': [('räka', True)],
          'räkt': [('räkt', False)],
          'räkt-': [('räkt', False)],
          'räktarnas': [('räktare', False)],
          'räkten': [('räkt', False)],
          'räktens': [('räkt', False)],
          'räkts': [('räkt', False)],
          'räkts-': [('räkt', False)],
          'räll': [('räll', False)],
          'räll-': [('räll', False)],
          'rällanden': [('rällande', False)],
          'rällandena': [('rällande', False)],
          'rällandenas': [('rällande', False)],
          'rällandens': [('rällande', False)],
          'rällar': [('räll', False)],
          'rällarna': [('rälle', False)],
          'rällarnas': [('rälle', False)],
          'rällars': [('räll', False)],
          'rällen': [('räll', False)],
          'rällens': [('rälle', False)],
          'rälls': [('räll', False)],
          'rälls-': [('räll', False)],
          'räls': [('räls', True), ('räl', True)],
          'räls-': [('räl', True), ('räls', True)],
          'rälsar': [('räls', True)],
          'rälsarna': [('räls', False)],
          'rälsarnas': [('räls', True)],
          'rälsen': [('räls', False)],
          'rälsens': [('räls', False)],
          'rälv': [('rälv', False)],
          'rälvs': [('rälv', False)],
          'rälvs-': [('rälv', False)],
          'räm': [('räm', False)],
          'räm-': [('rämma', False)],
          'rämme': [('rämma', False)],
          'rämne': [('rämna', True)],
          'rämne-': [('rämna', True)],
          'rämpe': [('rämpa', False)],
          'rämpe-': [('rämpa', False)],
          'rämpor': [('rämpa', False)],
          'rämporna': [('rämpa', False)],
          'rämpornas': [('rämpa', False)],
          'rämpors': [('rämpa', False)],
          'räms': [('rämma', False)],
          'räms-': [('rämma', False)],
          'ränd': [('ränd', False)],
          'ränd-': [('ränd', False)],
          'rändarna': [('rände', False)],
          'rände': [('rände', False)],
          'rände-': [('rände', False)],
          'ränden': [('ränd', False)],
          'rändens': [('ränd', False)],
          'ränder': [('rand', True)],
          'ränderna': [('rand', True)],
          'rändernas': [('rand', True)],
          'ränders': [('rand', True)],
          'ränds': [('ränd', False)],
          'ränds-': [('ränd', False)],
          'räng': [('räng', False)],
          'räng-': [('räng', False)],
          'rängar': [('räng', False)],
          'rängarna': [('räng', False)],
          'rängarnas': [('räng', False)],
          'rängen': [('räng', False)],
          'rängens': [('räng', False)],
          'ränger': [('räng', False)],
          'rängerna': [('räng', False)],
          'rängernas': [('räng', False)],
          'rängers': [('räng', False)],
          'ränget': [('räng', False)],
          'rängs': [('räng', False)],
          'rängs-': [('räng', False)],
          'ränk': [('ränker', True)],
          'ränk-': [('ränker', True)],
          'ränke': [('ränka', False)],
          'ränks': [('ränker', True)],
          'ränks-': [('ränker', True)],
          'ränn': [('ränn', True), ('ränna', True)],
          'ränn-': [('ränn', True), ('ränna', True)],
          'ränne': [('ränna', False)],
          'ränne-': [('ränna', False)],
          'rännet': [('ränn', True)],
          'rännets': [('ränn', True)],
          'ränns': [('ränn', True), ('ränna', True)],
          'ränns-': [('ränn', True), ('ränna', True)],
          'räns-': [('räns', False)],
          'ränsle': [('ränsle', False)],
          'ränsle-': [('ränsle', False)],
          'ränt': [('ränt', False)],
          'räntans': [('ränta', False)],
          'ränte': [('ränta', False)],
          'ränts-': [('ränt', False)],
          'räppe': [('räppa', False)],
          'räppe-': [('räppa', False)],
          'räppen': [('räpp', False)],
          'räppens': [('räpp', False)],
          'rärgs-': [('rärg', False)],
          'rärt-': [('rärt', False)],
          'räs': [('rä', False)],
          'räs-': [('rä', False)],
          'räsk': [('räsk', False)],
          'räsk-': [('räsk', False)],
          'räskor': [('räsko', False)],
          'rässar': [('räss', False)],
          'rässars': [('räss', False)],
          'rässens': [('räss', False)],
          'räst-': [('räst', False)],
          'rästen': [('räst', False)],
          'rästens': [('räst', False)],
          'räster': [('räst', False)],
          'rästers': [('räst', False)],
          'räsvärden': [('räsvärd', False)],
          'räsvärdens': [('räsvärd', False)],
          'räsvärdet': [('räsvärd', False)],
          'räsvärdets': [('räsvärd', False)],
          'räts-': [('räta', False)],
          'rätt': [('rätt', False)],
          'rätt-': [('rätt', False)],
          'rättar': [('rättare', True)],
          'rättarna': [('rättare', False)],
          'rättarnas': [('rättare', True)],
          'rättars': [('rätt', False)],
          'rätten': [('rätt', False)],
          'rättens': [('rätt', True)],
          'rätter': [('rätt', False)],
          'rätterna': [('rätt', False)],
          'rätternas': [('rätt', False)],
          'rätters': [('rätt', False)],
          'rättet': [('rätt', False)],
          'rättets': [('rätte', False)],
          'rättigheter': [('rättighet', True)],
          'rättigheterna': [('rättighet', True)],
          'rättigheternas': [('rättighet', True)],
          'rättigheters': [('rättighet', True)],
          'rättighets': [('rättighet', True)],
          'rättighets-': [('rättighet', True)],
          'rätts': [('rätt', False)],
          'rätts-': [('rätt', False)],
          'rättsväsendet': [('rättsväsende', True), ('rättsväsen', True)],
          'rättsväsendets': [('rättsväsen', True), ('rättsväsende', True)],
          'räv': [('räv', True)],
          'räv-': [('räv', False)],
          'rävan': [('räva', False)],
          'rävans': [('räva', False)],
          'rävar': [('räv', False)],
          'rävar-': [('rävare', False)],
          'rävarna': [('räv', True)],
          'rävarnas': [('räv', True)],
          'rävlar': [('rävlare', False)],
          'rävlarna': [('rävlare', False)],
          'rävlarnas': [('rävlare', False)],
          'rävs': [('räv', True)],
          'rävs-': [('räv', True)],
          'rå': [('rå', False)],
          'rå-': [('rå', False)],
          'råar': [('rå', False)],
          'råarna': [('rå', False)],
          'råben': [('råben', False)],
          'råd': [('råd', False)],
          'råd-': [('råd', True)],
          'rådan': [('rådan', False)],
          'rådans': [('rådan', False)],
          'rådarnas': [('råd', False)],
          'råde': [('råde', False)],
          'råde-': [('råde', False)],
          'råden': [('råd', True)],
          'rådens': [('råd', True)],
          'rådet': [('råd', True)],
          'rådets': [('råd', False)],
          'råds': [('råd', False)],
          'råds-': [('råd', False)],
          'råge': [('råge', True)],
          'råge-': [('råge', True)],
          'rågen': [('råge', True), ('råg', True)],
          'rågens': [('råge', True), ('råg', True)],
          'råget': [('råget', True)],
          'rågets': [('råget', True)],
          'rågångar': [('rågång', True)],
          'råk': [('råk', True), ('råka', True)],
          'råk-': [('råk', True), ('råka', True)],
          'råkar': [('råk', True)],
          'råkarna': [('råk', True)],
          'råkarnas': [('råk', False)],
          'råkars': [('råk', True)],
          'råke': [('råka', True)],
          'råken': [('råk', True)],
          'råkens': [('råk', True)],
          'råker': [('råker', False)],
          'råks': [('råk', True), ('råka', True)],
          'råks-': [('råka', True), ('råk', True)],
          'råle': [('råle', False)],
          'råle-': [('råle', False)],
          'rålen': [('rål', False)],
          'råligheter': [('rålighet', False)],
          'råligheterna': [('rålighet', False)],
          'råligheternas': [('rålighet', False)],
          'råligheters': [('rålighet', False)],
          'rålighets-': [('rålighet', False)],
          'rålkrans': [('rålkrans', False)],
          'rålkrans-': [('rålkrans', False)],
          'rållar': [('rålle', False)],
          'rållarnas': [('rålle', False)],
          'rållens': [('rålle', False)],
          'råm-': [('råma', False)],
          'råman': [('råma', False)],
          'råmans': [('råma', False)],
          'rån': [('rå', True), ('rån', True)],
          'råna': [('rå', False)],
          'rånarna': [('rånare', True)],
          'rånas': [('rå', False)],
          'rång': [('rång', False)],
          'rång-': [('rång', False)],
          'rången': [('rång', False)],
          'rångens': [('rång', False)],
          'rångs': [('rång', False)],
          'rångs-': [('rång', False)],
          'råns': [('rån', True), ('rå', True)],
          'råpar': [('råpare', False)],
          'råparna': [('råpare', False)],
          'rår': [('rå', False)],
          'rårs': [('rå', False)],
          'rårs-': [('rår', False)],
          'rås': [('rå', False)],
          'rås-': [('rå', False)],
          'råsar': [('råse', False)],
          'råsarna': [('råse', False)],
          'råsarnas': [('råse', False)],
          'råsars': [('råse', False)],
          'råse': [('råse', False)],
          'råsen': [('råse', False)],
          'råsens': [('råse', False)],
          'råstens': [('råsten', False)],
          'råt': [('rå', False)],
          'råtarnas': [('råt', False)],
          'råte': [('råte', False)],
          'råte-': [('råte', False)],
          'råten': [('råte', False)],
          'råtens': [('råte', False)],
          'råtet': [('råte', False)],
          'råtets': [('råte', False)],
          'råts': [('rå', False)],
          'råvar': [('råvara', False)],
          'réerna': [('ré', False)],
          'réernas': [('ré', False)],
          'rés-': [('ré', False)],
          'röar': [('röare', False)],
          'röarna': [('röare', False)],
          'röarnas': [('röare', False)],
          'röd': [('röda', False)],
          'röd-': [('röd', True)],
          'röde': [('röda', False)],
          'röden': [('röd', False)],
          'rödens': [('röd', False)],
          'rödet': [('röd', False)],
          'rödets': [('röd', False)],
          'röds': [('röda', False)],
          'röds-': [('röda', False)],
          'rödsdagar': [('rödsdagar', False)],
          'rödsdagarna': [('rödsdagar', False)],
          'rödsdagarnas': [('rödsdagar', False)],
          'rödsdagars': [('rödsdagar', False)],
          'rödsdags': [('rödsdagar', False)],
          'röen': [('rö', False)],
          'röens': [('rö', False)],
          'rögar': [('rögare', False)],
          'rögarna': [('rögare', False)],
          'rögarnas': [('rögare', False)],
          'rögat': [('röga', False)],
          'rögats': [('röga', False)],
          'rögonens': [('röga', False)],
          'rögons': [('röga', False)],
          'röj': [('röja', False)],
          'röj-': [('röja', False)],
          'röjar': [('röjare', False)],
          'röjarna': [('röjare', False)],
          'röjarnas': [('röjare', False)],
          'röjs': [('röja', False)],
          'röjs-': [('röja', False)],
          'rökar': [('rök', True), ('rökare', True)],
          'rökarna': [('rök', True), ('rökare', True)],
          'rökarnas': [('rökare', True), ('rök', True)],
          'röken': [('rök', True)],
          'rökens': [('rök', True)],
          'römen': [('röm', False)],
          'römens': [('röm', False)],
          'römmen': [('röm', False)],
          'römmets': [('röm', False)],
          'rön': [('rön', True), ('rö', True)],
          'rön-': [('rön', True)],
          'röna': [('rö', True)],
          'rönarna': [('rönare', False)],
          'rönas': [('rö', False)],
          'röns': [('rön', True), ('rö', True)],
          'röns-': [('rön', False)],
          'rönskan': [('rönska', False)],
          'rönskans': [('rönska', False)],
          'röpe': [('röpe', False)],
          'röpe-': [('röpe', False)],
          'röpet': [('röpe', False)],
          'röpets': [('röpe', False)],
          'röre': [('röra', False)],
          'röre-': [('röra', False)],
          'rören': [('rör', True)],
          'rörens': [('rör', False)],
          'röret': [('rör', False)],
          'rörets': [('rör', False)],
          'rörigheter': [('rörighet', False)],
          'rörigheterna': [('rörighet', False)],
          'rörigheternas': [('rörighet', False)],
          'rörigheters': [('rörighet', False)],
          'rörighets-': [('rörighet', False)],
          'rörn': [('rörn', False)],
          'rörnar': [('rörn', False)],
          'rörnarna': [('rörn', False)],
          'rörnen': [('rörn', False)],
          'rörnens': [('rörn', False)],
          'rörns-': [('rörn', False)],
          'rörten': [('rört', False)],
          'rös': [('röse', True), ('rö', True), ('rös', True)],
          'rös-': [('rö', True), ('rös', True), ('röse', True)],
          'rösar': [('röse', False)],
          'rösarna': [('röse', False)],
          'rösarnas': [('röse', False)],
          'rösars': [('röse', False)],
          'röse': [('röse', True)],
          'rösen': [('rös', True), ('röse', True)],
          'rösens': [('rös', True), ('röse', True)],
          'röset': [('röse', True), ('rös', True)],
          'rösets': [('rös', True), ('röse', True)],
          'rösk-': [('röska', False)],
          'röske': [('röska', False)],
          'röskorna': [('röska', False)],
          'röskornas': [('röska', False)],
          'röskors': [('röska', False)],
          'röst': [('röste', True), ('röst', True)],
          'röst-': [('röste', True), ('röst', True)],
          'röstan': [('röstan', False)],
          'röstans': [('rösta', False)],
          'röstarnas': [('röstare', False)],
          'röste': [('röste', True)],
          'rösten': [('röste', True), ('röst', True)],
          'röstens': [('röste', True), ('röst', True)],
          'röster': [('röst', False)],
          'rösters': [('röst', False)],
          'röstet': [('röste', True), ('röst', True)],
          'röstets': [('röste', True), ('röst', True)],
          'röt': [('röta', True), ('rö', True)],
          'röt-': [('röta', True)],
          'rötarnas': [('röt', False)],
          'rötets': [('röt', False)],
          'röts': [('rö', False)],
          'rött': [('rött', False)],
          'rött-': [('rött', False)],
          'rötter': [('rötter', True), ('rot', True)],
          'rötterna': [('rötter', True), ('rot', True)],
          'rötternas': [('rötter', True), ('rot', True)],
          'rötters': [('rötter', True), ('rot', True)],
          'rötts': [('rött', False)],
          'rövar': [('röv', True), ('rövare', True)],
          'rövarna': [('rövare', True), ('röv', True)],
          'rövarnas': [('röv', True), ('rövare', True)],
          'rövrar': [('rövrare', False)],
          'rövrarna': [('rövrare', False)],
          's': [('s', True)],
          's-': [('s', True)],
          'sa': [('sa', False)],
          'sa-': [('sa', False)],
          'sabb': [('sabb', True)],
          'sabb-': [('sabb', True)],
          'sabbs': [('sabb', True)],
          'sabbs-': [('sabb', True)],
          'sabin': [('sabin', True)],
          'sabins': [('sabin', True)],
          'sabis': [('sabi', False)],
          'sack-': [('sack', False)],
          'sackar': [('sack', False)],
          'sackarna': [('sack', False)],
          'sackars': [('sack', False)],
          'sacken': [('sack', False)],
          'sackens': [('sack', False)],
          'sacker': [('sack', False)],
          'sackers': [('sack', False)],
          'sacks': [('sack', False)],
          'sacks-': [('sack', False)],
          'saffian': [('saffian', True)],
          'saffransbulle': [('saffransbulla', True), ('saffransbulle', True)],
          'saffransbulle-': [('saffransbulla', True), ('saffransbulle', True)],
          'safter': [('saft', True)],
          'safterna': [('saft', False)],
          'safternas': [('saft', False)],
          'safters': [('saft', False)],
          'safts': [('saft', False)],
          'safts-': [('saft', False)],
          'sagar': [('sagare', False)],
          'sagar-': [('sagare', False)],
          'sagarna': [('sagare', False)],
          'sagarnas': [('sagare', False)],
          'sagen': [('sage', False)],
          'sagens': [('sage', False)],
          'sagerna': [('sage', False)],
          'sagernas': [('sage', False)],
          'sagers': [('sage', False)],
          'sagg': [('sagg', True)],
          'sagg-': [('sagg', True)],
          'saggs-': [('sagg', True)],
          'sagnen': [('sagne', False)],
          'sagnens': [('sagne', False)],
          'sago': [('sago', True), ('saga', True)],
          'sago-': [('saga', True), ('sago', True)],
          'sajter': [('sajt', False)],
          'sajterna': [('sajt', False)],
          'sajternas': [('sajt', False)],
          'sajters': [('sajt', False)],
          'sak-': [('sak', True)],
          'sakar': [('sakare', False)],
          'sakarna': [('sakare', False)],
          'saker': [('sak', True)],
          'sakerna': [('sak', True)],
          'sakernas': [('sak', True)],
          'sakers': [('sak', True)],
          'sakist': [('sakista', False)],
          'sakistan': [('sakista', False)],
          'sakon': [('sako', False)],
          'sakor': [('sako', False)],
          'sakorna': [('sako', False)],
          'sakornas': [('sako', False)],
          'sakors': [('sako', False)],
          'sakos': [('sako', False)],
          'saks': [('sak', False)],
          'saks-': [('sak', False)],
          'sakter': [('sakt', False)],
          'sakters': [('sakt', False)],
          'salan': [('sala', False)],
          'salandets': [('salande', True)],
          'salans': [('sala', False)],
          'salar': [('sal', False)],
          'salas': [('sala', False)],
          'salats': [('salat', True)],
          'salbens': [('salben', False)],
          'sale-': [('sale', False)],
          'salen': [('sal', True)],
          'salens': [('sal', True)],
          'sales': [('sale', False)],
          'salet': [('sale', False)],
          'salets': [('sal', False)],
          'salfens': [('salf', False)],
          'salie': [('salie', False)],
          'saliens': [('salie', False)],
          'salier': [('salie', False)],
          'salierna': [('salie', False)],
          'saliernas': [('salie', False)],
          'saliers': [('salie', False)],
          'salin': [('salin', True)],
          'salis': [('salis', False)],
          'salivsugar': [('salivsugare', True), ('salivsug', True)],
          'salivsugarna': [('salivsugare', True), ('salivsug', True)],
          'salivsugarnas': [('salivsugare', True), ('salivsug', True)],
          'sall': [('sall', False)],
          'sall-': [('sall', False)],
          'sallen': [('sall', False)],
          'saller': [('sall', False)],
          'sallerna': [('sall', False)],
          'sallernas': [('sall', False)],
          'sallers': [('sall', False)],
          'salls': [('sall', False)],
          'salls-': [('sall', False)],
          'salong': [('salong', False)],
          'salonger': [('salong', False)],
          'salongerna': [('salong', False)],
          'salongernas': [('salong', False)],
          'salongers': [('salong', True)],
          'salongs': [('salong', False)],
          'salongs-': [('salong', False)],
          'sals': [('sal', False)],
          'sals-': [('sal', False)],
          'salt-': [('salt', False)],
          'saltar': [('saltare', False)],
          'saltarna': [('saltare', False)],
          'saltarnas': [('saltare', False)],
          'salter': [('salt', False)],
          'salterna': [('salt', False)],
          'salternas': [('salt', False)],
          'salters': [('salt', False)],
          'salts': [('salt', False)],
          'salts-': [('salt', False)],
          'salv': [('salva', False)],
          'salv-': [('salva', False)],
          'salvar': [('salvare', False)],
          'salvar-': [('salvare', False)],
          'salvaren': [('salvare', False)],
          'salvarens': [('salvare', False)],
          'salvor': [('salva', False)],
          'salvorna': [('salva', False)],
          'salvornas': [('salva', True)],
          'salvors': [('salva', False)],
          'salvs': [('salva', False)],
          'salvs-': [('salva', True)],
          'sam': [('sam', False)],
          'sam-': [('sam', False)],
          'sambor': [('samba', True), ('sambo', True)],
          'samborna': [('samba', True), ('sambo', True)],
          'sambornas': [('samba', True), ('sambo', True)],
          'sambors': [('sambo', True), ('samba', True)],
          'same': [('same', False)],
          'same-': [('same', False)],
          'samen': [('same', True)],
          'samens': [('same', True)],
          'samer': [('same', True)],
          'samerna': [('same', False)],
          'samernas': [('same', True)],
          'samers': [('same', True)],
          'sames-': [('same', False)],
          'samhällena': [('samhälle', True)],
          'samin': [('samin', False)],
          'samins': [('samin', False)],
          'samlandet': [('samlande', True)],
          'samlarnas': [('samlare', False)],
          'sammet': [('sammet', True)],
          'sammets': [('sammet', True)],
          'samos': [('samos', False)],
          'sampan': [('sampan', True)],
          'sampans': [('sampan', True)],
          'sams': [('sam', False)],
          'sams-': [('sam', False)],
          'san': [('sa', False)],
          'sand': [('sand', False)],
          'sand-': [('sand', False)],
          'sandar': [('sandar', False)],
          'sandarna': [('sandar', False)],
          'sandarnas': [('sandar', False)],
          'sandars': [('sandar', False)],
          'sanden': [('sand', False)],
          'sandens': [('sand', False)],
          'sandets': [('sande', False)],
          'sands': [('sand', False)],
          'sands-': [('sand', False)],
          'sanens': [('san', False)],
          'sanets': [('san', False)],
          'sang': [('sang', True)],
          'sang-': [('sang', True)],
          'sangen': [('sang', True)],
          'sangens': [('sang', True)],
          'sangs': [('sang', True)],
          'sankar': [('sankare', False)],
          'sankar-': [('sankare', False)],
          'sanke-': [('sanka', False)],
          'sankor': [('sanka', False)],
          'sankorna': [('sanka', False)],
          'sankornas': [('sanka', False)],
          'sanmälningar': [('sanmälning', False)],
          'sanmälningarna': [('sanmälning', False)],
          'sanmälningarnas': [('sanmälan', False)],
          'sanmälningars': [('sanmälning', False)],
          'sans': [('sans', True)],
          'sans-': [('sans', True)],
          'sansen': [('sans', False)],
          'sansens': [('sans', False)],
          'sanser': [('sans', False)],
          'sanserna': [('sans', False)],
          'sansernas': [('sans', False)],
          'sansers': [('sans', False)],
          'sanskrit': [('sanskrit', True)],
          'sanskrits': [('sanskrit', True)],
          'sanstalter': [('sanstalt', False)],
          'sanstalterna': [('sanstalt', False)],
          'sanstalternas': [('sanstalt', False)],
          'sanstalters': [('sanstalt', False)],
          'sanstalts': [('sanstalt', False)],
          'sanstalts-': [('sanstalt', False)],
          'sant': [('sant', False)],
          'santen': [('sant', False)],
          'santens': [('sant', False)],
          'santer': [('sant', False)],
          'santerna': [('sant', False)],
          'santernas': [('sant', False)],
          'santers': [('sant', False)],
          'saordens': [('saorden', False)],
          'sap-': [('sapa', False)],
          'sapan': [('sapa', False)],
          'sapans': [('sapa', False)],
          'sapas': [('sapa', False)],
          'sapp-': [('sapp', True)],
          'sappens': [('sapp', True)],
          'sapperna': [('sapp', True)],
          'sappernas': [('sapp', True)],
          'sappers': [('sapp', True)],
          'sapps': [('sapp', True)],
          'sapps-': [('sapp', True)],
          'sar': [('sare', False)],
          'sar-': [('sare', False)],
          'sarans': [('sara', False)],
          'sard': [('sard', False)],
          'sard-': [('sard', False)],
          'sardas': [('sardas', False)],
          'sarden': [('sard', False)],
          'sardens': [('sard', False)],
          'sarder': [('sard', False)],
          'sarderna': [('sard', False)],
          'sardernas': [('sard', False)],
          'sarders': [('sard', False)],
          'sardin': [('sardin', True)],
          'sardins': [('sardin', True)],
          'sardisk': [('sardiska', True)],
          'sardisk-': [('sardiska', True)],
          'sards': [('sard', False)],
          'sards-': [('sard', False)],
          'sare': [('sare', False)],
          'sarens': [('sare', False)],
          'sares': [('sare', False)],
          'sargen': [('sarg', True)],
          'sargens': [('sarg', True)],
          'sarger': [('sarg', True)],
          'sargerna': [('sarg', True)],
          'sargernas': [('sarg', True)],
          'sargers': [('sarg', True)],
          'sari': [('sari', True)],
          'sari-': [('sari', True)],
          'sarie': [('sarium', False)],
          'sarier': [('sari', True)],
          'sarierna': [('sari', True)],
          'sariernas': [('sari', True)],
          'sariers': [('sari', True)],
          'sarin': [('sari', True), ('sarin', True)],
          'sarins': [('sari', True), ('sarin', True)],
          'saris': [('sari', True)],
          'saris-': [('sari', True)],
          'sarisarna': [('sari', True)],
          'sarismer': [('sarism', False)],
          'sarismerna': [('sarism', False)],
          'sarismernas': [('sarism', False)],
          'sarismers': [('sarism', False)],
          'sarmar': [('sarm', False)],
          'sarmarna': [('sarm', False)],
          'sarmarnas': [('sarm', False)],
          'sarna': [('', False)],
          'saron-': [('saron', False)],
          'sarons': [('saron', False)],
          'sars': [('sars', True)],
          'sars-': [('sars', True)],
          'sarsens': [('sars', True)],
          'sarser': [('sars', True)],
          'sarsers': [('sars', True)],
          'sarset': [('sars', True)],
          'sarsets': [('sars', True)],
          'sart': [('sart', False)],
          'sart-': [('sart', False)],
          'sarten': [('sart', False)],
          'sartens': [('sart', False)],
          'sarter': [('sart', False)],
          'sarterna': [('sart', False)],
          'sarters': [('sart', False)],
          'sartrons': [('sartron', False)],
          'sarts': [('sart', False)],
          'sarts-': [('sart', False)],
          'sarv': [('sarv', False)],
          'sarv-': [('sarv', True)],
          'sarvar': [('sarv', True)],
          'sarvarna': [('sarv', True)],
          'sarvarnas': [('sarv', True)],
          'sarvars': [('sarv', True)],
          'sarven': [('sarv', False)],
          'sarvens': [('sarv', False)],
          'sarvs': [('sarv', False)],
          'sarvs-': [('sarv', True)],
          'sas': [('sa', False)],
          'sas-': [('sa', False)],
          'sask': [('sask', False)],
          'sask-': [('sask', False)],
          'saskarna': [('sask', False)],
          'saskrin': [('saskrin', False)],
          'sasnåret': [('sasnår', False)],
          'sasnårets': [('sasnår', False)],
          'sat': [('sate', True)],
          'sat-': [('sate', True)],
          'satans': [('satan', True)],
          'satarna': [('sate', True)],
          'satars': [('sate', True)],
          'sate': [('sate', True)],
          'saten': [('sate', True)],
          'satens': [('sate', True)],
          'sates': [('sate', True)],
          'sates-': [('sate', True)],
          'satidens': [('satid', False)],
          'satids': [('satid', False)],
          'satids-': [('satid', False)],
          'satin': [('satin', True)],
          'sation': [('sation', False)],
          'sationen': [('sation', False)],
          'sations': [('sation', False)],
          'sator': [('sator', False)],
          'sators': [('sator', False)],
          'satrons': [('satro', False)],
          'sats': [('sate', True), ('sats', True)],
          'sats-': [('sats', True), ('sate', True)],
          'satsbräde': [('satsbräda', True), ('satsbräde', True)],
          'satsen': [('sats', False)],
          'satsens': [('sats', False)],
          'saun': [('sauna', True)],
          'sauna': [('sauna', True)],
          'saunas': [('sauna', True)],
          'saur': [('saur', False)],
          'saur-': [('saur', False)],
          'saurier': [('saurie', False)],
          'saurierna': [('saurie', False)],
          'saurs': [('saur', False)],
          'savan': [('sava', False)],
          'savanden': [('savande', True)],
          'savandens': [('savande', True)],
          'savans': [('sava', False)],
          'saven': [('sav', False)],
          'savens': [('sav', False)],
          'saxar': [('sax', True), ('saxare', True)],
          'saxarna': [('saxare', True), ('sax', True)],
          'saxarnas': [('sax', True), ('saxare', True)],
          'says': [('say', False)],
          'sb': [('sb', False)],
          'sback': [('sback', False)],
          'sback-': [('sbacke', False)],
          'sbackar': [('sbacke', False)],
          'sbackarna': [('sback', False)],
          'sbackarnas': [('sback', False)],
          'sbackars': [('sbacke', False)],
          'sbacke': [('sbacke', False)],
          'sbacke-': [('sbacke', False)],
          'sbacken': [('sbacke', False)],
          'sbackens': [('sbacke', False)],
          'sbacks': [('sback', False)],
          'sbacks-': [('sbacke', False)],
          'sbagg': [('sbagge', False)],
          'sbagg-': [('sbagge', False)],
          'sbaggar': [('sbagge', False)],
          'sbaggarna': [('sbagge', False)],
          'sbaggarnas': [('sbagge', False)],
          'sbaggars': [('sbagge', False)],
          'sbaggen': [('sbagge', False)],
          'sbaggens': [('sbagge', False)],
          'sbaggs': [('sbagge', False)],
          'sbaggs-': [('sbagge', False)],
          'sbal': [('sbal', False)],
          'sbal-': [('sbal', False)],
          'sbalar': [('sbal', False)],
          'sbalarna': [('sbal', False)],
          'sbalarnas': [('sbal', False)],
          'sbalars': [('sbal', False)],
          'sbalen': [('sbal', False)],
          'sbalens': [('sbal', False)],
          'sbals': [('sbal', False)],
          'sbals-': [('sbal', False)],
          'sbanan': [('sbana', False)],
          'sbanans': [('sbana', False)],
          'sbandets': [('sband', False)],
          'sbane': [('sbana', False)],
          'sbane-': [('sbana', False)],
          'sbar': [('sbar', False)],
          'sbarens': [('sbar', False)],
          'sbars': [('sbar', False)],
          'sbas': [('sbas', False)],
          'sbasar': [('sbasar', False)],
          'sbasar-': [('sbasar', False)],
          'sbasarens': [('sbasar', False)],
          'sbasars': [('sbasar', False)],
          'sben': [('sben', False)],
          'sbens': [('sben', False)],
          'sbens-': [('sben', False)],
          'sbet': [('sbeta', False)],
          'sbet-': [('sbeta', False)],
          'sbete': [('sbeta', False)],
          'sbeten': [('sbete', False)],
          'sbetens': [('sbete', False)],
          'sbetets': [('sbete', False)],
          'sbets': [('sbeta', False)],
          'sbets-': [('sbeta', False)],
          'sbevis': [('sbevis', False)],
          'sbevis-': [('sbevis', False)],
          'sbil': [('sbil', False)],
          'sbilar': [('sbil', False)],
          'sbilars': [('sbil', False)],
          'sbill': [('sbill', False)],
          'sbill-': [('sbill', False)],
          'sbills': [('sbill', False)],
          'sbills-': [('sbill', False)],
          'sbils': [('sbil', False)],
          'sbils-': [('sbil', False)],
          'sbin': [('sbi', False)],
          'sbind': [('sbinda', False)],
          'sbind-': [('sbinda', False)],
          'sbinds': [('sbinda', False)],
          'sbinds-': [('sbinda', False)],
          'sbit': [('sbi', False)],
          'sbitar': [('sbit', False)],
          'sbitars': [('sbit', False)],
          'sbits': [('sbit', False)],
          'sbits-': [('sbit', False)],
          'sbloggar': [('sblogg', False)],
          'sbloggarna': [('sblogg', False)],
          'sbloggarnas': [('sblogg', False)],
          'sblom': [('sblomma', False)],
          'sblom-': [('sblomma', False)],
          'sbloms': [('sblomma', False)],
          'sbloms-': [('sblomma', False)],
          'sblänket': [('sblänk', False)],
          'sblänkets': [('sblänk', False)],
          'sblänks': [('sblänk', False)],
          'sblänks-': [('sblänk', False)],
          'sblåsarna': [('sblåsare', False)],
          'sboj': [('sboj', False)],
          'sboj-': [('sboj', False)],
          'sbojar': [('sboj', False)],
          'sbojars': [('sboj', False)],
          'sbojs': [('sboj', False)],
          'sbojs-': [('sboj', False)],
          'sbokhandlar': [('sbokhandel', False)],
          'sbokhandlarna': [('sbokhandel', False)],
          'sbokhandlarnas': [('sbokhandel', False)],
          'sbolaget': [('sbolag', False)],
          'sbomb': [('sbomb', False)],
          'sbomber': [('sbomb', False)],
          'sbomberna': [('sbomb', False)],
          'sbombernas': [('sbomb', False)],
          'sbombers': [('sbomb', False)],
          'sbombs': [('sbomb', False)],
          'sbombs-': [('sbomb', False)],
          'sbond': [('sbonde', False)],
          'sbond-': [('sbonde', False)],
          'sbondens': [('sbonde', False)],
          'sbonds': [('sbonde', False)],
          'sbor': [('sbo', False)],
          'sborgar': [('sborgare', False)],
          'sborgarna': [('sborgare', False)],
          'sborgarnas': [('sborgare', False)],
          'sborr': [('sborre', False)],
          'sborr-': [('sborre', False)],
          'sborrar': [('sborre', False)],
          'sborrarna': [('sborre', False)],
          'sborrarnas': [('sborre', False)],
          'sborrars': [('sborre', False)],
          'sborren': [('sborre', False)],
          'sborrens': [('sborre', False)],
          'sborrs': [('sborre', False)],
          'sborrs-': [('sborre', False)],
          'sbors': [('sbo', False)],
          'sborst': [('sborste', False)],
          'sborst-': [('sborste', False)],
          'sborsten': [('sborste', False)],
          'sborstens': [('sborste', False)],
          'sbot': [('sbo', False)],
          'sbots': [('sbo', False)],
          'sboxar': [('sbox', False)],
          'sboxarna': [('sbox', False)],
          'sboxarnas': [('sbox', False)],
          'sbranden': [('sbrand', False)],
          'sbrandens': [('sbrand', False)],
          'sbroder': [('sbroder', False)],
          'sbrodern': [('sbroder', False)],
          'sbroderns': [('sbroder', False)],
          'sbroders': [('sbroder', False)],
          'sbroms': [('sbroms', False)],
          'sbromsar': [('sbroms', False)],
          'sbromsarna': [('sbroms', False)],
          'sbromsarnas': [('sbroms', False)],
          'sbrons': [('sbro', False)],
          'sbrynet': [('sbryn', False)],
          'sbrynets': [('sbryn', False)],
          'sbryns': [('sbryn', False)],
          'sbryns-': [('sbryn', False)],
          'sbrytar': [('sbrytare', False)],
          'sbrytarna': [('sbrytare', False)],
          'sbrytarnas': [('sbrytare', False)],
          'sbräds': [('sbräda', False)],
          'sbräds-': [('sbräda', False)],
          'sbränne': [('sbränna', False)],
          'sbränne-': [('sbränna', False)],
          'sbråk': [('sbråk', False)],
          'sbråks': [('sbråk', False)],
          'sbråks-': [('sbråk', False)],
          'sbröder': [('sbroder', False)],
          'sbröderna': [('sbroder', False)],
          'sbrödernas': [('sbroder', False)],
          'sbröders': [('sbroder', False)],
          'sbröst': [('sbröst', False)],
          'sbröst-': [('sbröst', False)],
          'sbubbel': [('sbubbla', False)],
          'sbubbel-': [('sbubbla', False)],
          'sbull': [('sbulle', False)],
          'sbulle': [('sbulle', False)],
          'sbulle-': [('sbulle', False)],
          'sbulls': [('sbulle', False)],
          'sbulls-': [('sbulle', False)],
          'sburs-': [('sbur', False)],
          'sbygget': [('sbygge', False)],
          'sbytet': [('sbyt', False)],
          'sbyx': [('sbyxa', False)],
          'sbyx-': [('sbyxa', False)],
          'sbyxorna': [('sbyxa', False)],
          'sbyxornas': [('sbyxa', False)],
          'sbäcken': [('sbäck', False)],
          'sbäckens': [('sbäck', False)],
          'sbälte': [('sbälte', False)],
          'sbärs': [('sbär', False)],
          'sbärs-': [('sbär', False)],
          'sbåg': [('sbåge', False)],
          'sbåg-': [('sbåge', False)],
          'sbågs': [('sbåge', False)],
          'sbågs-': [('sbåge', False)],
          'sbön': [('sbön', False)],
          'sbön-': [('sböna', False)],
          'sböne': [('sböna', False)],
          'sböne-': [('sböna', False)],
          'sböns-': [('sbön', False)],
          'sböter': [('sbot', False)],
          'sböterna': [('sbot', False)],
          'sböternas': [('sbot', False)],
          'sböters': [('sbot', False)],
          'scell': [('scell', False)],
          'scellens': [('scell', False)],
          'scen': [('scen', False)],
          'scens': [('scen', True)],
          'scens-': [('scen', False)],
          'scenter': [('scenter', False)],
          'scenters': [('scent', False)],
          'scentrer': [('scentrum', False)],
          'scentrerna': [('scentrum', False)],
          'scentrernas': [('scentrum', False)],
          'scentret': [('scenter', False)],
          'scentrets': [('scenter', False)],
          'scepter': [('scepter', True)],
          'scepters': [('scepter', True)],
          'schackbräde': [('schackbräde', True), ('schackbräda', True)],
          'schans': [('scha', False)],
          'schar': [('sch', False)],
          'scharnas': [('sch', False)],
          'schars': [('sch', False)],
          'schas': [('scha', False)],
          'schasens': [('schas', False)],
          'schetten': [('schett', False)],
          'schetter': [('schett', False)],
          'schetterna': [('schett', False)],
          'schetternas': [('schett', False)],
          'schips': [('schips', False)],
          'schips-': [('schips', False)],
          'schis': [('schis', False)],
          'schis-': [('schis', False)],
          'schors': [('scha', False)],
          'scot': [('sco', False)],
          'sdagar': [('sdag', False)],
          'sdagarna': [('sdag', False)],
          'sdagarnas': [('sdag', False)],
          'sdagars': [('sdag', False)],
          'sdagen': [('sdag', False)],
          'sdagens': [('sdag', False)],
          'sdags': [('sdag', False)],
          'sdags-': [('sdag', False)],
          'sdamen': [('sdam', False)],
          'sdamens': [('sdam', False)],
          'sdamer': [('sdam', False)],
          'sdamerna': [('sdam', False)],
          'sdamernas': [('sdam', False)],
          'sdans': [('sdag', False)],
          'sdar': [('sdag', False)],
          'sdars': [('sdag', False)],
          'sdator': [('sdator', False)],
          'sdators': [('sdator', False)],
          'sdeg': [('sdeg', False)],
          'sdeg-': [('sdeg', False)],
          'sdel': [('sdel', False)],
          'sdelar': [('sdelar', False)],
          'sdelarna': [('sdelar', False)],
          'sdelarnas': [('sdelar', False)],
          'sdelars': [('sdel', False)],
          'sdels': [('sdel', False)],
          'sdels-': [('sdel', False)],
          'sdiskar': [('sdisk', False)],
          'sdiskarna': [('sdisk', False)],
          'sdiskarnas': [('sdisk', False)],
          'sdock-': [('sdocka', False)],
          'sdocks': [('sdocka', False)],
          'sdolmar': [('sdolma', False)],
          'sdomen': [('sdom', False)],
          'sdominans': [('sdominans', False)],
          'sdos': [('sdosa', False)],
          'sdos-': [('sdosa', False)],
          'sdosen': [('sdos', False)],
          'sdosens': [('sdos', False)],
          'sdramer': [('sdrama', False)],
          'sdramerna': [('sdrama', False)],
          'sdramernas': [('sdrama', False)],
          'sdricks': [('sdricka', False)],
          'sdricks-': [('sdricka', False)],
          'sdrivar': [('sdrivare', False)],
          'sdrivarna': [('sdrivare', False)],
          'sdrivarnas': [('sdrivare', False)],
          'sdropp': [('sdroppe', False)],
          'sdropp-': [('sdroppe', False)],
          'sdropps': [('sdroppe', False)],
          'sdropps-': [('sdroppe', False)],
          'sdrömmar': [('sdröm', False)],
          'sdrömmarna': [('sdröm', False)],
          'sdrömmarnas': [('sdröm', False)],
          'sdyn': [('sdyna', False)],
          'sdyn-': [('sdyna', False)],
          'sdyns': [('sdyna', False)],
          'sdyns-': [('sdyna', False)],
          'sdyrkar': [('sdyrkare', False)],
          'sdyrkarna': [('sdyrkare', False)],
          'sdyrkarnas': [('sdyrkare', False)],
          'sdödarna': [('sdöd', False)],
          'sebus': [('sebu', True)],
          'sed': [('sed', True)],
          'sed-': [('sed', False)],
          'sedan': [('sedan', True)],
          'sedans': [('sedan', True)],
          'sede': [('sed', False)],
          'sede-': [('sed', True)],
          'seds': [('sed', False)],
          'seds-': [('sed', False)],
          'sedyns': [('sedyn', False)],
          'seen': [('se', False)],
          'seens': [('se', False)],
          'seer': [('se', False)],
          'seerna': [('se', False)],
          'seernas': [('se', False)],
          'seers': [('seum', False)],
          'seets': [('seum', False)],
          'sefas': [('sefas', False)],
          'seffekt': [('seffekter', False)],
          'seffekt-': [('seffekter', False)],
          'seffekter': [('seffekter', False)],
          'seffekterna': [('seffekt', False)],
          'seffekternas': [('seffekter', False)],
          'seffekters': [('seffekter', False)],
          'seffekts': [('seffekter', False)],
          'seffekts-': [('seffekter', False)],
          'segas': [('segas', False)],
          'segas-': [('segas', False)],
          'seger': [('seger', False)],
          'segers': [('seger', True)],
          'seglar': [('seglare', False)],
          'seglarna': [('seglare', True)],
          'seglarnas': [('seglare', False)],
          'segranden': [('segrande', True)],
          'segrandens': [('segrande', True)],
          'segrar': [('segrare', True), ('seger', True)],
          'segrarna': [('seger', True), ('segrare', True)],
          'segrarnas': [('segrare', True), ('seger', True)],
          'segångarnas': [('segång', False)],
          'sehandlarna': [('sehandel', False)],
          'seiner': [('sein', False)],
          'seinerna': [('sein', False)],
          'seinernas': [('sein', False)],
          'seiners': [('sein', False)],
          'sejdarna': [('sejdare', True)],
          'sejdarnas': [('sejdare', True)],
          'sejden': [('sejd', True)],
          'sejdens': [('sejd', True)],
          'sejtar': [('sejte', True)],
          'sejtarna': [('sejte', True)],
          'sejtarnas': [('sejte', True)],
          'sek': [('seka', False)],
          'sek-': [('seka', False)],
          'sekar': [('sekar', False)],
          'sekar-': [('sekar', False)],
          'sekaren': [('sekar', False)],
          'sekars': [('sekar', False)],
          'seke': [('seka', False)],
          'seke-': [('seka', False)],
          'seklipp': [('seklippa', False)],
          'seklipps': [('seklippa', False)],
          'seklipps-': [('seklippa', False)],
          'sekrets': [('sekret', True)],
          'sekrets-': [('sekret', True)],
          'seks': [('seka', False)],
          'seks-': [('seka', False)],
          'sekt': [('sekt', True)],
          'sekt-': [('sekt', False)],
          'sekten': [('sekt', False)],
          'sektens': [('sekt', False)],
          'sekter': [('sekter', True), ('sekt', True)],
          'sekterna': [('sekt', False)],
          'sekternas': [('sekt', True)],
          'sekters': [('sekter', True), ('sekt', True)],
          'sekts': [('sekt', False)],
          'sekts-': [('sekt', True)],
          'sel': [('sele', True), ('sel', True)],
          'sel-': [('sel', True), ('sele', True)],
          'selager': [('selager', False)],
          'selagerna': [('selager', False)],
          'selagernas': [('selager', False)],
          'selagers': [('selager', False)],
          'selanden': [('selande', True)],
          'selandens': [('selande', True)],
          'selandets': [('selande', True)],
          'selar': [('sele', False)],
          'selarna': [('sele', False)],
          'selarnas': [('sele', False)],
          'selars': [('sele', False)],
          'seldar': [('seld', False)],
          'seldarna': [('seld', False)],
          'seldarnas': [('seld', False)],
          'sele': [('sele', False)],
          'sele-': [('sele', False)],
          'selen': [('selen', True), ('sel', True), ('sele', True)],
          'selens': [('sele', True), ('selen', True), ('sel', True)],
          'seler': [('seler', False)],
          'selers': [('sel', False)],
          'selet': [('sel', True)],
          'selets': [('sel', True)],
          'selfies': [('selfie', True), ('selfies', True)],
          'selfies-': [('selfie', True), ('selfies', True)],
          'selfiesen': [('selfie', True), ('selfies', True)],
          'selfiesens': [('selfie', True), ('selfies', True)],
          'selgångarnas': [('selgång', False)],
          'selin': [('selin', False)],
          'selkammar': [('selkammare', False)],
          'selkrokarnas': [('selkrok', False)],
          'sell': [('sell', False)],
          'sell-': [('sell', False)],
          'sellan': [('sella', False)],
          'sellen': [('sell', False)],
          'seller': [('sell', False)],
          'sellerna': [('sell', False)],
          'sellernas': [('sell', False)],
          'sellers': [('sell', False)],
          'sells': [('sell', False)],
          'sells-': [('sell', False)],
          'sels': [('sel', True), ('sele', True)],
          'sels-': [('sele', True), ('sel', True)],
          'selön': [('selön', False)],
          'selöns': [('selön', False)],
          'sem': [('sem', False)],
          'sem-': [('sem', False)],
          'semang': [('semang', False)],
          'semang-': [('semang', False)],
          'semanger': [('semang', False)],
          'semangerna': [('semang', False)],
          'semangernas': [('semang', False)],
          'semangers': [('semang', False)],
          'semangs': [('semang', False)],
          'semangs-': [('semang', False)],
          'sematt': [('sematt', False)],
          'sematt-': [('sematt', False)],
          'sematts-': [('sematt', False)],
          'sementen': [('sement', False)],
          'sementens': [('sement', False)],
          'sementet': [('sement', False)],
          'sements-': [('sement', False)],
          'semestrar': [('semestrare', True), ('semester', True)],
          'semestrarna': [('semestrare', True), ('semester', True)],
          'semestrarnas': [('semestrare', True), ('semester', True)],
          'semien': [('semi', False)],
          'semiens': [('semi', False)],
          'semis': [('semi', False)],
          'semits': [('semit', True)],
          'sems': [('sem', False)],
          'sen': [('sena', True), ('s', True)],
          'sen-': [('sena', True)],
          'sena': [('sena', False)],
          'senans': [('sena', True)],
          'senap': [('senap', True)],
          'senaps': [('senap', True)],
          'senar': [('senar', True)],
          'senaren': [('senar', True)],
          'senars': [('senar', True)],
          'senas': [('sena', True)],
          'senat-': [('senat', True)],
          'senats-': [('senat', True)],
          'sendets': [('sende', False)],
          'sene': [('sena', False)],
          'sene-': [('sena', False)],
          'senet': [('sen', False)],
          'senets': [('sen', False)],
          'seng': [('seng', False)],
          'seng-': [('seng', False)],
          'sengs': [('seng', False)],
          'senheter': [('senhet', False)],
          'senheterna': [('senhet', False)],
          'senheternas': [('senhet', False)],
          'senheters': [('senhet', False)],
          'senhets': [('senhet', False)],
          'senhets-': [('senhet', False)],
          'senkrans-': [('senkrans', False)],
          'sens': [('s', True), ('sena', True)],
          'sens-': [('sena', False)],
          'sensen': [('sens', False)],
          'sensens': [('sens', False)],
          'senser': [('sens', False)],
          'senserna': [('sens', False)],
          'sensernas': [('sens', False)],
          'sensers': [('sens', False)],
          'sent': [('sent', False)],
          'sentanden': [('sentande', False)],
          'sentandens': [('sentande', False)],
          'senten': [('sent', False)],
          'sentens': [('sentens', True)],
          'sentens-': [('sentens', True)],
          'senter': [('sent', False)],
          'senterna': [('sent', False)],
          'senternas': [('sent', False)],
          'senters': [('sent', False)],
          'sents-': [('sent', False)],
          'senyans': [('senyans', False)],
          'sepsis': [('sepsis', True)],
          'ser-': [('sera', False)],
          'sera': [('serum', True)],
          'seran': [('sera', False)],
          'serans': [('sera', False)],
          'serare': [('serare', False)],
          'serares': [('serare', False)],
          'serarna': [('serare', False)],
          'serarnas': [('serare', False)],
          'seras': [('serum', True)],
          'serbens': [('serb', True)],
          'serber': [('serb', True)],
          'serberna': [('serb', True)],
          'serbernas': [('serb', True)],
          'serbers': [('serb', True)],
          'sergin': [('sergi', False)],
          'sergins': [('sergi', False)],
          'seri': [('seri', False)],
          'seri-': [('seri', False)],
          'serier': [('serie', True)],
          'serierna': [('serie', True)],
          'seriernas': [('serie', True)],
          'seriers': [('serie', True)],
          'seriet': [('seri', False)],
          'seris': [('seri', False)],
          'seris-': [('seri', False)],
          'serit': [('seri', False)],
          'sern-': [('sern', False)],
          'serner': [('sern', False)],
          'serners': [('sern', False)],
          'serns-': [('sern', False)],
          'serornas': [('sera', False)],
          'sers-': [('sera', False)],
          'sersarnas': [('ser', False)],
          'sersen': [('ser', False)],
          'sersikten': [('sersikte', False)],
          'sersiktens': [('sersikte', False)],
          'sertens': [('sert', False)],
          'serter': [('sert', False)],
          'serters': [('sert', False)],
          'serts': [('sert', False)],
          'serts-': [('sert', False)],
          'serv': [('serve', True)],
          'serv-': [('serve', True)],
          'servant': [('servant', False)],
          'servant-': [('servant', False)],
          'servants': [('servant', False)],
          'servar': [('serve', True)],
          'servaren': [('servare', False)],
          'servarna': [('serve', True)],
          'servarnas': [('serve', True)],
          'serven': [('serve', True)],
          'servens': [('serve', True)],
          'server': [('server', True)],
          'servers': [('server', True)],
          'servis': [('servis', False)],
          'servis-': [('servis', False)],
          'servs': [('serve', True)],
          'servs-': [('serve', True)],
          'ses': [('se', False)],
          'ses-': [('se', False)],
          'sesarnas': [('ses', False)],
          'seskedens': [('seskede', False)],
          'seskedets': [('seskede', False)],
          'sess': [('sessa', False)],
          'sess-': [('sessa', False)],
          'sesse': [('sessa', False)],
          'sesse-': [('sessa', False)],
          'sessens': [('sess', False)],
          'sesser': [('sess', False)],
          'sesserna': [('sess', False)],
          'sessernas': [('sess', False)],
          'sessers': [('sess', False)],
          'sessor': [('sessa', False)],
          'sessors': [('sessa', False)],
          'sestan': [('sestad', False)],
          'sester': [('sest', False)],
          'sesterna': [('sest', False)],
          'sesternas': [('sest', False)],
          'sesters': [('sest', False)],
          'set': [('s', True), ('set', True)],
          'setan': [('seta', False)],
          'setans': [('seta', False)],
          'setarnas': [('set', False)],
          'seten': [('set', False)],
          'setens': [('set', True)],
          'setets': [('set', False)],
          'setidens': [('setid', False)],
          'setiker': [('setik', False)],
          'setikerna': [('setik', False)],
          'setikernas': [('setik', False)],
          'setikers': [('setik', False)],
          'setrons': [('setro', False)],
          'sets': [('set', True), ('s', True)],
          'setsarna': [('set', False)],
          'setsarnas': [('set', False)],
          'sett': [('sett', False)],
          'sett-': [('sett', False)],
          'settar': [('settare', False)],
          'settarna': [('settare', False)],
          'settarnas': [('settare', False)],
          'sette': [('setta', False)],
          'setten': [('sett', False)],
          'setter': [('setter', True)],
          'setterna': [('sett', False)],
          'setternas': [('sett', False)],
          'setters': [('setter', True)],
          'settor': [('setta', False)],
          'settors': [('setta', False)],
          'setts': [('sett', False)],
          'setts-': [('sett', False)],
          'severket': [('severk', False)],
          'sevisa': [('sevisum', False)],
          'sex': [('sex', True)],
          'sex-': [('sex', True)],
          'sexistens': [('sexist', True)],
          'sextidens': [('sextiden', True)],
          'señor': [('señora', True), ('señor', True)],
          'señor-': [('señora', True), ('señor', True)],
          'señors': [('señora', True), ('señor', True)],
          'señors-': [('señora', True), ('señor', True)],
          'sfader': [('sfar', False)],
          'sfader-': [('sfar', False)],
          'sfadern': [('sfader', False)],
          'sfaderns': [('sfar', False)],
          'sfaders': [('sfader', False)],
          'sfaders-': [('sfar', False)],
          'sfan': [('sfana', False)],
          'sfan-': [('sfana', False)],
          'sfanas': [('sfana', False)],
          'sfans': [('sfana', False)],
          'sfans-': [('sfana', False)],
          'sfar': [('sfar', False)],
          'sfar-': [('sfar', False)],
          'sfare': [('sfara', False)],
          'sfarmar': [('sfarm', False)],
          'sfarmarna': [('sfarm', False)],
          'sfarmarnas': [('sfarm', False)],
          'sfars': [('sfara', False)],
          'sfars-': [('sfara', False)],
          'sfas': [('sfas', False)],
          'sfasen': [('sfas', False)],
          'sfasens': [('sfas', False)],
          'sfasonerna': [('sfason', False)],
          'sfasonernas': [('sfason', False)],
          'sfasoners': [('sfason', False)],
          'sfat': [('sfat', False)],
          'sfats': [('sfat', False)],
          'sfel': [('sfel', False)],
          'sfel-': [('sfel', False)],
          'sfels': [('sfel', False)],
          'sfels-': [('sfel', False)],
          'sfen': [('sfena', False)],
          'sfena': [('sfena', False)],
          'sfens': [('sfena', False)],
          'sfer-': [('sfer', False)],
          'sfilen': [('sfil', False)],
          'sfilens': [('sfil', False)],
          'sfinans': [('sfinanser', False)],
          'sfinans-': [('sfinanser', False)],
          'sfink': [('sfinka', False)],
          'sfink-': [('sfinka', False)],
          'sfinks': [('sfinka', False)],
          'sfinks-': [('sfinka', False)],
          'sfirmandens': [('sfirmande', False)],
          'sfiskar': [('sfiskare', False)],
          'sfiskarna': [('sfiskare', False)],
          'sfiskarnas': [('sfisk', False)],
          'sflagg-': [('sflagga', False)],
          'sflaggs-': [('sflagga', False)],
          'sflams': [('sflamma', False)],
          'sflams-': [('sflamma', False)],
          'sflott': [('sflotta', False)],
          'sflott-': [('sflotta', False)],
          'sflotte': [('sflotta', False)],
          'sflotts': [('sflotta', False)],
          'sflotts-': [('sflotta', False)],
          'sflyt': [('sfly', False)],
          'sflyts': [('sfly', False)],
          'sfläck': [('sfläck', False)],
          'sflödet': [('sflöde', False)],
          'sfor': [('sfor', False)],
          'sfor-': [('sfor', False)],
          'sfora': [('sforum', False)],
          'sforas': [('sforum', False)],
          'sformar': [('sform', False)],
          'sformarna': [('sform', False)],
          'sformarnas': [('sform', False)],
          'sfors': [('sfor', False)],
          'sfoton': [('sfoto', False)],
          'sfotons': [('sfoto', False)],
          'sfots': [('sfot', False)],
          'sfots-': [('sfot', False)],
          'sframställningar': [('sframställning', False)],
          'sframställningarna': [('sframställning', False)],
          'sframställningars': [('sframställning', False)],
          'sfräsarna': [('sfräs', False)],
          'sfunds': [('sfunder', False)],
          'sfunds-': [('sfunder', False)],
          'sfyrar': [('sfyr', False)],
          'sfyrarnas': [('sfyr', False)],
          'sfäder': [('sfader', False)],
          'sfäderna': [('sfader', False)],
          'sfädernas': [('sfar', False)],
          'sfäders': [('sfader', False)],
          'sfärs': [('sfär', True)],
          'sfärs-': [('sfär', False)],
          'sfång-': [('sfånge', False)],
          'sfångens': [('sfånge', False)],
          'sfångs': [('sfånge', False)],
          'sfår': [('sfår', False)],
          'sfår-': [('sfår', False)],
          'sfårs': [('sfår', False)],
          'sfårs-': [('sfår', False)],
          'sförar': [('sförare', False)],
          'sförarna': [('sförare', False)],
          'sförarnas': [('sförare', False)],
          'sfördelar': [('sfördel', False)],
          'sfördelarna': [('sfördel', False)],
          'sfördelarnas': [('sfördel', False)],
          'sförlust-': [('sförlust', False)],
          'sförluster': [('sförlust', False)],
          'sförlusterna': [('sförlust', False)],
          'sförlusternas': [('sförlust', False)],
          'sförnödenheter': [('sförnödenheter', False)],
          'sförnödenheterna': [('sförnödenheter', False)],
          'sförnödenheternas': [('sförnödenheter', False)],
          'sförnödenheters': [('sförnödenheter', False)],
          'sförnödenhets': [('sförnödenheter', False)],
          'sförnödenhets-': [('sförnödenheter', False)],
          'sförsäkringar': [('sförsäkring', False)],
          'sförsäkringarna': [('sförsäkring', False)],
          'sförsäkringarnas': [('sförsäkring', False)],
          'sförsäkringars': [('sförsäkran', False)],
          'sgaller': [('sgaller', False)],
          'sgallerna': [('sgaller', False)],
          'sgallernas': [('sgaller', False)],
          'sgallers': [('sgaller', False)],
          'sgamen': [('sgam', False)],
          'sgamens': [('sgam', False)],
          'sgas': [('sgas', False)],
          'sgaser': [('sgas', False)],
          'sgaserna': [('sgas', False)],
          'sgasernas': [('sgas', False)],
          'sgasers': [('sgas', False)],
          'sgatan': [('sgatan', False)],
          'sgate': [('sgata', False)],
          'sgate-': [('sgata', False)],
          'sgator': [('sgata', False)],
          'sgators': [('sgata', False)],
          'sgats': [('sgata', False)],
          'sgenier': [('sgeni', False)],
          'sgenierna': [('sgeni', False)],
          'sgeniernas': [('sgeni', False)],
          'sgeniers': [('sgeni', False)],
          'sgetter': [('sget', False)],
          'sgiftens': [('sgifte', False)],
          'sgiftet': [('sgifte', False)],
          'sgiftets': [('sgift', False)],
          'sgifts': [('sgift', False)],
          'sgifts-': [('sgift', False)],
          'sgillen': [('sgille', False)],
          'sgillets': [('sgille', False)],
          'sgivar': [('sgivare', False)],
          'sgivarna': [('sgivare', False)],
          'sgivarnas': [('sgivare', False)],
          'sglasögon': [('sglasögon', False)],
          'sglasögonen': [('sglasögon', False)],
          'sglasögonens': [('sglasögon', False)],
          'sglasögons': [('sglasögon', False)],
          'sgods': [('sgods', False)],
          'sgods-': [('sgods', False)],
          'sgrammatik': [('sgrammatik', False)],
          'sgrammatik-': [('sgrammatik', False)],
          'sgrammatiker': [('sgrammatik', False)],
          'sgrammatikerna': [('sgrammatik', False)],
          'sgrammatikernas': [('sgrammatik', False)],
          'sgrammatikers': [('sgrammatik', False)],
          'sgrammatiks': [('sgrammatik', False)],
          'sgrammatiks-': [('sgrammatik', False)],
          'sgrann': [('sgranne', False)],
          'sgrann-': [('sgranne', False)],
          'sgranns': [('sgranne', False)],
          'sgranns-': [('sgranne', False)],
          'sgrims': [('sgrimma', False)],
          'sgrims-': [('sgrimma', False)],
          'sgrynet': [('sgryn', False)],
          'sgrynets': [('sgryn', False)],
          'sgryt': [('sgryta', False)],
          'sgryt-': [('sgryta', False)],
          'sgryts': [('sgryta', False)],
          'sgryts-': [('sgryta', False)],
          'sgränder': [('sgränd', False)],
          'sgräns': [('sgräns', False)],
          'sgräns-': [('sgräns', False)],
          'sgubb': [('sgubbe', False)],
          'sgubbs': [('sgubbe', False)],
          'sgubbs-': [('sgubbe', False)],
          'sgäng': [('sgäng', False)],
          'sgängen': [('sgäng', False)],
          'sgängens': [('sgäng', False)],
          'sgänget': [('sgäng', False)],
          'sgängets': [('sgäng', False)],
          'sgängs': [('sgäng', False)],
          'sgängs-': [('sgäng', False)],
          'sgärden': [('sgärd', False)],
          'sgärdens': [('sgärd', False)],
          'sgångar': [('sgång', False)],
          'sgångarna': [('sgång', False)],
          'sgångarnas': [('sgång', False)],
          'sgås': [('sgås', False)],
          'sgås-': [('sgås', False)],
          'sgåsen': [('sgås', False)],
          'sgåsens': [('sgås', False)],
          'sgåt': [('sgåta', False)],
          'sgåt-': [('sgåta', False)],
          'sgåts': [('sgåta', False)],
          'sgåts-': [('sgåta', False)],
          'sgåve': [('sgåva', False)],
          'sgåve-': [('sgåva', False)],
          'sgåvor': [('sgåva', False)],
          'sgåvorna': [('sgåva', False)],
          'sgåvornas': [('sgåvor', False)],
          'sgåvors': [('sgåva', False)],
          'sh': [('sh', False)],
          'sh-': [('sh', False)],
          'shag': [('shag', True)],
          'shag-': [('shag', True)],
          'shagen': [('shag', True)],
          'shagens': [('shag', True)],
          'shags': [('shag', True)],
          'shags-': [('shag', False)],
          'shak': [('shak', False)],
          'shak-': [('shak', False)],
          'shake': [('shake', False)],
          'shake-': [('shake', False)],
          'shaken': [('shake', False)],
          'shakens': [('shake', False)],
          'shaks': [('shak', False)],
          'shaks-': [('shak', False)],
          'shamrar': [('shammare', False)],
          'shan': [('sha', False)],
          'shanden': [('shande', False)],
          'shandens': [('shande', False)],
          'shandlar': [('shandel', False)],
          'shandlarna': [('shandlare', False)],
          'shandlarnas': [('shandlare', False)],
          'shans': [('shane', False)],
          'shans-': [('shane', False)],
          'shar': [('sh', False)],
          'shar-': [('share', False)],
          'sharen': [('share', False)],
          'sharmonier': [('sharmoni', False)],
          'sharmonierna': [('sharmoni', False)],
          'sharmoniernas': [('sharmoni', False)],
          'sharmoniers': [('sharmoni', False)],
          'sharmonik': [('sharmonika', False)],
          'sharmonik-': [('sharmonika', False)],
          'sharmoniks': [('sharmonika', False)],
          'sharna': [('sh', False)],
          'sharnas': [('share', False)],
          'shars': [('sh', False)],
          'shas': [('shas', False)],
          'shasen': [('shas', False)],
          'she': [('sha', False)],
          'she-': [('sha', False)],
          'shen': [('sh', False)],
          'shens': [('sh', False)],
          'sher': [('sh', False)],
          'sherna': [('sh', False)],
          'shernas': [('sh', False)],
          'shers': [('sh', False)],
          'shet': [('sh', False)],
          'sheter': [('shet', False)],
          'sheterna': [('shet', False)],
          'sheternas': [('shet', False)],
          'sheters': [('shet', False)],
          'shets': [('shet', False)],
          'shets-': [('shet', False)],
          'shias': [('shia', True)],
          'shin': [('shi', False)],
          'shins': [('shi', False)],
          'ships': [('ship', False)],
          'ships-': [('ship', False)],
          'shmans': [('shman', False)],
          'shonas': [('shona', False)],
          'shone': [('shona', False)],
          'shoparna': [('shop', True)],
          'shoper': [('shop', False)],
          'shopers': [('shop', False)],
          'shopp': [('shoppa', False)],
          'shopp-': [('shoppa', False)],
          'shoppingcentrer': [('shoppingcenter', True), ('shoppingcentrum', True)],
          'shoppingcentrerna': [('shoppingcenter', True), ('shoppingcentrum', True)],
          'shoppingcentrernas': [('shoppingcenter', True), ('shoppingcentrum', True)],
          'shoppingcentrers': [('shoppingcenter', True), ('shoppingcentrum', True)],
          'shoppingcentret': [('shoppingcenter', True), ('shoppingcentrum', True)],
          'shoppingcentrets': [('shoppingcentrum', True), ('shoppingcenter', True)],
          'shopps': [('shoppa', False)],
          'shopps-': [('shoppa', False)],
          'shor': [('sha', False)],
          'shor-': [('shora', False)],
          'shorna': [('sha', False)],
          'shornas': [('sha', False)],
          'shors': [('shora', False)],
          'shors-': [('shora', False)],
          'shorts': [('shorts', False)],
          'shots': [('shots', True), ('shot', True)],
          'shots-': [('shots', True), ('shot', True)],
          'shotsen': [('shots', True)],
          'shotsens': [('shots', True)],
          'shundars': [('shund', False)],
          'shus': [('shus', False)],
          'shuv': [('shuv', False)],
          'shuven': [('shuv', False)],
          'shuvens': [('shuv', False)],
          'shuvs': [('shuv', False)],
          'shuvs-': [('shuv', False)],
          'shylle': [('shylla', False)],
          'shylle-': [('shylla', False)],
          'shylls-': [('shylla', False)],
          'shytt': [('shytt', False)],
          'shytt-': [('shytt', False)],
          'shytts': [('shytt', False)],
          'shytts-': [('shytta', False)],
          'shyvlar': [('shyvel', False)],
          'shyvlarna': [('shyvel', False)],
          'shyvlarnas': [('shyvel', False)],
          'shälar': [('shäl', False)],
          'shälarna': [('shäl', False)],
          'shälarnas': [('shäl', False)],
          'shäll': [('shäll', False)],
          'shälls': [('shäll', False)],
          'shälls-': [('shäll', False)],
          'shärskare': [('shärskare', False)],
          'shäst': [('shäst', False)],
          'shästar': [('shäst', False)],
          'shästarnas': [('shäst', False)],
          'shästars': [('shäst', False)],
          'shävd': [('shävd', False)],
          'shävd-': [('shävd', False)],
          'shävder': [('shävd', False)],
          'shävderna': [('shävd', False)],
          'shävdernas': [('shävd', False)],
          'shävders': [('shävd', False)],
          'shävds': [('shävd', False)],
          'shävds-': [('shävd', False)],
          'shål': [('shål', False)],
          'shåls': [('shål', False)],
          'shåls-': [('shål', False)],
          'shögskolan': [('shögskola', False)],
          'shögskolans': [('shögskola', False)],
          'shökar': [('shök', False)],
          'shökarna': [('shök', False)],
          'shökarnas': [('shök', False)],
          'shölje': [('shölje', False)],
          'shöns': [('shöns', False)],
          'shöns-': [('shöns', False)],
          'si': [('si', False)],
          'si-': [('si', False)],
          'sialen': [('sial', True)],
          'sialens': [('sial', True)],
          'sian': [('sian', False)],
          'sian-': [('sian', False)],
          'sianden': [('siande', True)],
          'sians': [('sian', False)],
          'siaren': [('siare', True)],
          'siat': [('siat', False)],
          'siater': [('siat', False)],
          'siaters': [('siat', False)],
          'siats': [('siat', False)],
          'sick-': [('sick', True)],
          'sickar': [('sick', True)],
          'sickarna': [('sick', True)],
          'sickat': [('sickat', False)],
          'sickels': [('sickel', True)],
          'sicklar': [('sickel', True)],
          'sicklarnas': [('sickel', True)],
          'sicks': [('sick', True)],
          'sicks-': [('sick', True)],
          'sid': [('sid', True), ('sida', True)],
          'sid-': [('sida', True), ('sid', True)],
          'sida': [('sida', False)],
          'sidan': [('sida', True)],
          'sidans': [('sida', True)],
          'sidas': [('sida', False)],
          'side': [('sida', True)],
          'side-': [('sida', True)],
          'siden': [('siden', False)],
          'sidens': [('siden', False)],
          'sidens-': [('sidens', False)],
          'sider': [('sider', False)],
          'siderits': [('siderit', True)],
          'siderna': [('sider', False)],
          'sidernas': [('sider', False)],
          'siders': [('sider', False)],
          'sides': [('sida', True)],
          'sidie': [('sidium', False)],
          'sidie-': [('sidium', False)],
          'sidier': [('sidier', False)],
          'sidierna': [('sidium', False)],
          'sidiernas': [('sidier', False)],
          'sidiers': [('sidier', False)],
          'sido': [('sida', True)],
          'sido-': [('sida', True)],
          'sidos': [('sidos', False)],
          'sids': [('sid', False)],
          'sids-': [('sida', False)],
          'sie': [('sium', False)],
          'sie-': [('sium', False)],
          'sien': [('si', False)],
          'siena': [('siena', True)],
          'sienas': [('siena', True)],
          'siens': [('si', False)],
          'sier': [('si', False)],
          'siernas': [('si', False)],
          'siet': [('sium', False)],
          'siets': [('sium', False)],
          'siffer': [('siffra', False)],
          'sigheter': [('sighet', False)],
          'sigheterna': [('sighet', False)],
          'sigheternas': [('sighet', False)],
          'sigheters': [('sighet', False)],
          'sighets-': [('sighet', False)],
          'sigmats': [('sigma', True)],
          'signor': [('signor', True), ('signora', True)],
          'signor-': [('signor', True), ('signora', True)],
          'signorans': [('signora', True)],
          'signore': [('signora', True)],
          'signore-': [('signora', True)],
          'signoren': [('signor', True)],
          'signorens': [('signor', True)],
          'signorer': [('signor', True)],
          'signorerna': [('signor', True)],
          'signorernas': [('signor', True)],
          'signorers': [('signor', True)],
          'signors': [('signora', True), ('signor', True)],
          'signors-': [('signor', True), ('signora', True)],
          'sik': [('sik', True)],
          'sik-': [('sik', True)],
          'sika': [('sika', False)],
          'sikalie-': [('sikalier', False)],
          'sikalier': [('sikalier', False)],
          'sikalierna': [('sikalier', False)],
          'sikarnas': [('sik', True)],
          'sikas': [('sika', False)],
          'sike': [('sike', False)],
          'siken': [('sik', True)],
          'sikens': [('sik', True)],
          'siker': [('siker', False)],
          'sikerna': [('siker', False)],
          'sikernas': [('siker', False)],
          'sikers': [('siker', False)],
          'siket': [('sike', False)],
          'siks': [('sik', True)],
          'siks-': [('sik', True)],
          'siktar': [('sikt', False)],
          'siktarna': [('sikt', True)],
          'sikten': [('sikte', True), ('sikt', True)],
          'siktens': [('sikte', True), ('sikt', True)],
          'siktets': [('sikte', False)],
          'sikts': [('sikt', False)],
          'sikts-': [('sikt', False)],
          'silage': [('silage', False)],
          'silage-': [('silage', False)],
          'silagor': [('silago', False)],
          'silagorna': [('silago', False)],
          'silagornas': [('silago', False)],
          'silagors': [('silago', False)],
          'silen': [('silen', True), ('sil', True)],
          'silens': [('silen', True), ('sil', True)],
          'silens-': [('silen', True)],
          'silian': [('silian', False)],
          'silians': [('silian', False)],
          'silierna': [('silier', False)],
          'siliernas': [('silier', False)],
          'sill': [('sill', False)],
          'sill-': [('sill', False)],
          'sillar': [('sill', False)],
          'sillars': [('sill', False)],
          'sillen': [('sill', False)],
          'siller': [('sill', False)],
          'sillerna': [('sill', False)],
          'sillernas': [('sill', False)],
          'sillers': [('sill', False)],
          'sills': [('sill', False)],
          'sills-': [('sill', False)],
          'silo': [('silo', True)],
          'silon': [('silo', True)],
          'silons': [('silo', True)],
          'silor': [('silo', True)],
          'silorna': [('silo', True)],
          'silornas': [('silo', True)],
          'silors': [('silo', True)],
          'silt-': [('silt', True)],
          'silts': [('silt', True)],
          'silts-': [('silt', True)],
          'sima': [('sima', False)],
          'simanden': [('simand', True)],
          'simas': [('sima', False)],
          'simmar': [('simmare', False)],
          'simmarna': [('simmare', False)],
          'simon': [('simo', False)],
          'simons': [('simo', False)],
          'simos': [('simo', False)],
          'sims': [('sims', False)],
          'sims-': [('sims', True)],
          'simturs-': [('simtur', True)],
          'sin': [('sin', False)],
          'sin-': [('siner', False)],
          'sina': [('si', False)],
          'sinandens': [('sinande', True)],
          'sinans': [('sina', False)],
          'sinas': [('si', False)],
          'sine': [('sine', False)],
          'sine-': [('sine', False)],
          'sinerna': [('siner', False)],
          'sinernas': [('siner', False)],
          'siners': [('siner', False)],
          'sines': [('sine', False)],
          'sines-': [('sine', False)],
          'sinets': [('sin', False)],
          'sing': [('sing', False)],
          'sing-': [('sing', False)],
          'singar': [('sing', False)],
          'singarna': [('sing', False)],
          'singarnas': [('sing', False)],
          'singars': [('sing', False)],
          'singel': [('singel', False)],
          'singel-': [('singel', True)],
          'singen': [('sing', False)],
          'singens': [('sing', False)],
          'singlar': [('singel', True)],
          'singlarna': [('singel', False)],
          'singlarnas': [('singel', False)],
          'sings': [('sing', False)],
          'sings-': [('sing', False)],
          'singskor': [('singska', False)],
          'singskorna': [('singska', False)],
          'singskornas': [('singska', False)],
          'singskors': [('singska', False)],
          'sinier': [('sinier', False)],
          'sinierna': [('sinier', False)],
          'sinkar': [('sinkare', True)],
          'sinkarna': [('sinkare', True)],
          'sinkarnas': [('sinkare', True)],
          'sinkomst-': [('sinkomst', False)],
          'sinkomster': [('sinkomst', False)],
          'sinkomsterna': [('sinkomst', False)],
          'sinkomsternas': [('sinkomst', False)],
          'sinkomsters': [('sinkomst', False)],
          'sinnen': [('sinne', False)],
          'sinnets': [('sinne', False)],
          'sinons': [('sino', False)],
          'sinos': [('sino', False)],
          'sins': [('si', False)],
          'sins-': [('siner', False)],
          'sinstans': [('sinstans', False)],
          'sint': [('sint', False)],
          'sinter': [('sinter', True)],
          'sintern': [('sinter', True)],
          'sinterna': [('sint', False)],
          'sinternas': [('sint', False)],
          'sinterns': [('sinter', True)],
          'sinters': [('sinter', True)],
          'sinträden': [('sinträd', False)],
          'sinträdens': [('sinträd', False)],
          'sinträdet': [('sinträd', False)],
          'sinträdets': [('sinträd', False)],
          'sints-': [('sint', False)],
          'sinventarie': [('sinventarier', False)],
          'sinventarie-': [('sinventarier', False)],
          'sinventarier': [('sinventarier', False)],
          'sinventarierna': [('sinventarier', False)],
          'sinventariernas': [('sinventarier', False)],
          'sinventariers': [('sinventarier', False)],
          'sion': [('sion', False)],
          'sionen': [('sion', False)],
          'sionens': [('sion', False)],
          'sioner': [('sion', False)],
          'sionerna': [('sion', False)],
          'sionernas': [('sion', False)],
          'sioners': [('sion', False)],
          'sions': [('sion', False)],
          'sionsdags': [('sionsdag', False)],
          'sionsdags-': [('sionsdag', False)],
          'sior': [('sia', False)],
          'siorna': [('sia', False)],
          'siornas': [('sia', False)],
          'siors': [('sia', False)],
          'sippe': [('sippa', False)],
          'sippe-': [('sippa', False)],
          'siren': [('siren', True)],
          'sirens': [('siren', True)],
          'sirer': [('sir', False)],
          'sirerna': [('sir', False)],
          'sirernas': [('sir', False)],
          'sirers': [('sir', False)],
          'sis': [('sis', True)],
          'sis-': [('sis', True)],
          'siskan': [('siska', False)],
          'siskans': [('siska', False)],
          'siske': [('siska', False)],
          'siske-': [('siska', False)],
          'sismernas': [('sism', False)],
          'sismers': [('sism', False)],
          'sist-': [('sist', False)],
          'sistans': [('sista', True)],
          'sisten': [('sisten', True)],
          'sistens': [('sisten', True)],
          'sistens-': [('sisten', True)],
          'sister': [('sist', False)],
          'sisterna': [('sist', False)],
          'sisternas': [('sist', False)],
          'sisters': [('sist', False)],
          'sit': [('sit', False)],
          'sita': [('sita', False)],
          'sitan': [('sita', False)],
          'sitar': [('sitar', True)],
          'sitaren': [('sitar', True)],
          'sitars': [('sitar', True)],
          'siternas': [('sit', False)],
          'sitets': [('sit', False)],
          'sitiv': [('sitiva', False)],
          'sitiv-': [('sitiva', False)],
          'sitivs': [('sitiva', False)],
          'sitorierna': [('sitorium', False)],
          'sitoriernas': [('sitorium', False)],
          'sitoriers': [('sitorium', False)],
          'sitoriets': [('sitorium', False)],
          'sits': [('sits', True)],
          'sits-': [('sits', False)],
          'sitsar': [('sits', False)],
          'sitsarna': [('sits', False)],
          'sitsen': [('sits', False)],
          'sitsens': [('sits', True)],
          'sittarnas': [('sittare', False)],
          'sittbräde': [('sittbräda', True), ('sittbräde', True)],
          'sitter': [('sitter', False)],
          'sitter-': [('sitter', False)],
          'sittrar': [('sitter', True)],
          'sittrarna': [('sitter', True)],
          'sium': [('sium', False)],
          'siums': [('sium', False)],
          'siver': [('siver', False)],
          'sivers': [('siver', False)],
          'sivrar': [('sivrare', False)],
          'sivrarna': [('sivrare', False)],
          'sivs': [('siva', False)],
          'sivs-': [('siva', False)],
          'sizer': [('sizer', False)],
          'sizers': [('sizer', False)],
          'sj': [('sja', False)],
          'sj-': [('sja', False)],
          'sjack': [('sjacka', False)],
          'sjack-': [('sjacka', False)],
          'sjacks': [('sjacka', False)],
          'sjacks-': [('sjacka', False)],
          'sjan': [('sjana', True)],
          'sjan-': [('sjana', True)],
          'sjana': [('sjana', True)],
          'sjanas': [('sjana', True)],
          'sjans': [('sjana', True)],
          'sjans-': [('sjana', True)],
          'sjar': [('sjar', False)],
          'sjar-': [('sjar', False)],
          'sjarens': [('sjar', False)],
          'sjas': [('sjas', False)],
          'sjas-': [('sjas', False)],
          'sje': [('sja', False)],
          'sje-': [('sja', False)],
          'sjor': [('sja', False)],
          'sjorna': [('sja', False)],
          'sjornas': [('sja', False)],
          'sjors': [('sja', False)],
          'sjuan': [('sjua', True)],
          'sjuans': [('sjua', True)],
          'sjukan': [('sjuka', True)],
          'sjukans': [('sjuka', False)],
          'sjus': [('sju', False)],
          'sjustjärnorna': [('sjustjärnorna', True), ('sjustjärna', True)],
          'sjustjärnornas': [('sjustjärnorna', True), ('sjustjärna', True)],
          'sjut': [('sju', False)],
          'sjuts': [('sju', False)],
          'själ': [('själ', False)],
          'själ-': [('själ', False)],
          'själar': [('själ', False)],
          'själarna': [('själ', False)],
          'själarnas': [('själ', True)],
          'själars': [('själ', False)],
          'själen': [('själ', False)],
          'själens': [('själ', False)],
          'själs-': [('själ', False)],
          'sjär': [('sjär', False)],
          'sjär-': [('sjär', False)],
          'sjärnvägar': [('sjärnväg', False)],
          'sjärnvägarna': [('sjärnväg', False)],
          'sjärnvägarnas': [('sjärnväg', False)],
          'sjärs': [('sjär', False)],
          'sjärs-': [('sjär', False)],
          'sjöns': [('sjö', False)],
          'sk': [('sk', False)],
          'sk-': [('sk', False)],
          'skad': [('skad', False)],
          'skad-': [('skad', False)],
          'skadans': [('skada', False)],
          'skadens': [('skad', False)],
          'skader': [('skad', False)],
          'skaders': [('skad', False)],
          'skador': [('skada', False)],
          'skadorna': [('skada', False)],
          'skadornas': [('skada', False)],
          'skadors': [('skada', False)],
          'skads': [('skad', False)],
          'skaj': [('skaj', False)],
          'skajers': [('skaj', False)],
          'skajs': [('skaj', False)],
          'skajs-': [('skaj', False)],
          'skak': [('skak', True)],
          'skak-': [('skak', True)],
          'skaks': [('skak', True)],
          'skaks-': [('skak', True)],
          'skal': [('skala', True), ('skal', True)],
          'skal-': [('skala', True), ('skal', True)],
          'skalas': [('skala', True)],
          'skall': [('skall', True), ('skalle', True)],
          'skall-': [('skalle', True), ('skall', True)],
          'skallar': [('skalle', False)],
          'skalle': [('skalle', False)],
          'skalle-': [('skalle', False)],
          'skallen': [('skall', True), ('skalle', True)],
          'skallens': [('skall', True), ('skalle', True)],
          'skaller': [('skaller', True), ('skallra', True)],
          'skaller-': [('skallra', True), ('skaller', True)],
          'skallras': [('skallra', True)],
          'skalls': [('skalle', True), ('skall', True)],
          'skalls-': [('skalle', True), ('skall', True)],
          'skals': [('skala', True), ('skal', True)],
          'skals-': [('skala', True), ('skal', True)],
          'skammar': [('skammare', False)],
          'skams': [('skam', False)],
          'skams-': [('skam', True)],
          'skana': [('skana', False)],
          'skanas': [('skana', False)],
          'skanden': [('skande', False)],
          'skankar': [('skank', True)],
          'skans': [('skans', True)],
          'skans-': [('skans', True)],
          'skaparna': [('skapare', False)],
          'skaper': [('skap', False)],
          'skaperna': [('skap', False)],
          'skapernas': [('skap', False)],
          'skapers': [('skap', False)],
          'skapp': [('skappa', False)],
          'skapp-': [('skappa', False)],
          'skappe': [('skappa', False)],
          'skapps': [('skappa', False)],
          'skapps-': [('skappa', False)],
          'skaps': [('skap', False)],
          'skaps-': [('skap', True)],
          'skapslandet': [('skapsland', False)],
          'skapslandets': [('skapsland', False)],
          'skar': [('skara', True)],
          'skar-': [('skara', True)],
          'skarakteristik': [('skarakteristik', False)],
          'skarakteristik-': [('skarakteristik', False)],
          'skarakteristiks': [('skarakteristik', False)],
          'skaraktäristik': [('skaraktäristik', False)],
          'skaraktäristik-': [('skaraktäristik', False)],
          'skaraktäristiks': [('skaraktäristik', False)],
          'skare': [('skara', True), ('skare', True)],
          'skare-': [('skare', True), ('skara', True)],
          'skaren': [('skare', False)],
          'skarens': [('skare', True)],
          'skaret': [('skar', False)],
          'skarets': [('skar', False)],
          'skarfar': [('skarf', True)],
          'skarfars': [('skarf', True)],
          'skarna': [('sk', False)],
          'skarnas': [('skare', False)],
          'skarpar': [('skarpar', False)],
          'skarpars': [('skarpar', False)],
          'skars': [('skara', True)],
          'skars-': [('skara', False)],
          'skart': [('skarta', False)],
          'skart-': [('skarta', False)],
          'skartan': [('skarta', False)],
          'skarts': [('skarta', False)],
          'skarts-': [('skarta', False)],
          'skas': [('ska', False)],
          'skass': [('skasse', False)],
          'skasse': [('skassa', False)],
          'skasse-': [('skasse', False)],
          'skassen': [('skasse', False)],
          'skassens': [('skasse', False)],
          'skat': [('skate', True), ('skata', True)],
          'skat-': [('skate', True), ('skata', True)],
          'skate': [('skate', True), ('skata', True)],
          'skaten': [('skate', True)],
          'skatens': [('skate', True)],
          'skator': [('skata', False)],
          'skators': [('skata', False)],
          'skats': [('skate', True), ('skata', True)],
          'skats-': [('skate', True), ('skata', True)],
          'skatt': [('skatt', False)],
          'skatt-': [('skatt', False)],
          'skatte': [('skatt', False)],
          'skatte-': [('skatt', True)],
          'skatten': [('skatt', False)],
          'skattens': [('skatt', False)],
          'skattepengar': [('skattepeng', True)],
          'skatts': [('skatt', False)],
          'skatts-': [('skatt', True)],
          'ske': [('ska', False)],
          'ske-': [('ska', False)],
          'skedanden': [('skedand', True), ('skedande', True)],
          'skedandens': [('skedand', True), ('skedande', True)],
          'skeden': [('skede', True), ('sked', True)],
          'skedens': [('skede', True), ('sked', True)],
          'skedet': [('skede', True)],
          'skedets': [('skede', False)],
          'skel': [('skel', False)],
          'skel-': [('skel', False)],
          'skelknippe': [('skelknippe', False)],
          'skels': [('skel', False)],
          'skels-': [('skel', False)],
          'skelsen': [('skelse', False)],
          'skelsens': [('skelse', False)],
          'sken': [('skena', True), ('sken', True)],
          'sken-': [('skena', True), ('sken', True)],
          'skena': [('skena', False)],
          'skenas': [('skena', False)],
          'skens': [('skena', True), ('sken', True)],
          'skens-': [('skena', True), ('sken', True)],
          'sker': [('sk', False)],
          'skerits': [('skeri', False)],
          'skerna': [('sk', False)],
          'skernas': [('sk', False)],
          'skers': [('sk', False)],
          'skesen': [('skes', False)],
          'skesens': [('skes', False)],
          'sket': [('sk', False)],
          'skets': [('ske', False)],
          'skfiskarna': [('skfisk', False)],
          'skick': [('skick', False)],
          'skick-': [('skick', False)],
          'skicks': [('skick', False)],
          'skicks-': [('skick', False)],
          'skid': [('skida', False)],
          'skid-': [('skida', False)],
          'skidan': [('skida', False)],
          'skidans': [('skida', False)],
          'skids': [('skida', False)],
          'skids-': [('skida', False)],
          'skiften': [('skift', True), ('skifte', True)],
          'skiftens': [('skift', True), ('skifte', True)],
          'skiftet': [('skift', True), ('skifte', True)],
          'skiftets': [('skifte', True), ('skift', True)],
          'skiljedomar': [('skiljedomare', True), ('skiljedom', True)],
          'skiljedomarna': [('skiljedomare', True), ('skiljedom', True)],
          'skiljedomarnas': [('skiljedomare', True), ('skiljedom', True)],
          'skill': [('skill', False)],
          'skill-': [('skill', False)],
          'skillen': [('skille', False)],
          'skillens': [('skill', False)],
          'skills': [('skille', False)],
          'skills-': [('skill', False)],
          'skink': [('skinka', True)],
          'skink-': [('skinka', True)],
          'skinks': [('skinka', False)],
          'skinks-': [('skinka', False)],
          'skinon': [('skino', False)],
          'skins': [('skin', False)],
          'skis': [('skis', False)],
          'skis-': [('skis', False)],
          'skisen': [('skis', False)],
          'skisens': [('skis', False)],
          'skiss': [('skiss', False)],
          'skiss-': [('skiss', True)],
          'skisse': [('skissa', False)],
          'skissen': [('skiss', False)],
          'skissens': [('skiss', True)],
          'skist': [('skist', False)],
          'skist-': [('skist', False)],
          'skistans': [('skista', False)],
          'skiv': [('skiva', True)],
          'skiv-': [('skiva', True)],
          'skivs': [('skiva', True)],
          'skivs-': [('skiva', True)],
          'skjuts': [('skjuts', True), ('skjut', True)],
          'skjuts-': [('skjuts', True), ('skjut', True)],
          'sklad': [('sklada', False)],
          'sklad-': [('sklada', False)],
          'sklads': [('sklada', False)],
          'sklanden': [('skland', False)],
          'sklandens': [('skland', False)],
          'sklandet': [('skland', False)],
          'sklapp': [('sklapp', False)],
          'sklapp-': [('sklapp', False)],
          'sklapps': [('sklapp', False)],
          'sklapps-': [('sklapp', False)],
          'sklar': [('skel', False)],
          'sklarna': [('skel', False)],
          'sklarnas': [('skel', False)],
          'sklars': [('skel', False)],
          'sklassiker': [('sklassiker', False)],
          'sklassikerna': [('sklassiker', False)],
          'sklassikernas': [('sklassiker', False)],
          'sklassikers': [('sklassiker', False)],
          'sklav': [('sklav', False)],
          'sklavar': [('sklav', False)],
          'sklavarna': [('sklav', False)],
          'sklavarnas': [('sklav', False)],
          'sklavars': [('sklav', False)],
          'sklaven': [('sklav', False)],
          'sklavens': [('sklav', False)],
          'sklavs': [('sklav', False)],
          'sklavs-': [('sklav', False)],
          'sklernas': [('skel', False)],
          'skling': [('skling', False)],
          'skling-': [('sklinga', False)],
          'sklings': [('sklinga', False)],
          'sklings-': [('skling', False)],
          'skliniker': [('sklinik', False)],
          'sklinikerna': [('sklinik', False)],
          'sklinikernas': [('sklinik', False)],
          'sklinikers': [('sklinik', False)],
          'sklipp': [('sklipp', False)],
          'sklipps': [('sklipp', False)],
          'sklipps-': [('sklipp', False)],
          'sklock': [('sklocka', False)],
          'sklot': [('sklot', False)],
          'sklots': [('sklot', False)],
          'sklots-': [('sklot', False)],
          'sklov': [('sklov', False)],
          'skloven': [('sklov', False)],
          'sklovens': [('sklov', False)],
          'sklovs': [('sklov', False)],
          'sklovs-': [('sklov', False)],
          'sklubb': [('sklubb', False)],
          'sklubbs': [('sklubb', False)],
          'sklubbs-': [('sklubb', False)],
          'sklyft': [('sklyfta', False)],
          'sklyft-': [('sklyfta', False)],
          'sklyfts': [('sklyfta', False)],
          'sklyfts-': [('sklyfta', False)],
          'sklädes': [('skläder', False)],
          'sklädes-': [('skläder', False)],
          'skläggar': [('sklägg', False)],
          'skläggarna': [('sklägg', False)],
          'skläggarnas': [('sklägg', False)],
          'sknall': [('sknall', False)],
          'sknallar': [('sknall', False)],
          'sknallarna': [('sknall', False)],
          'sknallarnas': [('sknall', False)],
          'sknallars': [('sknall', False)],
          'sknallen': [('sknall', False)],
          'sknallens': [('sknall', False)],
          'sknalls': [('sknall', False)],
          'sknalls-': [('sknall', False)],
          'skningar': [('skning', False)],
          'skningarna': [('skning', False)],
          'skningarnas': [('skning', False)],
          'skningars': [('skning', False)],
          'sknings': [('skning', False)],
          'sknings-': [('skning', False)],
          'sknippe': [('sknippe', False)],
          'sknippe-': [('sknippe', False)],
          'sknot': [('sknot', False)],
          'sknot-': [('sknot', False)],
          'sknots': [('sknot', False)],
          'sknots-': [('sknot', False)],
          'sknut': [('sknut', False)],
          'sknuts': [('sknut', False)],
          'sknuts-': [('sknut', False)],
          'sknäppar': [('sknäpp', False)],
          'sknäpparna': [('sknäpp', False)],
          'sknäpparnas': [('sknäpp', False)],
          'sknäppen': [('sknäpp', False)],
          'sknäppens': [('sknäpp', False)],
          'sknät': [('sknät', False)],
          'sknäts': [('sknät', False)],
          'sko': [('sko', True)],
          'sko-': [('sko', False)],
          'skock': [('skock', True), ('skocka', True)],
          'skock-': [('skock', True), ('skocka', True)],
          'skocks': [('skock', True), ('skocka', True)],
          'skocks-': [('skocka', True), ('skock', True)],
          'skodans': [('skodans', False)],
          'skogen': [('skog', False)],
          'skogens': [('skog', False)],
          'skoj': [('skoj', True)],
          'skoj-': [('skoj', False)],
          'skojs': [('skoj', True)],
          'skojs-': [('skoj', True)],
          'skol': [('skola', False)],
          'skol-': [('skola', True)],
          'skolan': [('skola', False)],
          'skolans': [('skola', False)],
          'skollagen': [('skollag', True)],
          'skollagens': [('skollag', True)],
          'skolor': [('skola', False)],
          'skolors': [('skola', False)],
          'skols': [('skola', False)],
          'skols-': [('skola', True)],
          'skolväsendet': [('skolväsen', True), ('skolväsende', True)],
          'skolväsendets': [('skolväsende', True), ('skolväsen', True)],
          'skon': [('sko', True)],
          'skon-': [('skon', False)],
          'skona': [('sko', False)],
          'skonas': [('sko', False)],
          'skons': [('sko', True)],
          'skons-': [('skon', False)],
          'skonst': [('skonster', False)],
          'skonst-': [('skonst', False)],
          'skonster': [('skonst', False)],
          'skonsterna': [('skonst', False)],
          'skonsternas': [('skonst', False)],
          'skonsters': [('skonst', False)],
          'skop': [('skopa', True)],
          'skop-': [('skopa', True)],
          'skope': [('skopa', True)],
          'skope-': [('skopa', False)],
          'skopen': [('skop', False)],
          'skopens': [('skop', False)],
          'skopp': [('skopp', False)],
          'skoppar': [('skopp', False)],
          'skoppars': [('skopp', False)],
          'skopps': [('skopp', False)],
          'skopps-': [('skopp', False)],
          'skops': [('skopa', True)],
          'skops-': [('skopa', True)],
          'skor': [('sko', True)],
          'skordans': [('skordans', False)],
          'skorna': [('sko', True)],
          'skornas': [('sko', True)],
          'skorp': [('skorpa', True)],
          'skorp-': [('skorpa', True)],
          'skorps': [('skorpa', False)],
          'skorps-': [('skorpa', True)],
          'skors': [('sko', True)],
          'skors-': [('skors', False)],
          'skos': [('sko', False)],
          'skos-': [('sko', False)],
          'skostnader': [('skostnad', False)],
          'skostnaderna': [('skostnad', False)],
          'skostnadernas': [('skostnad', False)],
          'skostnaders': [('skostnad', False)],
          'skostnads': [('skostnad', False)],
          'skostnads-': [('skostnad', False)],
          'skot': [('skot', True)],
          'skot-': [('skot', True)],
          'skotanden': [('skotande', True)],
          'skotandens': [('skotande', True)],
          'skoter': [('skoter', True)],
          'skoters': [('skoter', True)],
          'skots': [('skot', True)],
          'skots-': [('skot', False)],
          'skott': [('skott', True)],
          'skott-': [('skott', True)],
          'skottar': [('skotte', True)],
          'skottarna': [('skotte', True)],
          'skottarnas': [('skotte', False)],
          'skotten': [('skotte', True), ('skott', True)],
          'skottens': [('skotte', True), ('skott', True)],
          'skotts': [('skott', False)],
          'skotts-': [('skott', True)],
          'skox': [('skoxe', False)],
          'skox-': [('skoxe', False)],
          'skoxen': [('skoxe', False)],
          'skoxens': [('skoxe', False)],
          'skrafter': [('skraft', False)],
          'skrafterna': [('skraft', False)],
          'skrafternas': [('skraft', False)],
          'skrafters': [('skraft', False)],
          'skrafts': [('skraft', False)],
          'skrafts-': [('skraft', False)],
          'skrak': [('skrake', True)],
          'skrak-': [('skrake', True)],
          'skrakar': [('skrake', True)],
          'skrakarna': [('skrake', True)],
          'skrakarnas': [('skrake', True)],
          'skrakars': [('skrake', False)],
          'skraken': [('skrake', True)],
          'skrakens': [('skrake', True)],
          'skraks': [('skrake', True)],
          'skraks-': [('skrake', True)],
          'skramar': [('skramare', False)],
          'skramarna': [('skramare', False)],
          'skramarnas': [('skram', False)],
          'skrams': [('skrams', False)],
          'skrams-': [('skram', False)],
          'skrank': [('skranka', True), ('skrank', True)],
          'skrank-': [('skranka', True), ('skrank', True)],
          'skranks': [('skranka', True), ('skrank', True)],
          'skranks-': [('skrank', True), ('skranka', True)],
          'skrans': [('skrans', False)],
          'skrans-': [('skrans', False)],
          'skrap': [('skrapa', True), ('skrap', True)],
          'skrap-': [('skrap', True), ('skrapa', True)],
          'skraps': [('skrapa', True), ('skrap', True)],
          'skraps-': [('skrap', True), ('skrapa', True)],
          'skrar': [('sker', False)],
          'skrarna': [('sker', False)],
          'skrater': [('skrater', False)],
          'skratt': [('skratt', True)],
          'skratt-': [('skratt', True)],
          'skratts': [('skratt', False)],
          'skratts-': [('skratt', False)],
          'skravaller': [('skravaller', False)],
          'skravallerna': [('skravaller', False)],
          'skravallernas': [('skravaller', False)],
          'skravallers': [('skravaller', False)],
          'skravalls': [('skravaller', False)],
          'skrens': [('skrens', False)],
          'skrets-': [('skrets', False)],
          'skrev': [('skrev', True), ('skreva', True)],
          'skrev-': [('skrev', True), ('skreva', True)],
          'skrevs': [('skrev', True), ('skreva', True)],
          'skrevs-': [('skrev', True), ('skreva', True)],
          'skri': [('skri', False)],
          'skri-': [('skri', False)],
          'skrik': [('skrik', True), ('skrika', True)],
          'skrik-': [('skrik', True), ('skrika', True)],
          'skriks': [('skrik', True), ('skrika', True)],
          'skriks-': [('skrika', True), ('skrik', True)],
          'skriminalen': [('skriminal', False)],
          'skriminalens': [('skriminal', False)],
          'skrin': [('skri', True), ('skrin', True)],
          'skrins': [('skrin', True), ('skri', True)],
          'skripta': [('skriptum', True), ('skripta', True)],
          'skriptas': [('skriptum', True), ('skripta', True)],
          'skriptor': [('skripta', True)],
          'skriptors': [('skripta', True)],
          'skris': [('skri', False)],
          'skris-': [('skris', False)],
          'skrit': [('skri', False)],
          'skrit-': [('skrit', False)],
          'skritiker': [('skritiker', False)],
          'skritikerna': [('skritiker', False)],
          'skritikernas': [('skritiker', False)],
          'skritikers': [('skritiker', False)],
          'skrits': [('skri', False)],
          'skrits-': [('skrit', False)],
          'skrocket': [('skrock', True)],
          'skrockets': [('skrock', True)],
          'skrokarnas': [('skrok', False)],
          'skronan': [('skrona', False)],
          'skronans': [('skrona', False)],
          'skrubb': [('skrubba', True), ('skrubb', True), ('skrubbor', True)],
          'skrubb-': [('skrubba', True), ('skrubb', True), ('skrubbor', True)],
          'skrubbor': [('skrubba', True), ('skrubbor', True)],
          'skrubborna': [('skrubbor', True), ('skrubba', True)],
          'skrubbornas': [('skrubbor', True), ('skrubba', True)],
          'skrubbors': [('skrubba', True), ('skrubbor', True)],
          'skrubbs': [('skrubbor', True), ('skrubb', True), ('skrubba', True)],
          'skrubbs-': [('skrubb', True), ('skrubba', True), ('skrubbor', True)],
          'skrymsle': [('skrymsle', True), ('skrymsla', True)],
          'skrymsle-': [('skrymsle', True), ('skrymsla', True)],
          'skräckens': [('skräck', False)],
          'skrällen': [('skrälle', True), ('skräll', True)],
          'skrällens': [('skräll', True), ('skrälle', True)],
          'skräm': [('skräm', False)],
          'skräm-': [('skrämma', False)],
          'skräms': [('skrämma', False)],
          'skräms-': [('skrämma', False)],
          'skräpböter': [('skräpbot', True), ('skräpböter', True)],
          'skräpböterna': [('skräpbot', True), ('skräpböter', True)],
          'skräpböternas': [('skräpbot', True), ('skräpböter', True)],
          'skräpböters': [('skräpbot', True), ('skräpböter', True)],
          'skräpp': [('skräppa', True)],
          'skräpp-': [('skräppa', True)],
          'skräpps': [('skräppa', True)],
          'skräpps-': [('skräppa', True)],
          'skråm': [('skråma', True)],
          'skråms': [('skråma', True)],
          'skråms-': [('skråma', True)],
          'skrås': [('skrå', False)],
          'skrön': [('skröna', True)],
          'skrön-': [('skröna', True)],
          'skröns': [('skröna', True)],
          'skröns-': [('skröna', True)],
          'sks': [('sk', False)],
          'sksläng': [('sksläng', False)],
          'skslängs-': [('sksläng', False)],
          'sksmälls': [('sksmäll', False)],
          'sksmälls-': [('sksmäll', False)],
          'sksnärt': [('sksnärt', False)],
          'sksnärts': [('sksnärt', False)],
          'sksopps': [('sksoppa', False)],
          'skspad': [('skspad', False)],
          'skspad-': [('skspad', False)],
          'skspads': [('skspad', False)],
          'skspads-': [('skspad', False)],
          'sksportar': [('sksportare', False)],
          'sksportarna': [('sksportare', False)],
          'skteater': [('skteater', False)],
          'skteaters': [('skteater', False)],
          'sktras': [('sktrasa', False)],
          'skubb': [('skubb', True)],
          'skubb-': [('skubb', True)],
          'skubben': [('skubb', True)],
          'skubbens': [('skubb', True)],
          'skubbs': [('skubb', True)],
          'skubbs-': [('skubb', True)],
          'skugg': [('skugga', False)],
          'skugg-': [('skugga', False)],
          'skugge': [('skugga', False)],
          'skuggs': [('skugga', False)],
          'skuggs-': [('skugga', False)],
          'skulder': [('skuldra', True), ('skuld', True)],
          'skulin': [('skulinum', False)],
          'skulinets': [('skulinum', False)],
          'skulins': [('skulinum', False)],
          'skull': [('skulle', True)],
          'skull-': [('skulle', False)],
          'skullar': [('skulle', False)],
          'skullarna': [('skulle', False)],
          'skullarnas': [('skulle', True)],
          'skullars': [('skulle', False)],
          'skulle': [('skulle', True)],
          'skulle-': [('skulle', False)],
          'skullen': [('skulle', True)],
          'skullens': [('skulle', True)],
          'skulls': [('skulle', False)],
          'skulls-': [('skulle', True)],
          'skulor': [('skulor', True)],
          'skulorna': [('skulor', True)],
          'skulornas': [('skulor', True)],
          'skulors': [('skulor', True)],
          'skultarnas': [('skult', True)],
          'skumpan': [('skumpa', True)],
          'skumpans': [('skumpa', True)],
          'skungar': [('skunge', False)],
          'skungarna': [('skunge', False)],
          'skungarnas': [('skunge', False)],
          'skungars': [('skunge', False)],
          'skungen': [('skunge', False)],
          'skungens': [('skunge', False)],
          'skunskaper': [('skunskap', False)],
          'skunskapernas': [('skunskap', False)],
          'skunskapers': [('skunskap', False)],
          'skunskaps': [('skunskap', False)],
          'skur': [('skur', False)],
          'skur-': [('skur', False)],
          'skurna': [('skurna', False)],
          'skurs': [('skur', True)],
          'skurs-': [('skur', True)],
          'skurv': [('skurva', False)],
          'skurv-': [('skurva', False)],
          'skurvor': [('skurva', False)],
          'skurvorna': [('skurva', False)],
          'skurvornas': [('skurva', False)],
          'skurvors': [('skurva', False)],
          'skurvs': [('skurva', False)],
          'skurvs-': [('skurva', False)],
          'skus': [('skus', False)],
          'skus-': [('skus', False)],
          'skusar': [('skus', False)],
          'skusarna': [('skus', False)],
          'skusarnas': [('skus', False)],
          'skusars': [('skus', False)],
          'skusen': [('skus', False)],
          'skusens': [('skus', False)],
          'skut': [('skuta', True)],
          'skut-': [('skuta', False)],
          'skutor': [('skuta', True)],
          'skutors': [('skuta', True)],
          'skuts': [('skuta', True)],
          'skuts-': [('skuta', False)],
          'skvallerbloggar': [('skvallerbloggare', True), ('skvallerblogg', True)],
          'skvallerbloggarna': [('skvallerbloggare', True), ('skvallerblogg', True)],
          'skvallerbloggarnas': [('skvallerbloggare', True), ('skvallerblogg', True)],
          'skvarter': [('skvarter', False)],
          'skvarters': [('skvarter', False)],
          'skvier': [('skvi', False)],
          'skvierna': [('skvi', False)],
          'skviernas': [('skvi', False)],
          'skviers': [('skvi', False)],
          'skvis': [('skvis', True)],
          'skvätt': [('skvätta', True), ('skvätt', True)],
          'skvätt-': [('skvätta', True), ('skvätt', True)],
          'skvätts': [('skvätt', True), ('skvätta', True)],
          'skvätts-': [('skvätta', True), ('skvätt', True)],
          'skyl': [('skyl', True)],
          'skyl-': [('skyl', False)],
          'skylar': [('skyl', True)],
          'skylarna': [('skyl', True)],
          'skylarnas': [('skyl', False)],
          'skyls': [('skyl', True)],
          'skyls-': [('skyl', False)],
          'skytten': [('skytte', True), ('skytt', True)],
          'skyttens': [('skytte', True), ('skytt', True)],
          'skyttet': [('skytte', True)],
          'skyttets': [('skytte', False)],
          'skägel': [('skägla', False)],
          'skägel-': [('skägla', False)],
          'skäkt': [('skäkta', True), ('skäkt', True)],
          'skäkt-': [('skäkta', True), ('skäkt', True)],
          'skäkts': [('skäkta', True), ('skäkt', True)],
          'skäll': [('skäll', True), ('skälla', True)],
          'skäll-': [('skäll', True), ('skälla', True)],
          'skälls': [('skäll', True), ('skälla', True)],
          'skälls-': [('skäll', True), ('skälla', True)],
          'skämparnas': [('skämpe', False)],
          'skändar': [('skändare', False)],
          'skändarna': [('skändare', True)],
          'skändarnas': [('skändare', True)],
          'skänger': [('skänger', False)],
          'skängers': [('skänger', False)],
          'skänk': [('skänk', True)],
          'skänk-': [('skänk', True)],
          'skänks': [('skänk', True)],
          'skänks-': [('skänk', True)],
          'skäpp': [('skäppa', True)],
          'skäpp-': [('skäppa', True)],
          'skäpps': [('skäppa', True)],
          'skäpps-': [('skäppa', True)],
          'skär': [('skära', True), ('skär', True)],
          'skär-': [('skära', True), ('skär', True)],
          'skärbräde': [('skärbräda', True), ('skärbräde', True)],
          'skärmar': [('skärm', True)],
          'skärmarna': [('skärm', True)],
          'skärmarnas': [('skärm', True)],
          'skärn': [('skär', False)],
          'skärns': [('skär', False)],
          'skärr': [('skärra', False)],
          'skärr-': [('skärra', True)],
          'skärrs': [('skärra', True)],
          'skärrs-': [('skärra', True)],
          'skärs': [('skära', True), ('skär', True)],
          'skärs-': [('skära', True), ('skär', True)],
          'skärv': [('skärv', True), ('skärva', True)],
          'skärv-': [('skärv', True), ('skärva', True)],
          'skärvar': [('skärv', True)],
          'skärvarna': [('skärv', True)],
          'skärvarnas': [('skärv', True)],
          'skärvars': [('skärv', True)],
          'skärve': [('skärva', True)],
          'skärven': [('skärv', True)],
          'skärvens': [('skärv', True)],
          'skärvs': [('skärv', True), ('skärva', True)],
          'skärvs-': [('skärv', True), ('skärva', True)],
          'skådan': [('skådan', False)],
          'skådans': [('skådan', False)],
          'skådra': [('skådra', False)],
          'skådrans': [('skådra', False)],
          'skådre-': [('skådra', False)],
          'skådror': [('skådra', False)],
          'skådrorna': [('skådra', False)],
          'skåp': [('skåp', False)],
          'skåp-': [('skåp', False)],
          'skåps': [('skåp', False)],
          'skåps-': [('skåp', False)],
          'skår': [('skåra', True), ('skåre', True), ('skår', True)],
          'skår-': [('skåra', True), ('skår', True), ('skåre', True)],
          'skårande': [('skårande', True)],
          'skårande-': [('skårande', True)],
          'skåre': [('skåra', True), ('skåre', True)],
          'skåre-': [('skåra', False)],
          'skåren': [('skåre', True), ('skår', True)],
          'skårens': [('skår', True), ('skåre', True)],
          'skårs': [('skåra', True), ('skåre', True), ('skår', True)],
          'skårs-': [('skåra', True), ('skåre', True), ('skår', True)],
          'skök': [('sköka', True)],
          'skök-': [('sköka', True)],
          'sköks': [('sköka', True)],
          'sköks-': [('sköka', True)],
          'sköldpadd': [('sköldpadd', True), ('sköldpadda', True)],
          'sköldpadds': [('sköldpadd', True), ('sköldpadda', True)],
          'sköldpadds-': [('sköldpadd', True), ('sköldpadda', True)],
          'skön': [('skön', True)],
          'skön-': [('skön', True)],
          'sköns': [('skön', True)],
          'sköns-': [('sköna', False)],
          'skör': [('sköra', True)],
          'skör-': [('sköra', True)],
          'sköre': [('sköre', True), ('sköra', True)],
          'sköre-': [('sköre', True), ('sköra', True)],
          'skörs': [('sköra', True)],
          'skörs-': [('sköra', True)],
          'sköt': [('sköt', True)],
          'sköt-': [('sköt', True)],
          'skötar': [('skötare', True), ('sköt', True)],
          'skötarna': [('skötare', True), ('sköt', True)],
          'skötarnas': [('sköt', True), ('skötare', True)],
          'skötars': [('sköt', False)],
          'sköten': [('sköte', True), ('sköt', True)],
          'skötens': [('sköte', True), ('sköt', True)],
          'sköts': [('sköt', True), ('sköte', True)],
          'sköts-': [('sköte', True), ('sköt', True)],
          'sl': [('sla', False)],
          'sl-': [('sla', False)],
          'slabb': [('slabb', True)],
          'slabb-': [('slabb', True)],
          'slabbs': [('slabb', True)],
          'slabbs-': [('slabb', True)],
          'slack': [('slack', True)],
          'slacks': [('slacks', True), ('slack', True)],
          'sladdar': [('sladd', False)],
          'sladdarna': [('sladd', False)],
          'sladdarnas': [('sladd', True)],
          'slafs': [('slafsa', True), ('slaf', True), ('slafs', True)],
          'slafs-': [('slaf', True), ('slafsa', True), ('slafs', True)],
          'slag': [('slaga', True), ('slag', True)],
          'slag-': [('slaga', True), ('slag', True)],
          'slagan': [('slaga', True)],
          'slagans': [('slaga', True)],
          'slagar': [('slag', False)],
          'slagarna': [('slag', False)],
          'slagarnas': [('slag', False)],
          'slage': [('slaga', True)],
          'slage-': [('slaga', True)],
          'slagen': [('slag', False)],
          'slagens': [('slag', True)],
          'slagerna': [('slager', False)],
          'slaget': [('slag', False)],
          'slagor': [('slaga', True)],
          'slagorna': [('slaga', True)],
          'slagornas': [('slaga', True)],
          'slagors': [('slaga', True)],
          'slags': [('slaga', True), ('slag', True)],
          'slags-': [('slag', True), ('slaga', True)],
          'slam': [('slam', False)],
          'slam-': [('slam', False)],
          'slammen': [('slam', False)],
          'slammens': [('slam', True)],
          'slammet': [('slam', False)],
          'slammets': [('slam', False)],
          'slamp': [('slampa', False)],
          'slamp-': [('slampa', True)],
          'slamps': [('slampa', False)],
          'slamps-': [('slampa', False)],
          'slams': [('slamsa', True), ('slam', True), ('slams', True)],
          'slams-': [('slams', True), ('slamsa', True), ('slam', True)],
          'slan': [('slana', True)],
          'slan-': [('slana', True)],
          'slana': [('slana', True)],
          'slanas': [('slana', True)],
          'slanden': [('slande', False)],
          'slandena': [('slande', False)],
          'slandenas': [('slande', False)],
          'slandens': [('slande', False)],
          'slandet': [('slande', False)],
          'slandets': [('sland', False)],
          'slane': [('slana', True)],
          'slangar': [('slang', False)],
          'slangarna': [('slang', False)],
          'slangarnas': [('slang', False)],
          'slans': [('slana', True)],
          'slans-': [('slana', True)],
          'slant-': [('slant', False)],
          'slantar': [('slant', True)],
          'slantarna': [('slant', True)],
          'slantarnas': [('slant', False)],
          'slantars': [('slant', True)],
          'slants': [('slant', False)],
          'slants-': [('slant', True)],
          'slaren': [('slare', False)],
          'slarv': [('slarva', True), ('slarv', True)],
          'slarv-': [('slarva', True), ('slarv', True)],
          'slarver': [('slarver', True)],
          'slarvers': [('slarver', True)],
          'slarvs': [('slarv', True), ('slarva', True)],
          'slarvs-': [('slarva', True)],
          'slas': [('slase', True)],
          'slas-': [('slase', True)],
          'slasarna': [('slase', True)],
          'slasarnas': [('slase', True)],
          'slasens': [('slase', True)],
          'slatt': [('slatt', True)],
          'slatt-': [('slatt', True)],
          'slattar': [('slatt', True)],
          'slattarna': [('slatt', True)],
          'slattarnas': [('slatt', True)],
          'slattars': [('slatt', True)],
          'slatten': [('slatt', True)],
          'slattens': [('slatt', True)],
          'slatts': [('slatt', True)],
          'slatts-': [('slatt', True)],
          'slav': [('slav', False)],
          'slav-': [('slav', False)],
          'slavar': [('slav', False)],
          'slavarna': [('slav', False)],
          'slavarnas': [('slav', True)],
          'slavars': [('slav', True)],
          'slaven': [('slav', False)],
          'slavens': [('slav', True)],
          'slaver': [('slav', False)],
          'slavs': [('slav', False)],
          'slavs-': [('slav', False)],
          'slegas': [('slegas', False)],
          'slegionen': [('slegionen', False)],
          'slegionens': [('slegionen', False)],
          'slejs-': [('slejs', True)],
          'slek': [('slek', False)],
          'slekar': [('slek', False)],
          'slekarna': [('slek', False)],
          'slekarnas': [('slek', False)],
          'sleke': [('sleke', True)],
          'sleken': [('sleke', True)],
          'slekens': [('sleke', True)],
          'sleks': [('sleke', True)],
          'sleks-': [('sleke', True)],
          'slem-': [('slem', False)],
          'slems-': [('slem', True)],
          'slen': [('sle', False)],
          'slens': [('sle', False)],
          'sler': [('sler', False)],
          'sler-': [('sler', False)],
          'slers': [('sler', False)],
          'slers-': [('sler', False)],
          'slet': [('sel', False)],
          'sletarnas': [('sletare', False)],
          'slets': [('sle', False)],
          'sleven': [('slev', True)],
          'slevens': [('slev', False)],
          'slevet': [('slev', False)],
          'slevets': [('slev', False)],
          'slevs': [('slev', False)],
          'sli': [('sli', False)],
          'sli-': [('sli', False)],
          'slic': [('slice', True)],
          'slic-': [('slice', True)],
          'slicens': [('slice', True)],
          'slick': [('slick', True)],
          'slickar': [('slick', True)],
          'slickarna': [('slick', True)],
          'slickarnas': [('slick', True)],
          'slid': [('slida', True), ('slid', True)],
          'slid-': [('slid', True), ('slida', True)],
          'slider': [('slid', True)],
          'sliderna': [('slid', True)],
          'slidernas': [('slid', True)],
          'sliders': [('slid', True)],
          'slids': [('slid', True), ('slida', True)],
          'slids-': [('slid', True), ('slida', True)],
          'slierna': [('sli', False)],
          'sliets': [('sli', False)],
          'sligens': [('slig', True)],
          'sliggarna': [('sliggare', False)],
          'sliggarnas': [('sliggare', False)],
          'slighets': [('slighet', False)],
          'slik': [('slik', False)],
          'slik-': [('slik', False)],
          'slikar': [('slikare', False)],
          'slikarna': [('slikare', False)],
          'slikarnas': [('slikare', False)],
          'sliken': [('slik', False)],
          'slikens': [('slik', False)],
          'sliks': [('slik', False)],
          'sliks-': [('slik', False)],
          'slimen': [('slim', False)],
          'slimens': [('slim', False)],
          'slimer': [('slim', False)],
          'slimerna': [('slim', False)],
          'slimernas': [('slim', False)],
          'slimers': [('slim', False)],
          'slimp': [('slimpa', False)],
          'slimps': [('slimpa', False)],
          'slimps-': [('slimpa', False)],
          'slin': [('slin', False)],
          'slin-': [('slin', False)],
          'slina': [('slina', False)],
          'slinas': [('slina', False)],
          'sline': [('slina', False)],
          'sline-': [('slina', False)],
          'slinen': [('slin', False)],
          'slinens': [('slin', False)],
          'sliner': [('slin', False)],
          'slinerna': [('slin', False)],
          'slinernas': [('slin', False)],
          'sliners': [('slin', False)],
          'slinet': [('slin', False)],
          'sling': [('slinga', True), ('sling', True)],
          'sling-': [('slinga', True), ('sling', True)],
          'slingets': [('sling', True)],
          'slings': [('slinga', True), ('sling', True)],
          'slings-': [('slinga', True), ('sling', True)],
          'slink': [('slinka', False)],
          'slinne': [('slinne', False)],
          'slinne-': [('slinne', False)],
          'slinnes': [('slinne', False)],
          'slinnes-': [('slinne', False)],
          'slins': [('slin', False)],
          'slins-': [('slin', False)],
          'slip': [('slip', False)],
          'slip-': [('slip', False)],
          'slipar': [('slip', False)],
          'sliparna': [('slip', False)],
          'sliparnas': [('slip', True)],
          'slips': [('slip', True), ('slips', True)],
          'slips-': [('slips', True), ('slip', True)],
          'slir': [('slira', True)],
          'slir-': [('slira', True)],
          'slire': [('slira', True)],
          'slire-': [('slira', True)],
          'slirs': [('slira', True)],
          'slirs-': [('slira', True)],
          'slis': [('sli', False)],
          'slis-': [('sli', False)],
          'slist': [('slist', False)],
          'slist-': [('slist', False)],
          'slit': [('slit', True)],
          'slit-': [('slit', True)],
          'slits': [('slit', True), ('slits', True)],
          'slits-': [('slit', True), ('slits', True)],
          'slivs': [('sliv', False)],
          'slivs-': [('sliv', False)],
          'slo': [('sla', False)],
          'slo-': [('sla', False)],
          'slock': [('slock', False)],
          'slog': [('slog', True)],
          'slog-': [('slog', True)],
          'slogar': [('slog', True)],
          'slogarna': [('slog', True)],
          'slogarnas': [('slog', True)],
          'slogars': [('slog', True)],
          'slogen': [('slog', True)],
          'slogens': [('slog', True)],
          'slogs': [('slog', True)],
          'slogs-': [('slog', True)],
          'slok': [('slok', False)],
          'slok-': [('slok', False)],
          'sloks': [('slok', True)],
          'sloks-': [('slok', True)],
          'slom': [('slom', True)],
          'slom-': [('slom', True)],
          'slommen': [('slom', True)],
          'slommens': [('slom', True)],
          'slopp': [('sloppa', False)],
          'slopp-': [('sloppa', False)],
          'slopps': [('sloppa', False)],
          'slopps-': [('sloppa', False)],
          'slor': [('sla', False)],
          'slorna': [('sla', False)],
          'slornas': [('sla', False)],
          'slors': [('sla', False)],
          'slots': [('slots', True), ('slot', True)],
          'slots-': [('slot', True)],
          'slott': [('slott', True)],
          'slott-': [('slott', True)],
          'slottarna': [('slott', True)],
          'slottarnas': [('slott', True)],
          'slottens': [('slott', False)],
          'slotts': [('slotts', True), ('slott', True)],
          'slotts-': [('slott', False)],
          'slov': [('slov', False)],
          'slov-': [('slov', False)],
          'sloven': [('sloven', True)],
          'slovens': [('sloven', True)],
          'slovs': [('slov', False)],
          'slovs-': [('slov', False)],
          'slrar': [('sler', False)],
          'slrarna': [('sler', False)],
          'slrars': [('sler', False)],
          'sluck': [('slucka', False)],
          'sluck-': [('slucka', False)],
          'slucks': [('slucka', False)],
          'sluffar': [('sluffare', False)],
          'slums': [('slum', True)],
          'slums-': [('slum', True)],
          'slus': [('slus', False)],
          'slust': [('slust', False)],
          'slut': [('slut', False)],
          'slut-': [('slut', True)],
          'slutar': [('slutare', True)],
          'slutarna': [('slutare', True)],
          'slutarnas': [('slutare', False)],
          'sluten': [('slut', False)],
          'slutens': [('slut', True)],
          'sluts': [('slut', False)],
          'sluts-': [('slut', False)],
          'slyftarnas': [('slyft', False)],
          'slyfts': [('slyft', False)],
          'slykt': [('slykta', False)],
          'slykt-': [('slykta', False)],
          'slykts': [('slykta', False)],
          'slykts-': [('slykta', False)],
          'slyn': [('slyna', True), ('sly', True)],
          'slyna': [('slyna', True), ('sly', True)],
          'slynas': [('slyna', True), ('sly', True)],
          'slyns': [('slyna', True), ('sly', True)],
          'slyr': [('slyr', False)],
          'slyr-': [('slyr', False)],
          'slyrs': [('slyr', False)],
          'slys': [('sly', False)],
          'slys-': [('sly', True)],
          'slyx': [('slyx', False)],
          'släck': [('släcka', False)],
          'släckar': [('släckare', False)],
          'släckarna': [('släckare', False)],
          'släcks': [('släcka', False)],
          'släcks-': [('släcka', False)],
          'släd-': [('släde', False)],
          'slädarna': [('släde', False)],
          'slädarnas': [('släde', False)],
          'slädars': [('släde', False)],
          'slädes': [('släde', False)],
          'slägg': [('slägga', True)],
          'slägg-': [('slägga', False)],
          'släggs': [('slägga', True)],
          'släggs-': [('slägga', True)],
          'släkten': [('släkt', True), ('släkte', True)],
          'släktens': [('släkt', True), ('släkte', True)],
          'släkts': [('släkt', True), ('släkte', True)],
          'släkts-': [('släkt', True), ('släkte', True)],
          'sländ': [('slända', False)],
          'sländ-': [('slända', False)],
          'sländar': [('sländare', False)],
          'sländarna': [('sländare', False)],
          'slände-': [('slända', False)],
          'sländer': [('sland', False)],
          'sländerna': [('sland', False)],
          'sländernas': [('sland', False)],
          'sländers': [('sland', False)],
          'sländs': [('slända', False)],
          'sländs-': [('slända', False)],
          'släng': [('släng', True)],
          'släng-': [('släng', True)],
          'slängs': [('släng', True)],
          'slängs-': [('släng', False)],
          'slänkar': [('slänk', False)],
          'slänkarna': [('slänk', False)],
          'slänkarnas': [('slänk', False)],
          'släns': [('slän', False)],
          'släns-': [('slän', False)],
          'slänt-': [('slänt', True)],
          'slänts': [('slänt', True)],
          'slärk': [('slärka', False)],
          'slärk-': [('slärka', False)],
          'slärks': [('slärka', False)],
          'slärks-': [('slärka', False)],
          'släsarnas': [('släsare', False)],
          'slån': [('slån', True), ('slå', True)],
          'slåns': [('slå', True), ('slån', True)],
          'slåns-': [('slån', True)],
          'slår': [('slå', False)],
          'slårs': [('slå', False)],
          'slås': [('slå', True)],
          'slås-': [('slå', False)],
          'slått': [('slåtta', True)],
          'slått-': [('slåtta', True)],
          'slåtts': [('slåtta', True)],
          'slöje': [('slöja', False)],
          'slöje-': [('slöja', False)],
          'slön': [('slön', False)],
          'slöp': [('slöpa', False)],
          'slöp-': [('slöpa', False)],
          'slöpe': [('slöpa', False)],
          'slöpe-': [('slöpa', False)],
          'slöps': [('slöpa', False)],
          'slöps-': [('slöpa', False)],
          'slösarna': [('slösare', True)],
          'slösarnas': [('slösare', True)],
          'slöss': [('slus', False)],
          'slössen': [('slus', False)],
          'slössens': [('slus', False)],
          'sm': [('sm', False)],
          'sm-': [('sm', False)],
          'smack': [('smack', True)],
          'smack-': [('smack', True)],
          'smacks': [('smack', True)],
          'smacks-': [('smack', True)],
          'smajor': [('smaja', False)],
          'smajors': [('smaja', False)],
          'smak': [('smak', False)],
          'smak-': [('smak', False)],
          'smakar': [('smakare', False)],
          'smakarna': [('smakare', False)],
          'smakarnas': [('smakare', False)],
          'smaken': [('smak', False)],
          'smakens': [('smak', False)],
          'smaker': [('smak', True)],
          'smakerna': [('smak', False)],
          'smakernas': [('smak', True)],
          'smakers': [('smak', False)],
          'smaks': [('smak', False)],
          'smaks-': [('smak', False)],
          'smalts': [('smalts', True), ('smalt', True)],
          'smalts-': [('smalts', True), ('smalt', True)],
          'smalände': [('smalände', True), ('smalända', True)],
          'smalände-': [('smalända', True), ('smalände', True)],
          'sman': [('sman', False)],
          'sman-': [('sman', False)],
          'smanden': [('smande', False)],
          'smaner': [('sman', False)],
          'smanerna': [('sman', False)],
          'smanernas': [('sman', False)],
          'smaners': [('sman', False)],
          'smanet': [('sman', False)],
          'smanets': [('sman', False)],
          'smannen': [('sman', False)],
          'smannens': [('sman', False)],
          'smans': [('sman', False)],
          'smar': [('sme', False)],
          'smar-': [('smare', False)],
          'smare': [('smare', False)],
          'smaren': [('smare', False)],
          'smarginaler': [('smarginal', False)],
          'smarginalerna': [('smarginal', False)],
          'smarginalernas': [('smarginal', False)],
          'smarginalers': [('smarginal', False)],
          'smarna': [('smare', False)],
          'smarnas': [('smare', False)],
          'smars': [('sme', False)],
          'smas': [('sma', False)],
          'smas-': [('sma', False)],
          'smask': [('smask', False)],
          'smask-': [('smask', False)],
          'smaster': [('smast', False)],
          'smasters': [('smast', False)],
          'smat': [('smat', False)],
          'smaten': [('smat', False)],
          'smatens': [('smat', False)],
          'smatik': [('smatik', False)],
          'smatik-': [('smatik', False)],
          'smatiks': [('smatik', False)],
          'smatros': [('smatros', False)],
          'smats': [('smat', False)],
          'smatt': [('smatt', True)],
          'smatt-': [('smatt', True)],
          'smattar': [('smatt', True)],
          'smattarna': [('smatt', False)],
          'smattarnas': [('smatt', True)],
          'smattars': [('smatt', True)],
          'smatte': [('smatta', False)],
          'smatte-': [('smatta', False)],
          'smatten': [('smatt', True)],
          'smattens': [('smatt', True)],
          'smatter': [('smatter', True)],
          'smatters': [('smatter', True)],
          'smatts': [('smatt', True)],
          'smatts-': [('smatt', True)],
          'sme': [('sma', False)],
          'sme-': [('sma', False)],
          'smed': [('smed', False)],
          'smed-': [('smed', True)],
          'smeden': [('smed', False)],
          'smedens': [('smed', False)],
          'smeds': [('smed', False)],
          'smeds-': [('smed', False)],
          'smek': [('smek', True), ('smeka', True)],
          'smek-': [('smek', True), ('smeka', True)],
          'smeks': [('smeka', True), ('smek', True)],
          'smeks-': [('smek', True), ('smeka', True)],
          'smelon': [('smelon', False)],
          'smelon-': [('smelon', False)],
          'smeloner': [('smelon', False)],
          'smelonerna': [('smelon', False)],
          'smelonernas': [('smelon', False)],
          'smeloners': [('smelon', False)],
          'smelons': [('smelon', False)],
          'smen': [('sm', False)],
          'smens': [('sm', False)],
          'smer': [('sm', False)],
          'smerit': [('smeri', False)],
          'smerits': [('smeri', False)],
          'smerna': [('sm', False)],
          'smernas': [('sm', False)],
          'smers': [('sm', False)],
          'smes': [('sme', False)],
          'smes-': [('smes', False)],
          'smet': [('smet', False)],
          'smeten': [('smet', False)],
          'smetens': [('smet', True)],
          'smeter': [('smet', False)],
          'smeterna': [('smet', False)],
          'smeternas': [('smet', True)],
          'smeters': [('smet', False)],
          'smetoden': [('smetod', False)],
          'smetodens': [('smetod', False)],
          'smetodiker': [('smetodik', False)],
          'smetodikerna': [('smetodik', False)],
          'smetodikernas': [('smetodik', False)],
          'smetodikers': [('smetodik', False)],
          'smets': [('smet', False)],
          'smidens': [('smide', False)],
          'smil': [('smil', True)],
          'smil-': [('smil', True)],
          'smilet': [('smil', True)],
          'smilets': [('smil', True)],
          'smils': [('smil', True)],
          'smils-': [('smil', True)],
          'smin': [('smin', False)],
          'smin-': [('smin', False)],
          'sminens': [('smin', False)],
          'sminister': [('sminister', False)],
          'sministers': [('sminister', False)],
          'sminkar': [('sminkare', True)],
          'sminkarna': [('sminkare', True)],
          'sminkarnas': [('sminkare', True)],
          'smins': [('smin', False)],
          'smins-': [('smin', False)],
          'smiss': [('smiss', False)],
          'smiss-': [('smiss', False)],
          'smissar': [('smiss', False)],
          'smissarna': [('smiss', False)],
          'smissarnas': [('smiss', False)],
          'smissars': [('smiss', False)],
          'smissen': [('smiss', False)],
          'smissens': [('smiss', False)],
          'smit': [('smita', True)],
          'smits': [('smita', True)],
          'smitt': [('smitta', True)],
          'smitt-': [('smitta', True)],
          'smitts': [('smitta', False)],
          'smitts-': [('smitta', False)],
          'smjölk': [('smjölk', False)],
          'smjölk-': [('smjölk', False)],
          'smjölken': [('smjölk', False)],
          'smjölkens': [('smjölk', False)],
          'smjölks': [('smjölk', False)],
          'smjölks-': [('smjölk', False)],
          'smock': [('smock', True), ('smocka', True)],
          'smock-': [('smocka', True), ('smock', True)],
          'smocks': [('smocka', True), ('smock', True)],
          'smocks-': [('smocka', True), ('smock', True)],
          'smodern': [('smor', False)],
          'smoderns': [('smor', False)],
          'smoders': [('smor', False)],
          'smoders-': [('smor', False)],
          'smodet': [('smode', False)],
          'smodets': [('smode', False)],
          'smods': [('smod', False)],
          'smods-': [('smod', False)],
          'smogen': [('smog', True)],
          'smogens': [('smog', True)],
          'smor': [('sma', False)],
          'smor-': [('smor', False)],
          'smorna': [('sma', False)],
          'smornas': [('sma', False)],
          'smors': [('sma', False)],
          'smors-': [('smor', False)],
          'smos': [('smos', False)],
          'smos-': [('smos', False)],
          'smosen': [('smos', False)],
          'smosens': [('smos', False)],
          'sms': [('sms', True)],
          'sms-': [('sms', True)],
          'smsets': [('sms', True)],
          'smul': [('smula', True)],
          'smul-': [('smula', True)],
          'smulans': [('smula', True)],
          'smule': [('smula', False)],
          'smulor': [('smula', True)],
          'smulorna': [('smula', False)],
          'smulornas': [('smula', True)],
          'smulors': [('smula', True)],
          'smuls': [('smula', True)],
          'smuls-': [('smula', True)],
          'smult': [('smult', True)],
          'smult-': [('smult', True)],
          'smults': [('smult', True)],
          'smults-': [('smult', True)],
          'smurar': [('smur', False)],
          'smurarna': [('smur', False)],
          'smurarnas': [('smur', False)],
          'smus': [('smus', False)],
          'smussel': [('smussel', True)],
          'smussel-': [('smussel', True)],
          'smut': [('smut', False)],
          'smut-': [('smut', False)],
          'smuts': [('smuts', True)],
          'smuts-': [('smuts', False)],
          'smutt': [('smutt', True)],
          'smutt-': [('smutt', True)],
          'smutts': [('smutt', True)],
          'smutts-': [('smutt', True)],
          'smynt': [('smynt', False)],
          'smynts': [('smynt', False)],
          'smynts-': [('smynt', False)],
          'smys': [('smys', False)],
          'smys-': [('smys', False)],
          'smäll': [('smäll', True), ('smälla', True)],
          'smäll-': [('smäll', True), ('smälla', True)],
          'smällar': [('smällare', True), ('smäll', True)],
          'smällarna': [('smällare', True), ('smäll', True)],
          'smällarnas': [('smällare', True), ('smäll', True)],
          'smälls': [('smäll', True), ('smälla', True)],
          'smälls-': [('smäll', True), ('smälla', True)],
          'smän': [('sman', False)],
          'smäns': [('sman', False)],
          'smäss': [('smäss', False)],
          'smäss-': [('smäss', False)],
          'smån': [('smån', False)],
          'smån-': [('smån', False)],
          'smånen': [('smån', False)],
          'smånens': [('smån', False)],
          'småns': [('smån', False)],
          'småns-': [('smån', False)],
          'smårätter': [('smårätter', True), ('smårätt', True)],
          'smårätterna': [('smårätter', True), ('smårätt', True)],
          'smårätternas': [('smårätter', True), ('smårätt', True)],
          'smårätters': [('smårätter', True), ('smårätt', True)],
          'smårätts': [('smårätter', True), ('smårätt', True)],
          'smårätts-': [('smårätter', True), ('smårätt', True)],
          'småsten': [('småsten', True)],
          'småstens': [('småsten', True)],
          'smör': [('smör', False)],
          'smörj': [('smörja', True), ('smörj', True)],
          'smörj-': [('smörja', True), ('smörj', True)],
          'smörjs': [('smörja', True), ('smörj', True)],
          'smörjs-': [('smörja', True)],
          'smörs': [('smör', False)],
          'smöss': [('smössa', False)],
          'sn': [('s', False)],
          'sna': [('sna', False)],
          'snack': [('snack', False)],
          'snack-': [('snack', False)],
          'snacks': [('snacks', True), ('snack', True)],
          'snacks-': [('snacks', True), ('snack', True)],
          'snader': [('snad', False)],
          'snaderna': [('snad', False)],
          'snadernas': [('snad', False)],
          'snaders': [('snad', False)],
          'snads': [('snad', False)],
          'snads-': [('snad', False)],
          'snaggs': [('snagg', True)],
          'snallar': [('snalle', False)],
          'snamn': [('snamn', False)],
          'snamn-': [('snamn', False)],
          'snamnen': [('snamn', False)],
          'snamnens': [('snamn', False)],
          'snamns': [('snamn', False)],
          'snamns-': [('snamn', False)],
          'snanden': [('snande', False)],
          'snappar': [('snappare', False)],
          'snapparna': [('snappare', False)],
          'snapparnas': [('snappare', False)],
          'snar': [('snara', True)],
          'snar-': [('snara', False)],
          'snare': [('snara', False)],
          'snare-': [('snara', False)],
          'snaren': [('snare', False)],
          'snarens': [('snare', False)],
          'snarnas': [('snare', False)],
          'snars': [('snara', False)],
          'snars-': [('snara', False)],
          'snas': [('sna', False)],
          'snask-': [('snask', True)],
          'snaskarna': [('snasker', True)],
          'snattar': [('snattare', True)],
          'snattarna': [('snattare', True)],
          'snattens': [('snatt', False)],
          'sne': [('sna', False)],
          'sne-': [('sna', False)],
          'snen': [('sne', False)],
          'snens': [('sen', False)],
          'sner': [('sner', False)],
          'snerna': [('sner', False)],
          'sners': [('sner', False)],
          'snes': [('snes', True)],
          'snes-': [('snes', True)],
          'snesar': [('snes', True)],
          'snesarna': [('snes', True)],
          'snesen': [('snes', True)],
          'snesens': [('snes', True)],
          'snet': [('sen', False)],
          'snets': [('sen', False)],
          'snickar': [('snickare', False)],
          'snickarna': [('snickare', False)],
          'snickarnas': [('snickare', True)],
          'sniernas': [('snier', False)],
          'sniers': [('snier', False)],
          'sniffar': [('sniff', True)],
          'sniffarna': [('sniff', True)],
          'sniffarnas': [('sniff', True)],
          'snilj': [('snilja', True), ('snilj', True)],
          'snilj-': [('snilja', True), ('snilj', True)],
          'sniljs': [('snilja', True), ('snilj', True)],
          'sniljs-': [('snilja', True), ('snilj', True)],
          'snillen': [('snille', False)],
          'sningsställen': [('sningsställe', False)],
          'sningsstället': [('sningsställe', False)],
          'sningsställets': [('sningsställe', False)],
          'snip': [('snip', True), ('snipa', True)],
          'snip-': [('snip', True), ('snipa', True)],
          'snipp': [('snippa', True)],
          'snipp-': [('snippa', True)],
          'snipps': [('snippa', True)],
          'snipps-': [('snippa', True)],
          'snips': [('snip', True), ('snipa', True)],
          'snips-': [('snip', True), ('snipa', True)],
          'snisse-': [('snisse', False)],
          'snissens': [('snisse', False)],
          'snit': [('snit', False)],
          'snits': [('snits', True)],
          'snits-': [('snits', True)],
          'sno-': [('snoa', True)],
          'snopp': [('snopp', False)],
          'snopp-': [('snopp', True)],
          'snoppar': [('snoppare', True), ('snopp', True)],
          'snopparna': [('snoppare', True), ('snopp', True)],
          'snopparnas': [('snopp', True), ('snoppare', True)],
          'snopps': [('snopp', False)],
          'snopps-': [('snopp', True)],
          'snor': [('snor', True)],
          'snor-': [('snor', True)],
          'snorna': [('sna', False)],
          'snornas': [('sna', False)],
          'snorrar': [('snorre', True)],
          'snorrarna': [('snorre', True)],
          'snorrarnas': [('snorre', True)],
          'snorrars': [('snorre', True)],
          'snorren': [('snorre', True)],
          'snorrens': [('snorre', True)],
          'snors': [('snor', True)],
          'snos': [('snoa', True)],
          'snos-': [('snoa', True)],
          'snot': [('snot', False)],
          'sns': [('s', False)],
          'snsen': [('sens', False)],
          'snsens': [('sens', False)],
          'snset': [('sens', False)],
          'snsets': [('sens', False)],
          'snubb': [('snubba', True), ('snubbe', True)],
          'snubb-': [('snubba', True), ('snubbe', True)],
          'snubbarna': [('snubbe', True)],
          'snubbars': [('snubbe', True)],
          'snubbe': [('snubba', True), ('snubbe', True)],
          'snubbe-': [('snubba', True)],
          'snubben': [('snubbe', True)],
          'snubbens': [('snubbe', True)],
          'snubbs': [('snubba', True), ('snubbe', True)],
          'snubbs-': [('snubba', True), ('snubbe', True)],
          'snurr': [('snurr', True), ('snurra', True)],
          'snurr-': [('snurr', True), ('snurra', True)],
          'snurrs': [('snurra', True), ('snurr', True)],
          'snurrs-': [('snurr', True), ('snurra', True)],
          'snus': [('snus', False)],
          'snus-': [('snus', True)],
          'snut': [('snut', False)],
          'snut-': [('snut', False)],
          'snuts': [('snut', False)],
          'snuts-': [('snut', False)],
          'snuttar': [('snutt', False)],
          'snuttarna': [('snutt', False)],
          'snuttarnas': [('snutt', False)],
          'snuttens': [('snutt', False)],
          'snutts-': [('snutt', True)],
          'snyckel': [('snycklar', False)],
          'snyckel-': [('snycklar', False)],
          'snyckels': [('snycklar', False)],
          'snyckels-': [('snycklar', False)],
          'snycklar': [('snycklar', False)],
          'snycklarna': [('snycklar', False)],
          'snycklarnas': [('snycklar', False)],
          'snycklars': [('snycklar', False)],
          'snyts': [('snyte', True)],
          'snäbb': [('snäbb', False)],
          'snäbb-': [('snäbb', False)],
          'snäbbs': [('snäbb', False)],
          'snäbbs-': [('snäbb', False)],
          'snäck': [('snäcka', False)],
          'snäck-': [('snäcka', False)],
          'snäcks': [('snäcka', False)],
          'snäcks-': [('snäcka', False)],
          'snäpp': [('snäpp', True), ('snäppa', True)],
          'snäpp-': [('snäpp', True), ('snäppa', True)],
          'snäppets': [('snäpp', True)],
          'snäpps': [('snäpp', True), ('snäppa', True)],
          'snäpps-': [('snäpp', True), ('snäppa', True)],
          'snär': [('snär', False)],
          'snär-': [('snär', False)],
          'snärer': [('snär', False)],
          'snärerna': [('snär', False)],
          'snärernas': [('snär', False)],
          'snärers': [('snär', False)],
          'snärje': [('snärje', True)],
          'snärjen': [('snärje', True), ('snärj', True)],
          'snärjens': [('snärje', True), ('snärj', True)],
          'snärjet': [('snärje', True), ('snärj', True)],
          'snärjets': [('snärj', True), ('snärje', True)],
          'snärjs': [('snärje', True), ('snärj', True)],
          'snärjs-': [('snärje', True), ('snärj', True)],
          'snärp': [('snärpa', True), ('snärp', True)],
          'snärp-': [('snärpa', True), ('snärp', True)],
          'snärps': [('snärpa', True), ('snärp', True)],
          'snärps-': [('snärpa', True), ('snärp', True)],
          'snärs': [('snär', False)],
          'snärs-': [('snär', False)],
          'snärt': [('snärt', True), ('snärta', True)],
          'snärt-': [('snärta', True), ('snärt', True)],
          'snärts': [('snärt', True), ('snärta', True)],
          'snärts-': [('snärta', True), ('snärt', True)],
          'snäs': [('snäsa', False)],
          'snäs-': [('snäsa', False)],
          'snäste': [('snäste', False)],
          'snästen': [('snäste', False)],
          'snästens': [('snäste', False)],
          'snästet': [('snäste', False)],
          'snästets': [('snäste', False)],
          'snät': [('snät', False)],
          'snäts': [('snät', False)],
          'snäv': [('snäva', False)],
          'snäv-': [('snäva', False)],
          'snäve': [('snäva', False)],
          'snävs': [('snäva', False)],
          'snävs-': [('snäva', False)],
          'snåret': [('snår', False)],
          'snårets': [('snår', False)],
          'snöbräde': [('snöbräde', True), ('snöbräda', True)],
          'snötter': [('snöt', False)],
          'snötterna': [('snöt', False)],
          'so': [('so', False)],
          'so-': [('so', True)],
          'soas-': [('soas', False)],
          'sobars': [('sobar', False)],
          'socenter': [('socenter', False)],
          'socenters': [('socenter', False)],
          'sock': [('socka', True)],
          'sodan': [('soda', False)],
          'soden': [('sod', False)],
          'sodens': [('sod', False)],
          'soders': [('sod', False)],
          'sodiers': [('sodi', False)],
          'sodis': [('sodi', False)],
          'sodlarnas': [('sodlare', False)],
          'sods': [('sod', False)],
          'sods-': [('sod', False)],
          'soen': [('soe', False)],
          'soens': [('soe', False)],
          'soer': [('so', False)],
          'soerna': [('so', False)],
          'soernas': [('so', False)],
          'soers': [('so', False)],
          'sofficerare': [('sofficer', False)],
          'sofficerares': [('sofficer', False)],
          'sofficerarna': [('sofficer', False)],
          'sofficerarnas': [('sofficer', False)],
          'sojan': [('soja', True)],
          'sojans': [('soja', True)],
          'solarie': [('solarium', True)],
          'solarier': [('solarium', True)],
          'solariernas': [('solarium', True)],
          'solariers': [('solarium', True)],
          'soli': [('solo', False)],
          'solin': [('solin', False)],
          'solk': [('solk', True)],
          'solk-': [('solk', True)],
          'solks': [('solk', True)],
          'solks-': [('solk', True)],
          'soll': [('soll', False)],
          'soll-': [('soll', False)],
          'sollen': [('soll', False)],
          'sollens': [('soll', False)],
          'soller': [('soll', False)],
          'sollerna': [('soll', False)],
          'sollernas': [('soll', False)],
          'sollers': [('soll', False)],
          'sollon': [('sollon', False)],
          'sollons': [('sollon', False)],
          'solls': [('soll', False)],
          'solls-': [('soll', False)],
          'solon': [('solo', False)],
          'solons': [('solo', True)],
          'solos': [('solo', True)],
          'solv': [('solv', True)],
          'solv-': [('solv', False)],
          'solvens': [('solvens', True), ('solv', True)],
          'solverande': [('solverande', True), ('solveranda', True)],
          'solverande-': [('solverande', True), ('solveranda', True)],
          'solvs': [('solv', False)],
          'solvs-': [('solv', True)],
          'somalier': [('somalier', True)],
          'somalierna': [('somalier', True)],
          'somen': [('som', False)],
          'somens': [('som', False)],
          'somer': [('somer', False)],
          'somers': [('somer', False)],
          'someter': [('someter', False)],
          'someters': [('someter', False)],
          'sommar': [('sommar', False)],
          'sommars': [('sommar', False)],
          'sompars-': [('sompar', False)],
          'sområdets': [('sområde', False)],
          'soms': [('som', False)],
          'soms-': [('som', False)],
          'son': [('son', True), ('so', True)],
          'son-': [('son', False)],
          'sonager': [('sonage', False)],
          'sonagers': [('sonage', False)],
          'sonar': [('sonar', False)],
          'sonar-': [('sonar', True)],
          'sonarna': [('sonare', False)],
          'sonarnas': [('sonar', False)],
          'sond': [('sond', False)],
          'sond-': [('sond', True)],
          'sonden': [('sond', False)],
          'sondens': [('sond', False)],
          'sonder': [('sond', True)],
          'sonders': [('sond', False)],
          'sonds': [('sond', False)],
          'sonds-': [('sond', False)],
          'song': [('song', False)],
          'song-': [('song', False)],
          'songer': [('song', False)],
          'songerna': [('song', False)],
          'songernas': [('song', False)],
          'songers': [('song', False)],
          'songs': [('song', False)],
          'songs-': [('song', False)],
          'sons': [('son', True), ('so', True)],
          'sons-': [('son', False)],
          'sonter': [('sont', False)],
          'sonters': [('sont', False)],
          'sonvals': [('sonval', False)],
          'sonvals-': [('sonval', False)],
          'sop': [('sopa', True), ('sop', True)],
          'sop-': [('sopa', True), ('sop', True)],
          'sopan': [('sopa', True)],
          'sopans': [('sopa', True)],
          'sopar': [('sop', True)],
          'soparens': [('sopare', False)],
          'soparna': [('sop', True)],
          'soparnas': [('sop', True)],
          'sopas': [('sopa', True)],
          'sopp': [('soppa', True), ('sopp', True)],
          'sopp-': [('sopp', True), ('soppa', True)],
          'soppar': [('sopp', False)],
          'sopparna': [('sopp', False)],
          'soppars': [('sopp', False)],
          'soppe': [('soppa', False)],
          'soppe-': [('soppa', False)],
          'soppen': [('sopp', True)],
          'soppens': [('sopp', False)],
          'soppers': [('sopp', False)],
          'soppor': [('soppa', False)],
          'sopporna': [('soppa', False)],
          'soppornas': [('soppa', False)],
          'soppors': [('soppa', False)],
          'sopps': [('soppa', True), ('sopp', True)],
          'sopps-': [('soppa', True), ('sopp', True)],
          'sopran': [('sopran', True)],
          'soprans': [('sopran', False)],
          'sops': [('sopa', True), ('sop', True)],
          'sops-': [('sopa', True), ('sop', True)],
          'sorber': [('sorb', True)],
          'sorbers': [('sorb', True)],
          'sord': [('sord', False)],
          'sord-': [('sord', False)],
          'sorden': [('sord', False)],
          'sordens': [('sord', False)],
          'sordnar': [('sorden', False)],
          'sordnarna': [('sorden', False)],
          'sordnarnas': [('sorden', False)],
          'sordrar': [('sorder', False)],
          'sordrarna': [('sorder', False)],
          'sords': [('sord', False)],
          'sords-': [('sord', False)],
          'sorgen': [('sorg', False)],
          'sorgens': [('sorg', False)],
          'sorgers': [('sorg', True)],
          'sorgier': [('sorgie', False)],
          'sorgierna': [('sorgie', False)],
          'sorie': [('sorium', False)],
          'sorie-': [('sorium', False)],
          'sorierna': [('sorium', False)],
          'soriernas': [('sorium', False)],
          'soriers': [('sorium', False)],
          'soriets': [('sorium', False)],
          'sork': [('sork', True)],
          'sorkar': [('sork', False)],
          'sorkarna': [('sork', False)],
          'sorl': [('sorl', False)],
          'sorl-': [('sorl', False)],
          'sorls': [('sorl', True)],
          'sorn': [('sor', False)],
          'sorns': [('sor', False)],
          'sorons': [('soro', False)],
          'soros': [('soro', False)],
          'sort': [('sort', False)],
          'sort-': [('sort', True)],
          'sorten': [('sort', False)],
          'sortens': [('sort', False)],
          'sorter': [('sort', False)],
          'sorterna': [('sort', False)],
          'sorternas': [('sort', False)],
          'sorters': [('sort', False)],
          'sortier': [('sorti', True)],
          'sortierna': [('sorti', True)],
          'sortiernas': [('sorti', True)],
          'sortiers': [('sorti', True)],
          'sortis': [('sorti', True)],
          'sorts': [('sort', False)],
          'sorts-': [('sort', False)],
          'sos': [('so', False)],
          'sos-': [('so', False)],
          'sosen': [('so', False)],
          'sosens': [('so', False)],
          'soss-': [('sosse', False)],
          'sossarna': [('sosse', True)],
          'sossarnas': [('sosse', False)],
          'sost-': [('sost', False)],
          'sostarna': [('sost', False)],
          'sot': [('sot', True)],
          'sotar': [('sotare', True)],
          'sotarna': [('sotare', True)],
          'sots': [('sot', True)],
          'sottis': [('sottis', True)],
          'sottis-': [('sottis', True)],
          'soulen': [('soul', True)],
          'soulens': [('soul', True)],
          'sovar': [('sovar', False)],
          'sovar-': [('sovare', False)],
          'sovaren': [('sovar', False)],
          'sovarens': [('sovare', False)],
          'sovarna': [('sovare', False)],
          'sovarnas': [('sovare', False)],
          'sovars': [('sovar', False)],
          'sovdags': [('sovdags', True)],
          'sp': [('sp', False)],
          'sp-': [('sp', False)],
          'spack': [('spacke', False)],
          'spack-': [('spacke', False)],
          'spacke': [('spacke', False)],
          'spacke-': [('spacke', False)],
          'spacken': [('spacke', False)],
          'spackens': [('spacke', False)],
          'spacks': [('spacke', False)],
          'spacks-': [('spacke', False)],
          'spad': [('spade', True), ('spad', True)],
          'spad-': [('spade', True), ('spad', True)],
          'spadarna': [('spade', False)],
          'spadarnas': [('spade', False)],
          'spads': [('spade', True), ('spad', True)],
          'spads-': [('spade', True), ('spad', True)],
          'spakets': [('spaket', False)],
          'spakten': [('spakt', False)],
          'spalt': [('spalt', False)],
          'spalt-': [('spalt', False)],
          'spalts': [('spalt', False)],
          'spalts-': [('spalt', False)],
          'span': [('spa', True)],
          'spande': [('spande', False)],
          'spande-': [('spande', False)],
          'spann': [('spann', False)],
          'spann-': [('spann', False)],
          'spanns': [('spann', False)],
          'spanns-': [('spann', False)],
          'spans': [('spa', True)],
          'spar-': [('spar', False)],
          'sparanden': [('sparande', False)],
          'sparandens': [('sparande', False)],
          'sparens': [('spar', False)],
          'sparna': [('sp', False)],
          'spars-': [('spar', False)],
          'spasch': [('spasch', False)],
          'spasch-': [('spasch', False)],
          'spasm': [('spasm', True)],
          'spasm-': [('spasm', True)],
          'spastor': [('spastor', False)],
          'spastors': [('spastor', False)],
          'spat': [('spa', True)],
          'spat-': [('spat', False)],
          'spaten': [('spat', False)],
          'spatens': [('spat', False)],
          'spater': [('spat', False)],
          'spaters': [('spat', False)],
          'spatier': [('spatium', True)],
          'spatierna': [('spatium', True)],
          'spatiers': [('spatium', True)],
          'spats': [('spa', True)],
          'spats-': [('spat', False)],
          'spatt': [('spatt', True)],
          'spatt-': [('spatt', True)],
          'spatten': [('spatt', True)],
          'spattens': [('spatt', True)],
          'spatts': [('spatt', True)],
          'spatts-': [('spatt', True)],
          'spe': [('spe', True)],
          'spe-': [('spe', True)],
          'species': [('species', True), ('specie', True)],
          'species-': [('specie', True), ('species', True)],
          'spektiven': [('spektive', False)],
          'spektivens': [('spektive', False)],
          'spelar': [('spelare', True)],
          'spelar-': [('spelare', True)],
          'spell': [('spelle', False)],
          'spell-': [('spelle', False)],
          'spellar': [('spelle', False)],
          'spellarna': [('spelle', False)],
          'spellars': [('spelle', False)],
          'spells': [('spelle', False)],
          'spells-': [('spelle', False)],
          'spen': [('spene', True)],
          'spen-': [('spene', True)],
          'spenar': [('spene', True)],
          'spenarna': [('spene', False)],
          'spenarnas': [('spene', False)],
          'spenars': [('spene', False)],
          'spenat': [('spenat', True)],
          'spenat-': [('spenat', True)],
          'spenats': [('spenat', True)],
          'spenen': [('spene', True)],
          'spenens': [('spene', True)],
          'speng': [('spengar', False)],
          'speng-': [('spengar', False)],
          'spengar': [('spengar', False)],
          'spengarna': [('spengar', False)],
          'spengarnas': [('spengar', False)],
          'spengars': [('spengar', False)],
          'spengs': [('spengar', False)],
          'spengs-': [('spengar', False)],
          'spenning': [('spenning', False)],
          'spenningar': [('spenning', False)],
          'spenningarna': [('spenning', False)],
          'spenningarnas': [('spenning', False)],
          'spenningars': [('spenning', False)],
          'spennings': [('spenning', False)],
          'spennings-': [('spenning', False)],
          'spens': [('spens', True), ('spene', True)],
          'spens-': [('spene', True), ('spens', True)],
          'spepsin': [('spepsi', False)],
          'spepsins': [('spepsi', False)],
          'sper': [('sper', False)],
          'spermien': [('spermie', True)],
          'spermiens': [('spermie', True)],
          'spermis': [('spermi', False)],
          'spers': [('sper', False)],
          'spers-': [('sper', False)],
          'spet': [('speta', True)],
          'spet-': [('speta', True)],
          'spets': [('speta', True), ('spets', True)],
          'spets-': [('speta', True), ('spets', True)],
          'spiller': [('spillra', True)],
          'spiller-': [('spillra', False)],
          'spillerna': [('spiller', False)],
          'spillers': [('spiller', False)],
          'spilt': [('spilta', True)],
          'spilt-': [('spilta', True)],
          'spilts': [('spilta', True)],
          'spilts-': [('spilta', True)],
          'spin': [('spin', False)],
          'spin-': [('spin', False)],
          'spingel': [('spingla', False)],
          'spingel-': [('spingla', False)],
          'spinn': [('spinn', True)],
          'spinn-': [('spinn', True)],
          'spinnar': [('spinnare', False)],
          'spinnarna': [('spinnare', False)],
          'spinnarnas': [('spinnare', True)],
          'spinnen': [('spinn', True)],
          'spinnens': [('spinn', True)],
          'spinns': [('spinn', True)],
          'spins': [('spin', False)],
          'spins-': [('spin', False)],
          'spip': [('spip', False)],
          'spipar': [('spip', False)],
          'spiparna': [('spip', False)],
          'spiparnas': [('spip', False)],
          'spips': [('spip', False)],
          'spips-': [('spip', False)],
          'spir': [('spira', False)],
          'spir-': [('spira', False)],
          'spirator': [('spirata', False)],
          'spirators': [('spirata', False)],
          'spire': [('spira', True), ('spirea', True)],
          'spire-': [('spirea', True), ('spira', True)],
          'spires': [('spirea', True)],
          'spirins': [('spirin', False)],
          'spirs': [('spira', False)],
          'spirs-': [('spira', True)],
          'spis': [('spis', False)],
          'spis-': [('spis', False)],
          'spisar': [('spisare', True), ('spis', True)],
          'spisarna': [('spisare', True), ('spis', True)],
          'spisarnas': [('spisare', True), ('spis', True)],
          'spisars': [('spis', False)],
          'spit': [('spit', False)],
          'spits': [('spit', False)],
          'spjäl': [('spjäle', True), ('spjäla', True)],
          'spjäl-': [('spjäla', True), ('spjäle', True)],
          'spjäle': [('spjäle', True), ('spjäla', True)],
          'spjäls': [('spjäla', True), ('spjäle', True)],
          'spjäls-': [('spjäle', True), ('spjäla', True)],
          'splandets': [('splande', False)],
          'splanet': [('splan', False)],
          'splanets': [('splan', False)],
          'splants': [('splanta', False)],
          'splants-': [('splanta', False)],
          'splar': [('spel', False)],
          'splarna': [('spel', False)],
          'splarnas': [('spel', False)],
          'splars': [('spel', False)],
          'split': [('split', True)],
          'split-': [('split', True)],
          'splits': [('splits', True), ('split', True)],
          'splits-': [('splits', True), ('split', True)],
          'spojk': [('spojke', False)],
          'spojk-': [('spojke', False)],
          'spojks': [('spojke', False)],
          'spojks-': [('spojke', False)],
          'spol': [('spole', True)],
          'spol-': [('spole', True)],
          'spolar': [('spole', True)],
          'spolarna': [('spole', False)],
          'spolarnas': [('spole', False)],
          'spolen': [('spole', True)],
          'spolens': [('spole', True)],
          'spolitikerna': [('spolitik', False)],
          'spols': [('spole', True)],
          'spols-': [('spole', False)],
          'spolskor': [('spolska', False)],
          'spolskorna': [('spolska', False)],
          'spolskornas': [('spolska', False)],
          'spolskors': [('spolska', False)],
          'spondens': [('spondens', False)],
          'sponents': [('sponent', False)],
          'sponents-': [('sponent', False)],
          'spons': [('spons', False)],
          'spons-': [('spons', False)],
          'spor': [('spor', True)],
          'sporna': [('spa', False)],
          'spornas': [('spa', False)],
          'sporr': [('sporre', True)],
          'sporr-': [('sporre', False)],
          'sporren': [('sporre', False)],
          'sporrens': [('sporre', False)],
          'sporrs': [('sporre', True)],
          'sporrs-': [('sporre', False)],
          'spors': [('spor', True)],
          'spors-': [('spor', True)],
          'sportar': [('sportare', False)],
          'sportarna': [('sportare', False)],
          'sportarnas': [('sport', False)],
          'sporter': [('sport', False)],
          'sporterna': [('sport', False)],
          'sporternas': [('sport', False)],
          'sporters': [('sport', False)],
          'sposter': [('spost', False)],
          'sposters': [('spost', False)],
          'spotens': [('spot', True)],
          'spots': [('spot', True)],
          'spott': [('spott', True)],
          'spott-': [('spott', True)],
          'spottar': [('spott', True)],
          'spottarna': [('spott', True)],
          'spottarnas': [('spott', True)],
          'spotts': [('spott', True)],
          'spotts-': [('spott', False)],
          'spraktik-': [('spraktik', False)],
          'spraktiker': [('spraktik', False)],
          'spraktikerna': [('spraktik', False)],
          'spraktikernas': [('spraktik', False)],
          'spraktikers': [('spraktik', False)],
          'spraktiks': [('spraktik', False)],
          'spremie': [('spremie', False)],
          'spremie-': [('spremie', False)],
          'spremier': [('spremie', False)],
          'spremierna': [('spremie', False)],
          'spremiernas': [('spremie', False)],
          'spremiers': [('spremie', False)],
          'spressar': [('spress', False)],
          'spressarna': [('spress', False)],
          'spressarnas': [('spress', False)],
          'sprick': [('spricka', False)],
          'sprick-': [('spricka', False)],
          'spricks': [('spricka', False)],
          'spricks-': [('spricka', False)],
          'spring': [('spring', True), ('springa', True)],
          'spring-': [('spring', True), ('springa', True)],
          'springarna': [('springare', True)],
          'springs': [('spring', True), ('springa', True)],
          'springs-': [('spring', True), ('springa', True)],
          'sprins': [('spri', False)],
          'spris': [('spri', False)],
          'sprit': [('spri', True), ('sprit', True)],
          'sprits': [('spri', True), ('sprits', True), ('sprit', True)],
          'sprits-': [('sprits', True), ('sprit', True)],
          'sprivilegiernas': [('sprivilegium', False)],
          'sproblemet': [('sproblem', False)],
          'sproblemets': [('sproblem', False)],
          'sprocessen': [('sprocess', False)],
          'sprocessens': [('sprocess', False)],
          'sprogrammet': [('sprogram', False)],
          'sprogrammets': [('sprogram', False)],
          'sprut': [('spruta', True), ('sprut', True)],
          'sprut-': [('sprut', True), ('spruta', True)],
          'spruts': [('sprut', True), ('spruta', True)],
          'spruts-': [('sprut', True), ('spruta', True)],
          'sprättarnas': [('sprätt', True)],
          'språngbräde': [('språngbräda', True), ('språngbräde', True)],
          'spröjsarna': [('spröjs', True)],
          'spröjsarnas': [('spröjs', True)],
          'sps': [('sp', False)],
          'spump': [('spump', False)],
          'spump-': [('spumpa', False)],
          'spumps': [('spumpa', False)],
          'spumps-': [('spumpa', False)],
          'sputs': [('sputs', False)],
          'sputs-': [('sputs', False)],
          'spyts': [('spyt', False)],
          'spyts-': [('spyt', False)],
          'spännen': [('spänn', True), ('spänne', True)],
          'spännens': [('spänn', True), ('spänne', True)],
          'spån': [('spåna', True), ('spån', True)],
          'spån-': [('spån', True), ('spåna', True)],
          'spåna': [('spåna', True)],
          'spånas': [('spåna', True)],
          'spåns': [('spåna', True), ('spån', True)],
          'spåns-': [('spåna', True), ('spån', True)],
          'spåsar': [('spåse', False)],
          'spös': [('spö', False)],
          'spös-': [('spö', True)],
          'squashracket': [('squashrack', True), ('squashracket', True)],
          'squashrackets': [('squashracket', True), ('squashrack', True)],
          'srack': [('srack', False)],
          'srack-': [('srack', False)],
          'srackar': [('srack', False)],
          'srackarna': [('srack', False)],
          'srackarnas': [('srack', False)],
          'sracks': [('srack', False)],
          'sracks-': [('srack', False)],
          'sraden': [('srad', False)],
          'sradens': [('srad', False)],
          'srads': [('srad', False)],
          'srakets': [('sraket', False)],
          'sramar': [('sram', False)],
          'sramarna': [('sram', False)],
          'srams': [('sram', False)],
          'srams-': [('sram', False)],
          'srande': [('srande', False)],
          'srande-': [('srande', False)],
          'sranden': [('srande', False)],
          'srandens': [('srande', False)],
          'srandet': [('srande', False)],
          'srarnas': [('ser', False)],
          'sras': [('sras', False)],
          'sras-': [('sras', False)],
          'srasen': [('sras', False)],
          'srasens': [('sras', False)],
          'sraster': [('srast', False)],
          'srasternas': [('srast', False)],
          'srasters': [('srast', False)],
          'sremmar': [('srem', False)],
          'sremmarna': [('srem', False)],
          'sremmarnas': [('srem', False)],
          'srems': [('sremsa', False)],
          'srems-': [('sremsa', False)],
          'sren': [('sren', False)],
          'srenar': [('sren', False)],
          'srens': [('sren', False)],
          'srese': [('sresa', False)],
          'srese-': [('sresa', False)],
          'srestriktioner': [('srestriktion', False)],
          'srestriktionernas': [('srestriktion', False)],
          'sriket': [('srike', False)],
          'srikets': [('srike', False)],
          'srim': [('srim', False)],
          'srims': [('srim', False)],
          'srims-': [('srim', False)],
          'sringarna': [('sring', False)],
          'sringarnas': [('sring', False)],
          'sris': [('sris', False)],
          'sris-': [('sris', False)],
          'srisk': [('srisk', False)],
          'srisk-': [('srisk', False)],
          'srit': [('srit', False)],
          'srit-': [('srit', False)],
          'sriter': [('srit', False)],
          'sriterna': [('srit', False)],
          'sriters': [('srit', False)],
          'srits': [('srit', False)],
          'srock': [('srock', False)],
          'srockar': [('srock', False)],
          'srockarna': [('srock', False)],
          'srockarnas': [('srock', False)],
          'sroller': [('sroll', False)],
          'srollerna': [('sroll', False)],
          'srollernas': [('sroll', False)],
          'srollers': [('sroll', False)],
          'srolls': [('sroll', False)],
          'srolls-': [('sroll', False)],
          'sromans': [('sroman', False)],
          'sropen': [('srop', False)],
          'sropens': [('srop', False)],
          'srops': [('srop', False)],
          'sros': [('sros', False)],
          'sros-': [('sros', False)],
          'srot': [('srot', False)],
          'sroten': [('srot', False)],
          'srotens': [('srot', False)],
          'srots': [('srot', False)],
          'srots-': [('srot', False)],
          'srull': [('srulle', False)],
          'srull-': [('srulle', False)],
          'srullarna': [('srulle', False)],
          'srulle': [('srulle', False)],
          'srulle-': [('srulle', False)],
          'srulls': [('srulle', False)],
          'srulls-': [('srulle', False)],
          'srum': [('srum', False)],
          'srum-': [('srum', False)],
          'srums': [('srum', False)],
          'srums-': [('srum', False)],
          'srun': [('sruna', False)],
          'srundans': [('srunda', False)],
          'srus': [('srus', False)],
          'srus-': [('srus', False)],
          'sryggar': [('srygg', False)],
          'srykten': [('srykte', False)],
          'sryktens': [('srykte', False)],
          'sräcke': [('sräcke', False)],
          'sräcken': [('sräcke', False)],
          'sräckens': [('sräcke', False)],
          'sräcket': [('sräcke', False)],
          'sräckets': [('sräcke', False)],
          'sräk-': [('sräka', False)],
          'sräknarnas': [('sräknare', False)],
          'sräkors': [('sräka', False)],
          'sräks-': [('sräka', False)],
          'sräls': [('sräls', False)],
          'sräls-': [('sräls', False)],
          'sränderna': [('srand', False)],
          'srändernas': [('srand', False)],
          'sränn': [('sränna', False)],
          'sränn-': [('sränna', False)],
          'sränns': [('sränna', False)],
          'sränns-': [('sränna', False)],
          'srättens': [('srätt', False)],
          'srättigheter': [('srättigheter', False)],
          'srättigheterna': [('srättighet', False)],
          'srättigheternas': [('srättighet', False)],
          'srättigheters': [('srättighet', False)],
          'srättighets': [('srättigheter', False)],
          'srättighets-': [('srättighet', False)],
          'sråden': [('sråd', False)],
          'srådens': [('sråd', False)],
          'srådet': [('sråd', False)],
          'srån': [('srå', False)],
          'sråns': [('srån', False)],
          'srön': [('srön', False)],
          'sröns': [('srön', False)],
          'sröst': [('sröst', False)],
          'sröst-': [('sröst', False)],
          'srösten': [('sröst', False)],
          'sröstens': [('sröst', False)],
          'srötter': [('srot', False)],
          'srötterna': [('srot', False)],
          'srötternas': [('srot', False)],
          'srötters': [('srot', False)],
          'ss': [('s', True)],
          'ssage': [('ssaga', False)],
          'ssage-': [('ssaga', False)],
          'ssago': [('ssaga', False)],
          'ssago-': [('ssaga', False)],
          'ssaker': [('ssak', False)],
          'ssakerna': [('ssak', False)],
          'ssakernas': [('ssak', False)],
          'ssakers': [('ssak', False)],
          'ssalen': [('ssal', False)],
          'ssalens': [('ssal', False)],
          'ssalets': [('ssale', False)],
          'ssamer': [('ssamer', False)],
          'ssamers': [('ssamer', False)],
          'ssamhällena': [('ssamhälle', False)],
          'ssanden': [('ssande', False)],
          'ssandens': [('ssande', False)],
          'ssans-': [('ssans', False)],
          'ssaren': [('ssare', False)],
          'ssarie': [('ssarie', False)],
          'ssarie-': [('ssarium', False)],
          'ssarier': [('ssario', False)],
          'ssarierna': [('ssarium', False)],
          'ssariernas': [('ssarie', False)],
          'ssariers': [('ssarium', False)],
          'ssarna': [('sse', False)],
          'ssarnas': [('sse', False)],
          'ssars': [('ss', False)],
          'ssars-': [('ssar', False)],
          'ssat': [('ssat', False)],
          'ssat-': [('ssat', False)],
          'ssaten': [('ssat', False)],
          'ssatens': [('ssat', False)],
          'ssats': [('ssats', False)],
          'ssats-': [('ssats', False)],
          'ssaxar': [('ssax', False)],
          'ssaxarna': [('ssax', False)],
          'ssaxarnas': [('ssax', False)],
          'ssbit': [('ssbit', False)],
          'sscentrers': [('sscentrum', False)],
          'sscentret': [('sscentrum', False)],
          'sscentrets': [('sscentrum', False)],
          'sse-': [('ssa', False)],
          'ssegrar': [('sseger', False)],
          'ssegrarna': [('sseger', False)],
          'ssegrarnas': [('sseger', False)],
          'ssel': [('ssel', False)],
          'ssel-': [('ssel', False)],
          'sselen': [('ssele', False)],
          'sselens': [('ssele', False)],
          'sselers': [('sseler', False)],
          'sselet': [('ssele', False)],
          'sselets': [('ssele', False)],
          'ssels': [('ssel', False)],
          'ssels-': [('ssel', False)],
          'ssemestrar': [('ssemester', False)],
          'ssemestrarna': [('ssemester', False)],
          'ssemestrarnas': [('ssemester', False)],
          'ssen': [('ss', False)],
          'ssenas': [('ssena', False)],
          'ssens': [('ss', False)],
          'ssens-': [('ssens', False)],
          'ssentens': [('ssent', False)],
          'ssenter': [('ssenter', False)],
          'ssenterna': [('ssenter', False)],
          'ssenternas': [('ssenter', False)],
          'ssenters': [('ssenter', False)],
          'sser': [('ss', False)],
          'sser-': [('sser', False)],
          'sserier': [('sseri', False)],
          'sserierna': [('sserie', False)],
          'sseriernas': [('sseri', False)],
          'sseriers': [('sseri', False)],
          'ssern': [('sser', False)],
          'sserna': [('ss', False)],
          'ssernas': [('ss', False)],
          'sserns': [('sser', False)],
          'ssers': [('ss', False)],
          'sserver': [('sserver', False)],
          'ssess': [('ssess', False)],
          'ssess-': [('ssess', False)],
          'ssessor': [('ssessor', False)],
          'ssessors': [('ssessor', False)],
          'sset': [('ss', False)],
          'ssetter': [('ssett', False)],
          'ssetters': [('ssett', False)],
          'ssgångar': [('ssgångare', False)],
          'ssgångarna': [('ssgångare', False)],
          'ssgångarnas': [('ssgångare', False)],
          'sshandlar': [('sshandlare', False)],
          'sshet': [('sshet', False)],
          'sshytts-': [('sshytt', False)],
          'ssian': [('ssia', False)],
          'ssians': [('ssia', False)],
          'ssidan': [('ssida', False)],
          'ssidans': [('ssida', False)],
          'sside': [('ssida', False)],
          'sside-': [('ssida', False)],
          'ssides': [('ssida', False)],
          'ssier': [('ssier', False)],
          'ssierna': [('ssi', False)],
          'ssiers': [('ssi', False)],
          'ssiet': [('ssi', False)],
          'ssiets': [('ssi', False)],
          'ssikten': [('ssikte', False)],
          'ssiktens': [('ssikte', False)],
          'ssilen': [('ssil', False)],
          'ssilens': [('ssil', False)],
          'ssims': [('ssim', False)],
          'ssims-': [('ssim', False)],
          'ssin': [('ssi', False)],
          'ssin-': [('ssin', False)],
          'ssinen': [('ssin', False)],
          'ssinens': [('ssin', False)],
          'ssiner': [('ssin', False)],
          'ssinerna': [('ssin', False)],
          'ssinernas': [('ssin', False)],
          'ssiners': [('ssin', False)],
          'ssins': [('ssin', False)],
          'ssins-': [('ssin', False)],
          'ssis': [('ssi', False)],
          'ssis-': [('ssis', False)],
          'ssistans': [('ssistans', False)],
          'ssisten': [('ssist', False)],
          'ssistens': [('ssist', False)],
          'ssit': [('ssi', False)],
          'ssits': [('ssi', False)],
          'ssiv': [('ssiv', False)],
          'ssiv-': [('ssiv', False)],
          'ssiven': [('ssiv', False)],
          'ssivens': [('ssiv', False)],
          'ssiver': [('ssivum', False)],
          'ssiverna': [('ssiv', False)],
          'ssivernas': [('ssiv', False)],
          'ssivers': [('ssivum', False)],
          'ssivet': [('ssiv', False)],
          'ssivs': [('ssiv', False)],
          'ssjan': [('ssja', False)],
          'ssjans': [('ssja', False)],
          'ssjas': [('ssja', False)],
          'ssjukan': [('ssjuka', False)],
          'sskal': [('sskala', False)],
          'sskal-': [('sskala', False)],
          'sskals': [('sskala', False)],
          'sskals-': [('sskala', False)],
          'sskaps-': [('sskap', False)],
          'sskar-': [('sskara', False)],
          'sskare': [('sskara', False)],
          'sskare-': [('sskara', False)],
          'sskatts-': [('sskatt', False)],
          'sskeden': [('sskede', False)],
          'sskedens': [('sskede', False)],
          'sskedet': [('sskede', False)],
          'ssken': [('sskena', False)],
          'ssken-': [('ssken', False)],
          'sskens': [('sskena', False)],
          'sskens-': [('sskena', False)],
          'sskiften': [('sskift', False)],
          'sskiftens': [('sskift', False)],
          'sskiftet': [('sskifte', False)],
          'sskiftets': [('sskifte', False)],
          'ssko': [('ssko', False)],
          'sskon': [('ssko', False)],
          'sskons': [('ssko', False)],
          'sskonst': [('sskonst', False)],
          'sskor': [('ssko', False)],
          'sskorna': [('ssko', False)],
          'sskornas': [('ssko', False)],
          'sskors': [('ssko', False)],
          'sskott': [('sskott', False)],
          'sskotten': [('sskott', False)],
          'sskottens': [('sskott', False)],
          'sskotts-': [('sskott', False)],
          'sskrank': [('sskrank', False)],
          'sskrank-': [('sskrank', False)],
          'sskranks': [('sskrank', False)],
          'sskranks-': [('sskrank', False)],
          'sskrap': [('sskrapa', False)],
          'sskrap-': [('sskrapa', False)],
          'sskraps': [('sskrapa', False)],
          'sskraps-': [('sskrapa', False)],
          'sskulder': [('sskuld', False)],
          'sskurs': [('sskurs', False)],
          'sskurs-': [('sskurs', False)],
          'sskäll': [('sskälla', False)],
          'sskäll-': [('sskälla', False)],
          'sskälls': [('sskälla', False)],
          'sskälls-': [('sskälla', False)],
          'sskärmar': [('sskärm', False)],
          'sskärmarnas': [('sskärm', False)],
          'sskärv': [('sskärva', False)],
          'sskärv-': [('sskärva', False)],
          'sskärve': [('sskärva', False)],
          'sskärvs': [('sskärva', False)],
          'sskärvs-': [('sskärva', False)],
          'sskör': [('sskör', False)],
          'sskörs': [('sskör', False)],
          'sskörs-': [('sskör', False)],
          'sskötar': [('sskötare', False)],
          'sskötarna': [('sskötare', False)],
          'sskötarnas': [('sskötare', False)],
          'ssköten': [('ssköte', False)],
          'sskötens': [('ssköte', False)],
          'sslag': [('sslag', False)],
          'sslags': [('sslag', False)],
          'sslags-': [('sslag', False)],
          'sslams': [('sslam', False)],
          'sslams-': [('sslam', False)],
          'sslan': [('ssla', False)],
          'sslan-': [('sslan', False)],
          'sslandets': [('sslande', False)],
          'sslans': [('ssla', False)],
          'sslans-': [('sslan', False)],
          'sslar': [('ssel', False)],
          'sslarna': [('ssel', False)],
          'sslarnas': [('ssel', False)],
          'sslas': [('ssla', False)],
          'ssle': [('ssle', False)],
          'ssle-': [('ssle', False)],
          'sslen': [('ssel', False)],
          'sslens': [('ssel', False)],
          'sslets': [('ssel', False)],
          'sslickar': [('sslickare', False)],
          'sslickarna': [('sslickare', False)],
          'sslickarnas': [('sslickare', False)],
          'ssling': [('ssling', False)],
          'ssling-': [('ssling', False)],
          'sslings': [('ssling', False)],
          'sslings-': [('ssling', False)],
          'sslipar': [('sslipare', False)],
          'ssliparna': [('sslipare', False)],
          'ssliparnas': [('sslipare', False)],
          'sslips': [('sslips', False)],
          'sslips-': [('sslips', False)],
          'sslotts': [('sslott', False)],
          'ssläkten': [('ssläkt', False)],
          'ssläktens': [('ssläkt', False)],
          'ssläkts': [('ssläkt', False)],
          'ssläkts-': [('ssläkt', False)],
          'ssmitt': [('ssmitt', False)],
          'ssmitts': [('ssmitt', False)],
          'ssmitts-': [('ssmitt', False)],
          'ssmodet': [('ssmod', False)],
          'ssmodets': [('ssmod', False)],
          'ssmörj': [('ssmörj', False)],
          'ssmörj-': [('ssmörj', False)],
          'ssmörjs': [('ssmörj', False)],
          'ssmörjs-': [('ssmörj', False)],
          'ssnacks': [('ssnack', False)],
          'ssnacks-': [('ssnack', False)],
          'ssnar': [('ssnare', False)],
          'ssnar-': [('ssnare', False)],
          'ssnare': [('ssnare', False)],
          'ssne': [('ssne', False)],
          'ssne-': [('ssne', False)],
          'ssnens': [('ssne', False)],
          'ssnes': [('ssne', False)],
          'ssnes-': [('ssne', False)],
          'ssnet': [('ssne', False)],
          'ssnets': [('ssne', False)],
          'ssnickarnas': [('ssnickare', False)],
          'ssnäpp': [('ssnäppa', False)],
          'ssnäpp-': [('ssnäppa', False)],
          'ssnäpps': [('ssnäppa', False)],
          'ssnäpps-': [('ssnäppa', False)],
          'sso': [('ssa', False)],
          'sso-': [('sso', False)],
          'ssområdet': [('ssområde', False)],
          'sson': [('sson', False)],
          'ssonarna': [('ssonar', False)],
          'ssons': [('sson', False)],
          'ssopp': [('ssoppa', False)],
          'ssopp-': [('ssoppa', False)],
          'ssopps': [('ssoppa', False)],
          'ssopps-': [('ssoppa', False)],
          'ssor': [('ssa', False)],
          'ssorna': [('ssa', False)],
          'ssornas': [('ssa', False)],
          'ssors': [('ssa', False)],
          'ssot': [('sso', False)],
          'ssots': [('sso', False)],
          'ssovar': [('ssovare', False)],
          'ssovaren': [('ssovare', False)],
          'sspad': [('sspade', False)],
          'sspad-': [('sspade', False)],
          'sspads': [('sspade', False)],
          'sspads-': [('sspade', False)],
          'sspan': [('sspan', False)],
          'sspans': [('sspan', False)],
          'sspat': [('sspat', False)],
          'sspats': [('sspat', False)],
          'sspets': [('sspets', False)],
          'sspets-': [('sspets', False)],
          'sspiller': [('sspillra', False)],
          'sspinn': [('sspinne', False)],
          'sspinn-': [('sspinne', False)],
          'sspinnen': [('sspinne', False)],
          'sspinnens': [('sspinne', False)],
          'sspinns': [('sspinne', False)],
          'sspisar': [('sspis', False)],
          'sspisarna': [('sspis', False)],
          'sspisarnas': [('sspis', False)],
          'sspol': [('sspole', False)],
          'sspol-': [('sspole', False)],
          'sspolar': [('sspole', False)],
          'sspolen': [('sspole', False)],
          'sspolens': [('sspole', False)],
          'ssportar': [('ssport', False)],
          'ssportarna': [('ssport', False)],
          'ssprut': [('sspruta', False)],
          'ssprut-': [('sspruta', False)],
          'sspruts': [('sspruta', False)],
          'sspruts-': [('sspruta', False)],
          'sspump': [('sspumpa', False)],
          'sspännen': [('sspänne', False)],
          'sspännens': [('sspänne', False)],
          'ssrems': [('ssrem', False)],
          'ssrems-': [('ssrem', False)],
          'sstadge': [('sstadga', False)],
          'sstadge-': [('sstadga', False)],
          'sstadie': [('sstadium', False)],
          'sstadie-': [('sstadium', False)],
          'sstadier': [('sstadium', False)],
          'sstadierna': [('sstadium', False)],
          'sstadiernas': [('sstadium', False)],
          'sstadiers': [('sstadium', False)],
          'sstadiet': [('sstadium', False)],
          'sstadiets': [('sstadium', False)],
          'sstadium': [('sstadium', False)],
          'sstadiums': [('sstadium', False)],
          'sstagets': [('sstag', False)],
          'sstaggar': [('sstaggare', False)],
          'sstaggarna': [('sstaggare', False)],
          'sstaggarnas': [('sstaggare', False)],
          'sstak': [('sstake', False)],
          'sstaken': [('sstake', False)],
          'sstalets': [('sstal', False)],
          'sstammar': [('sstam', False)],
          'sstammarna': [('sstam', False)],
          'sstammarnas': [('sstam', False)],
          'sstankarna': [('sstanke', False)],
          'sstankarnas': [('sstanke', False)],
          'sstanken': [('sstanke', False)],
          'sstankens': [('sstanke', False)],
          'sstans': [('sstad', False)],
          'sstarter': [('sstart', False)],
          'sstarterna': [('sstart', False)],
          'sstarternas': [('sstart', False)],
          'sstarters': [('sstart', False)],
          'sstatistiker': [('sstatistik', False)],
          'sstatistikerna': [('sstatistik', False)],
          'sstatistikernas': [('sstatistik', False)],
          'sstatistikers': [('sstatistik', False)],
          'sstavarna': [('sstav', False)],
          'ssteg': [('sstege', False)],
          'ssteg-': [('sstege', False)],
          'sstegen': [('ssteg', False)],
          'sstegens': [('sstege', False)],
          'sstegs': [('ssteg', False)],
          'sstegs-': [('sstege', False)],
          'sstekar': [('sstek', False)],
          'sstekarna': [('sstek', False)],
          'sstekarnas': [('sstek', False)],
          'ssten': [('ssten', False)],
          'sstens': [('ssten', False)],
          'sstick': [('ssticka', False)],
          'sstick-': [('ssticka', False)],
          'ssticks': [('ssticka', False)],
          'ssticks-': [('ssticka', False)],
          'sstol': [('sstol', False)],
          'sstol-': [('sstol', False)],
          'sstols': [('sstol', False)],
          'sstols-': [('sstol', False)],
          'sston': [('ssto', False)],
          'sstormar': [('sstorm', False)],
          'sstormarna': [('sstorm', False)],
          'sstormarnas': [('sstorm', False)],
          'sstorvs': [('sstorv', False)],
          'sstruts': [('sstrut', False)],
          'sstruts-': [('sstrut', False)],
          'ssträck': [('ssträcka', False)],
          'ssträck-': [('ssträcka', False)],
          'ssträcks': [('ssträcka', False)],
          'ssträcks-': [('ssträcka', False)],
          'ssträvan': [('ssträvan', False)],
          'ssträvans': [('ssträvan', False)],
          'sstråk': [('sstråk', False)],
          'sstråken': [('sstråk', False)],
          'sstråkens': [('sstråk', False)],
          'sstråks': [('sstråk', False)],
          'sstråks-': [('sstråk', False)],
          'sstråns': [('sstrå', False)],
          'sstråt': [('sstrå', False)],
          'sstråts': [('sstrå', False)],
          'sstudie': [('sstudie', False)],
          'sstudie-': [('sstudie', False)],
          'sstudier': [('sstudie', False)],
          'sstudierna': [('sstudie', False)],
          'sstudiernas': [('sstudie', False)],
          'sstudiers': [('sstudier', False)],
          'sstudsar': [('sstudsare', False)],
          'sstudsarna': [('sstudsare', False)],
          'sstudsarnas': [('sstudsare', False)],
          'sstup': [('sstup', False)],
          'sstups': [('sstup', False)],
          'sstups-': [('sstup', False)],
          'sstycken': [('sstycke', False)],
          'sstyckena': [('sstycke', False)],
          'sstyckenas': [('sstycke', False)],
          'sstyckens': [('sstycke', False)],
          'sstycket': [('sstycke', False)],
          'sstyckets': [('sstycke', False)],
          'sstycks': [('sstycke', False)],
          'sstyrkan': [('sstyrka', False)],
          'sstyrkans': [('sstyrka', False)],
          'sstyrke': [('sstyrka', False)],
          'sställanden': [('sställande', False)],
          'sställandens': [('sställande', False)],
          'sställen': [('sställ', False)],
          'sställens': [('sställe', False)],
          'sstället': [('sställ', False)],
          'sställets': [('sställ', False)],
          'sställningar': [('sställning', False)],
          'sställningarna': [('sställning', False)],
          'sställningarnas': [('sställning', False)],
          'sställningars': [('sställning', False)],
          'sställnings': [('sställning', False)],
          'sställnings-': [('sställning', False)],
          'sstötarnas': [('sstöt', False)],
          'sstövlars': [('sstövel', False)],
          'ssug': [('ssug', False)],
          'ssur': [('ssur', False)],
          'ssur-': [('ssur', False)],
          'ssurans': [('ssurans', False)],
          'ssure': [('ssure', False)],
          'ssurs': [('ssur', False)],
          'ssvale': [('ssvala', False)],
          'ssvans': [('ssvans', False)],
          'ssvans-': [('ssvans', False)],
          'ssveck': [('ssveck', False)],
          'ssveck-': [('ssveck', False)],
          'ssvecks': [('ssveck', False)],
          'ssvecks-': [('ssveck', False)],
          'ssvensk': [('ssvenska', False)],
          'ssvensk-': [('ssvenska', False)],
          'ssvärdet': [('ssvärd', False)],
          'ssvärmar': [('ssvärm', False)],
          'ssvärmarna': [('ssvärm', False)],
          'ssvärmarnas': [('ssvärm', False)],
          'ssväsendet': [('ssväsen', False)],
          'ssylt': [('ssylt', False)],
          'ssylt-': [('ssylta', False)],
          'ssylts': [('ssylta', False)],
          'ssylts-': [('ssylta', False)],
          'ssyns': [('ssyn', False)],
          'ssyre': [('ssyra', False)],
          'ssyre-': [('ssyra', False)],
          'ssyren': [('ssyr', False)],
          'ssyrens': [('ssyr', False)],
          'ssyrs': [('ssyr', False)],
          'ssyrs-': [('ssyr', False)],
          'ssysslorna': [('ssyssla', False)],
          'ssysslornas': [('ssyssla', False)],
          'ssäkringar': [('ssäkring', False)],
          'ssäkringars': [('ssäkring', False)],
          'ssås': [('ssås', False)],
          'ssås-': [('ssås', False)],
          'sséer': [('ssé', False)],
          'sséers': [('ssé', False)],
          'ssögon': [('ssöga', False)],
          'ssömmar': [('ssöm', False)],
          'ssömmarna': [('ssöm', False)],
          'ssömmarnas': [('ssöm', False)],
          'ssören': [('ssör', False)],
          'ssörens': [('ssör', False)],
          'ssörns': [('ssör', False)],
          'ssös-': [('ssös', False)],
          'st': [('st', True)],
          'st-': [('st', False)],
          'sta': [('ste', False)],
          'sta-': [('ste', False)],
          'stack': [('stack', False)],
          'stack-': [('stack', False)],
          'stackar': [('stackare', True), ('stack', True)],
          'stackarna': [('stackare', True), ('stack', True)],
          'stackarnas': [('stackare', True), ('stack', True)],
          'stacks': [('stack', False)],
          'stacks-': [('stack', False)],
          'stadge': [('stadgar', True), ('stadga', True)],
          'stadge-': [('stadgar', True), ('stadga', True)],
          'stadie': [('stadion', True), ('stadium', True)],
          'stadie-': [('stadion', True), ('stadium', True)],
          'stadier': [('stadion', True), ('stadium', True)],
          'stadierna': [('stadion', True), ('stadium', True)],
          'stadiernas': [('stadion', True), ('stadium', True)],
          'stadiers': [('stadion', True), ('stadium', True)],
          'stadiet': [('stadion', True), ('stadium', True)],
          'stadiets': [('stadion', True), ('stadium', True)],
          'stadium': [('stadion', True), ('stadium', True)],
          'stadiums': [('stadion', True), ('stadium', True)],
          'stadsfullmäktige': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stadsfullmäktigen': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stadsfullmäktigena': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stadsfullmäktigenas': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stadsfullmäktigens': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stadsfullmäktiges': [('stadsfullmäktige', True), ('stadsfullmäktig', True)],
          'stagen': [('stag', False)],
          'stagens': [('stag', False)],
          'staget': [('stag', False)],
          'stagets': [('stag', True)],
          'staggar': [('stagg', True)],
          'staggarna': [('stagg', True)],
          'staggarnas': [('stagg', True)],
          'stak': [('stake', True)],
          'stak-': [('stake', False)],
          'staken': [('stake', True)],
          'stakens': [('stake', False)],
          'staket': [('staket', True)],
          'stakets': [('staket', False)],
          'staks': [('stake', False)],
          'staks-': [('stake', False)],
          'staktiker': [('staktik', False)],
          'staktikerna': [('staktik', False)],
          'staktikernas': [('staktik', False)],
          'staktikers': [('staktik', False)],
          'stalandenas': [('stalande', False)],
          'stalandens': [('stalande', False)],
          'stalar': [('stalare', False)],
          'stalar-': [('stalare', False)],
          'stalaren': [('stalare', False)],
          'stalarens': [('stalare', False)],
          'stalen': [('stal', False)],
          'stalens': [('stal', False)],
          'staler': [('stal', False)],
          'stalerna': [('stal', False)],
          'stalernas': [('stal', False)],
          'stalers': [('stal', False)],
          'stalet': [('stal', False)],
          'stallanden': [('stalland', False)],
          'stallandens': [('stalland', False)],
          'stamenten': [('stamente', False)],
          'stamentens': [('stamente', False)],
          'stamentet': [('stamente', False)],
          'stamentets': [('stament', False)],
          'staments': [('stament', False)],
          'staments-': [('stamente', False)],
          'stammar': [('stammare', True), ('stam', True)],
          'stammarna': [('stammare', True), ('stam', True)],
          'stammarnas': [('stammare', True), ('stam', True)],
          'stampen': [('stampen', True), ('stamp', True)],
          'stampens': [('stampen', True), ('stamp', True)],
          'stan': [('stad', False)],
          'stan-': [('stan', False)],
          'stana': [('sta', False)],
          'stanas': [('sta', False)],
          'standen': [('stande', False)],
          'standens': [('stande', False)],
          'stangens': [('stang', False)],
          'stangenten': [('stangent', False)],
          'stangentens': [('stangent', False)],
          'stank': [('stank', True)],
          'stank-': [('stank', True)],
          'stankar': [('stanke', False)],
          'stankarna': [('stankar', False)],
          'stankarnas': [('stankar', False)],
          'stankars': [('stanke', False)],
          'stanke': [('stanke', False)],
          'stanke-': [('stanke', False)],
          'stanken': [('stank', True)],
          'stankens': [('stank', True)],
          'stanker': [('stank', True)],
          'stankerna': [('stank', True)],
          'stankernas': [('stank', True)],
          'stankers': [('stank', True)],
          'stanks': [('stank', True)],
          'stanks-': [('stank', True)],
          'stans': [('stans', True), ('stad', True)],
          'stans-': [('stans', True)],
          'stant-': [('stant', False)],
          'stants': [('stant', False)],
          'star': [('stare', True), ('star', True)],
          'star-': [('star', True), ('stare', True)],
          'staren': [('stare', False)],
          'starna': [('st', False)],
          'stars': [('star', True), ('stare', True)],
          'stars-': [('stare', False)],
          'starter': [('starter', True), ('start', True)],
          'starterna': [('starter', True), ('start', True)],
          'starternas': [('starter', True), ('start', True)],
          'starters': [('starter', True), ('start', True)],
          'starven': [('starv', False)],
          'stas': [('stas', False)],
          'stas-': [('stas', False)],
          'stasen': [('stas', True)],
          'stasens': [('stas', False)],
          'stat': [('stat', False)],
          'statar': [('statare', True)],
          'statar-': [('statare', True)],
          'stataren': [('statare', True)],
          'statarens': [('statare', True)],
          'statistiker': [('statistiker', True), ('statistik', True)],
          'statistikerna': [('statistiker', True), ('statistik', True)],
          'statistikernas': [('statistiker', True), ('statistik', True)],
          'statistikers': [('statistiker', True), ('statistik', True)],
          'stator': [('stator', True)],
          'stators': [('stator', True)],
          'statron': [('statro', False)],
          'stats': [('stat', False)],
          'stavar': [('stav', False)],
          'stavarna': [('stav', True)],
          'stavarnas': [('stav', False)],
          'staverna': [('stav', False)],
          'stavernas': [('stav', False)],
          'stax': [('staxa', False)],
          'stax-': [('staxa', False)],
          'stdags': [('stdags', False)],
          'stdags-': [('stdags', False)],
          'stdropps-': [('stdroppar', False)],
          'ste': [('sta', False)],
          'ste-': [('sta', False)],
          'steaters': [('steater', False)],
          'stedags': [('stedag', False)],
          'steg': [('stege', True), ('steg', True)],
          'steg-': [('stege', True), ('steg', True)],
          'stegar': [('stege', False)],
          'stegarna': [('stege', False)],
          'stegarnas': [('stege', False)],
          'stegars': [('stege', False)],
          'stegen': [('stege', True), ('steg', True)],
          'stegens': [('stege', True), ('steg', True)],
          'steglits': [('steglits', True), ('steglitsa', True)],
          'steglits-': [('steglitsa', True), ('steglits', True)],
          'stegs': [('steg', True), ('stege', True)],
          'stegs-': [('stege', True), ('steg', True)],
          'stekar': [('stekare', True), ('stek', True)],
          'stekarna': [('stekare', True), ('stek', True)],
          'stekarnas': [('stekare', True), ('stek', True)],
          'stekniker': [('stekniker', False)],
          'steknikerna': [('stekniker', False)],
          'steknikernas': [('stekniker', False)],
          'steknikers': [('stekniker', False)],
          'stel': [('stele', True)],
          'stel-': [('stele', True)],
          'stellan': [('stellan', False)],
          'steln': [('stel', False)],
          'stelns': [('stel', False)],
          'stels': [('stele', True)],
          'stels-': [('stele', True)],
          'steman': [('steman', False)],
          'stemans': [('steman', False)],
          'sten': [('sten', True)],
          'stenbit': [('stenbit', True)],
          'stenrös': [('stenröse', True), ('stenrös', True)],
          'stenrös-': [('stenröse', True), ('stenrös', True)],
          'stenrösen': [('stenrös', True), ('stenröse', True)],
          'stenrösens': [('stenröse', True), ('stenrös', True)],
          'stenröset': [('stenröse', True), ('stenrös', True)],
          'stenrösets': [('stenrös', True), ('stenröse', True)],
          'stens': [('sten', True)],
          'stens-': [('sten', False)],
          'stenskvätt': [('stenskvätta', True)],
          'stenterna': [('stent', False)],
          'ster': [('st', False)],
          'ster-': [('ster', False)],
          'steranden': [('sterande', False)],
          'sterandens': [('sterande', False)],
          'sterhak': [('sterhaka', False)],
          'sterhak-': [('sterhaka', False)],
          'sterhake': [('sterhake', False)],
          'sterhaks': [('sterhaka', False)],
          'sterhaks-': [('sterhake', False)],
          'sterian': [('steria', False)],
          'sterians': [('steria', False)],
          'sterie': [('sterium', False)],
          'sterie-': [('steria', False)],
          'sterien': [('steri', False)],
          'steriernas': [('steri', False)],
          'steriets': [('steri', False)],
          'sterin': [('sterin', True)],
          'sterins': [('sterin', True)],
          'sterits': [('steri', False)],
          'stermin': [('stermin', False)],
          'stern': [('ster', False)],
          'sterna': [('st', False)],
          'sternas': [('st', False)],
          'sterns': [('ster', False)],
          'sterorden': [('sterorden', False)],
          'sterordens': [('sterorden', False)],
          'sters': [('st', False)],
          'sters-': [('ster', False)],
          'stersen': [('ster', False)],
          'stersens': [('ster', False)],
          'stervar': [('stervar', False)],
          'stes': [('ste', False)],
          'stes-': [('ste', False)],
          'stestens': [('stest', False)],
          'stet': [('st', False)],
          'steters': [('stet', False)],
          'stets': [('ste', False)],
          'stfiskar': [('stfiskare', False)],
          'stfiskarna': [('stfisk', False)],
          'stfiskarnas': [('stfiskare', False)],
          'sthandlarnas': [('sthandlare', False)],
          'sthet': [('sthet', False)],
          'sthets': [('sthet', False)],
          'sti': [('stia', False)],
          'sti-': [('stia', False)],
          'stian': [('stia', False)],
          'stians': [('stia', True)],
          'stias': [('stia', True)],
          'stick': [('sticka', True), ('stick', True)],
          'stick-': [('stick', True), ('sticka', True)],
          'sticks': [('stick', True), ('sticka', True)],
          'sticks-': [('stick', True), ('sticka', True)],
          'stidar': [('stidag', False)],
          'stiden': [('stid', False)],
          'stider': [('stid', False)],
          'stiderna': [('stid', False)],
          'stiders': [('stid', False)],
          'stigar': [('stig', False)],
          'stigarna': [('stig', False)],
          'stigarnas': [('stig', False)],
          'stige': [('stige', False)],
          'stigen': [('stig', False)],
          'stigens': [('stig', False)],
          'stighets': [('stighet', False)],
          'stigman': [('stigma', True), ('stigman', True)],
          'stigmans': [('stigma', True), ('stigman', True)],
          'stik': [('stik', False)],
          'stik-': [('stik', False)],
          'stiker': [('stik', False)],
          'stikerna': [('stik', False)],
          'stikernas': [('stik', False)],
          'stikers': [('stik', False)],
          'stiks': [('stik', False)],
          'stiks-': [('stik', False)],
          'stilen': [('stil', False)],
          'stilens': [('stil', False)],
          'still': [('stilla', False)],
          'still-': [('stilla', False)],
          'stillgångar': [('stillgångar', False)],
          'stillgångarna': [('stillgångar', False)],
          'stillgångarnas': [('stillgång', False)],
          'stillgångars': [('stillgångar', False)],
          'stillgångs': [('stillgångar', False)],
          'stillgångs-': [('stillgång', False)],
          'stillhörigheter': [('stillhörighet', False)],
          'stillhörigheterna': [('stillhörighet', False)],
          'stillhörigheternas': [('stillhörighet', False)],
          'stillhörigheters': [('stillhörighet', False)],
          'stillhörighets': [('stillhörighet', False)],
          'stillhörighets-': [('stillhörighet', False)],
          'stills': [('stilla', False)],
          'stills-': [('stilla', False)],
          'stim': [('stim', False)],
          'stim-': [('stim', True)],
          'stimmarna': [('stimme', False)],
          'stimmen': [('stim', True)],
          'stimmens': [('stim', True)],
          'stims': [('stim', False)],
          'stims-': [('stim', False)],
          'stin': [('sti', False)],
          'stinne': [('stinna', False)],
          'stins': [('stins', True)],
          'stins-': [('stins', True)],
          'stint': [('stinta', False)],
          'stions-': [('stion', False)],
          'stior': [('stia', False)],
          'stippar': [('stipp', False)],
          'stipparna': [('stipp', False)],
          'stipparnas': [('stipp', False)],
          'stis-': [('stia', False)],
          'stit': [('stit', False)],
          'stit-': [('stit', False)],
          'stits': [('stit', False)],
          'stitutet': [('stitut', False)],
          'stjärn': [('stjärna', True), ('stjärn', True)],
          'stjärn-': [('stjärn', True), ('stjärna', True)],
          'stjärnorna': [('stjärna', False)],
          'stjärnornas': [('stjärna', False)],
          'stjärns': [('stjärn', True), ('stjärna', True)],
          'stjärns-': [('stjärna', True), ('stjärn', True)],
          'stlandet': [('stland', False)],
          'stlar': [('stel', False)],
          'stlarna': [('stel', False)],
          'stlarnas': [('stel', False)],
          'stlernas': [('stel', False)],
          'stman': [('stma', False)],
          'stmans': [('stman', False)],
          'stmask': [('stmask', False)],
          'stmask-': [('stmask', False)],
          'stmaster': [('stmaster', False)],
          'sto-': [('sto', False)],
          'stoden': [('stod', False)],
          'stodens': [('stod', False)],
          'stok': [('stok', False)],
          'stok-': [('stok', False)],
          'stoks': [('stok', False)],
          'stoks-': [('stok', False)],
          'stol': [('stola', True), ('stol', True)],
          'stol-': [('stola', True), ('stol', True)],
          'stolan': [('stola', True)],
          'stolans': [('stola', True)],
          'stole': [('stola', True)],
          'stole-': [('stola', True)],
          'stolen': [('stol', False)],
          'stolens': [('stol', False)],
          'stolkar': [('stolk', False)],
          'stolkarna': [('stolk', False)],
          'stolkarnas': [('stolk', False)],
          'stoll': [('stolla', True), ('stoll', True), ('stolle', True)],
          'stoll-': [('stolle', True), ('stoll', True), ('stolla', True)],
          'stollar': [('stolle', True), ('stoll', True)],
          'stollarna': [('stoll', True), ('stolle', True)],
          'stollarnas': [('stoll', True), ('stolle', True)],
          'stollars': [('stoll', True), ('stolle', True)],
          'stolle': [('stolla', True), ('stolle', True)],
          'stollen': [('stoll', True), ('stolle', True)],
          'stollens': [('stoll', True), ('stolle', True)],
          'stolls': [('stoll', True), ('stolla', True), ('stolle', True)],
          'stolls-': [('stolle', True), ('stolla', True), ('stoll', True)],
          'stols': [('stola', True), ('stol', True)],
          'stols-': [('stola', True), ('stol', True)],
          'stom': [('stomme', True)],
          'stom-': [('stomme', True)],
          'stoms': [('stomme', True)],
          'stoms-': [('stomme', False)],
          'stomtens': [('stomt', False)],
          'ston': [('sto', True)],
          'stoner': [('ston', False)],
          'stonerna': [('ston', False)],
          'stonernas': [('ston', False)],
          'stoners': [('ston', False)],
          'stons': [('sto', False)],
          'stonvals': [('stonvals', False)],
          'stonvals-': [('stonvals', False)],
          'stoppar': [('stopp', True)],
          'stopparna': [('stopp', True)],
          'stopparnas': [('stopp', False)],
          'stops': [('stop', True)],
          'stops-': [('stop', True)],
          'stor': [('stor', True)],
          'storanden': [('storande', False)],
          'storandens': [('storande', False)],
          'storden': [('storden', False)],
          'stordens': [('storden', False)],
          'storebrors': [('storebror', True), ('storebrorsa', True)],
          'storen': [('store', True), ('stor', True)],
          'storens': [('store', True), ('stor', True)],
          'storer': [('store', True)],
          'storerna': [('store', True)],
          'storernas': [('store', True)],
          'storers': [('store', True)],
          'storian': [('storia', False)],
          'storians': [('storia', False)],
          'storiet': [('storium', False)],
          'stork': [('stork', False)],
          'stork-': [('stork', True)],
          'storkarnas': [('stork', False)],
          'stormar': [('storm', True)],
          'stormarna': [('storm', True)],
          'stormarnas': [('storm', True)],
          'storn': [('stor', False)],
          'storna': [('sta', False)],
          'stornas': [('sta', False)],
          'storns': [('stor', False)],
          'stors': [('stor', True)],
          'stort': [('stort', False)],
          'storts': [('stort', False)],
          'storts-': [('stort', False)],
          'storv': [('storv', False)],
          'storv-': [('storva', False)],
          'storvs-': [('storv', False)],
          'stos': [('sto', False)],
          'stos-': [('sto', False)],
          'stra': [('stra', False)],
          'stran': [('stra', False)],
          'stranden': [('strand', False)],
          'strandens': [('strand', False)],
          'strans-': [('stran', False)],
          'strapp': [('strappa', False)],
          'strapp-': [('strappa', False)],
          'strapps': [('strappa', False)],
          'strapps-': [('strappa', False)],
          'strar': [('ster', False)],
          'strarna': [('ster', False)],
          'strars': [('ster', False)],
          'stras': [('stra', False)],
          'stras-': [('stras', False)],
          'stratt': [('stratt', False)],
          'stratts': [('stratt', False)],
          'stratts-': [('stratt', False)],
          'streamer': [('streamer', True)],
          'streamers': [('streamer', True)],
          'strems': [('stremsa', False)],
          'stren': [('ster', False)],
          'strer': [('ster', False)],
          'strerna': [('ster', False)],
          'strernas': [('ster', False)],
          'stressen': [('stress', False)],
          'stressens': [('stress', False)],
          'stretanden': [('stretande', True)],
          'stretandens': [('stretande', True)],
          'strets': [('ster', False)],
          'stricks': [('strick', False)],
          'stricks-': [('strick', False)],
          'stridskrafts': [('stridskrafter', True), ('stridskraft', True)],
          'stridskrafts-': [('stridskrafter', True), ('stridskraft', True)],
          'strier': [('stri', False)],
          'strierna': [('stri', False)],
          'striers': [('stri', False)],
          'strig': [('striga', True)],
          'strig-': [('striga', True)],
          'strigs': [('striga', True)],
          'strigs-': [('striga', True)],
          'strik': [('strike', False)],
          'strik-': [('strike', False)],
          'striken': [('strike', False)],
          'strikens': [('strike', False)],
          'striks': [('strike', False)],
          'striktioner': [('striktion', True)],
          'striktionerna': [('striktion', True)],
          'striktionernas': [('striktion', True)],
          'striktioners': [('striktion', True)],
          'striktions': [('striktion', True)],
          'striktions-': [('striktion', False)],
          'strilandet': [('strilande', True)],
          'strilandets': [('strilande', True)],
          'strim': [('strimma', False)],
          'strim-': [('strimma', False)],
          'strims': [('strimma', False)],
          'strims-': [('strimma', False)],
          'stringar': [('string', False)],
          'stringars': [('string', False)],
          'stringens': [('stringens', True)],
          'strins': [('stri', False)],
          'strion': [('strion', False)],
          'strions': [('strion', False)],
          'strip': [('stripa', True)],
          'stripp': [('strippa', True), ('stripp', True)],
          'stripp-': [('strippa', True), ('stripp', True)],
          'strippar': [('stripp', False)],
          'stripparna': [('stripp', False)],
          'stripps': [('strippa', True), ('stripp', True)],
          'stripps-': [('strippa', True), ('stripp', True)],
          'strips': [('stripa', True)],
          'strips-': [('stripa', True)],
          'stris': [('stri', False)],
          'stron': [('stro', False)],
          'stron-': [('stron', False)],
          'strone': [('strone', False)],
          'strone-': [('strone', False)],
          'stronen': [('strone', False)],
          'stronens': [('strone', False)],
          'strons': [('stro', False)],
          'stror': [('stra', False)],
          'stros': [('stro', False)],
          'stros-': [('stro', False)],
          'strots': [('strot', False)],
          'strots-': [('strot', False)],
          'strulls': [('strull', False)],
          'strulls-': [('strull', False)],
          'struls': [('strul', True)],
          'struls-': [('strul', True)],
          'strum': [('strum', False)],
          'strum-': [('strumma', False)],
          'strums': [('strumma', False)],
          'strums-': [('strum', False)],
          'strun': [('struna', False)],
          'struns': [('struna', False)],
          'strus': [('stru', False)],
          'strus-': [('stru', False)],
          'struts': [('struts', True), ('strut', True)],
          'struts-': [('struts', True), ('strut', True)],
          'strycken': [('stryck', False)],
          'stryckens': [('stryck', False)],
          'strycket': [('stryck', False)],
          'stryckets': [('stryck', False)],
          'strycks': [('stryck', False)],
          'strycks-': [('stryck', False)],
          'strykbräde': [('strykbräde', True), ('strykbräda', True)],
          'sträck': [('sträcka', True), ('sträck', True)],
          'sträck-': [('sträcka', True), ('sträck', True)],
          'sträcke': [('sträcka', False)],
          'sträcken': [('sträck', True)],
          'sträckens': [('sträck', False)],
          'sträcket': [('sträck', False)],
          'sträcks': [('sträcka', True), ('sträck', True)],
          'sträcks-': [('sträcka', True), ('sträck', True)],
          'sträd': [('sträd', False)],
          'sträd-': [('sträd', False)],
          'sträden': [('sträd', False)],
          'strädens': [('sträd', False)],
          'strädet': [('sträd', False)],
          'strädets': [('sträd', False)],
          'sträds': [('sträd', False)],
          'sträds-': [('sträd', False)],
          'strän': [('sträd', False)],
          'sträna': [('strä', False)],
          'stränas': [('strä', False)],
          'sträns': [('sträd', False)],
          'strät': [('strä', False)],
          'sträts': [('strä', False)],
          'strävan': [('sträva', True), ('strävan', True)],
          'strävans': [('sträva', True), ('strävan', True)],
          'strävar': [('strävare', False)],
          'strävar-': [('strävare', False)],
          'strävs': [('sträva', True)],
          'strävs-': [('sträva', True)],
          'stråk': [('stråke', True), ('stråk', True)],
          'stråk-': [('stråke', True), ('stråk', True)],
          'stråkar': [('stråke', True)],
          'stråkarna': [('stråke', False)],
          'stråkarnas': [('stråke', True)],
          'stråkars': [('stråke', True)],
          'stråken': [('stråke', True), ('stråk', True)],
          'stråkens': [('stråk', True), ('stråke', True)],
          'stråks': [('stråke', True), ('stråk', True)],
          'stråks-': [('stråke', True), ('stråk', True)],
          'strål': [('stråle', False)],
          'strål-': [('stråle', True)],
          'strålar': [('stråle', False)],
          'strålarna': [('stråle', False)],
          'strålarnas': [('stråle', True)],
          'strålars': [('stråle', False)],
          'strålen': [('stråle', False)],
          'strålens': [('stråle', False)],
          'stråls': [('stråle', False)],
          'stråls-': [('stråle', False)],
          'strån': [('strå', True)],
          'stråns': [('strå', True)],
          'stråt': [('stråt', True), ('strå', True)],
          'stråts': [('stråt', True), ('strå', True)],
          'strömmen': [('ström', False)],
          'sts': [('st', False)],
          'stskatt': [('stskatt', False)],
          'stskatt-': [('stskatt', False)],
          'stskatte': [('stskatt', False)],
          'stskatte-': [('stskatt', False)],
          'stskatts': [('stskatt', False)],
          'stskeden': [('stsked', False)],
          'stskedens': [('stsked', False)],
          'stskjuts-': [('stskjuts', False)],
          'stskris': [('stskri', False)],
          'stspads-': [('stspade', False)],
          'stströmmen': [('stström', False)],
          'stsäden': [('stsäd', False)],
          'stsädens': [('stsäd', False)],
          'stsädes-': [('stsäd', False)],
          'sttidens': [('sttid', False)],
          'stton': [('stton', False)],
          'sttons': [('stton', False)],
          'stträn': [('stträ', False)],
          'stträna': [('stträ', False)],
          'stträns': [('stträ', False)],
          'sttysk': [('sttysk', False)],
          'sttysk-': [('sttysk', False)],
          'stub': [('stub', False)],
          'stubb': [('stubbe', True), ('stubb', True)],
          'stubb-': [('stubb', True), ('stubbe', True)],
          'stubbar': [('stubb', True), ('stubbe', True)],
          'stubbarna': [('stubbe', True), ('stubb', True)],
          'stubbarnas': [('stubbe', True), ('stubb', True)],
          'stubbars': [('stubbe', True), ('stubb', True)],
          'stubben': [('stubbe', True), ('stubb', True)],
          'stubbens': [('stubbe', True), ('stubb', True)],
          'stubbs': [('stubbe', True), ('stubb', True)],
          'stubbs-': [('stubbe', True), ('stubb', True)],
          'stubs': [('stub', False)],
          'stubs-': [('stub', False)],
          'studie': [('studium', True), ('studie', True)],
          'studie-': [('studie', True), ('studium', True)],
          'studier': [('studie', True), ('studium', True)],
          'studierna': [('studium', True), ('studie', True)],
          'studiernas': [('studie', True), ('studium', True)],
          'studiers': [('studium', True), ('studie', True)],
          'studsar': [('studs', True), ('studsare', True)],
          'studsarna': [('studs', True), ('studsare', True)],
          'studsarnas': [('studs', True), ('studsare', True)],
          'stug-': [('stuga', True)],
          'stullar': [('stull', False)],
          'stullarna': [('stull', False)],
          'stullarnas': [('stull', False)],
          'stump': [('stumpa', True), ('stump', True)],
          'stump-': [('stumpa', True), ('stump', True)],
          'stumps': [('stumpa', True), ('stump', True)],
          'stumps-': [('stumpa', True), ('stump', True)],
          'stun': [('stu', False)],
          'stundan': [('stundan', False)],
          'stunge': [('stunge', False)],
          'stunge-': [('stunge', False)],
          'stungen': [('stunge', False)],
          'stungens': [('stunge', False)],
          'stuns': [('stuns', True)],
          'stuns-': [('stuns', True)],
          'stup': [('stupa', True), ('stup', True)],
          'stup-': [('stupa', True), ('stup', True)],
          'stupor': [('stupa', True), ('stupor', True)],
          'stupors': [('stupor', True), ('stupa', True)],
          'stups': [('stupa', True), ('stup', True)],
          'stups-': [('stupa', True), ('stup', True)],
          'stur': [('stur', False)],
          'sturer': [('stur', False)],
          'sturerna': [('stur', False)],
          'sturers': [('stur', False)],
          'sturs': [('stur', False)],
          'sturs-': [('stur', False)],
          'stut': [('stut', True)],
          'stut-': [('stut', True)],
          'stuts': [('stut', True)],
          'stuts-': [('stut', True)],
          'stuv': [('stuv', True)],
          'stuv-': [('stuv', True)],
          'stuvar': [('stuv', True), ('stuvare', True)],
          'stuvarna': [('stuv', True), ('stuvare', True)],
          'stuvarnas': [('stuv', True), ('stuvare', True)],
          'stuvs': [('stuv', True)],
          'stuvs-': [('stuv', True)],
          'stvind': [('stvind', False)],
          'stvinds': [('stvinda', False)],
          'stvinds-': [('stvinda', False)],
          'styck': [('styck', True), ('stycke', True)],
          'styck-': [('styck', True), ('stycke', True)],
          'stycken': [('styck', True), ('stycke', True)],
          'styckena': [('styck', True), ('stycke', True)],
          'styckenas': [('styck', True), ('stycke', True)],
          'styckens': [('styck', True), ('stycke', True)],
          'stycket': [('styck', True), ('stycke', True)],
          'styckets': [('styck', True), ('stycke', True)],
          'stycks': [('styck', True), ('stycke', True)],
          'stylen': [('style', False)],
          'stylens': [('styl', False)],
          'stypen': [('styp', False)],
          'stypens': [('styp', False)],
          'styper': [('styp', False)],
          'styperna': [('styp', False)],
          'stypernas': [('styp', False)],
          'stypers': [('styp', False)],
          'styr': [('styr', False)],
          'styr-': [('styr', True)],
          'styren': [('styre', True), ('styren', True)],
          'styrens': [('styre', True), ('styren', True)],
          'styret': [('styre', True)],
          'styrets': [('styre', True)],
          'styrkan': [('styrka', True)],
          'styrkans': [('styrka', True)],
          'styrke': [('styrka', True)],
          'styrs': [('styr', False)],
          'styrs-': [('styr', False)],
          'ställanden': [('ställande', True)],
          'ställandena': [('ställande', True)],
          'ställandenas': [('ställande', True)],
          'ställandens': [('ställande', True)],
          'ställen': [('ställ', True), ('ställe', True)],
          'ställens': [('ställe', True), ('ställ', True)],
          'stället': [('ställe', True), ('ställ', True)],
          'ställets': [('ställ', True), ('ställe', True)],
          'ställningar': [('ställningar', True), ('ställning', True)],
          'ställningarna': [('ställningar', True), ('ställning', True)],
          'ställningarnas': [('ställning', True), ('ställningar', True)],
          'ställningars': [('ställningar', True), ('ställning', True)],
          'ställnings': [('ställningar', True), ('ställning', True)],
          'ställnings-': [('ställningar', True), ('ställning', True)],
          'ständar': [('ständare', False)],
          'ständer': [('stånd', True)],
          'ständerna': [('stånd', True)],
          'ständernas': [('stånd', True)],
          'ständers': [('stånd', True)],
          'stängar': [('stängare', False)],
          'stängen': [('stänge', True)],
          'stänger': [('stång', False)],
          'stängerna': [('stång', False)],
          'stängernas': [('stång', False)],
          'stängers': [('stång', False)],
          'stängs': [('stänge', True)],
          'stängs-': [('stänge', True)],
          'stänk': [('stänk', True)],
          'stänk-': [('stänk', True)],
          'stänks': [('stänk', True)],
          'stänks-': [('stänk', True)],
          'stäpp': [('stäpp', True)],
          'stäpp-': [('stäpp', True)],
          'stäpps': [('stäpp', True)],
          'stäpps-': [('stäpp', True)],
          'stäten': [('stät', False)],
          'stätens': [('stät', False)],
          'stäv': [('stäva', True), ('stäv', True)],
          'stäv-': [('stäva', True), ('stäv', True)],
          'stävs': [('stäva', True), ('stäv', True)],
          'stävs-': [('stäva', True), ('stäv', True)],
          'ståg': [('ståg', False)],
          'stågs': [('ståg', False)],
          'stågs-': [('ståg', False)],
          'stång': [('stång', False)],
          'stång-': [('stång', False)],
          'stången': [('stång', False)],
          'stångens': [('stång', False)],
          'stångs': [('stång', False)],
          'stångs-': [('stång', False)],
          'stånk': [('stånka', True), ('stånk', True)],
          'stånk-': [('stånka', True), ('stånk', True)],
          'stånks': [('stånka', True), ('stånk', True)],
          'stånks-': [('stånka', True), ('stånk', True)],
          'står': [('står', False)],
          'stårs': [('stå', False)],
          'stårs-': [('står', False)],
          'stön': [('stön', True)],
          'stöns': [('stön', True)],
          'störar': [('stör', True)],
          'störarna': [('stör', False)],
          'störarnas': [('stör', False)],
          'stös': [('stö', False)],
          'stös-': [('stö', False)],
          'stöt': [('stöt', False)],
          'stötar': [('stöt', False)],
          'stötarna': [('stöt', False)],
          'stötarnas': [('stöt', True)],
          'stöts': [('stöt', True)],
          'stövel': [('stövel', True)],
          'stövel-': [('stövel', False)],
          'stövels': [('stövel', False)],
          'stövels-': [('stövel', False)],
          'stövlar': [('stövel', False)],
          'stövlarna': [('stövel', False)],
          'stövlarnas': [('stövel', False)],
          'stövlars': [('stövel', True)],
          'su': [('su', False)],
          'su-': [('su', False)],
          'suar': [('suar', False)],
          'suar-': [('suar', False)],
          'suaren': [('suar', False)],
          'suarens': [('suar', False)],
          'suarie': [('suarium', False)],
          'suarierna': [('suarium', False)],
          'suariers': [('suarium', False)],
          'subb': [('subba', True)],
          'subb-': [('subba', True)],
          'subbe': [('subba', True)],
          'subbe-': [('subba', True)],
          'subbor': [('subba', True)],
          'subborna': [('subba', True)],
          'subbornas': [('subba', True)],
          'subbors': [('subba', True)],
          'subbs-': [('subba', True)],
          'suck': [('suck', False)],
          'suck-': [('suck', True)],
          'suckan': [('suckan', True)],
          'suckans': [('suckan', True)],
          'suckar': [('suck', False)],
          'suckarna': [('suck', False)],
          'sucks': [('suck', True)],
          'sucks-': [('suck', False)],
          'sudd': [('sudd', False)],
          'sudd-': [('sudd', True)],
          'suddar': [('sudd', False)],
          'suddarna': [('sudd', False)],
          'suddarnas': [('sudd', True)],
          'suddars': [('sudd', False)],
          'sudden': [('sudd', False)],
          'suddens': [('sudd', False)],
          'sudds': [('sudd', False)],
          'sudds-': [('sudd', False)],
          'sug': [('sug', True)],
          'sug-': [('sug', False)],
          'sugar': [('sug', True)],
          'sugarna': [('sug', True)],
          'sugarnas': [('sug', True)],
          'sugets': [('sug', False)],
          'sugg': [('sugga', True)],
          'sugge': [('sugga', False)],
          'suggs': [('sugga', False)],
          'suggs-': [('sugga', True)],
          'sugs-': [('sug', False)],
          'sul': [('sula', True)],
          'sul-': [('sula', True)],
          'sula': [('sula', False)],
          'sulan': [('sula', False)],
          'sulans': [('sula', False)],
          'sulas': [('sula', False)],
          'sulinets': [('sulin', False)],
          'sull': [('sull', False)],
          'sulls': [('sull', False)],
          'sulls-': [('sull', False)],
          'suls': [('sula', True)],
          'suls-': [('sula', True)],
          'sult-': [('sult', False)],
          'sultan': [('sultan', True)],
          'sultans': [('sultan', True)],
          'sulten': [('sult', False)],
          'sultens': [('sult', False)],
          'sulter': [('sult', False)],
          'sults': [('sult', False)],
          'sults-': [('sult', False)],
          'suman': [('suma', False)],
          'sumer': [('sumer', True)],
          'sumerer': [('sumerer', True), ('sumer', True)],
          'sumererna': [('sumerer', True), ('sumer', True)],
          'sumerernas': [('sumerer', True), ('sumer', True)],
          'sumerers': [('sumerer', True), ('sumer', True)],
          'sumers': [('sumer', True)],
          'summe': [('summa', False)],
          'summe-': [('summa', False)],
          'sump': [('sump', False)],
          'sump-': [('sump', False)],
          'sumps': [('sump', False)],
          'sumps-': [('sump', False)],
          'sun': [('sun', False)],
          'sund': [('sund', True)],
          'sund-': [('sund', True)],
          'sunds': [('sund', True)],
          'sunds-': [('sund', True)],
          'sunk': [('sunk', True)],
          'sunk-': [('sunk', True)],
          'sunks': [('sunk', True)],
          'sunks-': [('sunk', True)],
          'sunnan': [('sunnan', True)],
          'sunnans': [('sunnan', True)],
          'suns': [('sun', False)],
          'suns-': [('sun', False)],
          'supar': [('supare', True), ('sup', True)],
          'suparna': [('supare', True), ('sup', True)],
          'suparnas': [('supare', True), ('sup', True)],
          'supiner': [('supinum', True)],
          'supinerna': [('supinum', True)],
          'supinernas': [('supinum', True)],
          'supiners': [('supinum', True)],
          'sur': [('sura', True)],
          'sur-': [('sura', True)],
          'suran': [('sura', True)],
          'surans': [('sura', True)],
          'surans-': [('surans', False)],
          'sure': [('sura', True)],
          'surfar': [('surfare', True)],
          'surfarnas': [('surfare', False)],
          'surfbräde': [('surfbräda', True), ('surfbräde', True)],
          'surfingbräde': [('surfingbräde', True), ('surfingbräda', True)],
          'surie': [('surium', False)],
          'surie-': [('surium', False)],
          'surier': [('surium', False)],
          'surierna': [('surium', False)],
          'suriernas': [('surium', False)],
          'surn': [('sur', False)],
          'surns': [('sur', False)],
          'surr': [('surr', True)],
          'surr-': [('surr', True)],
          'surren': [('surr', False)],
          'surrens': [('surr', False)],
          'surrs': [('surr', False)],
          'surrs-': [('surr', False)],
          'surs': [('sura', True)],
          'surs-': [('sura', True)],
          'surskris': [('surskris', False)],
          'sus': [('sus', True)],
          'susarnas': [('sus', False)],
          'sutans': [('sutan', True)],
          'sutar': [('sutare', True)],
          'sutarna': [('sutare', True)],
          'sutarnas': [('sutare', True)],
          'sutsago': [('sutsaga', False)],
          'sutsago-': [('sutsaga', False)],
          'suturer': [('sutur', True)],
          'suturerna': [('sutur', True)],
          'suturernas': [('sutur', True)],
          'svabbar': [('svabb', True)],
          'svabbarna': [('svabb', True)],
          'svabbarnas': [('svabb', True)],
          'svacks-': [('svacka', True)],
          'svaj': [('svaj', True)],
          'svaj-': [('svaj', True)],
          'svajs': [('svaj', True)],
          'svak': [('svaka', False)],
          'svak-': [('svak', False)],
          'svakans': [('svaka', False)],
          'svakar': [('svak', False)],
          'svakarna': [('svak', False)],
          'svakarnas': [('svak', False)],
          'svaks': [('svaka', False)],
          'svaks-': [('svak', False)],
          'sval': [('svale', True), ('svala', True), ('sval', True)],
          'sval-': [('svala', True), ('sval', True), ('svale', True)],
          'svalar': [('svale', True), ('sval', True)],
          'svalarna': [('svale', True), ('sval', True)],
          'svalarnas': [('sval', True), ('svale', True)],
          'svalars': [('svale', True), ('sval', True)],
          'svale': [('svale', True), ('svala', True)],
          'svalen': [('svale', True), ('sval', True)],
          'svalens': [('svale', True), ('sval', True)],
          'svallar': [('svall', False)],
          'svallarna': [('svall', False)],
          'svallarnas': [('svall', False)],
          'svalls-': [('svall', False)],
          'svals': [('svale', True), ('svala', True), ('sval', True)],
          'svals-': [('svala', True), ('svale', True), ('sval', True)],
          'svan': [('svan', False)],
          'svana': [('svana', False)],
          'svanas': [('svana', False)],
          'svane': [('svana', False)],
          'svane-': [('svana', False)],
          'svanen': [('svan', False)],
          'svankar': [('svank', True)],
          'svankarna': [('svank', True)],
          'svanor': [('svan', True)],
          'svanorna': [('svan', True)],
          'svanornas': [('svan', True)],
          'svanors': [('svan', True)],
          'svans': [('svan', True), ('svans', True)],
          'svans-': [('svans', True), ('svan', True)],
          'svantar': [('svantar', False)],
          'svantarna': [('svantar', False)],
          'svantarnas': [('svantar', False)],
          'svantars': [('svantar', False)],
          'svante': [('svantar', False)],
          'svar': [('svar', True)],
          'svar-': [('svara', False)],
          'svaran': [('svara', False)],
          'svarans': [('svara', False)],
          'svarar': [('svar', False)],
          'svararna': [('svar', False)],
          'svararnas': [('svar', False)],
          'svard': [('svard', False)],
          'svard-': [('svard', False)],
          'svarden': [('svard', False)],
          'svardens': [('svard', False)],
          'svards': [('svard', False)],
          'svards-': [('svard', False)],
          'svarens': [('svar', False)],
          'svars': [('svar', False)],
          'svarvar': [('svarvare', True), ('svarv', True)],
          'svarvarna': [('svarvare', True), ('svarv', True)],
          'svarvarnas': [('svarvare', True), ('svarv', True)],
          'svas': [('svase', False)],
          'svas-': [('svase', False)],
          'svasen': [('svase', False)],
          'svasens': [('svase', False)],
          'svatten': [('svatten', False)],
          'svear': [('svear', True)],
          'svearna': [('svear', True)],
          'sveck': [('svecka', False)],
          'sveck-': [('svecka', False)],
          'svecks': [('svecka', False)],
          'svecks-': [('svecka', False)],
          'svek': [('svek', True)],
          'svek-': [('svek', True)],
          'sveken': [('svek', True)],
          'svekens': [('svek', True)],
          'sveks': [('svek', True)],
          'sveks-': [('svek', True)],
          'sven': [('sven', True)],
          'svennar': [('svenne', True)],
          'svennarna': [('svenne', True)],
          'svennarnas': [('svenne', True)],
          'svennars': [('svenne', True)],
          'svennen': [('svenne', True), ('sven', True)],
          'svennens': [('sven', True), ('svenne', True)],
          'svens': [('sven', False)],
          'svens-': [('sven', False)],
          'svensk': [('svenska', True), ('svensk', True)],
          'svensk-': [('svenska', True), ('svensk', True)],
          'svep': [('svep', True)],
          'svep-': [('svep', True)],
          'svepe': [('svepe', True)],
          'svepen': [('svepe', True), ('svep', True)],
          'svepens': [('svepe', True), ('svep', True)],
          'svepet': [('svep', True), ('svepe', True)],
          'svepets': [('svepe', True), ('svep', True)],
          'sveps': [('svep', True), ('svepe', True)],
          'sveps-': [('svep', True), ('svepe', True)],
          'sverben': [('sverb', False)],
          'sverbens': [('sverb', False)],
          'sverkets': [('sverk', False)],
          'svers': [('svers', False)],
          'svets': [('svets', False)],
          'svets-': [('svets', True)],
          'svetsar': [('svetsare', True), ('svets', True)],
          'svetsarna': [('svetsare', True), ('svets', True)],
          'svetsarnas': [('svets', True), ('svetsare', True)],
          'svett': [('svett', False)],
          'svett-': [('svett', True)],
          'svetten': [('svett', False)],
          'svettens': [('svett', False)],
          'svetts': [('svett', False)],
          'svetts-': [('svett', False)],
          'svick': [('svicka', True), ('svick', True)],
          'svick-': [('svicka', True), ('svick', True)],
          'svicks': [('svicka', True), ('svick', True)],
          'svicks-': [('svicka', True)],
          'svid': [('svid', True)],
          'svid-': [('svid', True)],
          'sviden': [('svid', True)],
          'svidens': [('svid', True)],
          'svids': [('svid', True)],
          'svids-': [('svid', True)],
          'svikar': [('svikare', True)],
          'svikarna': [('svikare', True)],
          'svikarnas': [('svikare', True)],
          'sviks-': [('svik', False)],
          'sviktarnas': [('svikt', True)],
          'svills': [('svilla', False)],
          'svin': [('svin', False)],
          'svin-': [('svin', False)],
          'svind': [('svind', False)],
          'svindarnas': [('svind', False)],
          'svindlar': [('svindlare', True)],
          'svindlarna': [('svindlare', True)],
          'svindlarnas': [('svindlare', True)],
          'svinds': [('svind', False)],
          'svinds-': [('svind', False)],
          'sving': [('sving', True)],
          'sving-': [('sving', True)],
          'svingar': [('sving', True)],
          'svingarna': [('sving', True)],
          'svingarnas': [('sving', True)],
          'svingars': [('sving', True)],
          'svingen': [('sving', True)],
          'svingens': [('sving', True)],
          'svings': [('sving', False)],
          'svings-': [('sving', False)],
          'svinn': [('svinn', True)],
          'svins': [('svin', False)],
          'svins-': [('svin', False)],
          'svinsten': [('svinst', False)],
          'svinstens': [('svinst', False)],
          'sviol': [('sviol', False)],
          'sviol-': [('sviol', False)],
          'sviols': [('sviol', False)],
          'sviols-': [('sviol', False)],
          'svip': [('svipa', False)],
          'svip-': [('svipa', False)],
          'svips': [('svipa', False)],
          'svips-': [('svipa', False)],
          'svir': [('svir', True)],
          'svir-': [('svir', True)],
          'svirs': [('svir', True)],
          'svirs-': [('svir', True)],
          'svis': [('svisa', False)],
          'svis-': [('svisa', False)],
          'svisa': [('svisa', False)],
          'svisar': [('svisare', False)],
          'svisarna': [('svisare', False)],
          'svisarnas': [('svisare', False)],
          'svisas': [('svisa', False)],
          'svisch': [('svisch', True)],
          'svisch-': [('svisch', True)],
          'svise': [('svisa', False)],
          'svisor': [('svisa', False)],
          'svisors': [('svisa', False)],
          'svit': [('svit', False)],
          'svit-': [('svit', True)],
          'sviten': [('svit', False)],
          'svitens': [('svit', True)],
          'sviter': [('sviter', True), ('svit', True)],
          'sviterna': [('sviter', True), ('svit', True)],
          'sviternas': [('sviter', True), ('svit', True)],
          'sviters': [('sviter', True), ('svit', True)],
          'svits': [('svit', True)],
          'svits-': [('svit', False)],
          'svitsar': [('svits', False)],
          'svitsarna': [('svits', False)],
          'svitsarnas': [('svits', False)],
          'svivlar': [('svivel', True)],
          'svreden': [('svred', False)],
          'svredens': [('svred', False)],
          'svägar': [('sväg', False)],
          'svägarna': [('sväg', False)],
          'svägarnas': [('sväg', False)],
          'svägars': [('sväg', False)],
          'svägen': [('sväg', False)],
          'svägs': [('sväg', False)],
          'svägs-': [('sväg', False)],
          'svälden': [('svälde', False)],
          'sväldens': [('svälde', False)],
          'svält': [('svält', True)],
          'svält-': [('svält', True)],
          'svälts': [('svält', False)],
          'svälts-': [('svält', True)],
          'svände-': [('svända', False)],
          'svärden': [('svärd', False)],
          'svärdens': [('svärd', True)],
          'svärdet': [('svärd', True)],
          'svärdets': [('svärd', False)],
          'svärmar': [('svärm', True), ('svärmare', True)],
          'svärmarna': [('svärm', True), ('svärmare', True)],
          'svärmarnas': [('svärm', True), ('svärmare', True)],
          'svärmen': [('svärm', False)],
          'svärmens': [('svärm', False)],
          'sväsendet': [('sväsende', False)],
          'sväsendets': [('sväsen', False)],
          'svävar': [('svävare', True)],
          'svävarna': [('svävare', True)],
          'svävarnas': [('svävare', True)],
          'sväxlar': [('sväxel', False)],
          'sväxlarna': [('sväxel', False)],
          'sväxlarnas': [('sväxel', False)],
          'svågarna': [('svåg', False)],
          'svål': [('svål', False)],
          'svål-': [('svål', True)],
          'svålar': [('svål', False)],
          'svålarna': [('svål', False)],
          'svålarnas': [('svål', True)],
          'svålars': [('svål', False)],
          'svålen': [('svål', False)],
          'svålens': [('svål', False)],
          'svåls': [('svål', True)],
          'svåls-': [('svål', False)],
          'svårdar': [('svård', False)],
          'svårdarna': [('svård', False)],
          'svårdarnas': [('svård', False)],
          'sy': [('sy', False)],
          'syftets': [('syfte', False)],
          'syfts-': [('syfte', False)],
          'sykandens': [('sykande', False)],
          'syke': [('syke', False)],
          'syken': [('syke', False)],
          'sykens': [('syke', False)],
          'syket': [('syke', False)],
          'syks': [('syke', False)],
          'sylarna': [('syl', True)],
          'syll': [('syll', True)],
          'syll-': [('syll', True)],
          'syllandets': [('sylland', False)],
          'syllar': [('syll', True)],
          'syllen': [('syll', True)],
          'sylls': [('syll', True)],
          'sylls-': [('syll', True)],
          'sylt': [('sylt', True), ('sylta', True)],
          'sylt-': [('sylt', True), ('sylta', True)],
          'sylte': [('sylta', False)],
          'sylten': [('sylt', True)],
          'syltens': [('sylt', False)],
          'sylts': [('sylt', True), ('sylta', True)],
          'sylts-': [('sylt', True), ('sylta', True)],
          'syn': [('syn', True)],
          'synd': [('synd', False)],
          'synd-': [('synd', False)],
          'synds': [('synd', False)],
          'synds-': [('synd', False)],
          'synets': [('syn', False)],
          'synk': [('synk', True)],
          'synkens': [('synk', True)],
          'synkopen': [('synkop', True), ('synkope', True)],
          'synkopens': [('synkop', True), ('synkope', True)],
          'syns': [('syn', True)],
          'synt': [('synt', True)],
          'syntarna': [('synt', True)],
          'syntets': [('syntet', True)],
          'synts-': [('synt', True)],
          'syors': [('syo', True)],
          'syre': [('syre', True)],
          'syre-': [('syre', True)],
          'syren': [('syren', True)],
          'syrens': [('syren', True)],
          'syrers': [('syr', False)],
          'syret': [('syre', True)],
          'syrets': [('syre', True)],
          'syrierna': [('syrier', True)],
          'syrs': [('syrsa', False)],
          'syrs-': [('syrsa', False)],
          'sys': [('sy', False)],
          'sysslor': [('syssla', True)],
          'sysslorna': [('syssla', True)],
          'sysslornas': [('syssla', True)],
          'sysslors': [('syssla', True)],
          'systemet': [('system', False)],
          'systemets': [('system', False)],
          'syx': [('syxa', False)],
          'syx-': [('syxa', False)],
          'szon': [('szon', False)],
          'szonen': [('szon', False)],
          'szonens': [('szon', False)],
          'szons': [('szon', False)],
          'säck': [('säck', False)],
          'säck-': [('säck', False)],
          'säckar': [('säck', False)],
          'säckarna': [('säck', False)],
          'säcken': [('säck', False)],
          'säckens': [('säck', False)],
          'säcks': [('säck', False)],
          'säcks-': [('säck', False)],
          'säde': [('säde', True)],
          'säden': [('säd', True), ('säde', True)],
          'sädens': [('säde', True), ('säd', True)],
          'sädes': [('säde', True), ('säd', True)],
          'sädes-': [('säd', False)],
          'sädet': [('säde', False)],
          'säds': [('säde', True), ('säd', True)],
          'säds-': [('säde', True), ('säd', True)],
          'sägar': [('sägare', False)],
          'sägarna': [('sägare', False)],
          'sägarnas': [('sägare', False)],
          'sägen': [('sägen', False)],
          'sägens': [('sägen', False)],
          'sägg': [('sägg', False)],
          'sägg-': [('sägg', False)],
          'säggs': [('sägg', False)],
          'säkringar': [('säkring', True)],
          'säkringarna': [('säkring', False)],
          'säkringarnas': [('säkring', False)],
          'säkringars': [('säkring', True)],
          'säkt': [('säkt', False)],
          'säkt-': [('säkt', False)],
          'säkten': [('säkt', False)],
          'säktens': [('säkt', False)],
          'säkts': [('säkt', False)],
          'säkts-': [('säkt', False)],
          'säll': [('sälle', True)],
          'säll-': [('sälle', True)],
          'sällar': [('sälle', True)],
          'sällarna': [('sälle', True)],
          'sällarnas': [('sälle', True)],
          'sällen': [('sälle', True)],
          'sällens': [('sälle', True)],
          'säller': [('säll', False)],
          'sälls': [('sälle', True)],
          'sälls-': [('sälle', True)],
          'säls': [('säl', True)],
          'sält': [('sälta', True)],
          'sälte': [('sälta', True)],
          'sälte-': [('sälta', True)],
          'sälv': [('sälv', False)],
          'sälvs': [('sälv', False)],
          'sälvs-': [('sälv', False)],
          'sän': [('sä', False)],
          'sänd': [('sända', False)],
          'sänd-': [('sända', False)],
          'sändar': [('sändare', True)],
          'sändarna': [('sändare', True)],
          'sändarnas': [('sändare', False)],
          'sänds': [('sända', False)],
          'sänds-': [('sända', False)],
          'säng': [('säng', False)],
          'säng-': [('säng', False)],
          'sängar': [('säng', False)],
          'sängarna': [('säng', False)],
          'sängarnas': [('säng', False)],
          'sängen': [('säng', False)],
          'sängens': [('säng', False)],
          'sänger': [('säng', False)],
          'sängerna': [('säng', False)],
          'sängernas': [('säng', False)],
          'sängers': [('säng', False)],
          'sängs': [('säng', False)],
          'sängs-': [('säng', False)],
          'sänkar': [('sänkare', False)],
          'sänkarna': [('sänkare', False)],
          'sänkarnas': [('sänkare', False)],
          'sänke': [('sänke', True), ('sänka', True)],
          'sänkets': [('sänke', True)],
          'sänks': [('sänke', True), ('sänka', True)],
          'sänks-': [('sänke', True), ('sänka', True)],
          'säns': [('sä', False)],
          'särk': [('särk', False)],
          'särk-': [('särk', False)],
          'särkar': [('särk', False)],
          'särkarna': [('särk', True)],
          'särken': [('särk', False)],
          'särkens': [('särk', False)],
          'särks': [('särk', True)],
          'särks-': [('särk', True)],
          'särmarnas': [('särm', False)],
          'särt': [('särt', False)],
          'särter': [('särter', False)],
          'särterna': [('särt', False)],
          'särternas': [('särt', False)],
          'särters': [('särt', False)],
          'särts': [('särter', False)],
          'särts-': [('särt', False)],
          'säs': [('sä', False)],
          'säte': [('säte', False)],
          'säten': [('säte', False)],
          'sätens': [('säte', False)],
          'säter': [('säter', True)],
          'säters': [('säter', True)],
          'sätet': [('säte', False)],
          'sätt': [('sätt', False)],
          'sätt-': [('sätt', False)],
          'sättarna': [('sättare', False)],
          'sättarnas': [('sättare', False)],
          'sätten': [('sätt', False)],
          'sätter': [('sätt', False)],
          'sätterna': [('sätt', False)],
          'sätternas': [('sätt', False)],
          'sätters': [('sätt', False)],
          'sättet': [('sätt', False)],
          'sätts': [('sätt', False)],
          'sätts-': [('sätt', False)],
          'säv': [('säv', True)],
          'säv-': [('säv', False)],
          'så': [('så', False)],
          'så-': [('så', True)],
          'såar': [('så', True)],
          'såarna': [('så', True)],
          'såder': [('såder', False)],
          'såder-': [('såder', False)],
          'såders': [('såder', False)],
          'sådor': [('sådor', True)],
          'sådorna': [('sådor', True)],
          'sådornas': [('sådor', True)],
          'sådors': [('sådor', True)],
          'sådra': [('såder', False)],
          'sådran': [('sådra', False)],
          'sådrans': [('såder', False)],
          'sådras': [('såder', False)],
          'sådre': [('sådra', False)],
          'sådre-': [('såder', False)],
          'sådror': [('såder', False)],
          'sådrorna': [('såder', False)],
          'sådrornas': [('sådra', False)],
          'sådrors': [('sådra', False)],
          'sågarnas': [('såg', False)],
          'såkarna': [('såkare', False)],
          'såker': [('såker', False)],
          'sålarnas': [('sål', False)],
          'sålars': [('sål', False)],
          'sålen': [('sål', False)],
          'såll': [('såll', True)],
          'såll-': [('såll', True)],
          'sållanden': [('sållande', True)],
          'sållandenas': [('sållande', True)],
          'sållen': [('såll', True)],
          'sålls': [('såll', True)],
          'sålls-': [('såll', True)],
          'sån': [('så', False)],
          'sång': [('sång', False)],
          'sång-': [('sång', True)],
          'sångarna': [('sångare', False)],
          'sången': [('sång', False)],
          'sångens': [('sång', False)],
          'sånger': [('sång', False)],
          'sångers': [('sång', False)],
          'sångs': [('sång', False)],
          'sångs-': [('sång', False)],
          'såns': [('så', False)],
          'såp': [('såpa', False)],
          'såp-': [('såpa', False)],
          'såps': [('såpa', False)],
          'såps-': [('såpa', False)],
          'sår': [('sår', False)],
          'sår-': [('sår', False)],
          'sårs': [('sår', False)],
          'sårs-': [('sår', False)],
          'sås': [('sås', True), ('så', True)],
          'sås-': [('så', True), ('sås', True)],
          'såsar': [('sås', False)],
          'såt': [('såt', True), ('såte', True)],
          'såt-': [('såt', True), ('såte', True)],
          'såtar': [('såt', True), ('såte', True)],
          'såtarna': [('såt', True), ('såte', True)],
          'såtarnas': [('såt', True), ('såte', True)],
          'såtars': [('såte', True), ('såt', True)],
          'såte': [('såte', True)],
          'såten': [('såt', True), ('såte', True)],
          'såtens': [('såt', True), ('såte', True)],
          'såts': [('såt', True), ('såte', True)],
          'såts-': [('såt', True), ('såte', True)],
          'séerna': [('sé', False)],
          'séernas': [('sé', False)],
          'söar': [('sö', False)],
          'söarna': [('sö', False)],
          'söde': [('söde', False)],
          'söden': [('söde', False)],
          'södens': [('söde', False)],
          'söder': [('söder', True)],
          'söders': [('söder', True)],
          'sögat': [('söga', False)],
          'sögats': [('söga', False)],
          'sögon': [('sögon', False)],
          'sögonen': [('söga', False)],
          'sögonens': [('söga', False)],
          'sögons': [('söga', False)],
          'sökar': [('sökare', False)],
          'sökarna': [('sökare', False)],
          'söken': [('sök', False)],
          'sökens': [('sök', False)],
          'sökets': [('sök', False)],
          'sölar': [('sölare', True)],
          'sölarna': [('sölare', True)],
          'sölarnas': [('sölare', True)],
          'sölje': [('sölja', True)],
          'söljs-': [('sölja', True)],
          'sömmar': [('sömmare', True), ('söm', True)],
          'sömmarna': [('sömmare', True), ('söm', True)],
          'sömmarnas': [('sömmare', True), ('söm', True)],
          'sömmen': [('söm', True)],
          'sömmets': [('söm', True)],
          'sön': [('sön', True)],
          'söner': [('son', True)],
          'sönerna': [('son', False)],
          'söners': [('son', False)],
          'söns': [('sö', False)],
          'sören': [('söre', False)],
          'sörens': [('söre', False)],
          'sörjan': [('sörja', False)],
          'sörjarnas': [('sörjare', False)],
          'sörn': [('sör', False)],
          'sörnar': [('sörn', False)],
          'sörnarna': [('sörn', False)],
          'sörnen': [('sörn', False)],
          'sörnens': [('sörn', False)],
          'sörns': [('sörn', False)],
          'sörns-': [('sörn', False)],
          'sörten': [('sört', False)],
          'sörtens': [('sört', False)],
          'sös': [('sös', False)],
          'sös-': [('sö', False)],
          'söt': [('söta', False)],
          'söts': [('söta', False)],
          'söts-': [('söta', False)],
          't': [('t', True)],
          't-': [('t', True)],
          'ta': [('ta', False)],
          'ta-': [('ta', False)],
          'tabb': [('tabbe', False)],
          'tabb-': [('tabbe', False)],
          'tabbar': [('tabbe', True)],
          'tabben': [('tabbe', False)],
          'tabbs-': [('tabbe', True)],
          'taber': [('tab', False)],
          'tabers': [('tab', False)],
          'tabus': [('tabu', True)],
          'tack': [('tack', True), ('tacka', True)],
          'tack-': [('tacka', True), ('tack', True)],
          'tackars': [('tack', False)],
          'tacke': [('tacka', True)],
          'tacke-': [('tacka', False)],
          'tackel': [('tackel', True)],
          'tackel-': [('tackel', True)],
          'tacken': [('tack', False)],
          'tackens': [('tack', False)],
          'tacker': [('tack', False)],
          'tackers': [('tack', False)],
          'tacket': [('tack', False)],
          'tackets': [('tack', False)],
          'tacklandets': [('tacklande', True)],
          'tackor': [('tacka', False)],
          'tackorna': [('tacka', False)],
          'tackornas': [('tacka', True)],
          'tackors': [('tacka', True)],
          'tacks': [('tacka', True), ('tack', True)],
          'tacks-': [('tacka', True), ('tack', True)],
          'tacon': [('taco', True)],
          'tacons': [('taco', True)],
          'tadien': [('tadien', False)],
          'tadiens': [('tadien', False)],
          'tadion': [('tadion', False)],
          'tadons': [('tadon', False)],
          'tador': [('tador', False)],
          'tadors': [('tador', False)],
          'tadskrans': [('tadskran', False)],
          'tadskrans-': [('tadskran', False)],
          'tafet': [('taf', False)],
          'tafets': [('taf', False)],
          'tafiets': [('tafium', False)],
          'tafs': [('tafs', True)],
          'tafs-': [('tafs', True)],
          'tafsar': [('tafs', True), ('tafsare', True)],
          'tafsarna': [('tafs', True), ('tafsare', True)],
          'tafsarnas': [('tafs', True), ('tafsare', True)],
          'tafts': [('taft', True)],
          'tafts-': [('taft', True)],
          'tagar': [('tagare', False)],
          'tagar-': [('tagare', False)],
          'tagarna': [('tagare', False)],
          'tagarnas': [('tagare', False)],
          'tagars': [('tag', False)],
          'tage': [('tage', False)],
          'tage-': [('tage', False)],
          'tagen': [('tag', True)],
          'tagens': [('tag', True)],
          'tagerna': [('tage', False)],
          'tagernas': [('tage', False)],
          'tagers': [('tage', False)],
          'taget': [('tag', True)],
          'tagets': [('tag', False)],
          'tagg': [('tagg', False)],
          'tagg-': [('tagg', False)],
          'taggar': [('tagg', True), ('taggare', True)],
          'taggarna': [('taggare', True), ('tagg', True)],
          'taggarnas': [('tagg', True), ('taggare', True)],
          'taggars': [('tagg', False)],
          'taggen': [('tagg', False)],
          'taggens': [('tagg', False)],
          'taggs': [('tagg', False)],
          'taggs-': [('tagg', False)],
          'tagm': [('tagm', False)],
          'tagm-': [('tagm', False)],
          'tagmer': [('tagm', False)],
          'tagmerna': [('tagm', False)],
          'tagmernas': [('tagm', False)],
          'tagmers': [('tagm', False)],
          'tagms': [('tagm', False)],
          'tagnar': [('tagnare', False)],
          'tagnarna': [('tagnare', False)],
          'tagnarnas': [('tagnare', False)],
          'tailar': [('tail', False)],
          'tailarna': [('tail', False)],
          'tailarnas': [('tail', False)],
          'tajs-': [('taj', False)],
          'tak': [('tak', True)],
          'tak-': [('tak', False)],
          'takar': [('take', False)],
          'takarna': [('take', False)],
          'takarnas': [('take', False)],
          'takars': [('take', False)],
          'take': [('take', False)],
          'take-': [('take', False)],
          'taken': [('tak', True)],
          'takens': [('tak', True)],
          'takes': [('take', False)],
          'taket': [('tak', True)],
          'takets': [('tak', False)],
          'takist-': [('takist', False)],
          'takos-': [('takos', False)],
          'takräcken': [('takräck', True), ('takräcke', True)],
          'takräckens': [('takräcke', True), ('takräck', True)],
          'takräcket': [('takräcke', True), ('takräck', True)],
          'takräckets': [('takräcke', True), ('takräck', True)],
          'takröst': [('takröst', True), ('takröste', True)],
          'takröst-': [('takröste', True), ('takröst', True)],
          'takrösten': [('takröste', True), ('takröst', True)],
          'takröstens': [('takröst', True), ('takröste', True)],
          'takröstet': [('takröste', True), ('takröst', True)],
          'takröstets': [('takröst', True), ('takröste', True)],
          'taks': [('tak', False)],
          'taks-': [('tak', False)],
          'takten': [('takt', False)],
          'takter': [('takt', False)],
          'takters': [('takt', False)],
          'taktik': [('taktik', False)],
          'taktik-': [('taktik', True)],
          'taktiker': [('taktik', True), ('taktiker', True)],
          'taktikerna': [('taktiker', True), ('taktik', True)],
          'taktikernas': [('taktiker', True), ('taktik', True)],
          'taktikers': [('taktiker', True), ('taktik', True)],
          'taktiks': [('taktik', False)],
          'taktiks-': [('taktik', False)],
          'talanden': [('talande', True)],
          'talandena': [('talande', True)],
          'talandenas': [('talande', True)],
          'talandens': [('talande', True)],
          'talandets': [('talande', False)],
          'talans': [('talan', False)],
          'talar': [('talar', True), ('talare', True)],
          'talar-': [('talar', True), ('talare', True)],
          'talaren': [('talar', True), ('talare', True)],
          'talarens': [('talar', True), ('talare', True)],
          'talarna': [('talare', False)],
          'talarnas': [('talare', False)],
          'talars': [('talar', True)],
          'talats': [('talat', False)],
          'talen': [('tal', True)],
          'talens': [('tal', True)],
          'talet': [('tal', True)],
          'talets': [('tal', False)],
          'talfen': [('talf', False)],
          'talfens': [('talf', False)],
          'talg-': [('talg', True)],
          'talgen': [('talg', True)],
          'talgens': [('talg', True)],
          'talgs': [('talg', False)],
          'talgs-': [('talg', False)],
          'talie-': [('talier', False)],
          'talierna': [('talier', False)],
          'taliker': [('taliker', False)],
          'talikerna': [('taliker', False)],
          'talikernas': [('taliker', False)],
          'talikers': [('taliker', False)],
          'talin': [('talin', False)],
          'talis': [('talis', False)],
          'talj': [('talja', True)],
          'talj-': [('talja', True)],
          'talje': [('talja', False)],
          'talje-': [('talja', True)],
          'taljen': [('talj', False)],
          'taljens': [('talj', False)],
          'taljer': [('talj', False)],
          'taljerna': [('talj', False)],
          'taljernas': [('talj', False)],
          'taljers': [('talj', False)],
          'taljs': [('talja', True)],
          'taljs-': [('talja', True)],
          'talk': [('talk', True)],
          'talk-': [('talk', True)],
          'talkarnas': [('talkare', False)],
          'talks': [('talk', True)],
          'talks-': [('talk', True)],
          'tall': [('tall', False)],
          'tall-': [('tall', False)],
          'tallanden': [('tallande', True)],
          'tallandens': [('tallande', True)],
          'tallandet': [('tallande', True)],
          'tallar': [('tall', False)],
          'tallars': [('tall', False)],
          'tallen': [('tall', False)],
          'taller': [('tall', False)],
          'tallerna': [('tall', False)],
          'tallernas': [('tall', False)],
          'tallers': [('tall', False)],
          'tallos': [('tallos', False)],
          'tallos-': [('tallos', False)],
          'talls': [('tall', False)],
          'talls-': [('tall', False)],
          'talong': [('talong', True)],
          'talong-': [('talong', False)],
          'talonger': [('talong', True)],
          'talongerna': [('talong', False)],
          'talongernas': [('talong', False)],
          'talongers': [('talong', True)],
          'talongs': [('talong', False)],
          'talongs-': [('talong', False)],
          'tals': [('tal', False)],
          'tals-': [('tal', False)],
          'talt-': [('talt', False)],
          'taltans': [('taltan', False)],
          'talts': [('talt', False)],
          'talts-': [('talt', False)],
          'talvar': [('talvara', False)],
          'talvar-': [('talvara', False)],
          'talvs': [('talv', False)],
          'talvs-': [('talv', False)],
          'tam': [('tam', False)],
          'tam-': [('tam', False)],
          'tamatens': [('tamat', False)],
          'tamen': [('tamen', False)],
          'tamens': [('tamen', False)],
          'tamenten': [('tament', False)],
          'tamentens': [('tament', False)],
          'tamentet': [('tament', False)],
          'tamentets': [('tamente', False)],
          'taments': [('tamente', False)],
          'taments-': [('tament', False)],
          'tamers': [('tam', False)],
          'tameter': [('tameter', False)],
          'tameters': [('tameter', False)],
          'tamin': [('tamin', False)],
          'tamins': [('tamin', False)],
          'tamp': [('tamp', False)],
          'tamp-': [('tamp', True)],
          'tampar': [('tamp', True)],
          'tamparna': [('tamp', False)],
          'tampen': [('tamp', True)],
          'tampens': [('tamp', False)],
          'tamps': [('tamp', False)],
          'tamps-': [('tamp', False)],
          'tams': [('tam', False)],
          'tams-': [('tam', False)],
          'tan': [('tana', True)],
          'tan-': [('tana', True)],
          'tana': [('tana', True)],
          'tanan': [('tana', False)],
          'tanans': [('tana', False)],
          'tanar': [('tanare', False)],
          'tanarna': [('tanare', False)],
          'tanas': [('tana', True)],
          'tand': [('tand', False)],
          'tand-': [('tand', False)],
          'tandana': [('tanda', False)],
          'tandanas': [('tanda', False)],
          'tandar': [('tandar', False)],
          'tandar-': [('tandar', False)],
          'tandarens': [('tandar', False)],
          'tandarna': [('tande', False)],
          'tandars': [('tandar', False)],
          'tanden': [('tand', False)],
          'tandens': [('tand', False)],
          'tander': [('tand', False)],
          'tanders': [('tand', False)],
          'tandets': [('tande', False)],
          'tands': [('tand', False)],
          'tands-': [('tand', False)],
          'tanens': [('tan', False)],
          'tanets': [('tan', False)],
          'tang': [('tang', False)],
          'tang-': [('tang', False)],
          'tangen': [('tang', False)],
          'tangens': [('tangens', True)],
          'tangenten': [('tangenten', True), ('tangent', True)],
          'tangentens': [('tangenten', True), ('tangent', True)],
          'tanger': [('tang', False)],
          'tangerna': [('tang', False)],
          'tangernas': [('tang', False)],
          'tangers': [('tang', False)],
          'tangosar': [('tango', True)],
          'tangosarnas': [('tango', True)],
          'tangosars': [('tango', True)],
          'tangs': [('tang', False)],
          'tangs-': [('tang', False)],
          'tani': [('tani', False)],
          'tani-': [('tani', False)],
          'tanie-': [('tania', False)],
          'tanien': [('tani', False)],
          'taniens': [('tani', False)],
          'tanier': [('tanier', False)],
          'tanierna': [('tanier', False)],
          'taniernas': [('tanier', False)],
          'taniker': [('taniker', False)],
          'tanikerna': [('taniker', False)],
          'tanikernas': [('taniker', False)],
          'tanikers': [('taniker', False)],
          'tanin': [('tani', False)],
          'tanins': [('tani', False)],
          'tanis': [('tania', False)],
          'tanis-': [('tania', False)],
          'tanister': [('tanist', False)],
          'tanisters': [('tanist', False)],
          'tank': [('tank', False)],
          'tank-': [('tank', True)],
          'tankar': [('tank', True), ('tanke', True)],
          'tankarna': [('tanke', True), ('tank', True)],
          'tankarnas': [('tank', True), ('tanke', True)],
          'tankars': [('tanke', True), ('tank', True)],
          'tanke': [('tanke', True)],
          'tanke-': [('tanke', True)],
          'tanken': [('tanke', True), ('tank', True)],
          'tankens': [('tanke', True), ('tank', True)],
          'tanker': [('tanker', True)],
          'tankerna': [('tanker', True)],
          'tankernas': [('tanker', True)],
          'tankers': [('tanker', True)],
          'tanks': [('tank', True), ('tanks', True)],
          'tanks-': [('tanks', True), ('tank', True)],
          'tanksen': [('tank', True), ('tanks', True)],
          'tanksens': [('tanks', True), ('tank', True)],
          'tanor': [('tana', True)],
          'tanorna': [('tana', True)],
          'tanornas': [('tana', True)],
          'tanors': [('tana', True)],
          'tans': [('tana', True)],
          'tans-': [('tana', True)],
          'tansar': [('tans', False)],
          'tansarna': [('tans', False)],
          'tansars': [('tans', False)],
          'tansen': [('tans', False)],
          'tansens': [('tans', False)],
          'tanser': [('tans', False)],
          'tanserna': [('tans', False)],
          'tansernas': [('tans', False)],
          'tansers': [('tans', False)],
          'tansk': [('tanska', False)],
          'tansk-': [('tanska', False)],
          'tanstalter': [('tanstalt', False)],
          'tanstalterna': [('tanstalt', False)],
          'tanstalternas': [('tanstalt', False)],
          'tanstalters': [('tanstalt', False)],
          'tanstalts': [('tanstalt', False)],
          'tanstalts-': [('tanstalt', False)],
          'tant': [('tant', False)],
          'tant-': [('tant', True)],
          'tanten': [('tant', False)],
          'tantens': [('tant', False)],
          'tanter': [('tant', False)],
          'tanterna': [('tant', True)],
          'tanternas': [('tant', False)],
          'tanters': [('tant', False)],
          'tantier': [('tantier', False)],
          'tantiernas': [('tantier', False)],
          'tantiers': [('tantier', False)],
          'tantros-': [('tantros', False)],
          'tants': [('tant', True)],
          'tants-': [('tant', False)],
          'tanvärden': [('tanvärde', False)],
          'tanvärdens': [('tanvärde', False)],
          'tap': [('tape', True)],
          'tap-': [('tape', True)],
          'tapas': [('tapas', True)],
          'tape': [('tape', False)],
          'tape-': [('tape', True)],
          'tapen': [('tape', True)],
          'tapens': [('tape', True)],
          'taper': [('tape', False)],
          'taperna': [('tape', False)],
          'tapernas': [('tape', True)],
          'tapers': [('tape', True)],
          'tapet': [('tapet', False)],
          'tapp': [('tapp', False)],
          'tapp-': [('tapp', False)],
          'tappar': [('tapp', True)],
          'tappars': [('tapp', False)],
          'tappen': [('tapp', False)],
          'tappens': [('tapp', False)],
          'tapperna': [('tapp', False)],
          'tappernas': [('tapp', False)],
          'tappers': [('tapp', False)],
          'tapps': [('tapp', False)],
          'tapps-': [('tapp', False)],
          'taps': [('tape', True)],
          'taps-': [('tape', True)],
          'tar': [('tare', False)],
          'tar-': [('tare', False)],
          'taran': [('tara', True)],
          'tarans': [('tara', False)],
          'tararnas': [('tare', False)],
          'tard': [('tard', False)],
          'tard-': [('tard', False)],
          'tarden': [('tard', False)],
          'tardens': [('tard', False)],
          'tarder': [('tard', False)],
          'tarderna': [('tard', False)],
          'tardernas': [('tard', False)],
          'tarders': [('tard', False)],
          'tards': [('tard', False)],
          'tards-': [('tard', False)],
          'tare': [('tare', False)],
          'tare-': [('tare', False)],
          'tarens': [('tare', False)],
          'tares': [('tare', False)],
          'tares-': [('tare', False)],
          'taret': [('tare', False)],
          'tarets': [('tare', False)],
          'tarian': [('tarian', False)],
          'tarians': [('tarian', False)],
          'tarie': [('tarium', False)],
          'tarie-': [('tarium', False)],
          'tarier': [('tarium', False)],
          'tarierna': [('tarie', False)],
          'tariernas': [('tarium', False)],
          'tarin': [('tarin', False)],
          'tarismer': [('tarism', False)],
          'tarismerna': [('tarism', False)],
          'tarismernas': [('tarism', False)],
          'tarismers': [('tarism', False)],
          'tarlek': [('tarlek', False)],
          'tarleks-': [('tarlek', False)],
          'tarmar': [('tarm', False)],
          'tarmarna': [('tarm', False)],
          'tarmarnas': [('tarm', False)],
          'tarna': [('tare', False)],
          'tarnas': [('t', False)],
          'taro': [('taro', True)],
          'taron': [('taro', True)],
          'tarons': [('taro', True)],
          'taros': [('taro', True)],
          'tarr': [('tarr', False)],
          'tarr-': [('tarr', False)],
          'tarren': [('tarr', False)],
          'tarrens': [('tarr', False)],
          'tarrs-': [('tarr', False)],
          'tars': [('tars', True)],
          'tars-': [('tars', True)],
          'tarsens': [('tars', True)],
          'tarser': [('tars', True)],
          'tarsers': [('tars', True)],
          'tarsi': [('tarsia', False)],
          'tarsi-': [('tarsia', False)],
          'tarsian': [('tarsia', False)],
          'tarsians': [('tarsia', False)],
          'tarsis': [('tarsia', False)],
          'tarskens': [('tarsken', False)],
          'tart': [('tart', False)],
          'tartan': [('tartan', True)],
          'tarten': [('tart', False)],
          'tartens': [('tart', False)],
          'tarter': [('tart', False)],
          'tarterna': [('tart', False)],
          'tarternas': [('tart', False)],
          'tarters': [('tart', False)],
          'tarton': [('tarton', False)],
          'tartons': [('tarton', False)],
          'tarts': [('tart', False)],
          'tarts-': [('tart', False)],
          'tarv': [('tarv', True)],
          'tarv-': [('tarv', True)],
          'tarvar': [('tarve', False)],
          'tarvarna': [('tarve', False)],
          'tarven': [('tarve', False)],
          'tarvens': [('tarv', False)],
          'tarvs': [('tarv', True)],
          'tarvs-': [('tarv', False)],
          'tas': [('ta', False)],
          'tas-': [('ta', False)],
          'tasarna': [('ta', False)],
          'tasarnas': [('ta', False)],
          'tasegrarnas': [('taseger', False)],
          'tasen': [('ta', False)],
          'tasens': [('ta', False)],
          'tasier': [('tasi', False)],
          'tasierna': [('tasi', False)],
          'tasiernas': [('tasi', False)],
          'tasins': [('tasi', False)],
          'tasis': [('tasi', False)],
          'task': [('taska', True), ('task', True)],
          'task-': [('taska', True), ('task', True)],
          'taskarna': [('task', False)],
          'taske': [('taska', False)],
          'taske-': [('taska', False)],
          'taskorna': [('taska', False)],
          'taskornas': [('taska', True)],
          'taskors': [('taska', False)],
          'taspets': [('taspets', False)],
          'tass': [('tass', False)],
          'tassar': [('tass', False)],
          'tassarna': [('tass', True)],
          'tassars': [('tass', True)],
          'tassen': [('tass', False)],
          'tassens': [('tass', True)],
          'tasslandets': [('tasslande', True)],
          'tast-': [('tast', False)],
          'tastas': [('tastas', False)],
          'tasten': [('tast', False)],
          'tastens': [('tasten', False)],
          'taster': [('tast', False)],
          'tasterna': [('tast', False)],
          'tasternas': [('tast', False)],
          'tasters': [('tast', False)],
          'tat': [('ta', False)],
          'tata': [('tata', False)],
          'tatan': [('tata', False)],
          'tatar': [('tatar', True)],
          'tatar-': [('tatar', True)],
          'tataren': [('tatar', True)],
          'tatarens': [('tatar', True)],
          'tatarna': [('tatare', False)],
          'tatarnas': [('tatare', False)],
          'tatas': [('tata', False)],
          'tatiden': [('tatiden', False)],
          'tation': [('tation', False)],
          'tationen': [('tation', False)],
          'tations': [('tation', False)],
          'tatis': [('tatis', False)],
          'tativets': [('tativ', False)],
          'tatonin': [('tatoni', False)],
          'tatonins': [('tatoni', False)],
          'tator': [('tator', False)],
          'tators': [('tator', False)],
          'tatron': [('tatron', False)],
          'tatrons': [('tatro', False)],
          'tats': [('ta', False)],
          'tats-': [('tat', False)],
          'tattarna': [('tattare', True)],
          'tattarnas': [('tattare', True)],
          'taur': [('taur', False)],
          'taur-': [('taur', False)],
          'taurs': [('taur', False)],
          'taurs-': [('taur', False)],
          'tavanden': [('tavande', False)],
          'tavandens': [('tavande', False)],
          'tavel': [('tavla', False)],
          'tavel-': [('tavla', False)],
          'taven': [('tav', False)],
          'tavens': [('tav', False)],
          'tavern': [('taverna', True)],
          'taverna': [('taverna', True)],
          'tavernas': [('taverna', True)],
          'tavers': [('tav', False)],
          'tavle': [('tavla', False)],
          'tavle-': [('tavla', False)],
          'tax': [('tax', True), ('taxa', True)],
          'tax-': [('tax', True), ('taxa', True)],
          'taxis': [('taxis', True), ('taxi', True)],
          'taxis-': [('taxi', True), ('taxis', True)],
          'tazon': [('tazo', False)],
          'tback': [('tback', False)],
          'tbackar': [('tback', False)],
          'tbackarna': [('tback', False)],
          'tbackarnas': [('tback', False)],
          'tbackars': [('tback', False)],
          'tbacken': [('tback', False)],
          'tbackens': [('tback', False)],
          'tbacks': [('tback', False)],
          'tbacks-': [('tback', False)],
          'tbagg': [('tbagge', False)],
          'tbagg-': [('tbagge', False)],
          'tbaggar': [('tbagge', False)],
          'tbaggarna': [('tbagge', False)],
          'tbaggarnas': [('tbagge', False)],
          'tbaggars': [('tbagge', False)],
          'tbaggen': [('tbagge', False)],
          'tbaggens': [('tbagge', False)],
          'tbaggs': [('tbagge', False)],
          'tbaggs-': [('tbagge', False)],
          'tball': [('tball', False)],
          'tball-': [('tball', False)],
          'tballen': [('tball', False)],
          'tballens': [('tball', False)],
          'tballs': [('tball', False)],
          'tballs-': [('tball', False)],
          'tbanan': [('tbana', False)],
          'tbanans': [('tbana', False)],
          'tbandets': [('tband', False)],
          'tbane': [('tbana', False)],
          'tbane-': [('tbana', False)],
          'tbars': [('tbar', False)],
          'tbas': [('tbas', False)],
          'tben': [('tben', False)],
          'tben-': [('tbena', False)],
          'tbens': [('tben', False)],
          'tbens-': [('tben', False)],
          'tbet': [('tbete', False)],
          'tbet-': [('tbeta', False)],
          'tbetar': [('tbete', False)],
          'tbetarna': [('tbete', False)],
          'tbetarnas': [('tbete', False)],
          'tbetars': [('tbete', False)],
          'tbete': [('tbeta', False)],
          'tbeten': [('tbete', False)],
          'tbetens': [('tbete', False)],
          'tbets': [('tbete', False)],
          'tbets-': [('tbete', False)],
          'tbevis': [('tbevis', False)],
          'tbiets': [('tbi', False)],
          'tbil': [('tbil', False)],
          'tbilar': [('tbil', False)],
          'tbilars': [('tbil', False)],
          'tbils': [('tbil', False)],
          'tbils-': [('tbil', False)],
          'tbit': [('tbi', False)],
          'tbitar': [('tbitar', False)],
          'tbitarnas': [('tbitar', False)],
          'tbitars': [('tbit', False)],
          'tbits': [('tbit', False)],
          'tbits-': [('tbit', False)],
          'tblack': [('tblacka', False)],
          'tblack-': [('tblacka', False)],
          'tblacks': [('tblacka', False)],
          'tblacks-': [('tblacka', False)],
          'tbloggar': [('tbloggare', False)],
          'tbloggarna': [('tbloggare', False)],
          'tbloggarnas': [('tbloggare', False)],
          'tblom': [('tblomma', False)],
          'tblom-': [('tblomma', False)],
          'tbloms': [('tblomma', False)],
          'tbloms-': [('tblomma', False)],
          'tbolaget': [('tbolag', False)],
          'tbondens': [('tbonde', False)],
          'tbonds': [('tbonde', False)],
          'tbonds-': [('tbonde', False)],
          'tbor': [('tbo', False)],
          'tbors': [('tbo', False)],
          'tborst': [('tborste', False)],
          'tborst-': [('tborste', False)],
          'tborsten': [('tborste', False)],
          'tborstens': [('tborste', False)],
          'tbot': [('tbo', False)],
          'tbots': [('tbo', False)],
          'tboxar': [('tbox', False)],
          'tboxarna': [('tbox', False)],
          'tboxarnas': [('tbox', False)],
          'tbroder': [('tbroder', False)],
          'tbrodern': [('tbroder', False)],
          'tbroderns': [('tbroder', False)],
          'tbroders': [('tbroder', False)],
          'tbroms': [('tbroms', False)],
          'tbromsar': [('tbroms', False)],
          'tbromsarna': [('tbroms', False)],
          'tbromsarnas': [('tbroms', False)],
          'tbrons': [('tbro', False)],
          'tbrytar': [('tbrytare', False)],
          'tbrytarna': [('tbrytare', False)],
          'tbrytarnas': [('tbrytare', False)],
          'tbräds': [('tbräda', False)],
          'tbräds-': [('tbräda', False)],
          'tbråk': [('tbråk', False)],
          'tbråks': [('tbråk', False)],
          'tbråks-': [('tbråk', False)],
          'tbröder': [('tbroder', False)],
          'tbröderna': [('tbroder', False)],
          'tbrödernas': [('tbroder', False)],
          'tbröders': [('tbroder', False)],
          'tbröst': [('tbröst', False)],
          'tbröst-': [('tbröst', False)],
          'tbubbel': [('tbubbla', False)],
          'tbubbel-': [('tbubbla', False)],
          'tbull': [('tbulle', False)],
          'tbull-': [('tbulle', False)],
          'tbulle': [('tbulle', False)],
          'tbulle-': [('tbulle', False)],
          'tbulls': [('tbulle', False)],
          'tbulls-': [('tbulle', False)],
          'tbygget': [('tbygge', False)],
          'tbyx': [('tbyxa', False)],
          'tbyx-': [('tbyxa', False)],
          'tbyxornas': [('tbyxa', False)],
          'tbärs': [('tbär', False)],
          'tbärs-': [('tbär', False)],
          'tbåg': [('tbåge', False)],
          'tbåg-': [('tbåge', False)],
          'tbågs': [('tbåge', False)],
          'tbågs-': [('tbåge', False)],
          'tbön': [('tböna', False)],
          'tbön-': [('tböna', False)],
          'tböne': [('tböna', False)],
          'tböne-': [('tböna', False)],
          'tböns': [('tböna', False)],
          'tböns-': [('tböna', False)],
          'tcell': [('tcell', False)],
          'tcentrer': [('tcentrum', False)],
          'tcentrerna': [('tcentrum', False)],
          'tcentrernas': [('tcentrum', False)],
          'tcentrers': [('tcentrum', False)],
          'tcentret': [('tcentrum', False)],
          'tcentrets': [('tcentrum', False)],
          'tchar': [('tch', False)],
          'tcharnas': [('tch', False)],
          'tchars': [('tch', False)],
          'tchman': [('tchman', False)],
          'tdagar': [('tdag', False)],
          'tdagarna': [('tdag', False)],
          'tdagarnas': [('tdag', False)],
          'tdagars': [('tdag', False)],
          'tdagen': [('tdag', False)],
          'tdagens': [('tdag', False)],
          'tdags': [('tdag', False)],
          'tdags-': [('tdag', False)],
          'tdans': [('tdag', False)],
          'tdel': [('tdel', False)],
          'tdelandet': [('tdelande', False)],
          'tdels': [('tdel', False)],
          'tdels-': [('tdel', False)],
          'tderivat': [('tderivat', False)],
          'tderivat-': [('tderivat', False)],
          'tderivats': [('tderivat', False)],
          'tderivats-': [('tderivat', False)],
          'tdiskar': [('tdisk', False)],
          'tdiskarna': [('tdisk', False)],
          'tdiskarnas': [('tdisk', False)],
          'tdock-': [('tdocka', False)],
          'tdocks': [('tdocka', False)],
          'tdomar': [('tdomare', False)],
          'tdomarna': [('tdomare', False)],
          'tdomarnas': [('tdomare', False)],
          'tdramer': [('tdrama', False)],
          'tdramerna': [('tdrama', False)],
          'tdrivar': [('tdrivare', False)],
          'tdrivarna': [('tdrivare', False)],
          'tdrivarnas': [('tdrivare', False)],
          'tdropp': [('tdroppe', False)],
          'tdropp-': [('tdroppe', False)],
          'tdroppar': [('tdroppar', False)],
          'tdropparna': [('tdroppar', False)],
          'tdropparnas': [('tdroppar', False)],
          'tdroppars': [('tdroppar', False)],
          'tdropps': [('tdroppar', False)],
          'tdropps-': [('tdroppe', False)],
          'tdunkar': [('tdunk', False)],
          'tdunkarna': [('tdunk', False)],
          'tdyn': [('tdyna', False)],
          'tdyn-': [('tdyna', False)],
          'tdyns': [('tdyna', False)],
          'tdyns-': [('tdyna', False)],
          'tdår': [('tdåre', False)],
          'tdödarna': [('tdöd', False)],
          'te': [('te', False)],
          'te-': [('te', False)],
          'teans': [('tea', False)],
          'teater': [('teater', True)],
          'teaters': [('teater', True)],
          'teborgar': [('teborgare', False)],
          'teborgarna': [('teborgare', False)],
          'teborgarnas': [('teborgare', False)],
          'ted': [('ted', False)],
          'tedags': [('tedags', True)],
          'tedags-': [('tedags', True)],
          'tedan': [('tedag', False)],
          'tedans': [('tedag', False)],
          'teder': [('teder', False)],
          'teders': [('teder', False)],
          'teds': [('ted', False)],
          'teds-': [('ted', False)],
          'tedödar': [('tedöd', False)],
          'tedödarnas': [('tedöd', False)],
          'teer': [('te', False)],
          'teerna': [('te', False)],
          'teernas': [('te', False)],
          'teers': [('te', True)],
          'teet': [('te', True)],
          'tefader': [('tefader', False)],
          'tefadern': [('tefader', False)],
          'tefaders-': [('tefader', False)],
          'teffekterna': [('teffekt', False)],
          'teg': [('teg', True)],
          'teg-': [('teg', True)],
          'tegar': [('teg', False)],
          'tegarna': [('teg', True)],
          'tegarnas': [('teg', True)],
          'tegars': [('teg', True)],
          'tege': [('tege', False)],
          'tege-': [('tege', False)],
          'tegen': [('teg', True)],
          'tegens': [('teg', True)],
          'teger': [('tege', False)],
          'tegerna': [('teg', False)],
          'tegernas': [('tege', False)],
          'tegers': [('tege', False)],
          'teges': [('tege', False)],
          'teges-': [('tege', False)],
          'tegier': [('tegi', False)],
          'tegierna': [('tegi', False)],
          'tegiernas': [('tegi', False)],
          'tegiers': [('tegi', False)],
          'tegis': [('tegi', False)],
          'tegranden': [('tegrande', False)],
          'tegrandens': [('tegrande', False)],
          'tegs': [('teg', False)],
          'tegs-': [('teg', True)],
          'tegångarnas': [('tegång', False)],
          'teiner': [('tein', False)],
          'teinerna': [('tein', False)],
          'teinernas': [('tein', False)],
          'teiners': [('tein', False)],
          'tek': [('tek', False)],
          'tek-': [('tek', False)],
          'tekar': [('tekare', False)],
          'tekarens': [('tekare', False)],
          'tekarna': [('tekare', False)],
          'tekarnas': [('tekare', False)],
          'teke': [('teka', False)],
          'teke-': [('teka', False)],
          'teker': [('tek', False)],
          'tekers': [('tek', False)],
          'tekes': [('tekes', False)],
          'tekes-': [('tekes', False)],
          'teket': [('tek', False)],
          'tekets': [('tek', False)],
          'tekniker': [('tekniker', True), ('teknik', True)],
          'teknikerna': [('tekniker', True), ('teknik', True)],
          'teknikernas': [('tekniker', True), ('teknik', True)],
          'teknikers': [('tekniker', True), ('teknik', True)],
          'teks': [('tek', False)],
          'teks-': [('tek', False)],
          'tekt': [('tekt', False)],
          'tekt-': [('tekt', False)],
          'tekten': [('tekt', False)],
          'tektens': [('tekt', False)],
          'tekter': [('tekt', False)],
          'tekterna': [('tekt', False)],
          'tekternas': [('tekt', False)],
          'tekters': [('tekt', False)],
          'tektiven': [('tektiv', False)],
          'tektivens': [('tektiv', False)],
          'tekts': [('tekt', False)],
          'tekts-': [('tekt', False)],
          'tel': [('tel', True)],
          'tel-': [('tel', True)],
          'telar': [('tele', False)],
          'telarna': [('tele', False)],
          'telarnas': [('tele', False)],
          'telars': [('tele', False)],
          'telborr': [('telborre', False)],
          'telborr-': [('telborre', False)],
          'telborrar': [('telborre', False)],
          'telborrarna': [('telborre', False)],
          'telborrarnas': [('telborre', False)],
          'telborrars': [('telborre', False)],
          'telborren': [('telborre', False)],
          'telborrens': [('telborre', False)],
          'telborrs': [('telborre', False)],
          'telborrs-': [('telborre', False)],
          'teldar': [('teld', False)],
          'teldarna': [('teld', False)],
          'teldarnas': [('teld', False)],
          'tele': [('tele', False)],
          'tele-': [('tele', False)],
          'telen': [('tele', False)],
          'telens': [('tele', False)],
          'teler': [('tele', False)],
          'telerna': [('tele', False)],
          'telernas': [('tele', False)],
          'telers': [('tel', False)],
          'telgångarnas': [('telgång', False)],
          'teli': [('teli', False)],
          'teli-': [('teli', False)],
          'telins': [('teli', False)],
          'telis': [('teli', False)],
          'tell': [('tell', False)],
          'tell-': [('tell', False)],
          'tellan': [('tella', False)],
          'tellans': [('tellan', False)],
          'telle': [('tella', False)],
          'telle-': [('tella', False)],
          'tellen': [('tell', False)],
          'teller': [('tell', False)],
          'tellerna': [('tell', False)],
          'tellernas': [('tell', False)],
          'tellers': [('tell', False)],
          'tellet': [('tell', False)],
          'tellets': [('tell', False)],
          'tellor': [('tella', False)],
          'tellorna': [('tella', False)],
          'tellornas': [('tella', False)],
          'tellors': [('tella', False)],
          'tells': [('tell', False)],
          'tells-': [('tell', False)],
          'teln': [('teln', True)],
          'telns': [('teln', True)],
          'telskur': [('telskura', False)],
          'teläggar': [('telägg', False)],
          'teläggarna': [('telägg', False)],
          'teläggarnas': [('telägg', False)],
          'telön': [('telön', False)],
          'telöns': [('telön', False)],
          'tem': [('tem', False)],
          'tem-': [('tem', False)],
          'teman': [('tema', False)],
          'temans': [('tema', True)],
          'tematiker': [('tematiker', False)],
          'tematikerna': [('tematiker', False)],
          'tematikernas': [('tematiker', False)],
          'tematikers': [('tematiker', False)],
          'tementen': [('tement', False)],
          'tementens': [('tement', False)],
          'tementet': [('tement', False)],
          'tements-': [('tement', False)],
          'temer': [('tema', False)],
          'temerna': [('tema', False)],
          'temernas': [('tema', False)],
          'temers': [('tema', False)],
          'temien': [('temi', False)],
          'temiens': [('temi', False)],
          'temis': [('temi', False)],
          'temis-': [('temi', False)],
          'temit': [('temi', False)],
          'temman': [('temman', False)],
          'temmans': [('temman', False)],
          'templar': [('templare', False)],
          'templar-': [('templare', False)],
          'templarens': [('templare', False)],
          'tems': [('tem', False)],
          'tems-': [('tem', False)],
          'ten': [('ten', True)],
          'tena': [('te', False)],
          'tenarnas': [('ten', False)],
          'tenas': [('te', False)],
          'tenbit': [('tenbi', False)],
          'tenbits': [('tenbit', False)],
          'tendelar': [('tendelare', False)],
          'tendelarna': [('tendelare', False)],
          'tendelarnas': [('tendelare', False)],
          'tendens': [('tendens', True)],
          'tenet': [('ten', False)],
          'tenets': [('ten', False)],
          'tenheter': [('tenhet', False)],
          'tenheterna': [('tenhet', False)],
          'tenheternas': [('tenhet', False)],
          'tenheters': [('tenhet', False)],
          'tenhets': [('tenhet', False)],
          'tenhets-': [('tenhet', False)],
          'tenhål': [('tenhål', False)],
          'tenhål-': [('tenhål', False)],
          'tenhåls': [('tenhål', False)],
          'tenhåls-': [('tenhål', False)],
          'teni': [('teni', False)],
          'teni-': [('teni', False)],
          'tenien': [('teni', False)],
          'teniens': [('teni', False)],
          'teniernas': [('teni', False)],
          'teniers': [('teni', False)],
          'teniets': [('tenium', False)],
          'tenis': [('teni', False)],
          'tenis-': [('tenis', False)],
          'tenitet': [('tenit', False)],
          'tenitets': [('tenit', False)],
          'tenits': [('tenit', False)],
          'tenknäckar': [('tenknäck', False)],
          'tenkrans': [('tenkran', False)],
          'tenn': [('tenn', False)],
          'tenn-': [('tenn', True)],
          'tennen': [('tenn', False)],
          'tennens': [('tenn', False)],
          'tenner': [('tenn', False)],
          'tennerna': [('tenn', False)],
          'tennernas': [('tenn', False)],
          'tenners': [('tenn', False)],
          'tennis': [('tennis', False)],
          'tennisracket': [('tennisracket', True), ('tennisrack', True)],
          'tennisrackets': [('tennisracket', True), ('tennisrack', True)],
          'tenns': [('tenn', True)],
          'tenns-': [('tenn', False)],
          'tenor': [('tenor', False)],
          'tenors': [('tenor', False)],
          'tens': [('ten', True)],
          'tens-': [('ten', True)],
          'tensarnas': [('tensare', False)],
          'tensats-': [('tensats', False)],
          'tensen': [('tens', False)],
          'tensens': [('tens', False)],
          'tenser': [('tens', False)],
          'tenserna': [('tens', False)],
          'tensernas': [('tens', False)],
          'tensers': [('tens', False)],
          'tenskaps-': [('tenskap', False)],
          'tenskvätt': [('tenskvätt', False)],
          'tenskvätt-': [('tenskvätta', False)],
          'tenskvätts': [('tenskvätta', False)],
          'tenskvätts-': [('tenskvätta', False)],
          'tensteinarnas': [('tensteinare', False)],
          'tent': [('tent', False)],
          'tentanden': [('tentande', True), ('tentand', True)],
          'tentandens': [('tentande', True), ('tentand', True)],
          'tentaren': [('tentare', False)],
          'tentat': [('tentat', False)],
          'tentats': [('tentat', False)],
          'tenten': [('tent', False)],
          'tentens': [('tent', False)],
          'tenter': [('tent', False)],
          'tenternas': [('tent', False)],
          'tenters': [('tent', False)],
          'tentet': [('tent', False)],
          'tentor': [('tenta', True)],
          'tentors': [('tenta', True)],
          'tents-': [('tent', False)],
          'tenus': [('tenusa', False)],
          'tenvägar': [('tenväg', False)],
          'tenvägarna': [('tenväg', False)],
          'tenvägarnas': [('tenväg', False)],
          'tenvägars': [('tenväg', False)],
          'teon': [('teon', False)],
          'teons': [('teon', False)],
          'teor': [('teor', False)],
          'teorna': [('tea', False)],
          'teornas': [('tea', False)],
          'teors': [('teor', False)],
          'teos': [('teos', False)],
          'teos-': [('teos', False)],
          'tepens': [('tep', False)],
          'tepp': [('tepp', False)],
          'tepp-': [('tepp', False)],
          'teppen': [('tepp', False)],
          'teppens': [('tepp', False)],
          'tepps': [('tepp', False)],
          'tepps-': [('tepp', False)],
          'tepås': [('tepåse', True)],
          'ter': [('ter', False)],
          'teran': [('teran', False)],
          'terand': [('terand', False)],
          'terand-': [('terand', False)],
          'terands': [('terand', False)],
          'terands-': [('terand', False)],
          'terans': [('teran', False)],
          'terare': [('terare', False)],
          'terares': [('terare', False)],
          'terarna': [('terare', False)],
          'terarnas': [('terare', False)],
          'terben': [('terben', False)],
          'terbens-': [('terben', False)],
          'terbyxorna': [('terbyxa', False)],
          'terbyxornas': [('terbyxa', False)],
          'terfar': [('terfar', False)],
          'terfar-': [('terfar', False)],
          'terfars': [('terfar', False)],
          'terfars-': [('terfar', False)],
          'terfiskar': [('terfiskare', False)],
          'terfiskarna': [('terfiskare', False)],
          'terflotts': [('terflott', False)],
          'terfots': [('terfot', False)],
          'terfots-': [('terfot', False)],
          'terhake-': [('terhaka', False)],
          'teri': [('teri', False)],
          'teri-': [('teri', False)],
          'terian': [('terian', False)],
          'terians': [('terian', False)],
          'terie': [('teria', False)],
          'terie-': [('terium', False)],
          'teriens': [('teri', False)],
          'teriers': [('teri', False)],
          'teriet': [('teri', False)],
          'terikan': [('terika', False)],
          'terikans': [('terika', False)],
          'terins': [('teri', False)],
          'teris': [('teri', False)],
          'teris-': [('teri', False)],
          'terit': [('teri', False)],
          'teriter': [('teritum', False)],
          'teriterna': [('teritum', False)],
          'teriternas': [('terit', False)],
          'teriters': [('teritum', False)],
          'terits': [('terit', False)],
          'terlik': [('terlik', False)],
          'terlikarna': [('terlikare', False)],
          'terlikens': [('terlik', False)],
          'terliks': [('terlik', False)],
          'terliks-': [('terlik', False)],
          'terman': [('terman', False)],
          'termans': [('terman', False)],
          'termer': [('term', True), ('termer', True)],
          'termerna': [('termer', True), ('term', True)],
          'termernas': [('term', True), ('termer', True)],
          'termers': [('termer', True), ('term', True)],
          'termin': [('termin', True)],
          'termins': [('termin', True)],
          'tern': [('tern', False)],
          'tern-': [('tern', False)],
          'terne': [('terna', False)],
          'terner': [('tern', False)],
          'terners': [('tern', True)],
          'ternes': [('ternes', False)],
          'ternes-': [('ternes', False)],
          'terns': [('tern', True)],
          'terns-': [('tern', False)],
          'terorden': [('terord', False)],
          'terordens': [('terord', False)],
          'terr': [('terr', False)],
          'terr-': [('terr', False)],
          'terren': [('terr', False)],
          'terrens': [('terr', False)],
          'terrs-': [('terr', False)],
          'terråns': [('terrån', False)],
          'ters': [('ters', True)],
          'ters-': [('ters', True)],
          'tersarnas': [('ter', False)],
          'tersen': [('ters', True)],
          'tersens': [('ters', True)],
          'terser': [('ters', True)],
          'terserna': [('ters', True)],
          'tersernas': [('ters', True)],
          'tersers': [('ters', True)],
          'tersikten': [('tersikte', False)],
          'tersiktens': [('tersikte', False)],
          'tersås': [('tersås', False)],
          'tervals-': [('terval', False)],
          'tervar': [('tervara', False)],
          'tervar-': [('tervara', False)],
          'tervarens': [('tervar', False)],
          'tervars': [('tervar', False)],
          'terätters': [('terätt', False)],
          'tes': [('tes', True), ('te', True)],
          'tes-': [('tes', True), ('te', True)],
          'tesar': [('tesare', False)],
          'tesarna': [('tesare', False)],
          'tesarnas': [('te', False)],
          'tesier': [('tesi', False)],
          'tesiernas': [('tesi', False)],
          'tesiers': [('tesi', False)],
          'tesis': [('tesi', False)],
          'teskeden': [('tesked', True)],
          'tess': [('tess', False)],
          'tessen': [('tess', False)],
          'tessens': [('tess', False)],
          'tesser': [('tess', False)],
          'tesserna': [('tess', False)],
          'tessernas': [('tess', False)],
          'tessers': [('tess', False)],
          'test-': [('test', False)],
          'testar': [('test', False)],
          'testarna': [('test', False)],
          'testen': [('test', False)],
          'testens': [('test', True)],
          'tester': [('test', False)],
          'testerna': [('test', False)],
          'testernas': [('test', False)],
          'testers': [('test', False)],
          'testet': [('test', False)],
          'testets': [('test', False)],
          'tet': [('te', False)],
          'teten': [('tet', False)],
          'tetens': [('tet', False)],
          'teter': [('tet', False)],
          'tetets': [('tet', False)],
          'tetidens': [('tetid', False)],
          'tetikerna': [('tetiker', False)],
          'tetikers': [('tetiker', False)],
          'tetrorna': [('tetra', True)],
          'tetrornas': [('tetra', False)],
          'tetrors': [('tetra', True)],
          'teträn': [('teträ', False)],
          'teträna': [('teträ', False)],
          'tetränas': [('teträ', False)],
          'teträns': [('teträ', False)],
          'tets': [('te', True)],
          'tetsflagg': [('tetsflagga', False)],
          'tetsflaggs': [('tetsflagga', False)],
          'tett': [('tett', False)],
          'tett-': [('tett', False)],
          'tetten': [('tett', False)],
          'tetter': [('tett', False)],
          'tetterna': [('tett', False)],
          'tetternas': [('tett', False)],
          'tetters': [('tett', False)],
          'tettors': [('tetta', False)],
          'tetts': [('tett', False)],
          'tetts-': [('tett', False)],
          'teve': [('teve', False)],
          'teve-': [('teve', False)],
          'teven': [('teve', False)],
          'tevens': [('teve', False)],
          'teverket': [('teverk', False)],
          'tf': [('tf', True)],
          'tfader': [('tfar', False)],
          'tfader-': [('tfar', False)],
          'tfadern': [('tfar', False)],
          'tfaderns': [('tfar', False)],
          'tfaders': [('tfar', False)],
          'tfaders-': [('tfar', False)],
          'tfar': [('tfar', False)],
          'tfar-': [('tfar', False)],
          'tfare': [('tfara', False)],
          'tfars': [('tfar', False)],
          'tfars-': [('tfar', False)],
          'tfas': [('tfas', False)],
          'tfasen': [('tfas', False)],
          'tfasens': [('tfas', False)],
          'tfasoner': [('tfasoner', False)],
          'tfasonerna': [('tfasoner', False)],
          'tfasonernas': [('tfasoner', False)],
          'tfasoners': [('tfasoner', False)],
          'tfats': [('tfat', False)],
          'tfel': [('tfel', False)],
          'tfel-': [('tfel', False)],
          'tfels': [('tfel', False)],
          'tfels-': [('tfel', False)],
          'tfen': [('tfena', False)],
          'tfena': [('tfena', False)],
          'tfens': [('tfena', False)],
          'tfilar': [('tfil', False)],
          'tfilarna': [('tfil', False)],
          'tfilarnas': [('tfil', False)],
          'tfilen': [('tfil', False)],
          'tfilens': [('tfil', False)],
          'tfiskar': [('tfisk', False)],
          'tfiskarnas': [('tfisk', False)],
          'tfixar': [('tfixare', False)],
          'tfixarna': [('tfixare', False)],
          'tfixarnas': [('tfixare', False)],
          'tflagg': [('tflagga', False)],
          'tflagg-': [('tflagga', False)],
          'tflaggs': [('tflagga', False)],
          'tflaggs-': [('tflagga', False)],
          'tflott': [('tflotta', False)],
          'tflott-': [('tflotta', False)],
          'tflotte': [('tflotta', False)],
          'tflotts': [('tflotta', False)],
          'tflotts-': [('tflotta', False)],
          'tflyt': [('tfly', False)],
          'tflyts': [('tfly', False)],
          'tfläck': [('tfläck', False)],
          'tfläcks': [('tfläck', False)],
          'tflödet': [('tflöde', False)],
          'tfolierna': [('tfolie', False)],
          'tfora': [('tforum', False)],
          'tforas': [('tforum', False)],
          'tfordringar': [('tfordran', False)],
          'tfordringarna': [('tfordran', False)],
          'tfordringarnas': [('tfordran', False)],
          'tfordringars': [('tfordran', False)],
          'tformar': [('tform', False)],
          'tformarna': [('tform', False)],
          'tformarnas': [('tform', False)],
          'tfoton': [('tfoto', False)],
          'tfotons': [('tfoto', False)],
          'tfots': [('tfot', False)],
          'tfots-': [('tfot', False)],
          'tframställningar': [('tframställning', False)],
          'tframställningarna': [('tframställning', False)],
          'tframställningarnas': [('tframställning', False)],
          'tframställningars': [('tframställning', False)],
          'tfs': [('tf', True)],
          'tfyrar': [('tfyr', False)],
          'tfäder': [('tfar', False)],
          'tfäderna': [('tfar', False)],
          'tfädernas': [('tfar', False)],
          'tfäders': [('tfar', False)],
          'tfånen': [('tfåne', False)],
          'tfånens': [('tfåne', False)],
          'tfångar': [('tfångare', False)],
          'tfångarna': [('tfångare', False)],
          'tfångarnas': [('tfångare', False)],
          'tföljen': [('tfölj', False)],
          'tföljens': [('tfölj', False)],
          'tföljs': [('tfölj', False)],
          'tföljs-': [('tfölj', False)],
          'tförar': [('tförare', False)],
          'tförarna': [('tförare', False)],
          'tförarnas': [('tförare', False)],
          'tförlust-': [('tförlust', False)],
          'tförluster': [('tförlust', False)],
          'tförlusterna': [('tförlust', False)],
          'tförlusternas': [('tförlust', False)],
          'tförsäkringar': [('tförsäkring', False)],
          'tförsäkringarna': [('tförsäkring', False)],
          'tförsäkringarnas': [('tförsäkring', False)],
          'tförsäkringars': [('tförsäkring', False)],
          'tgaller': [('tgaller', False)],
          'tgallerna': [('tgaller', False)],
          'tgallernas': [('tgaller', False)],
          'tgallers': [('tgaller', False)],
          'tgandens': [('tgande', False)],
          'tgas': [('tgas', False)],
          'tgaserna': [('tgas', False)],
          'tgasernas': [('tgas', False)],
          'tgen': [('tgen', False)],
          'tgen-': [('tgen', False)],
          'tgens-': [('tgen', False)],
          'tgenus': [('tgenus', False)],
          'tgenus-': [('tgenus', False)],
          'tgiften': [('tgift', False)],
          'tgiftens': [('tgift', False)],
          'tgiftet': [('tgift', False)],
          'tgiftets': [('tgift', False)],
          'tgifts': [('tgift', False)],
          'tgifts-': [('tgift', False)],
          'tgin': [('tgina', False)],
          'tgin-': [('tgina', False)],
          'tgine': [('tgina', False)],
          'tgins': [('tgina', False)],
          'tgins-': [('tgina', False)],
          'tgivar': [('tgivare', False)],
          'tgivarna': [('tgivare', False)],
          'tgivarnas': [('tgivare', False)],
          'tgods': [('tgods', False)],
          'tgods-': [('tgods', False)],
          'tgots': [('tgot', False)],
          'tgrens': [('tgren', False)],
          'tgrevar': [('tgreve', False)],
          'tgrevarna': [('tgreve', False)],
          'tgrevarnas': [('tgreve', False)],
          'tgrevars': [('tgreve', False)],
          'tgrevens': [('tgreve', False)],
          'tgrill': [('tgrill', False)],
          'tgrills': [('tgrill', False)],
          'tgrills-': [('tgrill', False)],
          'tgrims': [('tgrimma', False)],
          'tgrims-': [('tgrimma', False)],
          'tgrums-': [('tgrums', False)],
          'tgryt': [('tgryta', False)],
          'tgryt-': [('tgryta', False)],
          'tgryts': [('tgryta', False)],
          'tgryts-': [('tgryta', False)],
          'tgräns': [('tgräns', False)],
          'tgräns-': [('tgräns', False)],
          'tgrönsaker': [('tgrönsak', False)],
          'tgrönsakerna': [('tgrönsak', False)],
          'tgrönsakernas': [('tgrönsak', False)],
          'tgrönsakers': [('tgrönsak', False)],
          'tgrönsaks': [('tgrönsak', False)],
          'tgrönsaks-': [('tgrönsak', False)],
          'tgubb': [('tgubbe', False)],
          'tgubbs': [('tgubbe', False)],
          'tgubbs-': [('tgubbe', False)],
          'tguten': [('tgut', False)],
          'tgutens': [('tgut', False)],
          'tgäng': [('tgäng', False)],
          'tgängen': [('tgäng', False)],
          'tgängens': [('tgäng', False)],
          'tgänget': [('tgäng', False)],
          'tgängets': [('tgäng', False)],
          'tgängs': [('tgäng', False)],
          'tgängs-': [('tgäng', False)],
          'tgärden': [('tgärd', False)],
          'tgärdens': [('tgärd', False)],
          'tgångar': [('tgång', False)],
          'tgångarna': [('tgång', False)],
          'tgångarnas': [('tgång', False)],
          'tgås': [('tgås', False)],
          'tgås-': [('tgås', False)],
          'tgåsen': [('tgås', False)],
          'tgåsens': [('tgås', False)],
          'tgåve-': [('tgåva', False)],
          'tgåvor': [('tgåva', False)],
          'tgåvors': [('tgåva', False)],
          'tgömme': [('tgömma', False)],
          'tgömme-': [('tgömma', False)],
          'tgöms': [('tgömma', False)],
          'tgöt': [('tgöte', False)],
          'tgöt-': [('tgöte', False)],
          'tgötar': [('tgöte', False)],
          'tgötarna': [('tgöte', False)],
          'tgötarnas': [('tgöte', False)],
          'tgötars': [('tgöte', False)],
          'tgöten': [('tgöte', False)],
          'tgötens': [('tgöte', False)],
          'tgöts': [('tgöte', False)],
          'tgöts-': [('tgöte', False)],
          'thak': [('thak', False)],
          'thake': [('thake', False)],
          'thake-': [('thake', False)],
          'thaken': [('thak', False)],
          'thakens': [('thake', False)],
          'thaks': [('thak', False)],
          'thaks-': [('thak', False)],
          'thalar': [('thalare', False)],
          'thalv': [('thalva', False)],
          'thalv-': [('thalva', False)],
          'thalvs': [('thalva', False)],
          'thalvs-': [('thalva', False)],
          'thandlar': [('thandlare', False)],
          'thandlarna': [('thandlare', False)],
          'thandlarnas': [('thandel', False)],
          'thar': [('thare', False)],
          'thar-': [('thare', False)],
          'then': [('th', False)],
          'thens': [('th', False)],
          'thet': [('the', True)],
          'theter': [('thet', False)],
          'theterna': [('thet', False)],
          'theternas': [('thet', False)],
          'theters': [('thet', False)],
          'thets': [('the', True)],
          'thets-': [('thet', False)],
          'thi': [('thia', False)],
          'thi-': [('thia', False)],
          'thias': [('thia', False)],
          'thimlen': [('thimmel', False)],
          'this': [('thia', False)],
          'tholmarna': [('tholme', False)],
          'thoparna': [('thop', False)],
          'thost': [('thosta', False)],
          'thost-': [('thosta', False)],
          'thots-': [('thot', False)],
          'thundars': [('thund', False)],
          'thus': [('thus', False)],
          'thuv': [('thuv', False)],
          'thuven': [('thuv', False)],
          'thuvens': [('thuv', False)],
          'thuvs': [('thuv', False)],
          'thuvs-': [('thuv', False)],
          'thylle': [('thylla', False)],
          'thylle-': [('thylla', False)],
          'thyvlar': [('thyvel', False)],
          'thyvlarna': [('thyvel', False)],
          'thyvlarnas': [('thyvel', False)],
          'thäfte': [('thäfte', False)],
          'thäften': [('thäfte', False)],
          'thäftens': [('thäfte', False)],
          'thäftet': [('thäfte', False)],
          'thål': [('thål', False)],
          'thåls': [('thål', False)],
          'thåls-': [('thål', False)],
          'thökar': [('thök', False)],
          'thökarna': [('thök', False)],
          'thökarnas': [('thök', False)],
          'thöns': [('thöns', False)],
          'thöns-': [('thöns', False)],
          'thörn': [('thörn', False)],
          'thörn-': [('thörn', False)],
          'thörns': [('thörn', False)],
          'thörns-': [('thörn', False)],
          'ti': [('ti', False)],
          'ti-': [('ti', False)],
          'tialen': [('tial', False)],
          'tialens': [('tial', False)],
          'tian': [('tia', True)],
          'tian-': [('tian', False)],
          'tians': [('tia', True)],
          'tiar': [('tiara', True)],
          'tiar-': [('tiara', True)],
          'tiare': [('tiara', True)],
          'tiars': [('tiara', True)],
          'tias': [('tia', True)],
          'tias-': [('tias', False)],
          'tiat': [('tiat', False)],
          'tiater': [('tiat', False)],
          'tiaters': [('tiat', False)],
          'tiats': [('tiat', False)],
          'tic': [('tic', True)],
          'tic-': [('tic', True)],
          'ticens': [('tic', True)],
          'tici': [('tici', False)],
          'tick': [('tick', True), ('ticka', True)],
          'tick-': [('ticka', True), ('tick', True)],
          'tickarnas': [('tickare', False)],
          'tickels': [('tickel', False)],
          'ticket': [('tick', False)],
          'ticklar': [('tickel', False)],
          'ticklarnas': [('tickel', False)],
          'ticks': [('ticka', True), ('tick', True)],
          'ticks-': [('ticka', True), ('tick', True)],
          'tics': [('tic', True)],
          'ticsen': [('tic', True)],
          'ticsens': [('tic', True)],
          'tidan': [('tidag', False)],
          'tidans': [('tidag', False)],
          'tidar': [('tidare', False)],
          'tidarna': [('tidag', False)],
          'tidarnas': [('tidag', False)],
          'tidars': [('tidag', False)],
          'tiden': [('tid', True)],
          'tidenderna': [('tidender', True)],
          'tidendernas': [('tidender', True)],
          'tidens': [('tid', False)],
          'tider': [('tid', True)],
          'tiderna': [('tid', True)],
          'tidernas': [('tid', True)],
          'tiders': [('tid', True)],
          'tidet': [('tid', False)],
          'tidets': [('tid', False)],
          'tidin': [('tidin', False)],
          'tidot': [('tidot', False)],
          'tids': [('tid', False)],
          'tids-': [('tid', False)],
          'tie': [('tia', False)],
          'tie-': [('tia', False)],
          'tiemens': [('tiem', False)],
          'tien': [('ti', False)],
          'tiens': [('ti', False)],
          'tier': [('ti', False)],
          'tierna': [('ti', False)],
          'tiernas': [('ti', False)],
          'tiers': [('ti', False)],
          'ties': [('ty', False)],
          'tietidens': [('tietiden', True)],
          'tiets': [('tium', False)],
          'tifs-': [('tif', False)],
          'tift': [('tift', False)],
          'tift-': [('tift', False)],
          'tiftan': [('tiftan', False)],
          'tiftarnas': [('tiftare', False)],
          'tiften': [('tift', False)],
          'tiftens': [('tift', False)],
          'tiftet': [('tift', False)],
          'tifts': [('tift', False)],
          'tifts-': [('tift', False)],
          'tigar': [('tigare', True)],
          'tigarna': [('tigare', False)],
          'tigarnas': [('tigare', False)],
          'tige-': [('tige', False)],
          'tigen': [('tige', False)],
          'tigens': [('tigen', False)],
          'tiger': [('tiger', False)],
          'tigerna': [('tige', False)],
          'tigernas': [('tige', False)],
          'tigers': [('tiger', False)],
          'tiges': [('tige', False)],
          'tiget': [('tige', False)],
          'tiggar': [('tiggare', True)],
          'tigheter': [('tighet', False)],
          'tigheterna': [('tighet', False)],
          'tigheternas': [('tighet', False)],
          'tigheters': [('tighet', False)],
          'tighets-': [('tighet', False)],
          'tigmats': [('tigma', False)],
          'tik': [('tik', True)],
          'tik-': [('tik', True)],
          'tika': [('tika', False)],
          'tikan': [('tika', False)],
          'tikana': [('tika', False)],
          'tikanas': [('tika', False)],
          'tikans': [('tika', False)],
          'tikarnas': [('tik', False)],
          'tikas': [('tika', False)],
          'tikat': [('tika', False)],
          'tikats': [('tika', False)],
          'tiker': [('tiker', False)],
          'tikerna': [('tiker', False)],
          'tikernas': [('tiker', False)],
          'tikers': [('tiker', False)],
          'tiks': [('tik', True)],
          'tiks-': [('tik', True)],
          'tilen-': [('tilena', False)],
          'tilens-': [('tilens', False)],
          'tiletten': [('tilett', False)],
          'tilian': [('tilian', False)],
          'tilians': [('tilian', False)],
          'tilie-': [('tilier', False)],
          'tilierna': [('tilier', False)],
          'tiliernas': [('tilier', False)],
          'tilister': [('tilist', False)],
          'tilisters': [('tilist', False)],
          'tilj': [('tilja', True)],
          'tilj-': [('tilja', True)],
          'tilje': [('tilja', False)],
          'tilje-': [('tilja', True)],
          'tiljen': [('tilj', False)],
          'tiljens': [('tilj', False)],
          'tiljs': [('tilja', True)],
          'tiljs-': [('tilja', True)],
          'tillan': [('tilla', False)],
          'tille': [('tilla', False)],
          'tille-': [('tilla', False)],
          'tillen': [('till', False)],
          'tiller': [('till', False)],
          'tillerna': [('till', False)],
          'tillernas': [('till', False)],
          'tillers': [('till', False)],
          'tillgångar': [('tillgångar', True), ('tillgång', True)],
          'tillgångarna': [('tillgångar', True), ('tillgång', True)],
          'tillgångarnas': [('tillgångar', True), ('tillgång', True)],
          'tillgångars': [('tillgångar', True), ('tillgång', True)],
          'tillgångs': [('tillgångar', True), ('tillgång', True)],
          'tillgångs-': [('tillgångar', True), ('tillgång', True)],
          'tillhörigheter': [('tillhörigheter', True), ('tillhörighet', True)],
          'tillhörigheterna': [('tillhörigheter', True), ('tillhörighet', True)],
          'tillhörigheternas': [('tillhörighet', True), ('tillhörigheter', True)],
          'tillhörigheters': [('tillhörigheter', True), ('tillhörighet', True)],
          'tillhörighets': [('tillhörigheter', True), ('tillhörighet', True)],
          'tillhörighets-': [('tillhörigheter', True), ('tillhörighet', True)],
          'tillor': [('tilla', False)],
          'tillorna': [('tilla', False)],
          'tillornas': [('tilla', False)],
          'tillors': [('tilla', False)],
          'tilt': [('tilta', True), ('tilt', True)],
          'tilt-': [('tilt', True), ('tilta', True)],
          'tilts': [('tilt', True), ('tilta', True)],
          'tilts-': [('tilt', True), ('tilta', True)],
          'tim': [('tim', True), ('timme', True)],
          'tim-': [('tim', True), ('timme', True)],
          'tima': [('tima', False)],
          'timan': [('timan', False)],
          'timandens': [('timande', True)],
          'timans': [('tima', False)],
          'timas': [('tima', False)],
          'time': [('time', False)],
          'time-': [('time', False)],
          'timen': [('time', False)],
          'timens': [('time', False)],
          'timer': [('timer', False)],
          'timers': [('timer', True)],
          'timmarna': [('timme', True)],
          'timmarnas': [('timme', False)],
          'timmen': [('timme', False)],
          'timmens': [('timme', False)],
          'timmerläns': [('timmerlänsa', True), ('timmerläns', True)],
          'timmerläns-': [('timmerlänsa', True), ('timmerläns', True)],
          'timmerna': [('timmer', False)],
          'timmers': [('timmer', False)],
          'tims': [('timme', False)],
          'tims-': [('timme', False)],
          'timulans': [('timulans', False)],
          'tin': [('tina', True)],
          'tin-': [('tina', False)],
          'tina': [('tina', True)],
          'tinandens': [('tinande', True)],
          'tinans': [('tina', False)],
          'tinar': [('tinare', False)],
          'tinar-': [('tinare', False)],
          'tinarens': [('tinare', False)],
          'tinarna': [('tinare', False)],
          'tinas': [('tina', True)],
          'tinens': [('tinens', False)],
          'tinets': [('tin', False)],
          'ting': [('ting', False)],
          'ting-': [('ting', False)],
          'tingan': [('tingan', False)],
          'tingans': [('tingan', False)],
          'tingar': [('ting', False)],
          'tingarna': [('ting', False)],
          'tingarnas': [('ting', False)],
          'tingars': [('ting', False)],
          'tingen': [('ting', False)],
          'tingens': [('ting', False)],
          'tinget': [('ting', False)],
          'tings': [('ting', True)],
          'tings-': [('ting', True)],
          'tingsvärmen': [('tingsvärm', False)],
          'tingsvärmens': [('tingsvärm', False)],
          'tini': [('tini', False)],
          'tini-': [('tini', False)],
          'tinier': [('tinier', False)],
          'tinierna': [('tinier', False)],
          'tinin': [('tini', False)],
          'tinins': [('tini', False)],
          'tinis': [('tini', False)],
          'tinister': [('tinist', False)],
          'tinisters': [('tinist', False)],
          'tinkomst-': [('tinkomst', False)],
          'tinkomster': [('tinkomst', False)],
          'tinkomsternas': [('tinkomst', False)],
          'tinkomsters': [('tinkomst', False)],
          'tinn': [('tinne', True)],
          'tinn-': [('tinne', True)],
          'tinnarna': [('tinne', True)],
          'tinne': [('tinne', True)],
          'tinne-': [('tinna', False)],
          'tinnen': [('tinne', True)],
          'tinns-': [('tinne', True)],
          'tinons': [('tino', False)],
          'tinor': [('tina', True)],
          'tinorna': [('tina', True)],
          'tinornas': [('tina', True)],
          'tinors': [('tina', True)],
          'tinos': [('tino', False)],
          'tinosen': [('tino', False)],
          'tins': [('tina', True)],
          'tins-': [('tina', True)],
          'tinstitutet': [('tinstitutet', False)],
          'tint': [('tint', False)],
          'tint-': [('tinta', False)],
          'tinter': [('tint', False)],
          'tinterna': [('tint', False)],
          'tinternas': [('tint', False)],
          'tinters': [('tint', False)],
          'tints': [('tinta', False)],
          'tion': [('tion', False)],
          'tionen': [('tion', False)],
          'tionens': [('tion', False)],
          'tioner': [('tion', False)],
          'tionerna': [('tion', False)],
          'tionernas': [('tion', False)],
          'tioners': [('tion', False)],
          'tions': [('tion', False)],
          'tionsdags': [('tionsdag', False)],
          'tionsdags-': [('tionsdag', False)],
          'tior': [('tia', True)],
          'tiorna': [('tia', False)],
          'tiornas': [('tia', True)],
          'tiors': [('tia', False)],
          'tiosats': [('tiosa', False)],
          'tipp': [('tipp', False)],
          'tipp-': [('tipp', False)],
          'tippar': [('tipp', True), ('tippare', True)],
          'tipparna': [('tippare', True), ('tipp', True)],
          'tipparnas': [('tippare', True), ('tipp', True)],
          'tippe': [('tippa', False)],
          'tippe-': [('tippa', False)],
          'tippen': [('tipp', True)],
          'tippens': [('tipp', False)],
          'tipps': [('tipp', False)],
          'tipps-': [('tipp', False)],
          'tips': [('tips', False)],
          'tips-': [('tips', False)],
          'tir': [('tir', True)],
          'tir-': [('tir', True)],
          'tirar': [('tir', True)],
          'tirarna': [('tir', True)],
          'tirarnas': [('tir', True)],
          'tirer': [('tir', False)],
          'tirerna': [('tir', False)],
          'tirernas': [('tir', False)],
          'tirers': [('tir', False)],
          'tirr': [('tirr', False)],
          'tirr-': [('tirr', False)],
          'tirrar': [('tirr', False)],
          'tirrarna': [('tirr', False)],
          'tirrarnas': [('tirr', False)],
          'tirrars': [('tirr', False)],
          'tirren': [('tirr', False)],
          'tirrens': [('tirr', False)],
          'tirrs-': [('tirr', False)],
          'tirs': [('tir', True)],
          'tirs-': [('tir', True)],
          'tis': [('tis', True)],
          'tis-': [('tis', True)],
          'tisarnas': [('tis', False)],
          'tisationen': [('tisation', False)],
          'tiskan': [('tiska', False)],
          'tiskans': [('tiska', False)],
          'tiske': [('tiska', False)],
          'tiske-': [('tiska', False)],
          'tismer': [('tism', False)],
          'tismerna': [('tism', False)],
          'tismernas': [('tism', False)],
          'tismers': [('tism', False)],
          'tiss-': [('tissa', False)],
          'tisse': [('tissa', False)],
          'tisse-': [('tissa', False)],
          'tissel': [('tissel', True)],
          'tissel-': [('tissel', True)],
          'tisserier': [('tisseri', False)],
          'tisseriernas': [('tisseri', False)],
          'tisseriers': [('tisseri', False)],
          'tist-': [('tist', False)],
          'tisten': [('tist', False)],
          'tistens': [('tist', False)],
          'tister': [('tist', False)],
          'tisterier': [('tisterium', False)],
          'tisterierna': [('tisterium', False)],
          'tisteriers': [('tisterium', False)],
          'tisteriet': [('tisterium', False)],
          'tisteriets': [('tisteri', False)],
          'tisterna': [('tist', False)],
          'tisternas': [('tist', False)],
          'tisters': [('tist', False)],
          'tistik': [('tistik', False)],
          'tistik-': [('tistik', False)],
          'tistiks': [('tistik', False)],
          'tistiks-': [('tistik', False)],
          'tit': [('tita', True)],
          'tit-': [('tita', True)],
          'tita': [('tita', False)],
          'titan': [('titan', True), ('tita', True)],
          'titans': [('titan', True), ('tita', True)],
          'titas': [('tita', False)],
          'titernas': [('tit', False)],
          'tites': [('tites', False)],
          'titorierna': [('titorium', False)],
          'titoriernas': [('titorium', False)],
          'titoriers': [('titorium', False)],
          'titoriets': [('titorium', False)],
          'tits': [('tita', True)],
          'tits-': [('tita', False)],
          'titt': [('titt', False)],
          'titt-': [('titt', False)],
          'tittar': [('titt', True), ('tittare', True)],
          'tittarna': [('titt', True), ('tittare', True)],
          'tittarnas': [('titt', True), ('tittare', True)],
          'titten': [('titt', False)],
          'titts': [('titt', False)],
          'titts-': [('titt', True)],
          'tium': [('tium', False)],
          'tiums': [('tium', False)],
          'tivator': [('tivator', False)],
          'tivators': [('tivator', False)],
          'tive': [('tive', False)],
          'tive-': [('tive', False)],
          'tivets': [('tiv', False)],
          'tivlins-': [('tivlins', False)],
          'tivs-': [('tiva', False)],
          'tj': [('tj', False)],
          'tjack': [('tjack', True)],
          'tjack-': [('tjack', True)],
          'tjacks': [('tjack', True)],
          'tjacks-': [('tjack', True)],
          'tjan': [('tja', False)],
          'tjans': [('tja', False)],
          'tjar': [('tj', False)],
          'tjaren': [('tjare', False)],
          'tjarna': [('tj', False)],
          'tjarnas': [('tjare', False)],
          'tjars': [('tj', False)],
          'tjat': [('tjat', True)],
          'tjats': [('tjat', True)],
          'tje': [('tja', False)],
          'tje-': [('tja', False)],
          'tjen': [('tj', False)],
          'tjens': [('tj', False)],
          'tjoll-': [('tjolle', False)],
          'tjon': [('tjon', False)],
          'tjoner': [('tjon', False)],
          'tjonerna': [('tjon', False)],
          'tjonernas': [('tjon', False)],
          'tjoners': [('tjon', False)],
          'tjons': [('tjon', False)],
          'tjos': [('tjo', True)],
          'tjos-': [('tjo', True)],
          'tjs': [('tj', False)],
          'tjs-': [('tj', False)],
          'tjug-': [('tjuga', True)],
          'tjugs-': [('tjuga', True)],
          'tjur': [('tjur', False)],
          'tjur-': [('tjur', False)],
          'tjurar': [('tjur', True)],
          'tjurarna': [('tjur', True)],
          'tjurarnas': [('tjur', False)],
          'tjurars': [('tjur', False)],
          'tjuren': [('tjur', True)],
          'tjurens': [('tjur', True)],
          'tjurs': [('tjur', False)],
          'tjurs-': [('tjur', False)],
          'tjut': [('tjut', False)],
          'tjut-': [('tjut', False)],
          'tjuten': [('tjut', False)],
          'tjutens': [('tjut', False)],
          'tjutet': [('tjut', False)],
          'tjutets': [('tjut', False)],
          'tjuts': [('tjut', False)],
          'tjuts-': [('tjut', True)],
          'tjälkarnas': [('tjälk', False)],
          'tjänt': [('tjänt', False)],
          'tjänt-': [('tjänt', False)],
          'tjänte': [('tjänte', False)],
          'tjänts': [('tjänt', False)],
          'tjänts-': [('tjänt', False)],
          'tjärn': [('tjärn', True)],
          'tjärn-': [('tjärn', True)],
          'tjärns': [('tjärn', True)],
          'tjärns-': [('tjärn', True)],
          'tjärtanden': [('tjärtand', False)],
          'tjärtandens': [('tjärtand', False)],
          'tkaj': [('tkaj', False)],
          'tkajers': [('tkaj', False)],
          'tkajs': [('tkaj', False)],
          'tkajs-': [('tkaj', False)],
          'tkalas': [('tkalas', False)],
          'tkammar': [('tkammare', False)],
          'tkapp': [('tkappa', False)],
          'tkapp-': [('tkappa', False)],
          'tkappe': [('tkappa', False)],
          'tkapps': [('tkappa', False)],
          'tkapps-': [('tkappa', False)],
          'tkar': [('tkar', False)],
          'tkar-': [('tkar', False)],
          'tkarens': [('tkar', False)],
          'tkaret': [('tkar', False)],
          'tkarets': [('tkar', False)],
          'tkars': [('tkar', False)],
          'tkars-': [('tkar', False)],
          'tkart': [('tkarta', False)],
          'tkart-': [('tkarta', False)],
          'tkarts': [('tkarta', False)],
          'tkarts-': [('tkarta', False)],
          'tkass': [('tkasse', False)],
          'tkasse': [('tkasse', False)],
          'tkasse-': [('tkasse', False)],
          'tkassen': [('tkasse', False)],
          'tkastanjen': [('tkastanj', False)],
          'tkastanjens': [('tkastanj', False)],
          'tkastanjer': [('tkastanj', False)],
          'tkastanjerna': [('tkastanj', False)],
          'tkastanjernas': [('tkastanj', False)],
          'tkastanjers': [('tkastanj', False)],
          'tkatt': [('tkatt', False)],
          'tkatt-': [('tkatt', False)],
          'tkatten': [('tkatt', False)],
          'tkattens': [('tkatt', False)],
          'tkatts': [('tkatt', False)],
          'tkatts-': [('tkatt', False)],
          'tkes': [('tkes', False)],
          'tkes-': [('tkes', False)],
          'tkesen': [('tkes', False)],
          'tkesens': [('tkes', False)],
          'tkikar': [('tkik', False)],
          'tkikarna': [('tkik', False)],
          'tkikarnas': [('tkikare', False)],
          'tkist-': [('tkista', False)],
          'tkistan': [('tkista', False)],
          'tkistans': [('tkista', False)],
          'tklapp': [('tklapp', False)],
          'tklapp-': [('tklapp', False)],
          'tklapps': [('tklapp', False)],
          'tklapps-': [('tklapp', False)],
          'tklav': [('tklav', False)],
          'tklav-': [('tklav', False)],
          'tklaven': [('tklav', False)],
          'tklavens': [('tklav', False)],
          'tklaver': [('tklav', False)],
          'tklavers': [('tklav', False)],
          'tklavs': [('tklav', False)],
          'tklavs-': [('tklav', False)],
          'tklipp': [('tklipp', False)],
          'tklipp-': [('tklipp', False)],
          'tklipps': [('tklipp', False)],
          'tklipps-': [('tklipp', False)],
          'tklubb': [('tklubb', False)],
          'tklubb-': [('tklubb', False)],
          'tklubbs': [('tklubb', False)],
          'tklubbs-': [('tklubb', False)],
          'tklädes': [('tkläder', False)],
          'tklädes-': [('tkläder', False)],
          'tklämmar': [('tkläm', False)],
          'tklämmarna': [('tkläm', False)],
          'tklämmarnas': [('tkläm', False)],
          'tknäckar': [('tknäckare', False)],
          'tknäckarna': [('tknäckare', False)],
          'tknäckarnas': [('tknäckare', False)],
          'tknäppar': [('tknäppare', False)],
          'tknäpparna': [('tknäppare', False)],
          'tknäpparnas': [('tknäppare', False)],
          'tko-': [('tko', False)],
          'tkol': [('tkol', False)],
          'tkol-': [('tkol', False)],
          'tkols': [('tkol', False)],
          'tkols-': [('tkol', False)],
          'tkom': [('tkom', False)],
          'tkom-': [('tkom', False)],
          'tkoms': [('tkom', False)],
          'tkomst-': [('tkomst', False)],
          'tkomster': [('tkomst', False)],
          'tkomsterna': [('tkomst', False)],
          'tkomsternas': [('tkomst', False)],
          'tkomsters': [('tkomst', False)],
          'tkon': [('tko', False)],
          'tkons': [('tko', False)],
          'tkonst-': [('tkonst', False)],
          'tkonsterna': [('tkonst', False)],
          'tkonsternas': [('tkonst', False)],
          'tkonsters': [('tkonst', False)],
          'tkopp': [('tkoppa', False)],
          'tkopp-': [('tkoppa', False)],
          'tkor': [('tko', False)],
          'tkors': [('tko', False)],
          'tkors-': [('tkors', False)],
          'tkos': [('tko', False)],
          'tkos-': [('tko', False)],
          'tkostnader': [('tkostnad', False)],
          'tkostnaderna': [('tkostnad', False)],
          'tkostnadernas': [('tkostnad', False)],
          'tkrafterna': [('tkraft', False)],
          'tkrafters': [('tkraft', False)],
          'tkrafts': [('tkraft', False)],
          'tkrafts-': [('tkraft', False)],
          'tkrakens': [('tkrake', False)],
          'tkramp': [('tkramp', False)],
          'tkramp-': [('tkramp', False)],
          'tkramps': [('tkramp', False)],
          'tkramps-': [('tkramp', False)],
          'tkrans': [('tkran', False)],
          'tkrans-': [('tkran', False)],
          'tkrets-': [('tkrets', False)],
          'tkris': [('tkris', False)],
          'tkris-': [('tkris', False)],
          'tkritiker': [('tkritiker', False)],
          'tkritikerna': [('tkritiker', False)],
          'tkritikernas': [('tkritiker', False)],
          'tkritikers': [('tkritiker', False)],
          'tkrokarnas': [('tkrok', False)],
          'tkronan': [('tkrona', False)],
          'tkronans': [('tkrona', False)],
          'tkrons-': [('tkrona', False)],
          'tkräks': [('tkräk', False)],
          'tkräks-': [('tkräk', False)],
          'tkräm': [('tkräm', False)],
          'tkröken': [('tkröken', False)],
          'tkrökens': [('tkröken', False)],
          'tkulan': [('tkulan', False)],
          'tkulans': [('tkulan', False)],
          'tkull': [('tkulle', False)],
          'tkull-': [('tkulle', False)],
          'tkullar': [('tkulle', False)],
          'tkullarna': [('tkulle', False)],
          'tkullarnas': [('tkulle', False)],
          'tkullars': [('tkulle', False)],
          'tkulle': [('tkulle', False)],
          'tkulle-': [('tkulle', False)],
          'tkullen': [('tkulle', False)],
          'tkullens': [('tkulle', False)],
          'tkulls': [('tkulle', False)],
          'tkulls-': [('tkulle', False)],
          'tkulors': [('tkula', False)],
          'tkurs': [('tkur', False)],
          'tkurs-': [('tkur', False)],
          'tkurv': [('tkurva', False)],
          'tkurv-': [('tkurva', False)],
          'tkurvor': [('tkurva', False)],
          'tkurvorna': [('tkurva', False)],
          'tkurvornas': [('tkurva', False)],
          'tkurvors': [('tkurva', False)],
          'tkurvs': [('tkurva', False)],
          'tkurvs-': [('tkurva', False)],
          'tkusinerna': [('tkusin', False)],
          'tkusiners': [('tkusin', False)],
          'tkusins': [('tkusin', False)],
          'tkäll': [('tkälla', False)],
          'tkäll-': [('tkälla', False)],
          'tkärr': [('tkärra', False)],
          'tkärr-': [('tkärra', False)],
          'tkärrs': [('tkärra', False)],
          'tkärrs-': [('tkärra', False)],
          'tkår': [('tkår', False)],
          'tkåren': [('tkår', False)],
          'tkårens': [('tkår', False)],
          'tkårs': [('tkår', False)],
          'tkårs-': [('tkår', False)],
          'tkök-': [('tkök', False)],
          'tköks': [('tkök', False)],
          'tköks-': [('tkök', False)],
          'tkön': [('tkö', False)],
          'tköns': [('tkö', False)],
          'tlag': [('tlag', False)],
          'tlag-': [('tlag', False)],
          'tlagarna': [('tlag', False)],
          'tlagen': [('tlag', False)],
          'tlagens': [('tlag', False)],
          'tlagerna': [('tlager', False)],
          'tlags': [('tlag', False)],
          'tlags-': [('tlag', False)],
          'tlahäst': [('tlahästar', False)],
          'tlahäst-': [('tlahästar', False)],
          'tlahästar': [('tlahästar', False)],
          'tlahästarna': [('tlahästar', False)],
          'tlamp': [('tlampa', False)],
          'tlamp-': [('tlampa', False)],
          'tlamps': [('tlampa', False)],
          'tlamps-': [('tlampa', False)],
          'tlanden': [('tlande', False)],
          'tlandena': [('tlande', False)],
          'tlandenas': [('tlande', False)],
          'tlandens': [('tlande', False)],
          'tlandet': [('tlande', False)],
          'tlandets': [('tland', False)],
          'tlandssvensk': [('tlandssvensk', False)],
          'tlandssvensk-': [('tlandssvensk', False)],
          'tlangarnas': [('tlangare', False)],
          'tlaren': [('tlare', False)],
          'tlas': [('tlas', False)],
          'tlasen': [('tlas', False)],
          'tlasens': [('tlas', False)],
          'tlaser': [('tlas', False)],
          'tlasers': [('tlas', False)],
          'tlasspinnar': [('tlasspinnare', False)],
          'tlasspinnarna': [('tlasspinnare', False)],
          'tlasspinnarnas': [('tlasspinnare', False)],
          'tlek': [('tlek', False)],
          'tlekar': [('tlek', False)],
          'tlekarna': [('tlek', False)],
          'tlekarnas': [('tlek', False)],
          'tleken': [('tlek', False)],
          'tleks-': [('tlek', False)],
          'tlemannen': [('tleman', False)],
          'tlemannens': [('tleman', False)],
          'tlementets': [('tlement', False)],
          'tlements': [('tlement', False)],
          'tlen': [('tel', False)],
          'tlens': [('tel', False)],
          'tler': [('tel', False)],
          'tler-': [('tler', False)],
          'tlerna': [('tel', False)],
          'tlernas': [('tler', False)],
          'tlers': [('tel', False)],
          'tlesen': [('tlese', False)],
          'tlet': [('tel', False)],
          'tleten': [('tlet', False)],
          'tletens': [('tlet', False)],
          'tlets': [('tel', False)],
          'tlets-': [('tlet', False)],
          'tlettens': [('tlett', False)],
          'tligans': [('tliga', False)],
          'tliggarna': [('tliggare', False)],
          'tlighets': [('tlighet', False)],
          'tlik': [('tlik', False)],
          'tliken': [('tlik', False)],
          'tlikens': [('tlik', False)],
          'tliks': [('tlik', False)],
          'tliks-': [('tlik', False)],
          'tlikvid': [('tlikvid', False)],
          'tlikvid-': [('tlikvid', False)],
          'tlikvids': [('tlikvid', False)],
          'tlimp': [('tlimpa', False)],
          'tlimps': [('tlimpa', False)],
          'tlimps-': [('tlimpa', False)],
          'tlin': [('tlina', False)],
          'tlin-': [('tlina', False)],
          'tlina': [('tlina', False)],
          'tlinne': [('tlinne', False)],
          'tlinnes': [('tlinne', False)],
          'tlins': [('tlina', False)],
          'tlins-': [('tlina', False)],
          'tlist': [('tlist', False)],
          'tlist-': [('tlist', False)],
          'tlivs': [('tliv', False)],
          'tlivs-': [('tliv', False)],
          'tlock': [('tlock', False)],
          'tlogiets': [('tlogi', False)],
          'tlopp': [('tlopp', False)],
          'tlopps': [('tlopp', False)],
          'tlopps-': [('tlopp', False)],
          'tlott': [('tlott', False)],
          'tlott-': [('tlott', False)],
          'tlottens': [('tlott', False)],
          'tlotts': [('tlott', False)],
          'tlotts-': [('tlott', False)],
          'tlov': [('tlov', False)],
          'tloven': [('tlov', False)],
          'tlovens': [('tlov', False)],
          'tlovs': [('tlov', False)],
          'tlovs-': [('tlov', False)],
          'tluck': [('tlucka', False)],
          'tluck-': [('tlucka', False)],
          'tlucks': [('tlucka', False)],
          'tlus': [('tlus', False)],
          'tlust': [('tlust', False)],
          'tlut': [('tlut', False)],
          'tlut-': [('tlut', False)],
          'tluten': [('tlut', False)],
          'tluts': [('tlut', False)],
          'tluts-': [('tlut', False)],
          'tlykts': [('tlykta', False)],
          'tläggar': [('tläggare', False)],
          'tläggarna': [('tläggare', False)],
          'tläggarnas': [('tläggare', False)],
          'tländar': [('tländare', False)],
          'tländarna': [('tländare', False)],
          'tländer': [('tland', False)],
          'tländerna': [('tland', False)],
          'tländernas': [('tland', False)],
          'tländers': [('tland', False)],
          'tlänkar': [('tlänk', False)],
          'tlänkarna': [('tlänk', False)],
          'tlänkarnas': [('tlänk', False)],
          'tlär': [('tlär', False)],
          'tlär-': [('tlär', False)],
          'tlärs': [('tlär', False)],
          'tlärs-': [('tlär', False)],
          'tläsanden': [('tläsande', False)],
          'tläsandens': [('tläsande', False)],
          'tläsarna': [('tläsare', False)],
          'tläsarnas': [('tläsare', False)],
          'tlåns': [('tlån', False)],
          'tlåns-': [('tlån', False)],
          'tlås': [('tlås', False)],
          'tlåt': [('tlåt', False)],
          'tlåtarna': [('tlåt', False)],
          'tlåts': [('tlåt', False)],
          'tlöje': [('tlöje', False)],
          'tlöje-': [('tlöje', False)],
          'tlön': [('tlön', False)],
          'tlöpe': [('tlöpe', False)],
          'tlöpe-': [('tlöpe', False)],
          'tlöpet': [('tlöpe', False)],
          'tlöpets': [('tlöpe', False)],
          'tlösarna': [('tlösare', False)],
          'tlösarnas': [('tlösare', False)],
          'tlöss': [('tlus', False)],
          'tlössen': [('tlus', False)],
          'tlössens': [('tlus', False)],
          'tm': [('tm', False)],
          'tm-': [('tm', False)],
          'tmack': [('tmacka', False)],
          'tmack-': [('tmacka', False)],
          'tmacks': [('tmacka', False)],
          'tmacks-': [('tmacka', False)],
          'tmajor': [('tmaja', False)],
          'tmajors': [('tmaja', False)],
          'tmakar': [('tmakare', False)],
          'tmakarna': [('tmakare', False)],
          'tmakarnas': [('tmakare', False)],
          'tman': [('tman', False)],
          'tmanar': [('tmanare', False)],
          'tmanarna': [('tmanare', False)],
          'tmanarnas': [('tmanare', False)],
          'tmanden': [('tmande', False)],
          'tmaner': [('tman', False)],
          'tmanerna': [('tman', False)],
          'tmanernas': [('tman', False)],
          'tmaners': [('tman', False)],
          'tmannen': [('tman', False)],
          'tmannens': [('tman', False)],
          'tmans': [('tma', False)],
          'tmarginaler': [('tmarginal', False)],
          'tmarginalerna': [('tmarginal', False)],
          'tmarginalernas': [('tmarginal', False)],
          'tmarginalers': [('tmarginal', False)],
          'tmars': [('tmara', False)],
          'tmars-': [('tmara', False)],
          'tmas': [('tma', False)],
          'tmas-': [('tmas', False)],
          'tmasen': [('tmas', False)],
          'tmask': [('tmaska', False)],
          'tmask-': [('tmaska', False)],
          'tmaster': [('tmast', False)],
          'tmasters': [('tmaster', False)],
          'tmat': [('tmat', False)],
          'tmaten': [('tmat', False)],
          'tmatros': [('tmatros', False)],
          'tmatt': [('tmatta', False)],
          'tmatt-': [('tmatta', False)],
          'tmatte': [('tmatta', False)],
          'tmatte-': [('tmatta', False)],
          'tmatten': [('tmatt', False)],
          'tmatts': [('tmatta', False)],
          'tmatts-': [('tmatta', False)],
          'tme': [('tma', False)],
          'tme-': [('tma', False)],
          'tmelon': [('tmelon', False)],
          'tmelon-': [('tmelon', False)],
          'tmeloner': [('tmelon', False)],
          'tmelonerna': [('tmelon', False)],
          'tmelonernas': [('tmelon', False)],
          'tmeloners': [('tmelon', False)],
          'tmelons': [('tmelon', False)],
          'tmen': [('tm', False)],
          'tmens': [('tm', False)],
          'tmer': [('tm', False)],
          'tmerna': [('tm', False)],
          'tmernas': [('tm', False)],
          'tmers': [('tm', False)],
          'tmes-': [('tmes', False)],
          'tmetoden': [('tmetod', False)],
          'tmetodens': [('tmetod', False)],
          'tmicklar': [('tmicklare', False)],
          'tmicklarna': [('tmicklare', False)],
          'tmicklarnas': [('tmicklare', False)],
          'tmin': [('tmi', False)],
          'tmin-': [('tmina', False)],
          'tminors': [('tmina', False)],
          'tmins': [('tmina', False)],
          'tmins-': [('tmina', False)],
          'tmjölk': [('tmjölk', False)],
          'tmjölk-': [('tmjölk', False)],
          'tmjölken': [('tmjölk', False)],
          'tmjölkens': [('tmjölk', False)],
          'tmjölks': [('tmjölk', False)],
          'tmjölks-': [('tmjölk', False)],
          'tmoder': [('tmoder', False)],
          'tmoder-': [('tmoder', False)],
          'tmodern': [('tmoder', False)],
          'tmoderns': [('tmoder', False)],
          'tmoders': [('tmoder', False)],
          'tmoders-': [('tmoder', False)],
          'tmodet': [('tmod', False)],
          'tmodets': [('tmod', False)],
          'tmods': [('tmod', False)],
          'tmods-': [('tmod', False)],
          'tmojs': [('tmoj', False)],
          'tmojs-': [('tmoj', False)],
          'tmor-': [('tmor', False)],
          'tmorna': [('tma', False)],
          'tmornas': [('tma', False)],
          'tmos': [('tmos', False)],
          'tmos-': [('tmos', False)],
          'tms': [('tm', False)],
          'tms-': [('tm', False)],
          'tmurar': [('tmur', False)],
          'tmurarna': [('tmur', False)],
          'tmurarnas': [('tmur', False)],
          'tmussel-': [('tmussla', False)],
          'tmynt': [('tmynt', False)],
          'tmynt-': [('tmynt', False)],
          'tmynts': [('tmynt', False)],
          'tmynts-': [('tmynt', False)],
          'tmyr': [('tmyra', False)],
          'tmyr-': [('tmyra', False)],
          'tmyrs': [('tmyra', False)],
          'tmyrs-': [('tmyra', False)],
          'tmän': [('tman', False)],
          'tmäns': [('tman', False)],
          'tmån': [('tmån', False)],
          'tmånen': [('tmån', False)],
          'tmånens': [('tmån', False)],
          'tmåns': [('tmåns', False)],
          'tmåns-': [('tmåns', False)],
          'tmås': [('tmås', False)],
          'tmödrar': [('tmoder', False)],
          'tmödrarna': [('tmoder', False)],
          'tmödrarnas': [('tmoder', False)],
          'tmödrars': [('tmoder', False)],
          'tmöss': [('tmössa', False)],
          'tn': [('tt', False)],
          'tnader': [('tnad', False)],
          'tnaderna': [('tnad', False)],
          'tnadernas': [('tnad', False)],
          'tnaders': [('tnad', False)],
          'tnads': [('tnad', False)],
          'tnads-': [('tnad', False)],
          'tnamn': [('tnamn', False)],
          'tnamn-': [('tnamn', False)],
          'tnamnen': [('tnamn', False)],
          'tnamnens': [('tnamn', False)],
          'tnamns': [('tnamn', False)],
          'tnamns-': [('tnamn', False)],
          'tnanden': [('tnande', False)],
          'tnar': [('ton', False)],
          'tnar-': [('tnare', False)],
          'tnaren': [('tnare', False)],
          'tnarens': [('tnare', False)],
          'tnarna': [('ton', False)],
          'tnarnas': [('ten', False)],
          'tnars': [('ten', False)],
          'tner': [('tner', False)],
          'tnerna': [('tner', False)],
          'tners': [('tner', False)],
          'tness-': [('tness', False)],
          'tnik': [('tnik', False)],
          'tnik-': [('tnik', False)],
          'tniks': [('tnik', False)],
          'tniks-': [('tnik', False)],
          'tningskurs': [('tningskurs', False)],
          'tningskurs-': [('tningskurs', False)],
          'tnisk': [('tniska', False)],
          'tnisk-': [('tniska', False)],
          'tnos': [('tnos', False)],
          'tnos-': [('tnos', False)],
          'tnosarna': [('tnos', False)],
          'tnosen': [('tnos', False)],
          'tnot': [('tnot', False)],
          'tnot-': [('tnot', False)],
          'tnots': [('tnot', False)],
          'tnots-': [('tnot', False)],
          'tns': [('tt', False)],
          'tnycklarna': [('tnyckel', False)],
          'tnär': [('tnär', False)],
          'tnärer': [('tnär', False)],
          'tnärerna': [('tnär', False)],
          'tnärernas': [('tnär', False)],
          'tnärers': [('tnär', False)],
          'tnärs': [('tnär', False)],
          'tnärs-': [('tnär', False)],
          'tnät': [('tnät', False)],
          'tnäts': [('tnät', False)],
          'tnäv': [('tnäve', False)],
          'tnäv-': [('tnäva', False)],
          'tnäve': [('tnäva', False)],
          'tnävs': [('tnäve', False)],
          'tnävs-': [('tnäva', False)],
          'tnötter': [('tnöt', False)],
          'tnötterna': [('tnöt', False)],
          'tnötternas': [('tnöt', False)],
          'tnötters': [('tnöt', False)],
          'to': [('to', False)],
          'to-': [('to', True)],
          'toar': [('to', False)],
          'toars': [('to', False)],
          'toas': [('toa', False)],
          'tober': [('tober', False)],
          'tobers': [('tober', False)],
          'tock-': [('tock', False)],
          'tockar': [('tock', False)],
          'tockarna': [('tock', False)],
          'tocken': [('tock', False)],
          'tockens': [('tock', False)],
          'tocks': [('tock', False)],
          'tocks-': [('tock', False)],
          'toddarna': [('toddy', True)],
          'toddarnas': [('toddy', False)],
          'toders': [('tod', False)],
          'todlarnas': [('todlare', False)],
          'tods': [('tod', False)],
          'tods-': [('tod', False)],
          'toe': [('toa', False)],
          'toe-': [('toa', False)],
          'toff': [('toff', False)],
          'toff-': [('toff', False)],
          'toffel': [('toffel', False)],
          'toffel-': [('toffel', True)],
          'toffer': [('toff', False)],
          'toffers': [('toff', False)],
          'tofficerare': [('tofficer', False)],
          'tofficerares': [('tofficer', False)],
          'tofficerarna': [('tofficer', False)],
          'tofficerarnas': [('tofficer', False)],
          'tofflan': [('toffel', False)],
          'tofflans': [('toffel', False)],
          'tofflorna': [('toffel', True)],
          'tofflornas': [('toffel', False)],
          'tofflors': [('toffel', False)],
          'toffs': [('toff', False)],
          'toffs-': [('toff', False)],
          'tofs': [('tofs', True)],
          'tofs-': [('tofs', False)],
          'toft': [('toft', False)],
          'toft-': [('toft', False)],
          'tofts': [('toft', False)],
          'tofts-': [('toft', True)],
          'tog': [('toga', True)],
          'tog-': [('toga', True)],
          'togans': [('toga', True)],
          'togas': [('toga', True)],
          'togen': [('togen', False)],
          'togenerna': [('togen', False)],
          'togens': [('togen', False)],
          'togrammet': [('togram', False)],
          'togrammets': [('togram', False)],
          'togs': [('toga', True)],
          'togs-': [('toga', True)],
          'tojets': [('toj', False)],
          'tok': [('toka', True), ('tok', True)],
          'tok-': [('toka', True), ('tok', True)],
          'tokan': [('toka', True)],
          'tokar': [('toker', True), ('tok', True)],
          'tokarna': [('toker', True), ('tok', True)],
          'tokarnas': [('tok', True), ('toker', True)],
          'tokars': [('toker', True), ('tok', True)],
          'toker': [('toker', True)],
          'tokerit': [('tokeri', True)],
          'tokers': [('toker', True)],
          'tokondrien': [('tokondrie', False)],
          'tokondriernas': [('tokondrie', False)],
          'toks': [('toka', True), ('tok', True)],
          'toks-': [('toka', True), ('tok', True)],
          'tolan': [('tolan', False)],
          'tolans': [('tolan', False)],
          'toles': [('tole', False)],
          'toli': [('toli', False)],
          'tolien': [('toli', False)],
          'toliens': [('toli', False)],
          'tolier': [('toli', False)],
          'tolierna': [('toli', False)],
          'toliernas': [('toli', False)],
          'toliers': [('toli', False)],
          'tolins': [('toli', False)],
          'tolis': [('toli', False)],
          'toliter': [('toliter', False)],
          'toliterna': [('toliter', False)],
          'toliternas': [('toliter', False)],
          'toliters': [('toliter', False)],
          'tolk': [('tolk', True)],
          'tolk-': [('tolk', False)],
          'tolkar': [('tolkare', True), ('tolk', True)],
          'tolkarna': [('tolkare', True), ('tolk', True)],
          'tolkarnas': [('tolkare', True), ('tolk', True)],
          'tolks': [('tolk', False)],
          'tolks-': [('tolk', False)],
          'toll': [('toll', False)],
          'tolle-': [('tolla', False)],
          'toller': [('toll', False)],
          'tollerna': [('toll', False)],
          'tollernas': [('toll', False)],
          'tollers': [('toll', False)],
          'tolls-': [('toll', False)],
          'tologier': [('tologi', False)],
          'tologierna': [('tologi', False)],
          'tologiers': [('tologi', False)],
          'tolt': [('tolta', True)],
          'tolts-': [('tolta', True)],
          'tom': [('tom', True)],
          'tom-': [('tom', True)],
          'tomans-': [('toman', False)],
          'tomb': [('tomb', False)],
          'tomb-': [('tomb', False)],
          'tomben': [('tomb', False)],
          'tombens': [('tomb', False)],
          'tomber': [('tomb', False)],
          'tomberna': [('tomb', False)],
          'tombernas': [('tomb', False)],
          'tombers': [('tomb', False)],
          'tombs': [('tomb', False)],
          'tombs-': [('tomb', False)],
          'tomen': [('tom', False)],
          'tomens': [('tom', False)],
          'tometer': [('tometer', False)],
          'tometers': [('tometer', False)],
          'tommar': [('tomme', False)],
          'tommarnas': [('tomme', False)],
          'tommars': [('tomme', False)],
          'tommen': [('tomme', False)],
          'tommens': [('tomme', False)],
          'tomos': [('tomos', False)],
          'tompar': [('tomp', False)],
          'tompars': [('tomp', False)],
          'toms': [('tom', True)],
          'toms-': [('tom', True)],
          'tomten': [('tomte', True), ('tomt', True)],
          'tomtens': [('tomte', True), ('tomt', True)],
          'ton': [('ton', True)],
          'ton-': [('ton', False)],
          'tona': [('to', False)],
          'tonar': [('ton', False)],
          'tonarnas': [('ton', False)],
          'tonars': [('ton', False)],
          'tonas': [('to', False)],
          'tondagen': [('tondag', False)],
          'tondagens': [('tondag', False)],
          'toner': [('ton', True)],
          'tonerna': [('ton', True)],
          'tonernas': [('ton', True)],
          'toners': [('ton', True)],
          'tong': [('tong', False)],
          'tong-': [('tong', False)],
          'tonger': [('tong', False)],
          'tongerna': [('tong', False)],
          'tongernas': [('tong', False)],
          'tongers': [('tong', False)],
          'tongs': [('tong', False)],
          'tongs-': [('tong', False)],
          'toni': [('toni', False)],
          'toni-': [('toni', False)],
          'tonien': [('toni', False)],
          'toniens': [('toni', False)],
          'tonierna': [('toni', False)],
          'toniers': [('toni', False)],
          'tonik': [('tonika', True)],
          'tonik-': [('tonika', True)],
          'toniker': [('toniker', False)],
          'tonikerna': [('toniker', False)],
          'tonikernas': [('toniker', False)],
          'tonikers': [('toniker', False)],
          'toniks': [('tonika', True)],
          'toniks-': [('tonika', True)],
          'tonin': [('toni', False)],
          'tonins': [('toni', False)],
          'tonis': [('toni', False)],
          'tonnen': [('ton', False)],
          'tonomens': [('tonom', False)],
          'tons': [('ton', True)],
          'tons-': [('ton', False)],
          'tonskal': [('tonskala', True)],
          'tonskals': [('tonskala', True)],
          'tonskals-': [('tonskala', True)],
          'tonvals': [('tonval', True)],
          'tonvals-': [('tonval', True)],
          'toorna': [('toa', False)],
          'toornas': [('toa', False)],
          'toparnas': [('top', False)],
          'topier': [('topi', False)],
          'topierna': [('topi', False)],
          'topiernas': [('topi', False)],
          'topiers': [('topi', False)],
          'topins': [('topi', False)],
          'topp': [('topp', False)],
          'topp-': [('topp', False)],
          'toppar': [('topp', False)],
          'topparen': [('toppare', False)],
          'topparens': [('toppare', False)],
          'topparna': [('topp', False)],
          'topparnas': [('topp', True)],
          'toppars': [('topp', True)],
          'toppen': [('topp', False)],
          'toppens': [('topp', False)],
          'topper': [('topper', False)],
          'topps': [('topp', False)],
          'topps-': [('topp', False)],
          'toppände': [('toppände', True), ('toppända', True)],
          'toppände-': [('toppända', True), ('toppände', True)],
          'tops': [('tops', False)],
          'tops-': [('tops', False)],
          'topsar': [('tops', True)],
          'topsarna': [('tops', False)],
          'topsarnas': [('tops', True)],
          'topsars': [('tops', False)],
          'topsen': [('tops', True)],
          'topsens': [('tops', True)],
          'topsis': [('topsi', False)],
          'tor': [('tor', False)],
          'toranden': [('torand', False)],
          'torandens': [('torand', False)],
          'torbrors': [('torbrorsa', False)],
          'tord': [('tord', False)],
          'tord-': [('tord', False)],
          'torden': [('tord', False)],
          'tordens': [('tord', False)],
          'tordnar': [('torden', False)],
          'tordnarna': [('torden', False)],
          'tordnarnas': [('torden', False)],
          'tords': [('tord', False)],
          'tore': [('tore', False)],
          'tore-': [('tore', False)],
          'tores': [('tore', False)],
          'tores-': [('tore', False)],
          'torgen': [('torg', False)],
          'torgens': [('torg', True)],
          'torgierna': [('torgie', False)],
          'tori': [('tori', False)],
          'tori-': [('tori', False)],
          'torian': [('torian', False)],
          'torians': [('torian', False)],
          'torie': [('torium', False)],
          'torie-': [('torium', False)],
          'torien': [('toria', False)],
          'torierna': [('torium', False)],
          'toriernas': [('torium', False)],
          'toriers': [('torium', False)],
          'toriet': [('torium', True)],
          'toriets': [('torium', False)],
          'toriker': [('toriker', False)],
          'torikerna': [('toriker', False)],
          'torikernas': [('toriker', False)],
          'torikers': [('toriker', False)],
          'torit': [('tori', False)],
          'torits': [('tori', False)],
          'tork': [('torka', True), ('tork', True)],
          'tork-': [('torka', True), ('tork', True)],
          'torkan': [('torka', False)],
          'torkans': [('torka', False)],
          'torkar': [('tork', False)],
          'torkarna': [('tork', False)],
          'torkarnas': [('tork', True)],
          'tormanden': [('tormande', False)],
          'tormar': [('torm', False)],
          'tormarna': [('torm', False)],
          'tormarnas': [('torm', False)],
          'torn': [('torn', False)],
          'torn-': [('torn', False)],
          'tornar': [('torn', True)],
          'tornarna': [('torn', False)],
          'tornarnas': [('torn', False)],
          'tornars': [('torn', False)],
          'tornen': [('torn', False)],
          'tornens': [('torn', False)],
          'tornister': [('tornister', True)],
          'tornisters': [('tornister', True)],
          'torns': [('torn', False)],
          'torns-': [('torn', False)],
          'toros': [('toro', False)],
          'torp': [('torp', True)],
          'torp-': [('torp', False)],
          'torparna': [('torpare', True)],
          'torparnas': [('torpare', False)],
          'torps': [('torp', False)],
          'torskarnas': [('torsk', False)],
          'tort': [('torta', True)],
          'tort-': [('torta', True)],
          'torte': [('torta', True)],
          'torte-': [('torta', True)],
          'torten': [('tort', False)],
          'tortens': [('tort', False)],
          'torter': [('tort', False)],
          'torternas': [('tort', False)],
          'torters': [('tort', False)],
          'torts': [('torta', True)],
          'torts-': [('torta', True)],
          'torv': [('torva', True), ('torv', True)],
          'torv-': [('torv', True), ('torva', True)],
          'torvs': [('torva', True), ('torv', True)],
          'torvs-': [('torva', True), ('torv', True)],
          'tos': [('tosa', True)],
          'tos-': [('tosa', True)],
          'tosa': [('tosa', True)],
          'tosan': [('tosa', True)],
          'tosans': [('tosa', True)],
          'tosas': [('tosa', True)],
          'tosk': [('tosk', True)],
          'tosk-': [('tosk', True)],
          'toss': [('tossa', True)],
          'tosse': [('tossa', False)],
          'tosse-': [('tossa', False)],
          'tost-': [('tost', False)],
          'tostarna': [('tost', False)],
          'tot': [('to', False)],
          'toton': [('toto', True)],
          'totons': [('toto', True)],
          'totron': [('totron', False)],
          'totrons': [('totron', False)],
          'tots': [('to', False)],
          'tott': [('tott', False)],
          'tott-': [('tott', False)],
          'tottar': [('tott', False)],
          'tottarnas': [('tott', False)],
          'tottars': [('tott', True)],
          'totten': [('tott', False)],
          'totter': [('tott', False)],
          'totterna': [('tott', False)],
          'totternas': [('tott', False)],
          'totters': [('tott', False)],
          'totts': [('tott', False)],
          'totts-': [('tott', False)],
          'toucher': [('touche', True)],
          'touchernas': [('touche', True)],
          'tours': [('tour', True)],
          'tours-': [('tour', True)],
          'touten': [('tout', False)],
          'toutens': [('tout', False)],
          'touter': [('tout', False)],
          'touterna': [('tout', False)],
          'touternas': [('tout', False)],
          'touters': [('tout', False)],
          'tov': [('tova', True)],
          'tov-': [('tova', True)],
          'tovs': [('tova', True)],
          'tovs-': [('tova', True)],
          'tox': [('toxe', False)],
          'tox-': [('tox', False)],
          'toxar': [('toxe', False)],
          'toxarna': [('toxe', False)],
          'toxarnas': [('toxe', False)],
          'toxars': [('toxe', False)],
          'toxen': [('toxe', False)],
          'toxens': [('toxe', False)],
          'toxin': [('toxin', False)],
          'tozon': [('tozo', False)],
          'tozons': [('tozo', False)],
          'tpack': [('tpacke', False)],
          'tpack-': [('tpacke', False)],
          'tpackarna': [('tpacke', False)],
          'tpacke': [('tpacke', False)],
          'tpacke-': [('tpacke', False)],
          'tpacken': [('tpacke', False)],
          'tpackens': [('tpacke', False)],
          'tpacks': [('tpacke', False)],
          'tpacks-': [('tpacke', False)],
          'tpakets': [('tpaket', False)],
          'tpakten': [('tpakt', False)],
          'tpastor': [('tpastor', False)],
          'tpastors': [('tpastor', False)],
          'tpelar': [('tpelare', False)],
          'tpelar-': [('tpelare', False)],
          'tpeng': [('tpengar', False)],
          'tpeng-': [('tpengar', False)],
          'tpengar': [('tpengar', False)],
          'tpengarna': [('tpengar', False)],
          'tpengarnas': [('tpeng', False)],
          'tpengars': [('tpengar', False)],
          'tpengs': [('tpengar', False)],
          'tpengs-': [('tpengar', False)],
          'tpenn': [('tpenna', False)],
          'tpiller': [('tpiller', False)],
          'tpillerna': [('tpiller', False)],
          'tpillers': [('tpiller', False)],
          'tpinnar': [('tpinne', False)],
          'tpinnarnas': [('tpinne', False)],
          'tpinnens': [('tpinne', False)],
          'tpinns': [('tpinne', False)],
          'tpipar': [('tpipare', False)],
          'tpiparna': [('tpipare', False)],
          'tpiparnas': [('tpipare', False)],
          'tpisk': [('tpiska', False)],
          'tpisk-': [('tpiska', False)],
          'tplanet': [('tplan', False)],
          'tplanets': [('tplan', False)],
          'tpojk': [('tpojke', False)],
          'tpojk-': [('tpojke', False)],
          'tpojks': [('tpojke', False)],
          'tpojks-': [('tpojke', False)],
          'tpol': [('tpol', False)],
          'tpolen': [('tpol', False)],
          'tpols': [('tpol', False)],
          'tpors': [('tpors', False)],
          'tpors-': [('tpors', False)],
          'tportarnas': [('tport', False)],
          'tposter': [('tpost', False)],
          'tposters': [('tpost', False)],
          'tpraktiks': [('tpraktik', False)],
          'tpressar': [('tpress', False)],
          'tpressarna': [('tpress', False)],
          'tpressarnas': [('tpressare', False)],
          'tprick-': [('tprick', False)],
          'tprickar': [('tprick', False)],
          'tprickarna': [('tprick', False)],
          'tprickarnas': [('tprick', False)],
          'tpricks': [('tprick', False)],
          'tpricks-': [('tprick', False)],
          'tproblemet': [('tproblem', False)],
          'tproblemets': [('tproblem', False)],
          'tprocessen': [('tprocess', False)],
          'tprocessens': [('tprocess', False)],
          'tprogrammet': [('tprogram', False)],
          'tprogrammets': [('tprogram', False)],
          'tpropeller': [('tpropeller', False)],
          'tpropellers': [('tpropeller', False)],
          'tprops': [('tprops', False)],
          'tpump': [('tpump', False)],
          'tpumps': [('tpump', False)],
          'tpumps-': [('tpump', False)],
          'tput': [('tput', False)],
          'tput-': [('tput', False)],
          'tputs': [('tput', False)],
          'tpåsar': [('tpåse', False)],
          'tr': [('tra', False)],
          'tr-': [('tra', False)],
          'tra': [('trum', False)],
          'tradans': [('trada', False)],
          'tradar': [('tradare', False)],
          'tradar-': [('tradare', False)],
          'trade': [('trade', True)],
          'traden': [('trad', False)],
          'tradens': [('trad', False)],
          'trador': [('trada', False)],
          'tradorna': [('trada', False)],
          'tradornas': [('trada', False)],
          'tradors': [('trada', False)],
          'trads': [('trad', False)],
          'trage': [('trage', False)],
          'trage-': [('trage', False)],
          'tragets': [('trage', False)],
          'tragus': [('tragus', False)],
          'traj': [('traj', False)],
          'traj-': [('traj', False)],
          'trajs': [('traj', True)],
          'trajs-': [('traj', True)],
          'trakan': [('trakan', False)],
          'trakans': [('trakan', False)],
          'tralier': [('tralier', False)],
          'traliernas': [('tralier', False)],
          'traliers': [('tralier', False)],
          'trall': [('trall', True), ('tralla', True)],
          'trall-': [('tralla', True), ('trall', True)],
          'trallar': [('trall', False)],
          'trallarna': [('trall', True)],
          'trallarnas': [('trall', True)],
          'tralls': [('trall', True), ('tralla', True)],
          'tralls-': [('tralla', True), ('trall', True)],
          'tramarna': [('tram', False)],
          'tramins': [('trami', False)],
          'tramp': [('trampa', True), ('tramp', True)],
          'tramp-': [('trampa', True), ('tramp', True)],
          'tramps': [('trampa', True), ('tramp', True)],
          'tramps-': [('trampa', True), ('tramp', True)],
          'trams': [('trams', True)],
          'trams-': [('trams', True)],
          'tran': [('trana', True), ('tran', True)],
          'tran-': [('trana', True), ('tran', True)],
          'trana': [('trana', True)],
          'tranas': [('trana', True)],
          'trancen': [('trance', True)],
          'trancens': [('trance', True)],
          'trande': [('trande', False)],
          'trande-': [('trande', False)],
          'tranden': [('trande', False)],
          'trandens': [('trande', False)],
          'trandet': [('trande', False)],
          'trans': [('trana', True), ('tran', True), ('transa', True), ('trans', True)],
          'trans-': [('trans', True), ('trana', True), ('transa', True), ('tran', True)],
          'trap-': [('trap', False)],
          'trapats': [('trapats', False)],
          'trapats-': [('trapats', False)],
          'trapets': [('trapets', False)],
          'trapp': [('trapp', True), ('trappa', True)],
          'trapp-': [('trapp', True), ('trappa', True)],
          'trappar': [('trapp', True)],
          'trapparna': [('trapp', True)],
          'trapparnas': [('trapp', True)],
          'trapper': [('trapper', True)],
          'trapperna': [('trapper', True)],
          'trappernas': [('trapper', True)],
          'trappers': [('trapper', True)],
          'trapps': [('trapp', True), ('trappa', True)],
          'trapps-': [('trappa', True), ('trapp', True)],
          'trappsteg': [('trappstege', True), ('trappsteg', True)],
          'trappsteg-': [('trappstege', True), ('trappsteg', True)],
          'trappstegen': [('trappsteg', True), ('trappstege', True)],
          'trappstegens': [('trappstege', True), ('trappsteg', True)],
          'trappstegs': [('trappsteg', True), ('trappstege', True)],
          'trappstegs-': [('trappstege', True), ('trappsteg', True)],
          'traps': [('trap', False)],
          'traps-': [('trap', False)],
          'trarnas': [('ter', False)],
          'tras': [('trasa', True)],
          'tras-': [('trasa', True)],
          'trasen': [('tras', False)],
          'trasens': [('tras', False)],
          'trassen': [('trass', False)],
          'trassens': [('trass', False)],
          'trasslandens': [('trasslande', True)],
          'trastens': [('trast', False)],
          'traster': [('trast', False)],
          'trasterna': [('trast', False)],
          'trasternas': [('trast', False)],
          'trasters': [('trast', False)],
          'trat': [('trat', False)],
          'tratanas': [('tratum', False)],
          'tratas': [('tratum', False)],
          'traten': [('trat', False)],
          'tratens': [('trat', False)],
          'trater': [('trat', False)],
          'traterna': [('trat', False)],
          'traternas': [('trat', False)],
          'traters': [('trat', False)],
          'trats': [('trat', False)],
          'tratt': [('tratta', True), ('tratt', True)],
          'tratt-': [('tratta', True), ('tratt', True)],
          'trattarna': [('tratt', False)],
          'trattarnas': [('tratt', False)],
          'tratts': [('tratta', True), ('tratt', True)],
          'tratts-': [('tratta', True), ('tratt', True)],
          'trav': [('trave', True), ('trav', True)],
          'trav-': [('trave', True), ('trav', True)],
          'travar': [('travare', True), ('trave', True)],
          'travarna': [('travare', True), ('trave', True)],
          'travarnas': [('travare', True), ('trave', True)],
          'traven': [('trave', True), ('trav', True)],
          'travens': [('trav', True), ('trave', True)],
          'travers': [('travers', True)],
          'travs': [('trave', True), ('trav', True)],
          'travs-': [('trave', True), ('trav', True)],
          'traxen': [('trax', False)],
          'traxens': [('trax', False)],
          'tre': [('tra', False)],
          'tre-': [('tra', False)],
          'trean': [('trea', True)],
          'treans': [('trea', True)],
          'treas': [('trea', True)],
          'tremens': [('trem', False)],
          'tremer': [('trem', False)],
          'tremerna': [('trem', False)],
          'tremernas': [('trem', False)],
          'tremers': [('trem', False)],
          'tremiss': [('tremiss', False)],
          'tremiss-': [('tremiss', False)],
          'tremmar': [('trem', False)],
          'tremmarna': [('trem', False)],
          'tremmarnas': [('trem', False)],
          'trems': [('trem', False)],
          'trems-': [('tremsa', False)],
          'tren': [('tur', False)],
          'trena': [('trum', False)],
          'trenar': [('trenare', False)],
          'trenarna': [('trenare', False)],
          'trenarnas': [('trenare', False)],
          'trenas': [('trum', False)],
          'trens': [('ter', False)],
          'trep': [('trep', False)],
          'trepan': [('trepan', True)],
          'trepans': [('trepan', True)],
          'trepen': [('trep', False)],
          'trepet': [('trep', False)],
          'trepets': [('trep', False)],
          'treps': [('trep', False)],
          'treps-': [('trep', False)],
          'trer': [('trum', False)],
          'trers': [('ter', False)],
          'trese': [('tresa', False)],
          'trese-': [('tresa', False)],
          'treskiftet': [('treskift', True), ('treskifte', True)],
          'treskiftets': [('treskifte', True), ('treskift', True)],
          'tressen': [('tresse', False)],
          'tressens': [('tresse', False)],
          'tresurs': [('tresurser', False)],
          'tresurs-': [('tresurser', False)],
          'tresurser': [('tresurser', False)],
          'tresurserna': [('tresurser', False)],
          'tresursernas': [('tresurser', False)],
          'tresursers': [('tresurser', False)],
          'tret': [('ter', False)],
          'tretanden': [('tretand', True)],
          'tretandens': [('tretand', True)],
          'tretarnas': [('tretare', False)],
          'trets': [('trum', False)],
          'trets-': [('tret', False)],
          'trev': [('treva', False)],
          'trev-': [('treva', False)],
          'trevar': [('trevare', True)],
          'trevarna': [('trevare', True)],
          'trevarnas': [('trevare', True)],
          'trevens': [('trev', False)],
          'trevs': [('trev', False)],
          'trevs-': [('treva', False)],
          'tri': [('tri', False)],
          'tri-': [('tri', False)],
          'trian': [('tria', False)],
          'trians': [('tria', False)],
          'trias': [('trias', True)],
          'trick': [('trick', False)],
          'trickarnas': [('trick', True)],
          'trickets': [('trick', False)],
          'tricks': [('tricks', True), ('trick', True)],
          'tricks-': [('tricks', True), ('trick', True)],
          'trid': [('trid', False)],
          'trider': [('trid', False)],
          'triderna': [('trid', False)],
          'tridernas': [('trid', False)],
          'triders': [('trid', False)],
          'tridis': [('tridis', False)],
          'trie': [('trium', False)],
          'trie-': [('trium', False)],
          'trien': [('tri', False)],
          'trier': [('trium', False)],
          'trierna': [('trium', False)],
          'triernas': [('tri', False)],
          'triers': [('trium', False)],
          'triet': [('trium', False)],
          'triets': [('trium', False)],
          'trig': [('trig', False)],
          'trig-': [('trig', False)],
          'triggar': [('triggare', False)],
          'triggarna': [('triggare', False)],
          'triggarnas': [('triggare', False)],
          'trighets': [('trighet', False)],
          'trigs': [('trig', False)],
          'trigs-': [('trig', False)],
          'trik': [('trik', False)],
          'trik-': [('trik', False)],
          'trikar': [('trike', False)],
          'trikarnas': [('trike', False)],
          'triken': [('trik', False)],
          'trikens': [('trik', False)],
          'triks': [('trik', False)],
          'triks-': [('trike', False)],
          'trilanden': [('trilande', False)],
          'trilandens': [('trilande', False)],
          'trill': [('trilla', True)],
          'trill-': [('trilla', True)],
          'trillar': [('trillare', False)],
          'trills': [('trilla', True)],
          'trills-': [('trilla', True)],
          'trim': [('trim', False)],
          'trim-': [('trim', True)],
          'trims': [('trim', False)],
          'trims-': [('trim', False)],
          'trin': [('tri', False)],
          'trin-': [('trin', False)],
          'triner': [('trin', False)],
          'trinerna': [('trin', False)],
          'trinernas': [('trin', False)],
          'triners': [('trin', False)],
          'tringarna': [('tring', False)],
          'tringarnas': [('tring', False)],
          'trins': [('tri', True)],
          'trins-': [('trin', False)],
          'triolets': [('triol', False)],
          'trion': [('trio', False)],
          'trions': [('trio', True)],
          'trior': [('trio', True)],
          'triorna': [('trio', True)],
          'triornas': [('trio', True)],
          'triors': [('trio', True)],
          'trios': [('trio', True)],
          'trios-': [('trio', True)],
          'triot': [('triot', False)],
          'tripar': [('trip', False)],
          'triparna': [('trip', False)],
          'tripp': [('tripp', True)],
          'tripp-': [('tripp', True)],
          'trippar': [('tripp', True)],
          'tripparna': [('tripp', True)],
          'tripparnas': [('tripp', False)],
          'tripplar': [('tripplare', True), ('trippel', True)],
          'tripplarna': [('tripplare', True), ('trippel', True)],
          'tripplarnas': [('tripplare', True), ('trippel', True)],
          'tripps': [('tripp', True)],
          'tripps-': [('tripp', True)],
          'trips': [('trips', True)],
          'trips-': [('trips', True)],
          'tris': [('tri', True)],
          'tris-': [('tris', False)],
          'trisens': [('tris', False)],
          'triser': [('tris', False)],
          'triserna': [('tris', False)],
          'trisernas': [('tris', False)],
          'trisers': [('tris', False)],
          'trisk': [('trisk', False)],
          'trisk-': [('trisk', False)],
          'triss': [('trissa', True), ('triss', True)],
          'triss-': [('triss', True), ('trissa', True)],
          'trit': [('trit', False)],
          'trit-': [('trit', False)],
          'tritar': [('trit', False)],
          'tritarna': [('trit', False)],
          'tritarnas': [('trit', False)],
          'triter': [('trit', False)],
          'triterna': [('trit', False)],
          'triters': [('trit', False)],
          'trits': [('trit', False)],
          'trits-': [('trit', False)],
          'trizon': [('trizon', False)],
          'trock': [('trock', False)],
          'trockar': [('trock', False)],
          'trockarna': [('trock', False)],
          'trockarnas': [('trock', False)],
          'trod': [('trod', False)],
          'trod-': [('trod', False)],
          'troder': [('trod', False)],
          'troderna': [('trod', False)],
          'trodernas': [('trod', False)],
          'troders': [('trod', False)],
          'trods': [('trod', False)],
          'trods-': [('trod', False)],
          'troen': [('troen', False)],
          'troens': [('troen', False)],
          'trogen': [('trogen', False)],
          'trogen-': [('trogen', False)],
          'trogener': [('trogen', False)],
          'trogenernas': [('trogen', False)],
          'trogeners': [('trogen', False)],
          'troket': [('troke', False)],
          'trokets': [('troke', False)],
          'trollar': [('trollare', False)],
          'trollarna': [('trollare', False)],
          'trollarnas': [('trollare', False)],
          'troller': [('troll', False)],
          'trollerna': [('troll', False)],
          'trollernas': [('troll', False)],
          'trollers': [('troll', False)],
          'trolls': [('troll', False)],
          'trolls-': [('troll', False)],
          'tromans': [('troman', False)],
          'tromans-': [('troman', True)],
          'tron': [('tro', True), ('tron', True)],
          'tron-': [('tron', True)],
          'trona': [('trona', False)],
          'tronas': [('trona', False)],
          'trone': [('trona', False)],
          'trone-': [('trona', False)],
          'tronen': [('tron', False)],
          'tronens': [('tron', False)],
          'troner': [('tron', False)],
          'tronerna': [('tron', False)],
          'tronernas': [('tron', False)],
          'troners': [('tron', False)],
          'tronik': [('tronik', False)],
          'tronik-': [('tronik', False)],
          'troniks': [('tronik', False)],
          'tronomen': [('tronom', False)],
          'trons': [('tron', True), ('tro', True)],
          'trons-': [('tron', False)],
          'tropar-': [('tropare', False)],
          'troparen': [('tropare', False)],
          'troparnas': [('tropare', False)],
          'tropen': [('trop', False)],
          'tropens': [('trop', False)],
          'tropikerna': [('tropik', True), ('tropikerna', True)],
          'tropikernas': [('tropikerna', True), ('tropik', True)],
          'tropin': [('tropi', False)],
          'tropins': [('tropin', False)],
          'tropparna': [('tropp', False)],
          'tropparnas': [('tropp', False)],
          'tropps': [('tropp', True)],
          'tropps-': [('tropp', True)],
          'trops': [('trop', False)],
          'trorna': [('tra', False)],
          'trornas': [('tra', False)],
          'trors': [('tra', False)],
          'tros': [('tro', True), ('trosa', True)],
          'tros-': [('tro', True), ('trosa', True)],
          'trosor': [('trosa', True)],
          'trosorna': [('trosa', False)],
          'trosornas': [('trosa', False)],
          'trosors': [('trosa', False)],
          'trossarna': [('tross', False)],
          'trot': [('trot', False)],
          'trotar': [('trot', False)],
          'trotarna': [('trot', False)],
          'trotarnas': [('trot', False)],
          'trotars': [('trot', False)],
          'troten': [('trot', False)],
          'trotens': [('trot', False)],
          'trots': [('trots', True)],
          'trots-': [('trots', True)],
          'trottarna': [('trott', False)],
          'trotter': [('trotter', False)],
          'trotters': [('trotter', False)],
          'trovers': [('trovers', False)],
          'trs': [('tra', False)],
          'trs-': [('tra', False)],
          'tru-': [('tru', False)],
          'trug': [('trug', True), ('truga', True)],
          'trug-': [('truga', True), ('trug', True)],
          'trugs': [('trug', True), ('truga', True)],
          'trugs-': [('truga', True), ('trug', True)],
          'truk': [('truk', False)],
          'truk-': [('truk', False)],
          'truks': [('truk', False)],
          'truks-': [('truk', False)],
          'trull': [('trull', False)],
          'trull-': [('trull', False)],
          'trullar': [('trullare', False)],
          'trullarna': [('trulle', False)],
          'trullarnas': [('trullare', False)],
          'trulle': [('trulle', False)],
          'trulle-': [('trulle', False)],
          'trullen': [('trull', False)],
          'trullens': [('trull', False)],
          'trulls': [('trulle', False)],
          'trulls-': [('trulle', False)],
          'truls': [('truls', True)],
          'truls-': [('truls', True)],
          'trum': [('trumma', True)],
          'trum-': [('trumma', True)],
          'trums': [('trumma', True)],
          'trums-': [('trumma', True)],
          'trumset': [('trumset', True)],
          'trundans': [('trunda', False)],
          'trunkar': [('trunk', True)],
          'trunkarna': [('trunk', True)],
          'trunkarnas': [('trunk', True)],
          'trus': [('trus', False)],
          'trus-': [('trus', False)],
          'trusar': [('trus', False)],
          'trusarna': [('trus', False)],
          'trusk': [('trusk', False)],
          'trusk-': [('trusk', False)],
          'trut': [('trut', False)],
          'trut-': [('trut', False)],
          'truten': [('trut', True)],
          'trutens': [('trut', True)],
          'truts': [('trut', False)],
          'truts-': [('trut', False)],
          'try': [('try', False)],
          'try-': [('try', False)],
          'tryck': [('tryck', False)],
          'trycke': [('trycke', True)],
          'trycken': [('trycke', True), ('tryck', True)],
          'tryckens': [('trycke', True), ('tryck', True)],
          'trycket': [('trycke', True), ('tryck', True)],
          'tryckets': [('trycke', True), ('tryck', True)],
          'trycks': [('trycke', True), ('tryck', True)],
          'trycks-': [('trycke', True), ('tryck', True)],
          'tryggar': [('trygg', False)],
          'tryn': [('tryne', True)],
          'trynets': [('tryne', True)],
          'tryns': [('tryne', True)],
          'trys': [('try', False)],
          'tryssarnas': [('tryss', False)],
          'tryt': [('try', False)],
          'tryts': [('try', False)],
          'träck': [('träck', True)],
          'träck-': [('träck', True)],
          'träckar': [('träckare', False)],
          'träckarna': [('träckare', False)],
          'träcke': [('träcke', False)],
          'träcken': [('träck', True)],
          'träckens': [('träck', True)],
          'träcket': [('träcke', False)],
          'träckets': [('träck', False)],
          'träcks': [('träck', True)],
          'träcks-': [('träck', True)],
          'träd': [('träda', True), ('träd', True)],
          'träd-': [('träd', True), ('träda', True)],
          'träde': [('träda', True), ('träde', True)],
          'träde-': [('träda', True)],
          'träden': [('träde', True), ('träd', True)],
          'trädens': [('träde', True), ('träd', True)],
          'trädet': [('träde', True), ('träd', True)],
          'trädets': [('träd', True), ('träde', True)],
          'träds': [('träde', True), ('träda', True), ('träd', True)],
          'träds-': [('träde', True), ('träda', True)],
          'träflis': [('träflisa', True), ('träflis', True)],
          'träflis-': [('träflisa', True), ('träflis', True)],
          'träkors': [('träkors', True)],
          'träls': [('träl', False)],
          'träls-': [('träl', True)],
          'trän': [('träd', True), ('trä', True)],
          'träna': [('trä', True), ('träd', True)],
          'tränas': [('trä', True), ('träd', True)],
          'tränderna': [('trand', False)],
          'trändernas': [('trand', False)],
          'tränders': [('trand', False)],
          'träns': [('träd', True), ('trä', True), ('träns', True)],
          'trät': [('träta', True), ('trä', True)],
          'träts': [('träta', True), ('trä', True)],
          'trättens': [('trätt', False)],
          'trättets': [('trätt', False)],
          'trättigheterna': [('trättighet', False)],
          'trättigheternas': [('trättighet', False)],
          'trättighets-': [('trättighet', False)],
          'träv': [('träva', False)],
          'träv-': [('träva', False)],
          'trävar': [('trävara', True)],
          'trävar-': [('trävara', True)],
          'trävarna': [('trävare', False)],
          'trävarnas': [('trävare', False)],
          'trävs': [('träv', False)],
          'trävs-': [('träv', False)],
          'tråden': [('tråd', False)],
          'trådens': [('tråd', False)],
          'trågen': [('tråg', False)],
          'trågens': [('tråg', True)],
          'tråget': [('tråg', False)],
          'trågets': [('tråg', False)],
          'tråk': [('tråk', True)],
          'tråk-': [('tråk', True)],
          'tråkar': [('tråk', True)],
          'tråkarna': [('tråk', True)],
          'tråkarnas': [('tråk', True)],
          'tråkars': [('tråk', True)],
          'tråke': [('tråke', False)],
          'tråken': [('tråk', False)],
          'tråkens': [('tråk', False)],
          'tråks': [('tråk', False)],
          'tråks-': [('tråk', False)],
          'trål': [('trål', True)],
          'trål-': [('trål', True)],
          'trålar': [('trålare', True), ('trål', True)],
          'trålarna': [('trålare', True), ('trål', True)],
          'trålarnas': [('trålare', True), ('trål', True)],
          'trålars': [('trål', True)],
          'trålen': [('trål', True)],
          'trålens': [('trål', True)],
          'tråls': [('trål', True)],
          'tråls-': [('trål', True)],
          'trån': [('trå', False)],
          'tråns': [('trå', False)],
          'tråten': [('tråt', False)],
          'tråtens': [('tråt', False)],
          'trökar': [('trök', False)],
          'trökarna': [('trök', False)],
          'trökarnas': [('trök', False)],
          'trökens': [('trök', False)],
          'trömmar': [('tröm', False)],
          'trömmarna': [('tröm', False)],
          'trömmarnas': [('tröm', False)],
          'trös': [('trö', False)],
          'tröst': [('tröst', True)],
          'tröst-': [('tröst', False)],
          'tröstans': [('tröstan', False)],
          'tröstar': [('tröstare', True), ('tröst', True)],
          'tröstarna': [('tröstare', True), ('tröst', True)],
          'tröstarnas': [('tröst', True), ('tröstare', True)],
          'trösten': [('tröst', False)],
          'tröstens': [('tröst', False)],
          'tröt': [('trö', False)],
          'trötter': [('trot', False)],
          'trötterna': [('trot', False)],
          'trötternas': [('trot', False)],
          'trötters': [('trot', False)],
          'trövar': [('trövare', False)],
          'trövarna': [('trövare', False)],
          'trövarnas': [('trövare', False)],
          'tsage': [('tsaga', False)],
          'tsage-': [('tsaga', False)],
          'tsago': [('tsaga', False)],
          'tsago-': [('tsaga', False)],
          'tsaker': [('tsak', False)],
          'tsakerna': [('tsak', False)],
          'tsakernas': [('tsak', False)],
          'tsakers': [('tsak', False)],
          'tsalen': [('tsal', False)],
          'tsalens': [('tsal', False)],
          'tsalvs-': [('tsalva', False)],
          'tsamhällena': [('tsamhälle', False)],
          'tsanden': [('tsande', False)],
          'tsandens': [('tsande', False)],
          'tsans': [('tsa', False)],
          'tsar': [('tsar', True)],
          'tsar-': [('tsar', True)],
          'tsaren': [('tsar', True)],
          'tsarens': [('tsar', True)],
          'tsarna': [('ts', False)],
          'tsars': [('tsar', True)],
          'tsars-': [('tsar', True)],
          'tsats': [('tsats', False)],
          'tsats-': [('tsats', False)],
          'tsaxar': [('tsax', False)],
          'tsaxarna': [('tsax', False)],
          'tsaxarnas': [('tsax', False)],
          'tsbackar': [('tsback', False)],
          'tsbackars': [('tsback', False)],
          'tsbacken': [('tsback', False)],
          'tsbackens': [('tsback', False)],
          'tsbacks-': [('tsback', False)],
          'tsbits': [('tsbi', False)],
          'tsbull-': [('tsbulle', False)],
          'tsbytet': [('tsbyte', False)],
          'tsch': [('tsch', False)],
          'tsch-': [('tsch', False)],
          'tschen': [('tsch', False)],
          'tschens': [('tsch', False)],
          'tscher': [('tsch', False)],
          'tschers': [('tsch', False)],
          'tsdans': [('tsdans', False)],
          'tsdelar': [('tsdel', False)],
          'tsdelarna': [('tsdel', False)],
          'tsdelarnas': [('tsdel', False)],
          'tse': [('tsa', False)],
          'tse-': [('tsa', False)],
          'tsel': [('tsel', False)],
          'tsel-': [('tsel', False)],
          'tselen': [('tsel', False)],
          'tselens': [('tsel', False)],
          'tseller': [('tseller', False)],
          'tsellerna': [('tseller', False)],
          'tsellernas': [('tseller', False)],
          'tsellers': [('tseller', False)],
          'tsels': [('tsel', False)],
          'tsels-': [('tsel', False)],
          'tsen': [('ts', False)],
          'tsens': [('ts', False)],
          'tser': [('ts', False)],
          'tserierna': [('tserie', False)],
          'tseriernas': [('tserie', False)],
          'tserna': [('ts', False)],
          'tsernas': [('ts', False)],
          'tsers': [('ts', False)],
          'tset': [('ts', False)],
          'tsets': [('ts', False)],
          'tsex': [('tsexa', False)],
          'tsex-': [('tsexa', False)],
          'tsfång': [('tsfånge', False)],
          'tsfången': [('tsfånge', False)],
          'tsfångs-': [('tsfånge', False)],
          'tsförsäkringars': [('tsförsäkring', False)],
          'tsgatan': [('tsgata', False)],
          'tsgiftet': [('tsgift', False)],
          'tsi': [('tsia', False)],
          'tsi-': [('tsia', False)],
          'tsian': [('tsia', False)],
          'tsians': [('tsia', False)],
          'tsidan': [('tsida', False)],
          'tsidans': [('tsida', False)],
          'tside': [('tsida', False)],
          'tside-': [('tsida', False)],
          'tsides': [('tsida', False)],
          'tsie': [('tsie', False)],
          'tsie-': [('tsia', False)],
          'tsien': [('tsie', False)],
          'tsiens': [('tsie', False)],
          'tsier': [('tsie', False)],
          'tsierna': [('tsie', False)],
          'tsiernas': [('tsie', False)],
          'tsiers': [('tsie', False)],
          'tsikten': [('tsikt', False)],
          'tsiktens': [('tsikte', False)],
          'tsims': [('tsim', False)],
          'tsims-': [('tsim', False)],
          'tsina': [('tsina', False)],
          'tsinas': [('tsina', False)],
          'tsis': [('tsia', False)],
          'tsis-': [('tsia', False)],
          'tsiter': [('tsit', False)],
          'tsiterna': [('tsit', False)],
          'tsiters': [('tsit', False)],
          'tsits': [('tsit', False)],
          'tsjukan': [('tsjuka', False)],
          'tsk': [('tsk', True)],
          'tsk-': [('tsk', True)],
          'tskak': [('tskaka', False)],
          'tskak-': [('tskaka', False)],
          'tskaks': [('tskaka', False)],
          'tskaks-': [('tskaka', False)],
          'tskal': [('tskal', False)],
          'tskallen': [('tskalle', False)],
          'tskallens': [('tskalle', False)],
          'tskals': [('tskal', False)],
          'tskals-': [('tskal', False)],
          'tskan': [('tska', False)],
          'tskans': [('tska', False)],
          'tskaps-': [('tskap', False)],
          'tskasse-': [('tskassa', False)],
          'tskatt': [('tskatta', False)],
          'tskatt-': [('tskatta', False)],
          'tskatte': [('tskatta', False)],
          'tskatte-': [('tskatta', False)],
          'tskatts': [('tskatta', False)],
          'tskatts-': [('tskatt', False)],
          'tskeden': [('tskede', False)],
          'tskedens': [('tskede', False)],
          'tskedet': [('tskede', False)],
          'tsken': [('tskena', False)],
          'tsken-': [('tskena', False)],
          'tskens': [('tskena', False)],
          'tskens-': [('tskena', False)],
          'tskiften': [('tskifte', False)],
          'tskiftens': [('tskift', False)],
          'tskiftet': [('tskifte', False)],
          'tskiftets': [('tskifte', False)],
          'tskjuts': [('tskjuts', False)],
          'tskjuts-': [('tskjut', False)],
          'tsklocks': [('tsklocka', False)],
          'tsklocks-': [('tsklocka', False)],
          'tsko': [('tsko', False)],
          'tskock': [('tskocka', False)],
          'tskock-': [('tskocka', False)],
          'tskocks': [('tskocka', False)],
          'tskocks-': [('tskocka', False)],
          'tskon': [('tsko', False)],
          'tskonst': [('tskonst', False)],
          'tskor': [('tsko', False)],
          'tskorna': [('tsko', False)],
          'tskornas': [('tsko', False)],
          'tskors': [('tsko', False)],
          'tskott': [('tskott', False)],
          'tskotten': [('tskott', False)],
          'tskottens': [('tskott', False)],
          'tskotts-': [('tskott', False)],
          'tskramarnas': [('tskramare', False)],
          'tskrans': [('tskran', False)],
          'tskrans-': [('tskran', False)],
          'tskrap': [('tskrapa', False)],
          'tskrap-': [('tskrapa', False)],
          'tskraps': [('tskrapa', False)],
          'tskraps-': [('tskrapa', False)],
          'tskrev': [('tskreva', False)],
          'tskrev-': [('tskreva', False)],
          'tskrevs': [('tskreva', False)],
          'tskrevs-': [('tskreva', False)],
          'tskrik': [('tskrika', False)],
          'tskrik-': [('tskrika', False)],
          'tskriks': [('tskrika', False)],
          'tskriks-': [('tskrika', False)],
          'tskrin': [('tskri', False)],
          'tskrins': [('tskri', False)],
          'tskripta': [('tskriptum', False)],
          'tskriptas': [('tskriptum', False)],
          'tskris': [('tskris', False)],
          'tskrymsle': [('tskrymsle', False)],
          'tskrymsle-': [('tskrymsle', False)],
          'tskräms': [('tskräm', False)],
          'tskräms-': [('tskräm', False)],
          'tskulor': [('tskula', False)],
          'tskulorna': [('tskula', False)],
          'tskulornas': [('tskula', False)],
          'tskulors': [('tskula', False)],
          'tskurs': [('tskur', False)],
          'tskytten': [('tskytt', False)],
          'tskyttens': [('tskytt', False)],
          'tskäll': [('tskälla', False)],
          'tskäll-': [('tskälla', False)],
          'tskälls': [('tskälla', False)],
          'tskälls-': [('tskälla', False)],
          'tskär': [('tskär', False)],
          'tskär-': [('tskär', False)],
          'tskärmar': [('tskärm', False)],
          'tskärmarnas': [('tskärm', False)],
          'tskärs': [('tskär', False)],
          'tskärs-': [('tskär', False)],
          'tskärv': [('tskärva', False)],
          'tskärv-': [('tskärva', False)],
          'tskärvs': [('tskärva', False)],
          'tskärvs-': [('tskärva', False)],
          'tskår': [('tskåre', False)],
          'tskår-': [('tskåra', False)],
          'tskåre': [('tskåre', False)],
          'tskåren': [('tskåre', False)],
          'tskårens': [('tskåre', False)],
          'tskårs': [('tskåre', False)],
          'tskårs-': [('tskåre', False)],
          'tsköldpadd': [('tsköldpadda', False)],
          'tsköldpadds': [('tsköldpadda', False)],
          'tsköldpadds-': [('tsköldpadda', False)],
          'tskötar': [('tskötare', False)],
          'tskötarna': [('tskötare', False)],
          'tskötarnas': [('tskötare', False)],
          'tslag': [('tslag', False)],
          'tslagar': [('tslagare', False)],
          'tslagarna': [('tslagare', False)],
          'tslagarnas': [('tslagare', False)],
          'tslager': [('tslager', False)],
          'tslagernas': [('tslager', False)],
          'tslagers': [('tslager', False)],
          'tslags': [('tslag', False)],
          'tslags-': [('tslag', False)],
          'tslams': [('tslam', False)],
          'tslams-': [('tslam', False)],
          'tslandets': [('tslande', False)],
          'tslar': [('tsel', False)],
          'tslarna': [('tsel', False)],
          'tslarnas': [('tsel', False)],
          'tsleken': [('tsleke', False)],
          'tslekens': [('tsleke', False)],
          'tsleks-': [('tsleke', False)],
          'tslen': [('tsel', False)],
          'tslens': [('tsel', False)],
          'tslets': [('tsel', False)],
          'tslin': [('tslina', False)],
          'tslin-': [('tslina', False)],
          'tsling': [('tsling', False)],
          'tsling-': [('tsling', False)],
          'tslings': [('tsling', False)],
          'tslings-': [('tsling', False)],
          'tslins': [('tslina', False)],
          'tslins-': [('tslins', False)],
          'tslotts': [('tslott', False)],
          'tsläkten': [('tsläkte', False)],
          'tsläktens': [('tsläkte', False)],
          'tsläkts': [('tsläkte', False)],
          'tsläkts-': [('tsläkte', False)],
          'tslån': [('tslån', False)],
          'tslåns': [('tslån', False)],
          'tslås': [('tslås', False)],
          'tslås-': [('tslås', False)],
          'tsmatt': [('tsmatta', False)],
          'tsmatt-': [('tsmatta', False)],
          'tsmatts': [('tsmatta', False)],
          'tsmatts-': [('tsmatta', False)],
          'tsmäll': [('tsmäll', False)],
          'tsmällar': [('tsmäll', False)],
          'tsmällarna': [('tsmäll', False)],
          'tsmällarnas': [('tsmäll', False)],
          'tsmälls': [('tsmäll', False)],
          'tsmälls-': [('tsmäll', False)],
          'tsnacks': [('tsnack', False)],
          'tsnacks-': [('tsnack', False)],
          'tsnyckel': [('tsnyckel', False)],
          'tsnyckel-': [('tsnyckel', False)],
          'tsnyckels': [('tsnyckel', False)],
          'tsnyckels-': [('tsnyckel', False)],
          'tsnycklar': [('tsnyckel', False)],
          'tsnycklarna': [('tsnyckel', False)],
          'tsnycklarnas': [('tsnyckel', False)],
          'tsnycklars': [('tsnyckel', False)],
          'tsnäpp': [('tsnäppa', False)],
          'tsnäpp-': [('tsnäppa', False)],
          'tsnäpps': [('tsnäppa', False)],
          'tsnäpps-': [('tsnäppa', False)],
          'tsnåret': [('tsnåret', False)],
          'tsnårets': [('tsnåret', False)],
          'tsområdet': [('tsområde', False)],
          'tsopar': [('tsopare', False)],
          'tsoparna': [('tsopare', False)],
          'tsoparnas': [('tsopare', False)],
          'tsopp': [('tsoppa', False)],
          'tsopp-': [('tsoppa', False)],
          'tsopps': [('tsoppa', False)],
          'tsopps-': [('tsoppa', False)],
          'tsor': [('tsa', False)],
          'tsorna': [('tsa', False)],
          'tsornas': [('tsa', False)],
          'tsors': [('tsa', False)],
          'tsots': [('tsot', False)],
          'tspad': [('tspade', False)],
          'tspad-': [('tspade', False)],
          'tspads': [('tspade', False)],
          'tspads-': [('tspad', False)],
          'tspan': [('tspa', False)],
          'tspar': [('tspar', False)],
          'tspars': [('tspar', False)],
          'tspat': [('tspa', False)],
          'tspats': [('tspat', False)],
          'tspeng': [('tspeng', False)],
          'tspengar': [('tspeng', False)],
          'tspengarna': [('tspeng', False)],
          'tspengarnas': [('tspeng', False)],
          'tspengars': [('tspeng', False)],
          'tspengs': [('tspeng', False)],
          'tspengs-': [('tspeng', False)],
          'tspets': [('tspets', False)],
          'tspets-': [('tspets', False)],
          'tspol-': [('tspole', False)],
          'tspolen': [('tspole', False)],
          'tsportar': [('tsport', False)],
          'tsportarna': [('tsport', False)],
          'tspring': [('tspringa', False)],
          'tspring-': [('tspringa', False)],
          'tsprings': [('tspringa', False)],
          'tsprings-': [('tspringa', False)],
          'tspris': [('tspris', False)],
          'tsprit': [('tsprit', False)],
          'tsprits': [('tsprit', False)],
          'tsprits-': [('tsprit', False)],
          'tsprut': [('tspruta', False)],
          'tsprut-': [('tspruta', False)],
          'tspruts': [('tspruta', False)],
          'tspruts-': [('tspruta', False)],
          'tspännen': [('tspänne', False)],
          'tspännens': [('tspänne', False)],
          'tsros': [('tsro', False)],
          'tsset': [('tsset', False)],
          'tssets': [('tsset', False)],
          'tssken-': [('tsskena', False)],
          'tsstegen': [('tsstege', False)],
          'tsstegs': [('tsstege', False)],
          'tsstudie': [('tsstudier', False)],
          'tsstudie-': [('tsstudier', False)],
          'tsstudier': [('tsstudier', False)],
          'tsstudierna': [('tsstudier', False)],
          'tsstudiernas': [('tsstudier', False)],
          'tssvensk': [('tssvensk', False)],
          'tssvensk-': [('tssvensk', False)],
          'tstadge': [('tstadga', False)],
          'tstadge-': [('tstadga', False)],
          'tstadie': [('tstadium', False)],
          'tstadie-': [('tstadium', False)],
          'tstadier': [('tstadium', False)],
          'tstadierna': [('tstadium', False)],
          'tstadiernas': [('tstadium', False)],
          'tstadiers': [('tstadium', False)],
          'tstadiet': [('tstadium', False)],
          'tstadiets': [('tstadium', False)],
          'tstadium': [('tstadium', False)],
          'tstadiums': [('tstadium', False)],
          'tstammar': [('tstam', False)],
          'tstammarna': [('tstam', False)],
          'tstammarnas': [('tstam', False)],
          'tstampen': [('tstamp', False)],
          'tstampens': [('tstamp', False)],
          'tstans': [('tstad', False)],
          'tstans-': [('tstans', False)],
          'tstavarna': [('tstav', False)],
          'tsteg': [('tstege', False)],
          'tsteg-': [('tsteg', False)],
          'tstegen': [('tsteg', False)],
          'tstegens': [('tsteg', False)],
          'tstegs': [('tsteg', False)],
          'tstegs-': [('tsteg', False)],
          'tstekar': [('tstek', False)],
          'tstekarna': [('tstek', False)],
          'tstekarnas': [('tstek', False)],
          'tsten': [('tsten', False)],
          'tstens': [('tsten', False)],
          'tstick': [('tsticka', False)],
          'tstick-': [('tsticka', False)],
          'tsticks': [('tstick', False)],
          'tsticks-': [('tsticka', False)],
          'tstim': [('tstimme', False)],
          'tstim-': [('tstimme', False)],
          'tstimmen': [('tstimme', False)],
          'tstimmens': [('tstimme', False)],
          'tstims': [('tstimme', False)],
          'tstims-': [('tstimme', False)],
          'tstol': [('tstol', False)],
          'tstol-': [('tstol', False)],
          'tstols': [('tstol', False)],
          'tstols-': [('tstol', False)],
          'tston': [('tston', False)],
          'tstons': [('tston', False)],
          'tstons-': [('tston', False)],
          'tstoppar': [('tstopp', False)],
          'tstopparna': [('tstopp', False)],
          'tstormar': [('tstorm', False)],
          'tstormarna': [('tstorm', False)],
          'tstormarnas': [('tstorm', False)],
          'tstorn': [('tstorn', False)],
          'tstorns': [('tstorn', False)],
          'tstras': [('tstrasa', False)],
          'tstras-': [('tstrasa', False)],
          'tsträck': [('tsträcka', False)],
          'tsträck-': [('tsträcka', False)],
          'tsträcks': [('tsträcka', False)],
          'tsträcks-': [('tsträcka', False)],
          'tsträna': [('tsträd', False)],
          'tstränas': [('tsträd', False)],
          'tstråk': [('tstråk', False)],
          'tstråken': [('tstråk', False)],
          'tstråkens': [('tstråk', False)],
          'tstråks': [('tstråk', False)],
          'tstråks-': [('tstråk', False)],
          'tströmmen': [('tströmmen', False)],
          'tstudie': [('tstudie', False)],
          'tstudie-': [('tstudium', False)],
          'tstudier': [('tstudie', False)],
          'tstudierna': [('tstudium', False)],
          'tstudiernas': [('tstudium', False)],
          'tstudiers': [('tstudium', False)],
          'tstup': [('tstup', False)],
          'tstup-': [('tstup', False)],
          'tstups': [('tstup', False)],
          'tstups-': [('tstup', False)],
          'tstycken': [('tstycke', False)],
          'tstyckena': [('tstycke', False)],
          'tstyckenas': [('tstycke', False)],
          'tstyckens': [('tstycke', False)],
          'tstycket': [('tstycke', False)],
          'tstyckets': [('tstycke', False)],
          'tstycks': [('tstycke', False)],
          'tstyren': [('tstyre', False)],
          'tstyrens': [('tstyre', False)],
          'tstyret': [('tstyre', False)],
          'tstyrkan': [('tstyrka', False)],
          'tstyrke': [('tstyrka', False)],
          'tställanden': [('tställande', False)],
          'tställandena': [('tställande', False)],
          'tställandenas': [('tställande', False)],
          'tställandens': [('tställande', False)],
          'tställen': [('tställ', False)],
          'tställens': [('tställe', False)],
          'tstället': [('tställ', False)],
          'tställets': [('tställe', False)],
          'tställningar': [('tställning', False)],
          'tställningarna': [('tställning', False)],
          'tställningarnas': [('tställning', False)],
          'tställningars': [('tställning', False)],
          'tställnings': [('tställning', False)],
          'tställnings-': [('tställning', False)],
          'tstänk': [('tstänk', False)],
          'tstänks': [('tstänk', False)],
          'tstänks-': [('tstänk', False)],
          'tstötarnas': [('tstöt', False)],
          'tstövlars': [('tstövel', False)],
          'tsuddar': [('tsuddare', False)],
          'tsuddarna': [('tsuddare', False)],
          'tsuddarnas': [('tsuddare', False)],
          'tsugar': [('tsugare', False)],
          'tsugarna': [('tsugare', False)],
          'tsugarnas': [('tsugare', False)],
          'tsun': [('tsu', False)],
          'tsuns': [('tsu', False)],
          'tsur': [('tsur', False)],
          'tsur-': [('tsur', False)],
          'tsurs': [('tsur', False)],
          'tsurs-': [('tsur', False)],
          'tsus': [('tsu', False)],
          'tsval': [('tsval', False)],
          'tsvalen': [('tsval', False)],
          'tsvalens': [('tsval', False)],
          'tsvals': [('tsval', False)],
          'tsvals-': [('tsval', False)],
          'tsvanor': [('tsvana', False)],
          'tsvanorna': [('tsvana', False)],
          'tsvanornas': [('tsvana', False)],
          'tsvanors': [('tsvanor', False)],
          'tsvans': [('tsvans', False)],
          'tsvans-': [('tsvans', False)],
          'tsvar': [('tsvara', False)],
          'tsvensk': [('tsvensk', False)],
          'tsvensk-': [('tsvensk', False)],
          'tsverken': [('tsverk', False)],
          'tsverkens': [('tsverk', False)],
          'tsverket': [('tsverk', False)],
          'tsverks': [('tsverk', False)],
          'tsverks-': [('tsverk', False)],
          'tsvetsar': [('tsvets', False)],
          'tsvetsarna': [('tsvets', False)],
          'tsvetsarnas': [('tsvets', False)],
          'tsvägens': [('tsväg', False)],
          'tsvärden': [('tsvärde', False)],
          'tsvärdens': [('tsvärde', False)],
          'tsvärdet': [('tsvärde', False)],
          'tsvärdets': [('tsvärde', False)],
          'tsvärmar': [('tsvärm', False)],
          'tsvärmarna': [('tsvärm', False)],
          'tsvärmarnas': [('tsvärm', False)],
          'tsyns': [('tsyn', False)],
          'tsyre': [('tsyra', False)],
          'tsyre-': [('tsyra', False)],
          'tsäden': [('tsäde', False)],
          'tsädens': [('tsäde', False)],
          'tsädes': [('tsäd', False)],
          'tsädes-': [('tsäde', False)],
          'tsäds': [('tsäd', False)],
          'tsäds-': [('tsäd', False)],
          'tsäkringar': [('tsäkring', False)],
          'tsäkringars': [('tsäkring', False)],
          'tsändar': [('tsändare', False)],
          'tsändarna': [('tsändare', False)],
          'tsång-': [('tsång', False)],
          'tsås': [('tsås', False)],
          'tsås-': [('tsås', False)],
          'tsömmar': [('tsöm', False)],
          'tsömmarna': [('tsöm', False)],
          'tsömmarnas': [('tsöm', False)],
          'ttack': [('ttack', False)],
          'ttack-': [('ttack', False)],
          'ttacks': [('ttack', False)],
          'ttacks-': [('ttack', False)],
          'ttagen': [('ttag', False)],
          'ttagens': [('ttag', False)],
          'ttaget': [('ttag', False)],
          'ttaggar': [('ttagg', False)],
          'ttaggarna': [('ttagg', False)],
          'ttaggarnas': [('ttagg', False)],
          'ttak': [('ttak', False)],
          'ttaken': [('ttak', False)],
          'ttaket': [('ttak', False)],
          'ttalandenas': [('ttalande', False)],
          'ttalandens': [('ttalande', False)],
          'ttalar': [('ttalare', False)],
          'ttalar-': [('ttalare', False)],
          'ttalaren': [('ttalare', False)],
          'ttalarens': [('ttalare', False)],
          'ttalen': [('ttal', False)],
          'ttalens': [('ttal', False)],
          'ttan-': [('ttan', False)],
          'ttanden': [('ttande', False)],
          'ttandens': [('ttande', False)],
          'ttangens': [('ttang', False)],
          'ttangenten': [('ttangent', False)],
          'ttangentens': [('ttangent', False)],
          'ttans': [('tta', False)],
          'ttants': [('ttant', False)],
          'ttar': [('tt', False)],
          'ttaren': [('ttare', False)],
          'ttars': [('tt', False)],
          'ttask': [('ttask', False)],
          'ttask-': [('ttask', False)],
          'ttbit': [('ttbit', False)],
          'ttbitar': [('ttbit', False)],
          'ttbitarna': [('ttbit', False)],
          'ttbitarnas': [('ttbit', False)],
          'ttdans': [('ttdans', False)],
          'ttdroppar': [('ttdroppe', False)],
          'ttdropparna': [('ttdroppe', False)],
          'ttdropparnas': [('ttdroppe', False)],
          'ttdroppars': [('ttdroppe', False)],
          'ttdropps': [('ttdroppe', False)],
          'tte': [('tta', False)],
          'tteater': [('tteater', False)],
          'tteder': [('tted', False)],
          'tteders': [('tted', False)],
          'ttekniker': [('ttekniker', False)],
          'tteknikerna': [('ttekniker', False)],
          'tteknikernas': [('ttekniker', False)],
          'tteknikers': [('ttekniker', False)],
          'ttel': [('ttel', False)],
          'tteln': [('ttel', False)],
          'ttelns': [('ttel', False)],
          'ttels': [('ttel', False)],
          'ttels-': [('ttel', False)],
          'tten': [('tt', False)],
          'ttena': [('tten', False)],
          'ttenas': [('tten', False)],
          'ttenbits': [('ttenbi', False)],
          'ttenis': [('ttenis', False)],
          'ttens-': [('tten', False)],
          'ttenskvätt-': [('ttenskvätt', False)],
          'ttenskvätts': [('ttenskvätt', False)],
          'ttenskvätts-': [('ttenskvätt', False)],
          'ttenterna': [('ttent', False)],
          'tter-': [('tter', False)],
          'tteran': [('ttera', False)],
          'tteranden': [('tterande', False)],
          'tterandens': [('tterande', False)],
          'tterans': [('ttera', False)],
          'tterier': [('tteri', False)],
          'tterierna': [('tteri', False)],
          'tteriernas': [('tteri', False)],
          'tteriets': [('tteri', False)],
          'tterits': [('tteri', False)],
          'ttermer': [('tterm', False)],
          'ttermerna': [('tterm', False)],
          'ttermernas': [('tterm', False)],
          'ttermers': [('tterm', False)],
          'ttermin': [('ttermin', False)],
          'ttermyr': [('ttermyr', False)],
          'ttermyr-': [('ttermyr', False)],
          'ttermyrs': [('ttermyr', False)],
          'ttermyrs-': [('ttermyr', False)],
          'ttern': [('tter', False)],
          'tterna': [('tt', False)],
          'tternas': [('tt', False)],
          'tterns': [('tter', False)],
          'tters-': [('tter', False)],
          'ttersen': [('tter', False)],
          'ttersens': [('tter', False)],
          'ttes': [('tte', False)],
          'ttes-': [('tte', False)],
          'ttesarna': [('tte', False)],
          'ttestens': [('ttest', False)],
          'ttet': [('tt', False)],
          'ttets': [('tte', False)],
          'ttfiskarna': [('ttfisk', False)],
          'tthaken': [('tthake', False)],
          'tthet': [('tthet', False)],
          'tthets': [('tthet', False)],
          'ttias': [('ttias', False)],
          'ttiden': [('ttid', False)],
          'ttider': [('ttid', False)],
          'ttiderna': [('ttid', False)],
          'ttiders': [('ttid', False)],
          'ttighets': [('ttighet', False)],
          'ttik': [('ttika', False)],
          'ttik-': [('ttika', False)],
          'ttiks': [('ttika', False)],
          'ttiks-': [('ttika', False)],
          'ttilj': [('ttilj', False)],
          'ttilj-': [('ttilj', False)],
          'ttiljs': [('ttilj', False)],
          'ttiljs-': [('ttilj', False)],
          'ttin': [('tti', False)],
          'ttin-': [('ttin', False)],
          'ttinas': [('tti', False)],
          'ttinens': [('ttin', False)],
          'ttiner': [('ttin', False)],
          'ttinerna': [('ttin', False)],
          'ttinernas': [('ttin', False)],
          'ttiners': [('ttin', False)],
          'ttinne': [('ttinna', False)],
          'ttins': [('tti', False)],
          'ttis': [('ttis', False)],
          'ttis-': [('ttis', False)],
          'ttit': [('ttit', False)],
          'ttit-': [('ttit', False)],
          'ttits': [('tti', False)],
          'ttjar': [('ttjare', False)],
          'ttjarna': [('ttjare', False)],
          'ttjärn': [('ttjärn', False)],
          'ttjärns': [('ttjärn', False)],
          'ttjärns-': [('ttjärn', False)],
          'ttkikar': [('ttkikare', False)],
          'ttkikarna': [('ttkikare', False)],
          'ttkoppor': [('ttkoppa', False)],
          'ttkopporna': [('ttkoppa', False)],
          'ttkoppornas': [('ttkoppa', False)],
          'ttkoppors': [('ttkoppa', False)],
          'ttkopps': [('ttkoppa', False)],
          'ttkopps-': [('ttkoppa', False)],
          'ttlanden': [('ttland', False)],
          'ttlandens': [('ttland', False)],
          'ttlandet': [('ttland', False)],
          'ttlandets': [('ttlande', False)],
          'ttlar': [('ttel', False)],
          'ttlarna': [('ttel', False)],
          'ttlarnas': [('ttel', False)],
          'ttmas': [('ttmas', False)],
          'ttmask': [('ttmask', False)],
          'ttmask-': [('ttmask', False)],
          'ttnar': [('tten', False)],
          'ttnarna': [('ttnare', False)],
          'ttnarnas': [('ttnare', False)],
          'ttnen': [('tten', False)],
          'ttnens': [('ttne', False)],
          'ttnet': [('ttne', False)],
          'ttnets': [('ttne', False)],
          'tto': [('tta', False)],
          'tto-': [('tto', False)],
          'ttoar': [('ttoar', False)],
          'ttoars': [('ttoar', False)],
          'ttolkar': [('ttolkare', False)],
          'ttolkarna': [('ttolkare', False)],
          'ttolkarnas': [('ttolkare', False)],
          'ttomten': [('ttomte', False)],
          'ttomtens': [('ttomte', False)],
          'tton': [('tto', False)],
          'ttoner': [('tton', False)],
          'ttonerna': [('tton', False)],
          'ttonernas': [('tton', False)],
          'ttoners': [('tton', False)],
          'ttons': [('tto', False)],
          'ttopparnas': [('ttopp', False)],
          'ttor': [('tta', False)],
          'ttorna': [('tta', False)],
          'ttornas': [('tta', False)],
          'ttors': [('tta', False)],
          'ttos': [('tto', False)],
          'ttos-': [('tto', False)],
          'ttpeng': [('ttpeng', False)],
          'ttpengar': [('ttpeng', False)],
          'ttpengars': [('ttpeng', False)],
          'ttpengs': [('ttpeng', False)],
          'ttpengs-': [('ttpeng', False)],
          'ttpressarnas': [('ttpress', False)],
          'ttra': [('ttra', False)],
          'ttrams': [('ttram', False)],
          'ttrams-': [('ttram', False)],
          'ttran': [('ttra', False)],
          'ttrans': [('ttra', False)],
          'ttrapp': [('ttrapp', False)],
          'ttrapp-': [('ttrapp', False)],
          'ttrapper': [('ttrapp', False)],
          'ttrapperna': [('ttrapp', False)],
          'ttrappernas': [('ttrapp', False)],
          'ttrappers': [('ttrapp', False)],
          'ttrapps': [('ttrapp', False)],
          'ttrapps-': [('ttrapp', False)],
          'ttrar': [('tter', False)],
          'ttrarna': [('tter', False)],
          'ttrars': [('tter', False)],
          'ttras': [('ttra', False)],
          'ttras-': [('ttras', False)],
          'ttre': [('ttre', False)],
          'ttre-': [('ttre', False)],
          'ttrems-': [('ttrem', False)],
          'ttren': [('tter', False)],
          'ttrets': [('tter', False)],
          'ttricks': [('ttrick', False)],
          'ttricks-': [('ttrick', False)],
          'ttringar': [('ttring', False)],
          'ttringars': [('ttring', False)],
          'ttringens': [('ttring', False)],
          'ttron': [('ttro', False)],
          'ttrons': [('ttro', False)],
          'ttror': [('ttra', False)],
          'ttros': [('ttros', False)],
          'ttros-': [('ttros', False)],
          'ttrosor': [('ttros', False)],
          'ttrosorna': [('ttros', False)],
          'ttrosornas': [('ttros', False)],
          'ttrosors': [('ttros', False)],
          'ttrull': [('ttrulle', False)],
          'ttrull-': [('ttrulle', False)],
          'ttrullar': [('ttrulle', False)],
          'ttrullarnas': [('ttrulle', False)],
          'ttrullen': [('ttrulle', False)],
          'ttrullens': [('ttrulle', False)],
          'ttrums': [('ttrumma', False)],
          'ttrycken': [('ttryck', False)],
          'ttryckens': [('ttryck', False)],
          'ttrycket': [('ttryck', False)],
          'ttryckets': [('ttryck', False)],
          'ttrycks': [('ttryck', False)],
          'ttrycks-': [('ttryck', False)],
          'tträcken': [('tträcke', False)],
          'tträckens': [('tträcke', False)],
          'tträckets': [('tträcke', False)],
          'tträd': [('tträd', False)],
          'tträd-': [('tträd', False)],
          'tträde': [('tträde', False)],
          'tträdets': [('tträd', False)],
          'tträds': [('tträd', False)],
          'tträds-': [('tträd', False)],
          'tträn': [('tträd', False)],
          'tträna': [('tträd', False)],
          'ttränas': [('tträ', False)],
          'tträns': [('tträd', False)],
          'tträt': [('tträ', False)],
          'tträts': [('tträ', False)],
          'ttsaker': [('ttsaker', False)],
          'ttsakerna': [('ttsaker', False)],
          'ttsakernas': [('ttsaker', False)],
          'ttsakers': [('ttsaker', False)],
          'ttsaks': [('ttsak', False)],
          'ttsaks-': [('ttsak', False)],
          'ttsanden': [('ttsand', False)],
          'ttsandens': [('ttsand', False)],
          'ttset': [('ttset', False)],
          'ttsets': [('ttset', False)],
          'ttsie-': [('ttsie', False)],
          'ttsikten': [('ttsikte', False)],
          'ttsits': [('ttsits', False)],
          'ttsk': [('ttska', False)],
          'ttsk-': [('ttska', False)],
          'ttskatts-': [('ttskatta', False)],
          'ttskiften': [('ttskift', False)],
          'ttskiftet': [('ttskift', False)],
          'ttskiftets': [('ttskift', False)],
          'ttskor': [('ttska', False)],
          'ttskorna': [('ttska', False)],
          'ttskornas': [('ttska', False)],
          'ttskors': [('ttska', False)],
          'ttslams': [('ttslamsa', False)],
          'ttslams-': [('ttslamsa', False)],
          'ttslins': [('ttslins', False)],
          'ttssamhällena': [('ttssamhälle', False)],
          'ttsstudier': [('ttsstudie', False)],
          'ttstick': [('ttstick', False)],
          'ttsticks-': [('ttstick', False)],
          'ttstim': [('ttstim', False)],
          'ttstimmen': [('ttstim', False)],
          'ttstimmens': [('ttstim', False)],
          'ttstims': [('ttstim', False)],
          'ttstims-': [('ttstim', False)],
          'ttströmmen': [('ttström', False)],
          'ttställen': [('ttställe', False)],
          'ttställens': [('ttställ', False)],
          'ttstället': [('ttställe', False)],
          'ttställets': [('ttställ', False)],
          'ttsång': [('ttsång', False)],
          'ttsång-': [('ttsånga', False)],
          'ttsångs': [('ttsång', False)],
          'ttsångs-': [('ttsång', False)],
          'ttullar': [('ttull', False)],
          'ttullarna': [('ttull', False)],
          'ttullarnas': [('ttull', False)],
          'ttun': [('ttun', False)],
          'ttuner': [('ttun', False)],
          'ttunerna': [('ttun', False)],
          'ttunernas': [('ttun', False)],
          'ttuners': [('ttun', False)],
          'ttunge': [('ttunge', False)],
          'ttunge-': [('ttunge', False)],
          'ttungen': [('ttunge', False)],
          'ttungens': [('ttunge', False)],
          'ttup': [('ttup', False)],
          'ttup-': [('ttup', False)],
          'ttups': [('ttup', False)],
          'ttups-': [('ttup', False)],
          'ttur': [('ttur', False)],
          'tturerna': [('ttur', False)],
          'tturs': [('ttur', False)],
          'tturs-': [('ttur', False)],
          'ttut': [('ttut', False)],
          'ttut-': [('ttut', False)],
          'ttuts': [('ttut', False)],
          'ttvind': [('ttvind', False)],
          'ttvisten': [('ttvisten', False)],
          'ttyr': [('ttyr', False)],
          'ttyr-': [('ttyr', False)],
          'ttyren': [('ttyr', False)],
          'ttyrens': [('ttyr', False)],
          'ttyrer': [('ttyr', False)],
          'ttyrerna': [('ttyr', False)],
          'ttyrernas': [('ttyr', False)],
          'ttyrers': [('ttyr', False)],
          'ttyrke': [('ttyrke', False)],
          'ttyrs': [('ttyr', False)],
          'ttyrs-': [('ttyr', False)],
          'ttysk': [('ttyska', False)],
          'ttysk-': [('ttyska', False)],
          'ttändar': [('ttändare', False)],
          'ttänderna': [('ttand', False)],
          'ttänders': [('ttand', False)],
          'ttänger': [('ttång', False)],
          'ttängerna': [('ttång', False)],
          'ttängernas': [('ttång', False)],
          'ttängers': [('ttång', False)],
          'ttåg': [('ttåg', False)],
          'ttågs': [('ttåg', False)],
          'ttågs-': [('ttåg', False)],
          'ttång': [('ttång', False)],
          'ttång-': [('ttång', False)],
          'ttången': [('ttång', False)],
          'ttångens': [('ttång', False)],
          'ttångs': [('ttång', False)],
          'ttår': [('ttår', False)],
          'ttårs': [('ttår', False)],
          'ttårs-': [('ttår', False)],
          'ttörn': [('ttör', False)],
          'ttörns': [('ttör', False)],
          'tu': [('tu', False)],
          'tu-': [('tu', False)],
          'tub': [('tuba', True), ('tub', True)],
          'tub-': [('tuba', True), ('tub', True)],
          'tuban': [('tuba', False)],
          'tubans': [('tuba', False)],
          'tubs': [('tuba', True), ('tub', True)],
          'tubs-': [('tuba', True), ('tub', True)],
          'tuck': [('tuck', False)],
          'tuck-': [('tuck', False)],
          'tucker': [('tuck', False)],
          'tuckerna': [('tuck', False)],
          'tuckernas': [('tuck', False)],
          'tuckers': [('tuck', False)],
          'tucks': [('tuck', False)],
          'tucks-': [('tuck', False)],
          'tuds': [('tuds', False)],
          'tuds-': [('tuds', False)],
          'tuernas': [('tuer', False)],
          'tuers': [('tuer', False)],
          'tuff': [('tuff', False)],
          'tuff-': [('tuff', False)],
          'tuffer': [('tuff', True)],
          'tuffs': [('tuff', False)],
          'tuffs-': [('tuff', False)],
          'tug': [('tuga', False)],
          'tug-': [('tug', False)],
          'tugg': [('tugga', True), ('tugg', True)],
          'tugg-': [('tugg', True), ('tugga', True)],
          'tugge': [('tugga', True)],
          'tuggs': [('tugga', True), ('tugg', True)],
          'tuggs-': [('tugg', True), ('tugga', True)],
          'tugs-': [('tug', False)],
          'tugu-': [('tuga', False)],
          'tuin': [('tui', False)],
          'tuit': [('tui', False)],
          'tuits': [('tui', False)],
          'tukans': [('tukan', True)],
          'tukors': [('tukors', False)],
          'tukt': [('tukt', False)],
          'tukt-': [('tukt', True)],
          'tuktans': [('tuktan', True)],
          'tuktans-': [('tuktan', True)],
          'tukts': [('tukt', False)],
          'tukts-': [('tukt', False)],
          'tula': [('tula', False)],
          'tulan': [('tula', False)],
          'tulans': [('tula', False)],
          'tulas': [('tula', False)],
          'tulens': [('tulens', False)],
          'tulinets': [('tulin', False)],
          'tull': [('tull', False)],
          'tull-': [('tull', False)],
          'tullar': [('tullare', True), ('tull', True)],
          'tullarna': [('tull', True), ('tullare', True)],
          'tullarnas': [('tullare', True), ('tull', True)],
          'tullars': [('tull', False)],
          'tullen': [('tull', False)],
          'tulls': [('tull', False)],
          'tulls-': [('tull', False)],
          'tulpan': [('tulpan', True)],
          'tulpans': [('tulpan', False)],
          'tult': [('tulta', True)],
          'tulte': [('tulta', False)],
          'tults': [('tulta', True)],
          'tults-': [('tulta', True)],
          'tum': [('tumme', True), ('tum', True)],
          'tum-': [('tumme', True), ('tum', True)],
          'tumans': [('tuman', False)],
          'tumen': [('tumen', False)],
          'tumens': [('tumen', False)],
          'tuminet': [('tumen', False)],
          'tumlarnas': [('tumlare', False)],
          'tumlet': [('tummel', False)],
          'tumlets': [('tummel', True)],
          'tummar': [('tumme', True)],
          'tummarnas': [('tumme', True)],
          'tummars': [('tumme', False)],
          'tummen': [('tumme', True), ('tum', True)],
          'tummens': [('tumme', True), ('tum', True)],
          'tumpor': [('tumpa', False)],
          'tumporna': [('tumpa', False)],
          'tumpornas': [('tumpa', False)],
          'tumpors': [('tumpa', False)],
          'tums': [('tumme', True), ('tum', True)],
          'tums-': [('tumme', True), ('tum', True)],
          'tumsugar': [('tumsugare', True)],
          'tumsugarnas': [('tumsugare', True)],
          'tun': [('tun', True)],
          'tuna': [('tu', False)],
          'tunas': [('tu', False)],
          'tund': [('tund', False)],
          'tund-': [('tund', False)],
          'tundan': [('tunda', False)],
          'tundans': [('tundan', False)],
          'tundans-': [('tundan', False)],
          'tunder': [('tund', False)],
          'tunderna': [('tund', False)],
          'tunders': [('tund', False)],
          'tundran': [('tundra', True)],
          'tundrans': [('tundra', True)],
          'tundras': [('tundra', True)],
          'tunds': [('tund', False)],
          'tunds-': [('tund', False)],
          'tuner': [('tuner', True)],
          'tunerna': [('tuner', True)],
          'tunernas': [('tuner', True)],
          'tuners': [('tuner', True)],
          'tung': [('tunga', True)],
          'tung-': [('tunga', True)],
          'tunge': [('tunga', True)],
          'tunge-': [('tunga', True)],
          'tungen': [('tung', False)],
          'tungens': [('tung', False)],
          'tungor': [('tunga', False)],
          'tungorna': [('tunga', True)],
          'tungs': [('tunga', True)],
          'tungs-': [('tunga', False)],
          'tunik': [('tunik', True), ('tunika', True)],
          'tunik-': [('tunik', True), ('tunika', True)],
          'tunika': [('tunika', True)],
          'tunikas': [('tunika', True)],
          'tuniks': [('tunik', True), ('tunika', True)],
          'tunior': [('tunia', False)],
          'tuniors': [('tunia', False)],
          'tunn': [('tunna', False)],
          'tunn-': [('tunna', False)],
          'tunne': [('tunna', False)],
          'tuns': [('tun', True)],
          'tuns-': [('tun', True)],
          'tuos': [('tuos', False)],
          'tuos-': [('tuos', False)],
          'tuosen': [('tuos', False)],
          'tuosens': [('tuos', False)],
          'tuparnas': [('tup', False)],
          'tupp': [('tupp', False)],
          'tupp-': [('tupp', False)],
          'tuppar': [('tupp', False)],
          'tupparna': [('tupp', False)],
          'tupps': [('tupp', False)],
          'tupps-': [('tupp', False)],
          'tur': [('tur', True)],
          'tur-': [('tur', True)],
          'turan': [('tura', False)],
          'turans': [('tura', False)],
          'ture': [('ture', False)],
          'turer': [('tur', True)],
          'turerna': [('tur', True)],
          'turernas': [('tur', True)],
          'turers': [('tur', True)],
          'turi': [('turi', False)],
          'turi-': [('turi', False)],
          'turiens': [('turi', False)],
          'turier': [('turi', False)],
          'turierna': [('turi', False)],
          'turiers': [('turi', False)],
          'turin': [('turi', False)],
          'turins': [('turi', False)],
          'turis': [('turi', False)],
          'turis-': [('turis', False)],
          'turk': [('turk', False)],
          'turk-': [('turk', False)],
          'turks': [('turk', True)],
          'turks-': [('turk', True)],
          'turlandets': [('turland', False)],
          'turn': [('turn', False)],
          'turn-': [('turn', False)],
          'turna': [('tu', False)],
          'turnas': [('tu', False)],
          'turne': [('turne', False)],
          'turne-': [('turne', False)],
          'turnen': [('turn', False)],
          'turnens': [('turn', False)],
          'turner': [('turn', False)],
          'turnerna': [('turn', False)],
          'turnernas': [('turn', False)],
          'turners': [('turn', False)],
          'turns': [('turn', False)],
          'turns-': [('turn', False)],
          'turs': [('tur', True), ('turs', True)],
          'turs-': [('turs', True), ('tur', True)],
          'tursar': [('turs', True)],
          'tursten': [('tursten', False)],
          'turstens': [('tursten', False)],
          'tus': [('tu', False)],
          'tus-': [('tu', False)],
          'tusans': [('tusan', False)],
          'tusans-': [('tusan', False)],
          'tusarnas': [('tus', False)],
          'tusins': [('tusi', False)],
          'tuss': [('tuss', True)],
          'tussar': [('tuss', False)],
          'tussars': [('tuss', True)],
          'tussen': [('tuss', False)],
          'tussens': [('tuss', False)],
          'tussin': [('tussi', False)],
          'tut': [('tut', True), ('tuta', True)],
          'tut-': [('tut', True), ('tuta', True)],
          'tutan': [('tuta', False)],
          'tutarnas': [('tut', True)],
          'tuteri': [('tuteri', False)],
          'tuteri-': [('tuteri', False)],
          'tuteriers': [('tuteri', False)],
          'tuteriet': [('tuteri', False)],
          'tutet': [('tut', True)],
          'tutets': [('tut', False)],
          'tutin': [('tutin', False)],
          'tuts': [('tut', True), ('tuta', True)],
          'tuts-': [('tut', True), ('tuta', True)],
          'tutt': [('tutte', True), ('tutt', True), ('tutta', True)],
          'tutt-': [('tutta', True), ('tutt', True), ('tutte', True)],
          'tuttar': [('tutt', True), ('tutte', True)],
          'tuttarna': [('tutte', True), ('tutt', True)],
          'tuttarnas': [('tutte', True), ('tutt', True)],
          'tuttars': [('tutt', True), ('tutte', True)],
          'tutte': [('tutta', True), ('tutte', True)],
          'tutten': [('tutt', True), ('tutte', True)],
          'tuttens': [('tutte', True), ('tutt', True)],
          'tuttinas': [('tutti', True)],
          'tutts': [('tutta', True), ('tutte', True), ('tutt', True)],
          'tutts-': [('tutt', True), ('tutta', True), ('tutte', True)],
          'tuv': [('tuva', False)],
          'tuv-': [('tuva', False)],
          'tuvs': [('tuva', False)],
          'tuvs-': [('tuva', False)],
          'tv': [('tv', False)],
          'tv-': [('tv', False)],
          'tvagans': [('tvaga', True)],
          'tvak': [('tvak', False)],
          'tvak-': [('tvak', False)],
          'tvaks': [('tvak', False)],
          'tvaks-': [('tvak', False)],
          'tval': [('tval', False)],
          'tval-': [('tval', False)],
          'tvalarnas': [('tval', False)],
          'tvalen': [('tval', False)],
          'tvalens': [('tval', False)],
          'tvalkar': [('tvalk', False)],
          'tvalkarna': [('tvalk', False)],
          'tvalkarnas': [('tvalk', False)],
          'tvals': [('tval', False)],
          'tvals-': [('tval', False)],
          'tvana': [('tvana', False)],
          'tvane': [('tvana', False)],
          'tvane-': [('tvana', False)],
          'tvanors': [('tvana', False)],
          'tvant': [('tvante', False)],
          'tvant-': [('tvante', False)],
          'tvanten': [('tvante', False)],
          'tvantens': [('tvante', False)],
          'tvants': [('tvante', False)],
          'tvants-': [('tvante', False)],
          'tvar': [('tvara', False)],
          'tvar-': [('tvara', False)],
          'tvaran': [('tvara', False)],
          'tvarans': [('tvara', False)],
          'tvarar': [('tvar', False)],
          'tvararna': [('tvar', False)],
          'tvararnas': [('tvar', False)],
          'tvard': [('tvard', False)],
          'tvard-': [('tvard', False)],
          'tvarden': [('tvard', False)],
          'tvardens': [('tvard', False)],
          'tvards': [('tvard', False)],
          'tvards-': [('tvard', False)],
          'tvarens': [('tvar', False)],
          'tvarp': [('tvarp', False)],
          'tvarp-': [('tvarp', False)],
          'tvarps': [('tvarp', False)],
          'tvarps-': [('tvarp', False)],
          'tvars': [('tvar', False)],
          'tvatten': [('tvatten', False)],
          'tverkets': [('tverk', False)],
          'tverkningar': [('tverkan', False)],
          'tverkningarna': [('tverkan', False)],
          'tverkningarnas': [('tverkan', False)],
          'tverkningars': [('tverkan', False)],
          'tvik': [('tvik', False)],
          'tviks-': [('tvik', False)],
          'tviktar': [('tviktare', False)],
          'tviktarna': [('tviktare', False)],
          'tvills': [('tvills', True)],
          'tvills-': [('tvills', True)],
          'tvin': [('tvin', False)],
          'tvind-': [('tvinda', False)],
          'tvindarnas': [('tvind', False)],
          'tvinds': [('tvind', False)],
          'tvinds-': [('tvind', False)],
          'tving': [('tving', True)],
          'tving-': [('tving', False)],
          'tvingar': [('tving', True)],
          'tvingarna': [('tving', True)],
          'tvingarnas': [('tving', True)],
          'tvingars': [('tving', True)],
          'tvingen': [('tving', True)],
          'tvingens': [('tving', False)],
          'tvings': [('tving', True)],
          'tvings-': [('tving', False)],
          'tvins': [('tvin', False)],
          'tvins-': [('tvin', False)],
          'tviol': [('tviol', False)],
          'tviol-': [('tviol', False)],
          'tviols': [('tviol', False)],
          'tviols-': [('tviol', False)],
          'tvisa': [('tvisa', False)],
          'tvisar': [('tvisare', False)],
          'tvisarna': [('tvisare', False)],
          'tvisarnas': [('tvisare', False)],
          'tvisas': [('tvisa', False)],
          'tvise': [('tvisa', False)],
          'tvisor': [('tvisa', False)],
          'tvist': [('tvist', True)],
          'tvist-': [('tvist', False)],
          'tvisten': [('tvist', True)],
          'tvistens': [('tvist', False)],
          'tvivlar': [('tvivlare', True)],
          'tvivlarna': [('tvivlare', True)],
          'tvivlarnas': [('tvivlare', True)],
          'tvs': [('tv', False)],
          'tvägar': [('tväg', False)],
          'tvägarna': [('tväg', False)],
          'tvägarnas': [('tväg', False)],
          'tvägars': [('tväg', False)],
          'tvägen': [('tvägen', False)],
          'tvägens': [('tvägen', False)],
          'tvägs': [('tväg', False)],
          'tvälden': [('tvälde', False)],
          'tväldens': [('tvälde', False)],
          'tvält': [('tvälta', False)],
          'tvält-': [('tvälta', False)],
          'tvälts': [('tvälta', False)],
          'tvälts-': [('tvälta', False)],
          'tvändar': [('tvändare', False)],
          'tvändarna': [('tvändare', False)],
          'tvärden': [('tvärde', False)],
          'tvärdens': [('tvärde', False)],
          'tvärdet': [('tvärde', False)],
          'tväsendet': [('tväsen', False)],
          'tväsendets': [('tväsen', False)],
          'tvätt': [('tvätt', False)],
          'tvätt-': [('tvätt', True)],
          'tvättar': [('tvätt', False)],
          'tvättarna': [('tvätt', False)],
          'tvättarnas': [('tvätt', False)],
          'tvättars': [('tvätt', False)],
          'tvättbräde': [('tvättbräde', True), ('tvättbräda', True)],
          'tvätten': [('tvätt', False)],
          'tvättens': [('tvätt', False)],
          'tvätts': [('tvätt', False)],
          'tvätts-': [('tvätt', False)],
          'tvävar': [('tvävare', False)],
          'tvävarna': [('tvävare', False)],
          'tvävarnas': [('tvävare', False)],
          'tväxlar': [('tväxel', False)],
          'tväxlarna': [('tväxel', False)],
          'tväxlarnas': [('tväxel', False)],
          'tvågar': [('tvåg', False)],
          'tvågarna': [('tvåg', False)],
          'tvål': [('tvål', False)],
          'tvål-': [('tvål', False)],
          'tvålar': [('tvål', False)],
          'tvålarna': [('tvål', False)],
          'tvålarnas': [('tvål', False)],
          'tvålars': [('tvål', False)],
          'tvålen': [('tvål', False)],
          'tvålens': [('tvål', False)],
          'tvåls': [('tvål', False)],
          'tvåls-': [('tvål', True)],
          'tvårdar': [('tvårdare', False)],
          'tvårdarna': [('tvårdare', False)],
          'tvårdarnas': [('tvårdare', False)],
          'tweets': [('tweet', True), ('tweets', True)],
          'tweets-': [('tweets', True), ('tweet', True)],
          'ty': [('ty', False)],
          'ty-': [('ty', False)],
          'tyckarnas': [('tyckare', True)],
          'tycken': [('tycke', True)],
          'tyckena': [('tycke', True)],
          'tyckenas': [('tycke', True)],
          'tyckens': [('tycke', True)],
          'tycket': [('tycke', True)],
          'tyckets': [('tycke', False)],
          'tyckningar': [('tyckning', False)],
          'tyckningarna': [('tyckning', False)],
          'tyckningarnas': [('tyckning', False)],
          'tyckningars': [('tyckning', False)],
          'tycknings': [('tyckning', False)],
          'tycknings-': [('tyckning', False)],
          'tycks': [('tycke', True)],
          'tycks-': [('tycke', False)],
          'tyd': [('tyda', True)],
          'tyd-': [('tyda', True)],
          'tydan': [('tyda', True)],
          'tydans': [('tyda', True)],
          'tyds': [('tyda', True)],
          'tyds-': [('tyda', True)],
          'tyer': [('ty', False)],
          'tyerna': [('ty', False)],
          'tyernas': [('ty', False)],
          'tyers': [('ty', False)],
          'tyggar': [('tygger', False)],
          'tyggarna': [('tygger', False)],
          'tyggarnas': [('tygger', False)],
          'tyggen': [('tygger', False)],
          'tyggens': [('tygger', False)],
          'tyk': [('tyk', False)],
          'tyle': [('tyle', False)],
          'tyle-': [('tyle', False)],
          'tyll': [('tyll', True)],
          'tyll-': [('tyll', True)],
          'tyllen': [('tyll', True)],
          'tyllet': [('tyll', True)],
          'tyllets': [('tyll', True)],
          'tylls': [('tyll', True)],
          'tylls-': [('tyll', True)],
          'tylt': [('tylta', False)],
          'tylte': [('tylta', False)],
          'tympar': [('tympare', False)],
          'tymparen': [('tympare', False)],
          'tymparna': [('tympare', False)],
          'tymparnas': [('tympare', False)],
          'tyn': [('ty', False)],
          'tyna': [('ty', False)],
          'tynas': [('ty', False)],
          'tynets': [('tyn', False)],
          'tyng': [('tyng', False)],
          'tyng-': [('tyng', False)],
          'tyngs': [('tyng', False)],
          'tyngs-': [('tyng', False)],
          'tyns': [('ty', False)],
          'type': [('type', False)],
          'type-': [('type', False)],
          'typen': [('typ', True)],
          'typens': [('typ', True)],
          'typer': [('typ', True)],
          'typerna': [('typ', True)],
          'typernas': [('typ', True)],
          'typers': [('typ', True)],
          'typins': [('typi', False)],
          'tyrar': [('tyrare', False)],
          'tyrarna': [('tyrare', False)],
          'tyrarnas': [('tyrare', False)],
          'tyre': [('tyre', False)],
          'tyre-': [('tyre', False)],
          'tyrer': [('tyrer', False)],
          'tyrerna': [('tyrer', False)],
          'tyrernas': [('tyrer', False)],
          'tyrers': [('tyrer', False)],
          'tyret': [('tyre', False)],
          'tyrets': [('tyre', False)],
          'tyrie': [('tyrium', False)],
          'tyrier': [('tyrium', False)],
          'tyriernas': [('tyrium', False)],
          'tyriers': [('tyrium', False)],
          'tyrs-': [('tyrer', False)],
          'tys': [('ty', False)],
          'tys-': [('ty', False)],
          'tysk': [('tysk', True), ('tyska', True)],
          'tysk-': [('tysk', True), ('tyska', True)],
          'tyt': [('ty', False)],
          'tyts': [('ty', False)],
          'tyts-': [('tyta', False)],
          'tyx': [('tyxa', False)],
          'tyx-': [('tyxa', False)],
          'tz': [('tz', False)],
          'tz-': [('tz', False)],
          'tzar': [('tz', False)],
          'tzarna': [('tz', False)],
          'tzarnas': [('tz', False)],
          'tzer': [('tz', False)],
          'tzers': [('tz', False)],
          'tzon': [('tzon', False)],
          'tzonens': [('tzon', False)],
          'tzons': [('tzon', False)],
          'täckarnas': [('täckare', False)],
          'täcke': [('täcke', True)],
          'täckets': [('täcke', False)],
          'tädar': [('tädare', False)],
          'tädarna': [('tädare', False)],
          'täder': [('tad', False)],
          'tädernas': [('tad', False)],
          'tädets': [('täd', False)],
          'täds': [('täd', False)],
          'täds-': [('täd', False)],
          'tägg': [('tägg', False)],
          'tägg-': [('tägg', False)],
          'täggs': [('tägg', False)],
          'täggs-': [('tägg', False)],
          'täkt': [('täkt', False)],
          'täkt-': [('täkt', False)],
          'täkten': [('täkt', False)],
          'täktens': [('täkt', False)],
          'täkts': [('täkt', False)],
          'täkts-': [('täkt', False)],
          'täll': [('täll', False)],
          'täll-': [('täll', False)],
          'tällans': [('tällan', False)],
          'tällarna': [('tällare', False)],
          'tällarnas': [('tällare', False)],
          'tälls': [('täll', False)],
          'tälls-': [('täll', False)],
          'täls': [('täl', False)],
          'tälskan': [('tälska', False)],
          'tälskans': [('tälska', False)],
          'tält-': [('tält', True)],
          'tältar': [('tältare', True)],
          'tältarnas': [('tältare', True)],
          'tälten': [('tält', False)],
          'tältens': [('tält', False)],
          'tältet': [('tält', False)],
          'tälts': [('tält', False)],
          'tälts-': [('tält', False)],
          'täm-': [('tämma', False)],
          'tämme': [('tämma', False)],
          'tämne-': [('tämne', False)],
          'täms': [('tämma', False)],
          'täms-': [('tämma', False)],
          'tän': [('tän', False)],
          'tänd': [('tända', False)],
          'tänd-': [('tända', False)],
          'tändar': [('tändare', True)],
          'tändarna': [('tändare', True)],
          'tändarnas': [('tändare', False)],
          'tänder': [('tand', True)],
          'tänderna': [('tand', True)],
          'tändernas': [('tand', True)],
          'tänders': [('tand', True)],
          'tänds': [('tända', False)],
          'tänds-': [('tända', False)],
          'täng': [('täng', False)],
          'täng-': [('täng', False)],
          'tängar': [('täng', False)],
          'tängarna': [('tängare', False)],
          'tängarnas': [('tängare', False)],
          'tängen': [('täng', False)],
          'tängens': [('tänge', False)],
          'tänger': [('tång', True)],
          'tängerna': [('tång', True)],
          'tängernas': [('tång', True)],
          'tängers': [('tång', True)],
          'tängets': [('tänge', False)],
          'tängs': [('täng', False)],
          'tängs-': [('täng', False)],
          'tängslet': [('tängsel', False)],
          'tänk': [('tänk', False)],
          'tänk-': [('tänk', False)],
          'tänkar': [('tänkare', False)],
          'tänkarna': [('tänkare', False)],
          'tänkarnas': [('tänkare', False)],
          'tänke': [('tänka', False)],
          'tänken': [('tänk', False)],
          'tänkens': [('tänk', False)],
          'tänket': [('tänk', False)],
          'tänks': [('tänk', False)],
          'tänks-': [('tänk', False)],
          'täns': [('tän', False)],
          'täpp': [('täppa', True)],
          'täpp-': [('täppa', True)],
          'täppe': [('täppa', False)],
          'täppe-': [('täppa', False)],
          'täppen': [('täpp', False)],
          'täppens': [('täpp', False)],
          'täpps': [('täppa', True)],
          'täpps-': [('täppa', True)],
          'tärkarnas': [('tärkare', False)],
          'tärmar': [('tärm', False)],
          'tärmarna': [('tärm', False)],
          'tärmarnas': [('tärm', False)],
          'tärnorna': [('tärna', True)],
          'tärnornas': [('tärna', True)],
          'tärt': [('tärt', False)],
          'tärt-': [('tärt', False)],
          'tärter': [('tärter', False)],
          'tärterna': [('tärt', False)],
          'tärternas': [('tärt', False)],
          'tärters': [('tärter', False)],
          'tärts': [('tärter', False)],
          'tärts-': [('tärter', False)],
          'tät-': [('tät', False)],
          'täte': [('täte', True)],
          'täte-': [('täte', True)],
          'täten': [('täte', True), ('tät', True)],
          'tätens': [('täte', True), ('tät', True)],
          'tätets': [('tät', False)],
          'tätt': [('tätta', False)],
          'tätt-': [('tätta', False)],
          'tätte': [('tätta', False)],
          'tätte-': [('tätta', False)],
          'tätts': [('tätta', False)],
          'tätts-': [('tätta', False)],
          'tävan': [('täva', False)],
          'tävans': [('täva', False)],
          'tävar': [('täv', False)],
          'tävets': [('täv', False)],
          'tävlar': [('tävlare', False)],
          'tävlarna': [('tävlare', False)],
          'tävlarnas': [('tävlare', False)],
          'tå': [('tå', False)],
          'tå-': [('tå', False)],
          'tåfjuttar': [('tåfjuttare', True), ('tåfjutt', True)],
          'tåfjuttarna': [('tåfjutt', True), ('tåfjuttare', True)],
          'tåfjuttarnas': [('tåfjutt', True), ('tåfjuttare', True)],
          'tåg': [('tåga', True), ('tåg', True)],
          'tåg-': [('tåga', True), ('tåg', True)],
          'tågs': [('tåga', True), ('tåg', True)],
          'tågs-': [('tåga', True), ('tåg', True)],
          'tågände': [('tågända', True), ('tågände', True)],
          'tågände-': [('tågände', True), ('tågända', True)],
          'tågångarna': [('tågångare', True)],
          'tågångarnas': [('tågångare', True)],
          'tåkarna': [('tåkare', False)],
          'tålar': [('tålar', False)],
          'tålarna': [('tålar', False)],
          'tålarnas': [('tålar', False)],
          'tålars': [('tålar', False)],
          'tålen': [('tål', False)],
          'tåligheter': [('tålighet', False)],
          'tåligheterna': [('tålighet', False)],
          'tåligheternas': [('tålighet', False)],
          'tåligheters': [('tålighet', False)],
          'tålighets-': [('tålighet', False)],
          'tånd': [('tånd', False)],
          'tånd-': [('tånd', False)],
          'tånds': [('tånd', False)],
          'tånds-': [('tånd', False)],
          'tång': [('tånge', True), ('tång', True)],
          'tång-': [('tånge', True), ('tång', True)],
          'tångar': [('tånge', True)],
          'tångarna': [('tånge', True)],
          'tångarnas': [('tånge', True)],
          'tånge': [('tånge', True)],
          'tången': [('tånge', True), ('tång', True)],
          'tångens': [('tånge', True), ('tång', True)],
          'tångs': [('tånge', True), ('tång', True)],
          'tångs-': [('tånge', True), ('tång', True)],
          'tåns': [('tå', False)],
          'tår': [('tår', True), ('tå', True)],
          'tår-': [('tår', False)],
          'tårar': [('tår', True)],
          'tårarna': [('tår', False)],
          'tårarnas': [('tår', False)],
          'tårars': [('tår', True)],
          'tårs': [('tår', True), ('tå', True)],
          'tårs-': [('tår', True)],
          'tårtbitar': [('tårtbit', False)],
          'tårtbitarna': [('tårtbit', False)],
          'tårtbitarnas': [('tårtbit', False)],
          'tås': [('tå', False)],
          'tås-': [('tå', False)],
          'tåtarnas': [('tåt', True)],
          'téerna': [('té', False)],
          'téernas': [('té', False)],
          'tés-': [('té', False)],
          'töar': [('tö', False)],
          'töarna': [('tö', False)],
          'töden': [('töd', False)],
          'tödens': [('töd', False)],
          'tödet': [('töd', False)],
          'tödets': [('töd', False)],
          'tögat': [('töga', False)],
          'tögats': [('töga', False)],
          'tögonen': [('töga', False)],
          'tögonens': [('töga', False)],
          'tögons': [('töga', False)],
          'töken': [('töken', False)],
          'tökens': [('töken', False)],
          'tökets': [('tök', False)],
          'tölj': [('tölj', False)],
          'tölj-': [('tölj', False)],
          'töljen': [('tölj', False)],
          'töljens': [('tölj', False)],
          'töljs': [('tölj', False)],
          'töljs-': [('tölj', False)],
          'tömmen': [('töm', True)],
          'tön': [('tö', True)],
          'töns': [('tö', True)],
          'töns-': [('tön', False)],
          'törböns': [('törböna', False)],
          'törböns-': [('törböna', False)],
          'tören': [('tör', False)],
          'törens': [('tör', False)],
          'törighets-': [('törighet', False)],
          'törn': [('törne', True), ('törn', True)],
          'törn-': [('törn', True), ('törne', True)],
          'törnar': [('törn', True)],
          'törnarna': [('törn', True)],
          'törne-': [('törne', False)],
          'törnen': [('törn', True), ('törne', True)],
          'törnens': [('törne', True), ('törn', True)],
          'törnets': [('törne', False)],
          'törns': [('törn', True), ('törne', True)],
          'törns-': [('törne', True), ('törn', True)],
          'törtarnas': [('törtare', False)],
          'törtens': [('tört', False)],
          'törts-': [('tört', False)],
          'tös': [('tös', True), ('tö', True)],
          'tös-': [('tös', True)],
          'töt': [('tö', True)],
          'töt-': [('töt', False)],
          'töts': [('tö', True)],
          'tövar': [('tövare', False)],
          'tövarnas': [('tövare', False)],
          'u': [('u', True)],
          'u-': [('u', True)],
          'ua': [('ua', False)],
          'ualet': [('ual', False)],
          'ualets': [('ual', False)],
          'ualie-': [('ualier', False)],
          'ualierna': [('ualier', False)],
          'ualis': [('ualis', False)],
          'uals': [('ual', False)],
          'uals-': [('ual', False)],
          'uan': [('ua', False)],
          'uana': [('uum', False)],
          'uanan': [('uana', False)],
          'uanans': [('uana', False)],
          'uanas': [('uum', False)],
          'uanden': [('uande', False)],
          'uandens': [('uande', False)],
          'uandets': [('uande', False)],
          'uanens': [('uan', False)],
          'uanets': [('uan', False)],
          'uanon': [('uano', False)],
          'uanons': [('uano', False)],
          'uanos': [('uano', False)],
          'uanos-': [('uano', False)],
          'uanot': [('uano', False)],
          'uanots': [('uano', False)],
          'uans': [('ua', False)],
          'uans-': [('uan', False)],
          'uansk': [('uanska', False)],
          'uansk-': [('uanska', False)],
          'uar': [('uare', False)],
          'uar-': [('uare', False)],
          'uard': [('uard', False)],
          'uard-': [('uard', False)],
          'uarden': [('uard', False)],
          'uardens': [('uard', False)],
          'uards': [('uard', False)],
          'uare': [('uare', False)],
          'uaren': [('uare', False)],
          'uarens': [('uare', False)],
          'uares': [('uare', False)],
          'uari': [('uari', False)],
          'uari-': [('uari', False)],
          'uarie-': [('uarium', False)],
          'uarier': [('uarium', False)],
          'uariernas': [('uarium', False)],
          'uaris': [('uari', False)],
          'uarna': [('uare', False)],
          'uarnas': [('u', False)],
          'uars': [('uar', False)],
          'uasarna': [('ua', False)],
          'uasarnas': [('ua', False)],
          'uasen': [('ua', False)],
          'uasens': [('ua', False)],
          'uation': [('uation', False)],
          'uationen': [('uation', False)],
          'uations': [('uation', False)],
          'uayans': [('uayan', False)],
          'ub': [('ub', False)],
          'ub-': [('ub', False)],
          'uban': [('uban', False)],
          'uban-': [('uban', False)],
          'ubaner': [('uban', False)],
          'ubaners': [('uban', False)],
          'ubans': [('uban', False)],
          'ubar': [('ub', False)],
          'ubarna': [('ub', False)],
          'ubarnas': [('ub', False)],
          'ubars': [('ub', False)],
          'ubas': [('uba', False)],
          'ubb-': [('ubb', False)],
          'ubbar': [('ubb', False)],
          'ubbarna': [('ubbe', False)],
          'ubbarnas': [('ubbe', False)],
          'ubbars': [('ubbe', False)],
          'ubbe': [('ubbe', False)],
          'ubbe-': [('ubbe', False)],
          'ubben': [('ubb', False)],
          'ubbens': [('ubbe', False)],
          'ubblar': [('ubblare', False)],
          'ubblarna': [('ubblare', False)],
          'ubblarnas': [('ubblare', False)],
          'ubble': [('ubbla', False)],
          'ubblet': [('ubbel', False)],
          'ubblets': [('ubbel', False)],
          'ubbs': [('ubba', False)],
          'ube': [('uba', False)],
          'ube-': [('uba', False)],
          'ubel': [('ubel', False)],
          'ubel-': [('ubel', False)],
          'ubels': [('ubel', False)],
          'uben': [('ub', False)],
          'ubens': [('ub', False)],
          'ubens-': [('uben', False)],
          'uber': [('ub', False)],
          'uberna': [('ub', False)],
          'ubernas': [('ub', False)],
          'ubers': [('ub', False)],
          'ubierna': [('ubier', False)],
          'ubiernas': [('ubier', False)],
          'ubiers': [('ubier', False)],
          'ubil': [('ubil', False)],
          'ubil-': [('ubil', False)],
          'ubilar': [('ubilar', False)],
          'ubilars': [('ubil', False)],
          'ubils': [('ubil', False)],
          'ubils-': [('ubil', False)],
          'ubin': [('ubin', False)],
          'ubiner': [('ubin', False)],
          'ubinerna': [('ubin', False)],
          'ubinernas': [('ubin', False)],
          'ubiners': [('ubin', False)],
          'ubins': [('ubin', False)],
          'ubister': [('ubist', False)],
          'ubisters': [('ubist', False)],
          'ubits': [('ubits', False)],
          'ubits-': [('ubits', False)],
          'ublernas': [('ubel', False)],
          'ubon': [('ubon', False)],
          'ubons': [('ubon', False)],
          'ubor': [('uba', False)],
          'uborna': [('uba', False)],
          'ubornas': [('uba', False)],
          'ubors': [('uba', False)],
          'ubrin': [('ubrin', False)],
          'ubroder': [('ubror', False)],
          'ubrodern': [('ubror', False)],
          'ubroderns': [('ubror', False)],
          'ubroders': [('ubror', False)],
          'ubrons': [('ubro', False)],
          'ubrors': [('ubror', False)],
          'ubrors-': [('ubror', False)],
          'ubröder': [('ubror', False)],
          'ubröderna': [('ubror', False)],
          'ubrödernas': [('ubror', False)],
          'ubröders': [('ubror', False)],
          'ubröst': [('ubröst', False)],
          'ubröst-': [('ubröst', False)],
          'ubs': [('ub', False)],
          'ubs-': [('ub', False)],
          'uc': [('uca', False)],
          'uc-': [('uca', False)],
          'uce': [('uca', False)],
          'uce-': [('uca', False)],
          'ucent-': [('ucent', False)],
          'ucenter': [('ucent', False)],
          'ucenters': [('ucent', False)],
          'ucents': [('ucent', False)],
          'uche': [('uche', False)],
          'uche-': [('uche', False)],
          'uchen': [('uche', False)],
          'uchens': [('uche', False)],
          'uchon': [('ucho', False)],
          'uchons': [('ucho', False)],
          'uchor': [('ucho', False)],
          'uchorna': [('ucho', False)],
          'uchornas': [('ucho', False)],
          'uchos': [('ucho', False)],
          'uchos-': [('ucho', False)],
          'uchosen': [('ucho', False)],
          'uchosens': [('ucho', False)],
          'ucian': [('ucia', False)],
          'ucians': [('ucia', False)],
          'ucins': [('ucin', False)],
          'uckan': [('ucka', False)],
          'uckans': [('ucka', False)],
          'uckar': [('uckare', False)],
          'uckarna': [('uckare', False)],
          'uckarnas': [('uck', False)],
          'uckats': [('uckat', False)],
          'uckel': [('uckla', False)],
          'uckel-': [('uckla', False)],
          'ucker': [('ucker', False)],
          'uckerna': [('ucker', False)],
          'uckernas': [('ucker', False)],
          'uckers': [('ucker', False)],
          'uckets': [('uck', False)],
          'ucklan': [('uckla', False)],
          'ucklanden': [('ucklande', False)],
          'ucklandens': [('ucklande', False)],
          'ucklandet': [('ucklande', False)],
          'ucklans': [('uckla', False)],
          'ucklar': [('ucklare', False)],
          'ucklarna': [('uckel', False)],
          'ucklarnas': [('ucklare', False)],
          'uckle': [('uckla', False)],
          'ucklen': [('uckle', False)],
          'ucklens': [('uckle', False)],
          'ucklet': [('uckle', False)],
          'ucklets': [('uckle', False)],
          'uckls-': [('uckle', False)],
          'ucko': [('ucko', False)],
          'ucor': [('uca', False)],
          'ucorna': [('uca', False)],
          'ucornas': [('uca', False)],
          'ucs': [('uca', False)],
          'ud': [('ud', False)],
          'ud-': [('ud', False)],
          'udagen': [('udag', False)],
          'udagens': [('udag', False)],
          'udags': [('udag', False)],
          'udags-': [('udag', False)],
          'udan': [('udan', False)],
          'udanden': [('udande', False)],
          'udandens': [('udande', False)],
          'udans': [('udan', False)],
          'udans-': [('udan', False)],
          'udar': [('ud', False)],
          'udaren': [('udare', False)],
          'udarna': [('ud', False)],
          'udarnas': [('ud', False)],
          'udars': [('ud', False)],
          'udat': [('udat', False)],
          'udaten': [('udat', False)],
          'udatens': [('udat', False)],
          'udboj-': [('udboj', False)],
          'udbojs': [('udboj', False)],
          'udd': [('udd', True), ('udde', True)],
          'udd-': [('udde', True), ('udd', True)],
          'uddar': [('udde', True), ('udd', True)],
          'uddarna': [('udde', True), ('udd', True)],
          'uddarnas': [('udd', True), ('udde', True)],
          'uddars': [('udd', True), ('udde', True)],
          'uddatalsmetoden': [('uddatalsmetoden', True), ('uddatalsmetod', True)],
          'uddatalsmetodens': [('uddatalsmetoden', True), ('uddatalsmetod', True)],
          'udde': [('udde', False)],
          'udde-': [('udde', False)],
          'uddelar': [('uddel', False)],
          'uddelarna': [('uddel', False)],
          'uddelarnas': [('uddel', False)],
          'udden': [('udd', True), ('udde', True)],
          'uddens': [('udd', True), ('udde', True)],
          'udder': [('udder', False)],
          'udders': [('udder', False)],
          'udds': [('udde', True), ('udd', True)],
          'udds-': [('udde', True), ('udd', True)],
          'ude': [('uda', False)],
          'ude-': [('uda', False)],
          'udel': [('udel', False)],
          'udelandet': [('udelande', False)],
          'udels': [('udel', False)],
          'udels-': [('udel', False)],
          'uden': [('ud', False)],
          'udena': [('ud', False)],
          'udenas': [('ud', False)],
          'udens': [('ud', False)],
          'uder': [('ud', False)],
          'uder-': [('uder', False)],
          'uderits': [('uderi', False)],
          'uderna': [('ud', False)],
          'udernas': [('ud', False)],
          'uders': [('ud', False)],
          'udet': [('ud', False)],
          'udevillen': [('udeville', False)],
          'udeviller': [('udeville', False)],
          'udevillerna': [('udeville', False)],
          'udevillernas': [('udeville', False)],
          'udevillers': [('udeville', False)],
          'udien': [('udie', False)],
          'udiens': [('udie', False)],
          'udier': [('udium', False)],
          'udiernas': [('udium', False)],
          'udies': [('udie', False)],
          'udiet': [('udium', False)],
          'udiets': [('udium', False)],
          'uding': [('uding', False)],
          'uding-': [('uding', False)],
          'udingar': [('uding', False)],
          'udingarna': [('uding', False)],
          'udingarnas': [('uding', False)],
          'udingars': [('uding', False)],
          'udingen': [('uding', False)],
          'udingens': [('uding', False)],
          'udings': [('uding', False)],
          'udings-': [('uding', False)],
          'udion': [('udio', False)],
          'udior': [('udio', False)],
          'udiorna': [('udio', False)],
          'udiornas': [('udio', False)],
          'udiors': [('udio', False)],
          'udiskar': [('udisk', False)],
          'udiskarna': [('udisk', False)],
          'udiskarnas': [('udisk', False)],
          'uditorier': [('uditorium', False)],
          'uditoriet': [('uditorium', False)],
          'udlar': [('udel', False)],
          'udlarna': [('udel', False)],
          'udlarnas': [('udel', False)],
          'udlars': [('udel', False)],
          'udmor': [('udmor', False)],
          'udo-': [('udo', False)],
          'udoar': [('udoar', False)],
          'udoars': [('udoar', False)],
          'udomar': [('udom', False)],
          'udomarna': [('udom', False)],
          'udomarnas': [('udom', False)],
          'udomen': [('udom', False)],
          'udon': [('udo', False)],
          'udons': [('udo', False)],
          'udor': [('uda', False)],
          'udorna': [('uda', False)],
          'udornas': [('uda', False)],
          'udors': [('uda', False)],
          'udos': [('udo', False)],
          'udosen': [('udo', False)],
          'udosens': [('udo', False)],
          'udr': [('udra', False)],
          'udr-': [('udra', False)],
          'udra': [('udra', False)],
          'udran': [('udra', False)],
          'udrans': [('udra', False)],
          'udras': [('udra', False)],
          'udrorna': [('udra', False)],
          'uds': [('ud', False)],
          'uds-': [('ud', False)],
          'udsdomar': [('udsdom', False)],
          'udsdomarna': [('udsdom', False)],
          'udsdomarnas': [('udsdom', False)],
          'udslagar': [('udslag', False)],
          'udslagarna': [('udslag', False)],
          'udslagarnas': [('udslag', False)],
          'udslån': [('udslån', False)],
          'udslåns': [('udslån', False)],
          'udsorden': [('udsord', False)],
          'udsordens': [('udsord', False)],
          'udsporr': [('udsporre', False)],
          'udsporr-': [('udsporre', False)],
          'udsporren': [('udsporre', False)],
          'udsporrens': [('udsporre', False)],
          'udsporrs': [('udsporre', False)],
          'udvägens': [('udväg', False)],
          'ue': [('ue', False)],
          'ue-': [('ue', False)],
          'uelan': [('uelan', False)],
          'uelans': [('uelan', False)],
          'uell': [('uell', False)],
          'uell-': [('uell', False)],
          'uellen': [('uell', False)],
          'ueller': [('uell', False)],
          'uellerna': [('uell', False)],
          'uellernas': [('uell', False)],
          'uellers': [('uell', False)],
          'uells': [('uell', False)],
          'uells-': [('uell', False)],
          'uen': [('uen', False)],
          'uenden': [('uend', False)],
          'uendens': [('uend', False)],
          'uender': [('uend', False)],
          'uenderna': [('uend', False)],
          'uenders': [('uend', False)],
          'uendos': [('uendo', False)],
          'uenet': [('uen', False)],
          'uenets': [('uen', False)],
          'uenne': [('uenna', False)],
          'uenne-': [('uenna', False)],
          'uenns': [('uenna', False)],
          'uens': [('ue', False)],
          'uens-': [('uens', False)],
          'uensen': [('uens', False)],
          'uensens': [('uens', False)],
          'uenser': [('uens', False)],
          'uenserna': [('uens', False)],
          'uensernas': [('uens', False)],
          'uensers': [('uens', False)],
          'uensor': [('uensa', False)],
          'uensors': [('uensa', False)],
          'uent': [('uent', False)],
          'uenten': [('uent', False)],
          'uentens': [('uent', False)],
          'uenter': [('uent', False)],
          'uenterna': [('uent', False)],
          'uenternas': [('uent', False)],
          'uenters': [('uent', False)],
          'uents-': [('uent', False)],
          'uer': [('uer', False)],
          'uer-': [('uer', False)],
          'uerare': [('uerare', False)],
          'uerares': [('uerare', False)],
          'uerarna': [('uerare', False)],
          'uerarnas': [('uerare', False)],
          'uerna': [('uer', False)],
          'uernas': [('ue', False)],
          'uers': [('ue', False)],
          'uers-': [('uer', False)],
          'ues': [('ue', False)],
          'ues-': [('ue', False)],
          'uet': [('uet', False)],
          'ueten': [('uet', False)],
          'uetens': [('uet', False)],
          'ueter': [('uet', False)],
          'ueters': [('uet', False)],
          'uets': [('u', False)],
          'uett': [('uett', False)],
          'uett-': [('uett', False)],
          'uette-': [('uette', False)],
          'uetten': [('uett', False)],
          'uettens': [('uette', False)],
          'uetter': [('uett', False)],
          'uetterna': [('uett', False)],
          'uetternas': [('uett', False)],
          'uetters': [('uette', False)],
          'uetts': [('uett', False)],
          'uetts-': [('uett', False)],
          'uf-': [('uf', False)],
          'ufakta': [('ufakta', False)],
          'ufaktana': [('ufakta', False)],
          'ufaktanas': [('ufakta', False)],
          'ufaktas': [('ufakta', False)],
          'ufaktur': [('ufaktur', False)],
          'ufaktur-': [('ufaktur', False)],
          'ufakturs': [('ufaktur', False)],
          'ufar': [('uf', False)],
          'ufarna': [('uf', False)],
          'ufars': [('uf', False)],
          'ufel': [('ufel', False)],
          'ufels': [('ufel', False)],
          'ufels-': [('ufel', False)],
          'ufen': [('uf', False)],
          'ufens': [('uf', False)],
          'uffarnas': [('uff', False)],
          'uffens': [('uff', False)],
          'uffer': [('uffra', False)],
          'uffer-': [('uffra', False)],
          'ufflar': [('ufflare', False)],
          'ufflarna': [('ufflare', False)],
          'ufflarnas': [('ufflare', False)],
          'uflage': [('uflage', False)],
          'uflage-': [('uflage', False)],
          'uflagen': [('uflage', False)],
          'uflagens': [('uflage', False)],
          'ufon': [('ufo', True)],
          'ufonis': [('ufoni', False)],
          'ufons': [('ufo', True)],
          'ufot': [('ufo', True)],
          'ufots': [('ufo', True)],
          'ufs': [('uf', False)],
          'ufs-': [('ufs', False)],
          'ufsarnas': [('ufs', False)],
          'uftets': [('uft', False)],
          'uftvägar': [('uftväg', False)],
          'uftvägarna': [('uftväg', False)],
          'uftvägarnas': [('uftväg', False)],
          'ug': [('ug', False)],
          'ug-': [('uga', False)],
          'ugan': [('uga', False)],
          'ugandens': [('ugande', False)],
          'ugans': [('uga', False)],
          'ugar': [('ug', False)],
          'ugaren': [('ugare', False)],
          'ugarna': [('ug', False)],
          'ugarnas': [('ug', False)],
          'ugars': [('ug', False)],
          'ugas': [('uga', False)],
          'ugat': [('ugat', False)],
          'ugat-': [('ugat', False)],
          'ugaten': [('ugat', False)],
          'ugatens': [('ugat', False)],
          'ugater': [('ugat', False)],
          'ugaterna': [('ugat', False)],
          'ugaternas': [('ugat', False)],
          'ugaters': [('ugat', False)],
          'ugats': [('ugat', False)],
          'uge': [('uga', False)],
          'uge-': [('uga', False)],
          'ugen': [('ug', False)],
          'ugens': [('ug', False)],
          'uger': [('ug', False)],
          'ugerna': [('ug', False)],
          'ugernas': [('ug', False)],
          'ugers': [('ug', False)],
          'uget': [('ug', False)],
          'ugets': [('uge', False)],
          'ugg': [('ugge', False)],
          'ugg-': [('ugga', False)],
          'uggar': [('uggare', False)],
          'uggarna': [('uggare', False)],
          'uggarnas': [('uggare', False)],
          'uggars': [('ugge', False)],
          'ugge': [('ugge', False)],
          'uggen': [('ugge', False)],
          'ugger': [('ugger', False)],
          'uggers': [('ugger', False)],
          'uggets': [('ugg', False)],
          'uggs': [('ugge', False)],
          'uggs-': [('ugge', False)],
          'ughets': [('ughet', False)],
          'ugis': [('ugis', False)],
          'ugis-': [('ugis', False)],
          'ugman': [('ugma', False)],
          'ugmans': [('ugma', False)],
          'ugmat': [('ugma', False)],
          'ugnarnas': [('ugn', True)],
          'ugnet': [('ugn', False)],
          'ugnets': [('ugn', False)],
          'ugor': [('uga', False)],
          'ugorna': [('uga', False)],
          'ugornas': [('uga', False)],
          'ugors': [('uga', False)],
          'ugräns': [('ugräns', False)],
          'ugräns-': [('ugräns', False)],
          'ugs': [('ug', False)],
          'ugs-': [('uga', False)],
          'ugu': [('uga', False)],
          'ugu-': [('ugu', False)],
          'uguinean': [('uguinean', False)],
          'uguineans': [('uguinean', False)],
          'uhandlar': [('uhandel', False)],
          'uhandlarna': [('uhandel', False)],
          'uhandlarnas': [('uhandel', False)],
          'uhus': [('uhus', False)],
          'uhylle': [('uhylla', False)],
          'uhylle-': [('uhylla', False)],
          'ui': [('ui', False)],
          'ui-': [('ui', False)],
          'uicen': [('uice', False)],
          'uicens': [('uice', False)],
          'uicers': [('uice', False)],
          'uide': [('uide', False)],
          'uide-': [('uidum', False)],
          'uiden': [('uide', False)],
          'uidens': [('uide', False)],
          'uider': [('uide', False)],
          'uiderna': [('uide', False)],
          'uidernas': [('uide', False)],
          'uiders': [('uide', False)],
          'uides': [('uide', False)],
          'uides-': [('uide', False)],
          'uidet': [('uidum', False)],
          'uidets': [('uidum', False)],
          'uids': [('uid', False)],
          'uiens': [('ui', False)],
          'uier': [('ui', False)],
          'uierna': [('ui', False)],
          'uiernas': [('ui', False)],
          'uiers': [('ui', False)],
          'uin': [('uin', False)],
          'uina': [('ui', False)],
          'uinas': [('ui', False)],
          'uins': [('ui', False)],
          'uinstans': [('uinstad', False)],
          'uis': [('ui', False)],
          'uis-': [('ui', False)],
          'uiskan': [('uiska', False)],
          'uiskans': [('uiska', False)],
          'uiske': [('uiska', False)],
          'uiske-': [('uiska', False)],
          'uiss': [('uiss', False)],
          'uissar': [('uiss', False)],
          'uissars': [('uiss', False)],
          'uissen': [('uiss', False)],
          'uissens': [('uiss', False)],
          'uisser': [('uiss', False)],
          'uisserna': [('uiss', False)],
          'uissernas': [('uiss', False)],
          'uissers': [('uiss', False)],
          'uist-': [('uist', False)],
          'uisten': [('uist', False)],
          'uistens': [('uist', False)],
          'uister': [('uist', False)],
          'uisterna': [('uist', False)],
          'uisternas': [('uist', False)],
          'uisters': [('uist', False)],
          'uistik': [('uistik', False)],
          'uistik-': [('uistik', False)],
          'uistiks': [('uistik', False)],
          'uit': [('uit', False)],
          'uiternas': [('uit', False)],
          'uits': [('uit', False)],
          'uj': [('uja', False)],
          'uj-': [('uja', False)],
          'ujan': [('uja', False)],
          'ujans': [('uja', False)],
          'uje': [('uja', False)],
          'uje-': [('uja', False)],
          'ujoner': [('ujon', False)],
          'ujonerna': [('ujon', False)],
          'ujonernas': [('ujon', False)],
          'ujoners': [('ujon', False)],
          'ujons': [('ujon', False)],
          'ujor': [('uja', False)],
          'ujorna': [('uja', False)],
          'ujornas': [('uja', False)],
          'ujors': [('uja', False)],
          'uk': [('uk', False)],
          'uk-': [('uk', False)],
          'ukammar': [('ukammare', False)],
          'ukan': [('ukan', False)],
          'ukan-': [('ukan', False)],
          'ukanden': [('ukande', False)],
          'ukans': [('uka', False)],
          'ukar': [('uk', False)],
          'ukar-': [('ukare', False)],
          'ukare': [('ukare', False)],
          'ukaren': [('ukare', False)],
          'ukarens': [('ukare', False)],
          'ukarna': [('uk', False)],
          'ukarnas': [('ukare', False)],
          'ukarpar': [('ukarpar', False)],
          'ukarpars': [('ukarpar', False)],
          'ukars': [('uk', False)],
          'ukas': [('ukas', True)],
          'ukas-': [('ukas', True)],
          'ukasen': [('ukas', True)],
          'ukasens': [('ukas', True)],
          'ukass': [('ukasse', False)],
          'ukasse': [('ukasse', False)],
          'ukasse-': [('ukasse', False)],
          'ukassen': [('ukasse', False)],
          'ukat': [('ukat', False)],
          'ukaten': [('ukat', False)],
          'ukatens': [('ukat', False)],
          'ukats': [('ukat', False)],
          'ukats-': [('ukat', False)],
          'ukdelar': [('ukdel', False)],
          'ukdelarna': [('ukdel', False)],
          'ukdelarnas': [('ukdel', False)],
          'uke': [('uka', False)],
          'uke-': [('uka', False)],
          'ukelsen': [('ukelse', False)],
          'ukelsens': [('ukelse', False)],
          'uken': [('uk', False)],
          'ukens': [('uk', False)],
          'uker': [('uk', False)],
          'ukerna': [('uk', False)],
          'ukernas': [('uk', False)],
          'ukers': [('uk', False)],
          'uket': [('uk', False)],
          'ukin': [('uki', False)],
          'ukina': [('uki', False)],
          'ukinas': [('uki', False)],
          'ukis': [('ukis', False)],
          'ukis-': [('uki', False)],
          'ukisarna': [('uki', False)],
          'ukisarnas': [('ukis', False)],
          'ukisen': [('ukis', False)],
          'ukisens': [('ukis', False)],
          'ukkasse-': [('ukkassa', False)],
          'ukling': [('ukling', False)],
          'ukling-': [('ukling', False)],
          'uklings': [('ukling', False)],
          'uklings-': [('ukling', False)],
          'uklubb': [('uklubb', False)],
          'uklubbs': [('uklubb', False)],
          'uklubbs-': [('uklubb', False)],
          'ukningar': [('ukning', False)],
          'ukningarna': [('ukning', False)],
          'ukningarnas': [('ukning', False)],
          'ukningars': [('ukning', False)],
          'uknings': [('ukning', False)],
          'uknings-': [('ukning', False)],
          'ukom': [('ukom', False)],
          'ukom-': [('ukom', False)],
          'ukomet': [('ukom', False)],
          'ukomets': [('ukom', False)],
          'ukoms': [('ukom', False)],
          'ukonst-': [('ukonst', False)],
          'ukor': [('uka', False)],
          'ukorna': [('uka', False)],
          'ukornas': [('uka', False)],
          'ukors': [('uka', False)],
          'ukors-': [('ukors', False)],
          'ukos': [('ukos', False)],
          'ukos-': [('ukos', False)],
          'ukravaller': [('ukravaller', False)],
          'ukravallerna': [('ukravaller', False)],
          'ukravallernas': [('ukravaller', False)],
          'ukravallers': [('ukravaller', False)],
          'ukravalls': [('ukravaller', False)],
          'ukringar': [('ukring', False)],
          'ukringars': [('ukring', False)],
          'uks': [('uk', False)],
          'uks-': [('uk', False)],
          'uksdammen': [('uksdammen', False)],
          'uksvärdet': [('uksvärde', False)],
          'uktans': [('uktans', False)],
          'uktans-': [('uktans', False)],
          'uktar': [('uktare', False)],
          'uktar-': [('uktare', False)],
          'uktarens': [('uktare', False)],
          'uktarna': [('uktare', False)],
          'uktarnas': [('ukt', False)],
          'uktioner': [('uktion', False)],
          'uktionerna': [('uktion', False)],
          'uktionernas': [('uktion', False)],
          'uktioners': [('uktion', False)],
          'uktions': [('uktion', False)],
          'uktor': [('uktor', False)],
          'uktors': [('uktor', False)],
          'uktträn': [('uktträd', False)],
          'uktträna': [('uktträd', False)],
          'uktträns': [('uktträd', False)],
          'ukök': [('ukök', False)],
          'ukök-': [('ukök', False)],
          'uköks': [('ukök', False)],
          'uköks-': [('ukök', False)],
          'ul': [('ul', False)],
          'ul-': [('ul', False)],
          'ula': [('ulum', False)],
          'ulad': [('ulad', False)],
          'ulad-': [('ulad', False)],
          'ulads': [('ulad', False)],
          'ulager': [('ulage', False)],
          'ulagerna': [('ulage', False)],
          'ulagernas': [('ulage', False)],
          'ulagers': [('ulage', False)],
          'ulaget': [('ulage', False)],
          'ulagets': [('ulage', False)],
          'ulak': [('ulak', False)],
          'ulak-': [('ulak', False)],
          'ulaken': [('ulak', False)],
          'ulakens': [('ulak', False)],
          'ulaks': [('ulak', False)],
          'ulaks-': [('ulak', False)],
          'ulan': [('ulan', True)],
          'ulan-': [('ulan', True)],
          'ulana': [('ulum', False)],
          'ulanas': [('ulum', False)],
          'ulanden': [('ulande', False)],
          'ulandena': [('ulande', False)],
          'ulandenas': [('ulande', False)],
          'ulandens': [('ulande', False)],
          'ulandet': [('ulande', False)],
          'ulandets': [('ulande', False)],
          'ulaner': [('ulan', True)],
          'ulanerna': [('ulan', True)],
          'ulanernas': [('ulan', True)],
          'ulaners': [('ulan', True)],
          'ulans': [('ulan', False)],
          'ulans-': [('ulans', False)],
          'ulant-': [('ulant', False)],
          'ulanterna': [('ulant', False)],
          'ulanternas': [('ulant', False)],
          'ulants': [('ulant', False)],
          'ulap': [('ulap', False)],
          'ulap-': [('ulap', False)],
          'ulaps': [('ulap', False)],
          'ulaps-': [('ulap', False)],
          'ular': [('ul', False)],
          'ular-': [('ular', False)],
          'ularens': [('ular', False)],
          'ularer': [('ular', False)],
          'ularerna': [('ular', False)],
          'ularernas': [('ular', False)],
          'ularers': [('ular', False)],
          'ularna': [('ule', False)],
          'ularnas': [('ul', False)],
          'ulars': [('ul', False)],
          'ulars-': [('ular', False)],
          'ulas': [('ulas', False)],
          'ulasen': [('ulas', False)],
          'ulasens': [('ulas', False)],
          'ulat': [('ulat', False)],
          'ulat-': [('ulat', False)],
          'ulaten': [('ulat', False)],
          'ulatens': [('ulat', False)],
          'ulater': [('ulat', False)],
          'ulaterna': [('ulat', False)],
          'ulaternas': [('ulat', False)],
          'ulaters': [('ulat', False)],
          'ulats': [('ulat', False)],
          'ulats-': [('ulat', False)],
          'ulatt': [('ulatt', False)],
          'ulatt-': [('ulatt', False)],
          'ulatten': [('ulatt', False)],
          'ulattens': [('ulatt', False)],
          'ulatts': [('ulatt', False)],
          'ulatts-': [('ulatt', False)],
          'ulbens': [('ulb', False)],
          'ulder-': [('uldra', False)],
          'uldets': [('uld', False)],
          'ule': [('ula', False)],
          'ule-': [('ula', False)],
          'ulelers': [('ulele', False)],
          'ulen': [('ul', False)],
          'ulens': [('ul', False)],
          'uler': [('ul', False)],
          'ulerna': [('ul', False)],
          'ulernas': [('ul', False)],
          'ulers': [('ul', False)],
          'ulet': [('ul', False)],
          'ulets': [('ul', False)],
          'ulettens': [('ulett', False)],
          'ulgar': [('ulgar', False)],
          'ulgaren': [('ulgar', False)],
          'ulgars': [('ulgar', False)],
          'uli': [('ulus', False)],
          'uli-': [('uli', False)],
          'ulian': [('ulia', False)],
          'ulians': [('ulia', False)],
          'ulias': [('ulia', False)],
          'ulierna': [('uli', False)],
          'uliet': [('ulium', False)],
          'uligan': [('uligan', False)],
          'uligans': [('uligan', False)],
          'ulighets': [('ulighet', False)],
          'ulik': [('ulik', False)],
          'ulik-': [('ulik', False)],
          'uliken': [('ulik', False)],
          'ulikens': [('ulik', False)],
          'uliks': [('ulik', False)],
          'ulin': [('ulin', False)],
          'ulin-': [('ulin', False)],
          'ulina': [('ulus', False)],
          'ulinas': [('ulus', False)],
          'ulinen': [('ulin', False)],
          'ulinens': [('ulin', False)],
          'uliner': [('ulin', False)],
          'ulinerna': [('ulin', False)],
          'ulinernas': [('ulin', False)],
          'uliners': [('ulin', False)],
          'ulinet': [('ulin', False)],
          'ulinne': [('ulinna', False)],
          'ulinne-': [('ulinna', False)],
          'ulins': [('ulin', False)],
          'ulins-': [('ulin', False)],
          'ulis': [('ulus', False)],
          'ulis-': [('uli', False)],
          'uliss-': [('uliss', False)],
          'ulist': [('ulist', False)],
          'ulist-': [('ulist', False)],
          'ulit': [('ulit', False)],
          'ulit-': [('ulit', False)],
          'uliten': [('ulit', False)],
          'ulitens': [('ulit', False)],
          'uliter': [('ulit', False)],
          'uliterna': [('ulit', False)],
          'uliternas': [('ulit', False)],
          'uliters': [('ulit', False)],
          'ulits': [('ulit', False)],
          'ulivs': [('uliv', False)],
          'ulivs-': [('uliv', False)],
          'ulk': [('ulk', True)],
          'ulk-': [('ulk', True)],
          'ulkan': [('ulkan', False)],
          'ulkans': [('ulka', False)],
          'ulkarnas': [('ulk', False)],
          'ulkasse': [('ulkasse', False)],
          'ulkor': [('ulka', False)],
          'ulkors': [('ulkors', False)],
          'ulkors-': [('ulkors', False)],
          'ulks': [('ulk', True)],
          'ulks-': [('ulk', True)],
          'ulkyn': [('ulky', False)],
          'ulkyns': [('ulky', False)],
          'ull': [('ull', True)],
          'ull-': [('ull', True)],
          'ullagens': [('ullag', False)],
          'ullandets': [('ullande', False)],
          'ullans': [('ulla', False)],
          'ullar': [('ulle', False)],
          'ullar-': [('ullare', False)],
          'ullarna': [('ulle', False)],
          'ullarnas': [('ull', False)],
          'ullars': [('ulle', False)],
          'ullbil': [('ullbil', False)],
          'ullbils': [('ullbil', False)],
          'ullbils-': [('ullbil', False)],
          'ulle': [('ulle', False)],
          'ullen': [('ull', True)],
          'ullens': [('ull', False)],
          'uller': [('uller', False)],
          'ullerna': [('uller', False)],
          'ullernas': [('uller', False)],
          'ullers': [('uller', False)],
          'ullkor': [('ullko', False)],
          'ullkors': [('ullko', False)],
          'ullmåns-': [('ullmåne', False)],
          'ulls': [('ull', True)],
          'ulls-': [('ull', True)],
          'ullspinnar': [('ullspinne', False)],
          'ullspinnarna': [('ullspinne', False)],
          'ullspinnarnas': [('ullspinne', False)],
          'ulländarnas': [('ulländare', False)],
          'ullås': [('ullås', False)],
          'ullås-': [('ullås', False)],
          'ullåts': [('ullåt', False)],
          'ulmen': [('ulmen', False)],
          'ulmens': [('ulmen', False)],
          'uln': [('ul', False)],
          'ulningar': [('ulning', False)],
          'ulningarna': [('ulning', False)],
          'ulningarnas': [('ulning', False)],
          'ulningars': [('ulning', False)],
          'ulnings': [('ulning', False)],
          'ulnings-': [('ulning', False)],
          'ulns': [('ul', False)],
          'ulom-': [('ulom', False)],
          'uloms': [('ulom', False)],
          'ulor': [('ula', False)],
          'ulorna': [('ula', False)],
          'ulornas': [('ula', False)],
          'ulors': [('ula', False)],
          'ulos': [('ulos', False)],
          'ulos-': [('ulos', False)],
          'ulosen': [('ulos', False)],
          'ulosens': [('ulos', False)],
          'ulott': [('ulott', False)],
          'ulott-': [('ulotta', False)],
          'ulotte': [('ulotte', False)],
          'ulotte-': [('ulotta', False)],
          'ulotten': [('ulotte', False)],
          'ulottens': [('ulott', False)],
          'ulotter': [('ulotte', False)],
          'ulotterna': [('ulotte', False)],
          'ulotternas': [('ulotte', False)],
          'ulotters': [('ulotte', False)],
          'ulotts': [('ulotta', False)],
          'ulotts-': [('ulotta', False)],
          'ulp': [('ulpa', False)],
          'ulp-': [('ulpa', False)],
          'ulpan': [('ulpa', False)],
          'ulpans': [('ulpa', False)],
          'ulparnas': [('ulp', False)],
          'ulps': [('ulp', False)],
          'ulps-': [('ulpa', False)],
          'uls': [('ul', False)],
          'uls-': [('ul', False)],
          'ulsaren': [('ulsar', False)],
          'ulsarnas': [('uls', False)],
          'ulsten': [('ulst', False)],
          'ulstens': [('ulst', False)],
          'ulster': [('ulster', True)],
          'ulsterna': [('ulst', False)],
          'ulsternas': [('ulst', False)],
          'ulsters': [('ulster', True)],
          'ulstrar': [('ulster', True)],
          'ulstrarna': [('ulster', True)],
          'ulstötarnas': [('ulstötare', False)],
          'ult': [('ult', False)],
          'ult-': [('ulta', False)],
          'ultan': [('ulta', False)],
          'ultans': [('ulta', False)],
          'ultar': [('ulte', False)],
          'ultarna': [('ulte', False)],
          'ultarnas': [('ult', False)],
          'ultars': [('ulte', False)],
          'ulte': [('ulte', False)],
          'ulter': [('ultra', False)],
          'ulter-': [('ultra', False)],
          'ultes': [('ulte', False)],
          'ultet': [('ultet', False)],
          'ultets': [('ult', False)],
          'ultorna': [('ulta', False)],
          'ultrans': [('ultra', True)],
          'ultron': [('ultron', False)],
          'ultrons': [('ultron', False)],
          'ulums': [('ulum', False)],
          'ulun': [('ulu', False)],
          'uluns': [('ulu', False)],
          'uluns-': [('ulun', False)],
          'ulus': [('ulu', False)],
          'ulvan': [('ulva', False)],
          'ulvans': [('ulva', False)],
          'ulvars': [('ulv', True)],
          'ulvens': [('ulv', False)],
          'ulver': [('ulver', False)],
          'ulverna': [('ulver', False)],
          'ulvernas': [('ulver', False)],
          'ulvers': [('ulver', False)],
          'ulär': [('ulär', False)],
          'ulär-': [('ulär', False)],
          'ulärs': [('ulär', False)],
          'ulärs-': [('ulär', False)],
          'ulåns': [('ulån', False)],
          'ulåns-': [('ulån', False)],
          'um': [('um', False)],
          'um-': [('um', False)],
          'umak': [('umak', False)],
          'umak-': [('umak', False)],
          'umaken': [('umak', False)],
          'umakens': [('umak', False)],
          'umaks': [('umak', False)],
          'uman': [('uman', False)],
          'umana': [('uma', False)],
          'umanas': [('uma', False)],
          'umannen': [('uman', False)],
          'umannens': [('uman', False)],
          'umans': [('uma', False)],
          'umar': [('um', False)],
          'umarna': [('um', False)],
          'umarnas': [('um', False)],
          'umars': [('um', False)],
          'umas': [('uma', False)],
          'umasarna': [('uma', False)],
          'umasarnas': [('uma', False)],
          'umasen': [('uma', False)],
          'umasens': [('uma', False)],
          'umat': [('uma', False)],
          'umatik': [('umatik', False)],
          'umatik-': [('umatik', False)],
          'umatiks': [('umatik', False)],
          'umatos': [('umato', False)],
          'umats': [('uma', False)],
          'umb': [('umba', False)],
          'umb-': [('umba', False)],
          'umbon': [('umbo', False)],
          'umbons': [('umbo', False)],
          'umbor': [('umbo', False)],
          'umborna': [('umbo', False)],
          'umbornas': [('umbo', False)],
          'umbors': [('umba', False)],
          'umbos': [('umbo', False)],
          'umbos-': [('umbo', False)],
          'umbs': [('umba', False)],
          'umbs-': [('umba', False)],
          'umen': [('um', False)],
          'umens': [('um', False)],
          'umentets': [('ument', False)],
          'uments': [('ument', False)],
          'umer': [('um', False)],
          'umerna': [('um', False)],
          'umernas': [('um', False)],
          'umers': [('um', False)],
          'umet': [('um', False)],
          'umets': [('um', False)],
          'umfar': [('umf', False)],
          'umie': [('umie', False)],
          'umie-': [('umie', False)],
          'umien': [('umie', False)],
          'umiens': [('umie', False)],
          'umier': [('umie', False)],
          'umierna': [('umie', False)],
          'umiernas': [('umie', False)],
          'umiers': [('umie', False)],
          'umies': [('umie', False)],
          'umin': [('umin', False)],
          'umin-': [('umin', False)],
          'uminalen': [('uminal', False)],
          'uminalens': [('uminal', False)],
          'uminens': [('umin', False)],
          'uminet': [('umin', False)],
          'uminets': [('umen', False)],
          'umins': [('umin', False)],
          'umins-': [('umin', False)],
          'umister': [('umist', False)],
          'umisters': [('umist', False)],
          'umlandets': [('umlande', False)],
          'umlar': [('umlare', False)],
          'umlarna': [('umlare', False)],
          'umlarnas': [('ummel', False)],
          'umlen': [('umle', False)],
          'umlens': [('umle', False)],
          'umlet': [('umle', False)],
          'umlets': [('umle', False)],
          'umman': [('umma', False)],
          'ummar': [('um', False)],
          'ummarens': [('ummare', False)],
          'ummarna': [('umme', False)],
          'ummarnas': [('ummare', False)],
          'ummars': [('um', False)],
          'umme': [('umme', False)],
          'umme-': [('umme', False)],
          'ummen': [('um', False)],
          'ummens': [('um', False)],
          'ummer': [('ummer', False)],
          'ummernas': [('ummer', False)],
          'ummet': [('um', False)],
          'ummets': [('um', False)],
          'ummin': [('ummin', False)],
          'ummins': [('ummin', False)],
          'ummis': [('ummi', False)],
          'ummis-': [('ummi', False)],
          'umnet': [('umen', False)],
          'umnets': [('umen', False)],
          'umo': [('umo', False)],
          'umonier': [('umoni', False)],
          'umoniernas': [('umoni', False)],
          'umoniers': [('umoni', False)],
          'umor': [('uma', False)],
          'umor-': [('umor', False)],
          'umorna': [('uma', False)],
          'umornas': [('uma', False)],
          'umors': [('umor', False)],
          'umos': [('umo', False)],
          'umot': [('umo', False)],
          'umots': [('umo', False)],
          'ump': [('umpa', False)],
          'ump-': [('umpa', False)],
          'umpan': [('umpa', False)],
          'umpans': [('umpa', False)],
          'umparnas': [('ump', False)],
          'umpas': [('umpa', False)],
          'umper': [('umper', False)],
          'umpers': [('umper', False)],
          'umpet': [('umpet', False)],
          'umpets': [('umpet', False)],
          'umpor': [('ump', False)],
          'umporna': [('ump', False)],
          'umpornas': [('ump', False)],
          'umpors': [('ump', False)],
          'umps': [('umpa', False)],
          'umps-': [('umpa', False)],
          'umpsen': [('umps', False)],
          'umpsens': [('umps', False)],
          'umrar': [('ummer', False)],
          'umrarna': [('ummer', False)],
          'umrarnas': [('ummer', False)],
          'umrars': [('ummer', False)],
          'ums': [('um', False)],
          'ums-': [('um', False)],
          'umsar': [('umse', False)],
          'umsarna': [('umse', False)],
          'umsarnas': [('ums', False)],
          'umsars': [('umse', False)],
          'umse': [('umse', False)],
          'umsen': [('umse', False)],
          'umsens': [('umse', False)],
          'umsets': [('ums', False)],
          'umsk': [('umske', False)],
          'umsk-': [('umske', False)],
          'umsugar': [('umsug', False)],
          'umsugarna': [('umsugare', False)],
          'umsugarnas': [('umsug', False)],
          'umtidens': [('umtid', False)],
          'umult': [('umult', False)],
          'umult-': [('umult', False)],
          'umulten': [('umult', False)],
          'umultens': [('umult', False)],
          'umults': [('umult', False)],
          'umults-': [('umult', False)],
          'umys': [('umys', False)],
          'umys-': [('umys', False)],
          'umän': [('uman', False)],
          'umäns': [('uman', False)],
          'umör': [('umör', False)],
          'umörs': [('umör', False)],
          'un-': [('un', False)],
          'una': [('una', False)],
          'unal': [('unal', False)],
          'unal-': [('unal', False)],
          'unalen': [('unal', False)],
          'unalens': [('unal', False)],
          'unaler': [('unal', False)],
          'unalerna': [('unal', False)],
          'unalernas': [('unal', False)],
          'unalers': [('unal', False)],
          'unals-': [('unal', False)],
          'unamn': [('unamn', False)],
          'unamn-': [('unamn', False)],
          'unamnen': [('unamn', False)],
          'unamnens': [('unamn', False)],
          'unamns': [('unamn', False)],
          'unamns-': [('unamn', False)],
          'unanden': [('unande', False)],
          'unandens': [('unand', False)],
          'unar': [('unare', False)],
          'unar-': [('unare', False)],
          'unaren': [('unare', False)],
          'unarens': [('unare', False)],
          'unarnas': [('unare', False)],
          'unas': [('una', False)],
          'unat': [('unat', False)],
          'unat-': [('unat', False)],
          'unaten': [('unat', False)],
          'unatens': [('unat', False)],
          'unats': [('unat', False)],
          'unats-': [('unat', False)],
          'unchar': [('unch', False)],
          'uncharna': [('unch', False)],
          'uncharnas': [('unchare', False)],
          'unda': [('unda', False)],
          'undan': [('undan', False)],
          'undans-': [('undans', False)],
          'undanten': [('undant', False)],
          'undantens': [('undant', False)],
          'undar': [('undare', False)],
          'undar-': [('undare', False)],
          'undarens': [('undare', False)],
          'undaret': [('undare', False)],
          'undarets': [('undare', False)],
          'undarna': [('undare', False)],
          'undarnas': [('und', False)],
          'undars-': [('undare', False)],
          'undas': [('unda', False)],
          'undelar': [('undel', False)],
          'undelarna': [('undel', False)],
          'undelarnas': [('undel', False)],
          'under': [('under', False)],
          'underbyxorna': [('underbyxa', True)],
          'underbyxornas': [('underbyxa', True)],
          'underkurs': [('underkur', True), ('underkurs', True)],
          'underkurs-': [('underkurs', True), ('underkur', True)],
          'underna': [('under', False)],
          'undernas': [('und', False)],
          'unders': [('under', True)],
          'undets': [('und', False)],
          'undin': [('undin', True)],
          'undiver': [('undivum', False)],
          'undiverna': [('undivum', False)],
          'undraden': [('undrade', False)],
          'undradens': [('undrade', False)],
          'undrads': [('undrade', False)],
          'undrads-': [('undrade', False)],
          'undran': [('undran', True)],
          'undrans': [('undran', True)],
          'undrar': [('undrare', False)],
          'undrarna': [('undrare', False)],
          'undras': [('undras', False)],
          'undringar': [('undran', True), ('undring', True)],
          'undringarna': [('undran', True), ('undring', True)],
          'undringarnas': [('undran', True), ('undring', True)],
          'undringars': [('undran', True), ('undring', True)],
          'undstons': [('undston', False)],
          'undstons-': [('undston', False)],
          'une': [('una', False)],
          'une-': [('una', False)],
          'unen': [('un', False)],
          'unens': [('un', False)],
          'uner': [('un', False)],
          'unerna': [('un', False)],
          'unernas': [('un', False)],
          'uners': [('un', False)],
          'unet': [('un', False)],
          'ung': [('unge', True)],
          'ung-': [('unge', True)],
          'unga': [('unga', False)],
          'unga-': [('unga', False)],
          'ungan': [('unga', False)],
          'ungans': [('unga', False)],
          'ungar': [('unge', False)],
          'ungarna': [('unge', False)],
          'ungarnas': [('unge', False)],
          'ungars': [('unge', False)],
          'ungas': [('unga', False)],
          'ungdomar': [('ungdom', False)],
          'ungdomarna': [('ungdom', False)],
          'ungdomarnas': [('ungdom', False)],
          'unge': [('unge', False)],
          'unge-': [('unge', False)],
          'ungen': [('unge', False)],
          'ungens': [('unge', False)],
          'unger': [('unger', False)],
          'ungerna': [('unge', False)],
          'ungernas': [('unge', False)],
          'ungers': [('unger', False)],
          'unges': [('unge', False)],
          'unges-': [('unge', False)],
          'ungets': [('ung', False)],
          'unglott-': [('unglotta', True)],
          'unglotts': [('unglotta', True)],
          'unglotts-': [('unglotta', True)],
          'ungmoder-': [('ungmor', True)],
          'ungmodern': [('ungmor', True)],
          'ungmoderns': [('ungmor', True)],
          'ungmoders': [('ungmor', True)],
          'ungmoders-': [('ungmor', True)],
          'ungmödrar': [('ungmor', True)],
          'ungmödrarnas': [('ungmor', True)],
          'ungmödrars': [('ungmor', True)],
          'ungo': [('unga', False)],
          'ungo-': [('unga', False)],
          'ungon': [('ungo', False)],
          'ungons': [('ungo', False)],
          'ungor': [('ungo', False)],
          'ungorna': [('ungo', False)],
          'ungornas': [('unga', False)],
          'ungors': [('unga', False)],
          'ungos': [('ungo', False)],
          'ungos-': [('ungo', False)],
          'ungrar': [('ungrare', True)],
          'ungrarna': [('ungrare', True)],
          'ungs': [('unge', True)],
          'ungs-': [('unge', True)],
          'ungsfiskarnas': [('ungsfiskare', False)],
          'ungside': [('ungsida', False)],
          'ungside-': [('ungsida', False)],
          'ungsides': [('ungsida', False)],
          'ungslandet': [('ungsland', False)],
          'ungstanken': [('ungstanke', False)],
          'ungsten': [('ungsten', False)],
          'uni': [('unia', False)],
          'uni-': [('unia', False)],
          'unie': [('unia', False)],
          'uniet': [('unium', False)],
          'unik': [('unika', True)],
          'unik-': [('unika', True)],
          'unika': [('unika', True), ('unikum', True)],
          'unikas': [('unikum', True), ('unika', True)],
          'uniker': [('unik', False)],
          'unikerna': [('unik', False)],
          'unikernas': [('unik', False)],
          'unikers': [('unik', False)],
          'uniks': [('unika', True)],
          'unior': [('unior', False)],
          'uniors': [('unior', False)],
          'unis': [('unia', False)],
          'unist': [('unist', False)],
          'unit': [('unit', False)],
          'unitens': [('unit', False)],
          'unitet': [('unitet', False)],
          'unitets': [('unitet', False)],
          'universitetet': [('universitet', True)],
          'unj': [('unja', False)],
          'unj-': [('unja', False)],
          'unjors': [('unja', False)],
          'unjs': [('unja', False)],
          'unjs-': [('unja', False)],
          'unk': [('unke', False)],
          'unk-': [('unke', False)],
          'unkar': [('unk', False)],
          'unkarna': [('unk', False)],
          'unkarnas': [('unkare', False)],
          'unkars': [('unke', False)],
          'unke': [('unke', False)],
          'unke-': [('unke', False)],
          'unken': [('unke', False)],
          'unkens': [('unke', False)],
          'unker': [('unker', False)],
          'unkers': [('unker', False)],
          'unkes': [('unke', False)],
          'unkes-': [('unke', False)],
          'unkets': [('unk', False)],
          'unkler': [('unkel', False)],
          'unklerna': [('unkel', False)],
          'unklers': [('unkel', False)],
          'unks-': [('unke', False)],
          'unkter': [('unkt', False)],
          'unkterna': [('unkt', False)],
          'unkternas': [('unkt', False)],
          'unkters': [('unkt', False)],
          'unkull': [('unkulla', False)],
          'unkull-': [('unkulla', False)],
          'unkulle': [('unkulla', False)],
          'unkulle-': [('unkulla', False)],
          'unn': [('unn', False)],
          'unn-': [('unn', False)],
          'unnan': [('unna', False)],
          'unnans': [('unna', False)],
          'unnans-': [('unnan', False)],
          'unnar': [('un', False)],
          'unnarna': [('unnare', False)],
          'unnars': [('unn', False)],
          'unne': [('unne', False)],
          'unnen': [('un', False)],
          'unnens': [('un', False)],
          'unnes': [('unne', False)],
          'unnes-': [('unne', False)],
          'unning': [('unning', False)],
          'unningar': [('unning', False)],
          'unningarna': [('unning', False)],
          'unningarnas': [('unning', False)],
          'unningars': [('unning', False)],
          'unnings': [('unning', False)],
          'unnings-': [('unning', False)],
          'unnis': [('unni', False)],
          'unnit': [('unnit', False)],
          'unnits': [('unnit', False)],
          'unns': [('unna', False)],
          'unns-': [('unna', False)],
          'uno': [('uno', True)],
          'uno-': [('uno', True)],
          'unor': [('una', False)],
          'unorna': [('una', False)],
          'unornas': [('una', False)],
          'unors': [('una', False)],
          'unos': [('uno', True)],
          'uns': [('uns', True)],
          'uns-': [('uns', True)],
          'unsa': [('unsa', False)],
          'unsarnas': [('uns', False)],
          'unsas': [('unsa', False)],
          'unsets': [('uns', True)],
          'unskans': [('unska', False)],
          'unskor': [('unska', False)],
          'unskorna': [('unska', False)],
          'unskornas': [('unska', False)],
          'unskors': [('unska', False)],
          'unst-': [('unst', False)],
          'unsten': [('unst', False)],
          'unstens': [('unst', False)],
          'unster': [('unst', False)],
          'unsterna': [('unst', False)],
          'unsternas': [('unst', False)],
          'unsters': [('unst', False)],
          'unt': [('unta', False)],
          'unt-': [('unt', False)],
          'unta': [('unta', False)],
          'untan': [('unta', False)],
          'untar': [('unt', False)],
          'untarna': [('unte', False)],
          'untarnas': [('unt', False)],
          'untars': [('unte', False)],
          'untas': [('unta', False)],
          'unte': [('unte', False)],
          'unte-': [('unte', False)],
          'untes': [('unte', False)],
          'untes-': [('unte', False)],
          'untets': [('unt', False)],
          'untie': [('untie', False)],
          'untie-': [('untie', False)],
          'untier': [('untie', False)],
          'untiernas': [('untie', False)],
          'untiers': [('untie', False)],
          'untran': [('untran', False)],
          'unts': [('unt', False)],
          'unts-': [('unta', False)],
          'unuck': [('unuck', False)],
          'unuck-': [('unuck', False)],
          'unucks': [('unuck', False)],
          'unucks-': [('unuck', False)],
          'unungar': [('ununge', False)],
          'unungarna': [('ununge', False)],
          'unungarnas': [('ununge', False)],
          'unungars': [('ununge', False)],
          'unungen': [('ununge', False)],
          'unungens': [('ununge', False)],
          'unötter': [('unöt', False)],
          'unötterna': [('unöt', False)],
          'uodes': [('uodes', False)],
          'uon': [('uo', False)],
          'uons': [('uo', False)],
          'uord': [('uord', False)],
          'uord-': [('uord', False)],
          'uorden': [('uord', False)],
          'uordens': [('uord', False)],
          'uords': [('uord', False)],
          'uos': [('uo', False)],
          'uos-': [('uo', False)],
          'uosa': [('uosa', False)],
          'uosan': [('uosa', False)],
          'uosans': [('uosa', False)],
          'uosas': [('uosa', False)],
          'uosen': [('uo', False)],
          'uosens': [('uo', False)],
          'up': [('up', False)],
          'up-': [('up', False)],
          'upande': [('upande', False)],
          'upande-': [('upande', False)],
          'upanter': [('upant', False)],
          'upanters': [('upant', False)],
          'upar': [('up', False)],
          'upar-': [('upare', False)],
          'uparen': [('upare', False)],
          'uparens': [('upare', False)],
          'upares': [('upare', False)],
          'uparna': [('up', False)],
          'upars': [('up', False)],
          'upation': [('upation', False)],
          'upations': [('upation', False)],
          'upe': [('upa', False)],
          'upe-': [('upa', False)],
          'upen': [('up', False)],
          'upens': [('up', False)],
          'uper': [('up', False)],
          'uperiets': [('uperi', False)],
          'uperits': [('uperi', False)],
          'uperna': [('up', False)],
          'upernas': [('up', False)],
          'upers': [('up', False)],
          'upet': [('up', False)],
          'upets': [('up', False)],
          'uphets': [('uphet', False)],
          'upie': [('upie', False)],
          'upie-': [('upie', False)],
          'upien': [('upie', False)],
          'upiens': [('upie', False)],
          'upier': [('upie', False)],
          'upierna': [('upie', False)],
          'upiernas': [('upie', False)],
          'upiers': [('upier', False)],
          'upies': [('upie', False)],
          'upiller': [('upill', False)],
          'upillerna': [('upill', False)],
          'upillernas': [('upill', False)],
          'upillers': [('upill', False)],
          'upin': [('upin', False)],
          'upin-': [('upin', False)],
          'upiner': [('upin', False)],
          'upinerna': [('upin', False)],
          'upinernas': [('upin', False)],
          'upiners': [('upin', False)],
          'upins': [('upin', False)],
          'uplanet': [('uplan', False)],
          'uplanets': [('uplan', False)],
          'upmask-': [('upmask', False)],
          'upol': [('upol', False)],
          'upolen': [('upol', False)],
          'upor': [('upa', False)],
          'uporna': [('upa', False)],
          'upornas': [('upa', False)],
          'upors': [('upa', False)],
          'upp': [('uppa', False)],
          'upp-': [('uppa', False)],
          'uppar': [('uppare', False)],
          'uppar-': [('uppare', False)],
          'upparna': [('uppare', False)],
          'upparnas': [('upp', False)],
          'uppbackar': [('uppbackare', True)],
          'uppbackarna': [('uppbackare', True)],
          'uppbackarnas': [('uppbackare', True)],
          'upper': [('upp', False)],
          'uppets': [('upp', False)],
          'uppies': [('uppy', False)],
          'upplandets': [('uppland', True)],
          'uppmuntringar': [('uppmuntran', True), ('uppmuntring', True)],
          'uppmuntringarna': [('uppmuntring', True), ('uppmuntran', True)],
          'uppmuntringarnas': [('uppmuntring', True), ('uppmuntran', True)],
          'uppmuntringars': [('uppmuntran', True), ('uppmuntring', True)],
          'upporter': [('upporter', False)],
          'uppror': [('uppror', False)],
          'upprors': [('uppror', False)],
          'upps': [('uppa', False)],
          'upps-': [('uppa', False)],
          'uppslagsände': [('uppslagsända', True), ('uppslagsände', True)],
          'uppslagsände-': [('uppslagsände', True), ('uppslagsända', True)],
          'uprogrammet': [('uprogram', False)],
          'ups': [('up', False)],
          'ups-': [('up', False)],
          'upsarna': [('up', False)],
          'upsen': [('up', False)],
          'uput': [('uput', False)],
          'uput-': [('uput', False)],
          'uputs': [('uput', False)],
          'uputs-': [('uput', False)],
          'ur': [('ur', False)],
          'ur-': [('ur', False)],
          'urage': [('urage', False)],
          'urage-': [('urage', False)],
          'uragets': [('urage', False)],
          'uraj': [('uraj', False)],
          'uraj-': [('uraj', False)],
          'urajs': [('uraj', False)],
          'urajs-': [('uraj', False)],
          'uralie': [('uralier', False)],
          'uralie-': [('uralier', False)],
          'uralier': [('uralier', False)],
          'uraliernas': [('uralier', False)],
          'uraliers': [('uralier', False)],
          'uramins': [('urami', False)],
          'uran': [('uran', False)],
          'uran-': [('uran', False)],
          'urande': [('urande', False)],
          'urande-': [('urande', False)],
          'uranden': [('urande', False)],
          'urandens': [('urande', False)],
          'urandet': [('urande', False)],
          'uranger': [('urang', False)],
          'urangers': [('urang', False)],
          'urankarnas': [('urankare', False)],
          'uranmälningar': [('uranmälan', False)],
          'uranmälningarna': [('uranmälan', False)],
          'uranmälningarnas': [('uranmälan', False)],
          'uranmälningars': [('uranmälan', False)],
          'urans': [('uran', False)],
          'urar': [('ur', False)],
          'urarie': [('uraria', False)],
          'urarie-': [('uraria', False)],
          'urarna': [('ur', False)],
          'urarnas': [('ur', False)],
          'urars': [('ur', False)],
          'uras': [('ura', False)],
          'urasier': [('urasier', False)],
          'urasierna': [('urasier', False)],
          'urat': [('urat', False)],
          'uraten': [('urat', False)],
          'uratens': [('urat', False)],
          'urater': [('urat', False)],
          'uraterna': [('urat', False)],
          'uraternas': [('urat', False)],
          'uraters': [('urat', False)],
          'urats': [('urat', False)],
          'urbens': [('urben', False)],
          'urbits': [('urbits', False)],
          'urbits-': [('urbits', False)],
          'urbäcken': [('urbäcken', False)],
          'urcentret': [('urcentrum', False)],
          'urcentrets': [('urcentrum', False)],
          'urdelar': [('urdel', False)],
          'urdelarna': [('urdel', False)],
          'urdelarnas': [('urdel', False)],
          'ure': [('ura', False)],
          'ure-': [('ura', False)],
          'ureas': [('urea', True), ('ureas', True)],
          'uremis': [('uremi', True)],
          'uren': [('ur', False)],
          'urens': [('ur', False)],
          'urer': [('ur', False)],
          'urerna': [('ur', False)],
          'urernas': [('ur', False)],
          'urers': [('ur', False)],
          'urese': [('uresa', False)],
          'urese-': [('uresa', False)],
          'uret': [('ur', False)],
          'uretan': [('uretan', False)],
          'uretans': [('uretan', True)],
          'urets': [('ur', False)],
          'urets-': [('uret', False)],
          'urfader': [('urfader', True)],
          'urfaders-': [('urfader', True)],
          'urfar': [('urf', False)],
          'urfare': [('urfare', False)],
          'urfarna': [('urfare', False)],
          'urfarnas': [('urf', False)],
          'urfars': [('urf', False)],
          'urfäderna': [('urfader', True)],
          'urfädernas': [('urfader', True)],
          'urfötter': [('urfot', False)],
          'urfötterna': [('urfot', False)],
          'urfötternas': [('urfot', False)],
          'urfötters': [('urfot', False)],
          'urgar': [('urgare', False)],
          'urgarna': [('urgare', False)],
          'urgarnas': [('urgare', False)],
          'urgien': [('urgi', False)],
          'urgiens': [('urgi', False)],
          'urgier': [('urgi', False)],
          'urgierna': [('urgi', False)],
          'urgiers': [('urgi', False)],
          'urgis': [('urgi', False)],
          'urglandet': [('urglande', False)],
          'urglandets': [('urglande', False)],
          'uri': [('uria', False)],
          'uri-': [('uria', False)],
          'urian': [('uria', False)],
          'urias': [('uria', False)],
          'urie': [('urie', False)],
          'urie-': [('uria', False)],
          'urien': [('uri', False)],
          'uriens': [('urie', False)],
          'urier': [('urie', False)],
          'urierna': [('urie', False)],
          'uriernas': [('uri', False)],
          'uriers': [('urium', False)],
          'uries': [('urie', False)],
          'uries-': [('urie', False)],
          'uriet': [('urium', False)],
          'uriets': [('urium', False)],
          'urighets': [('urighet', False)],
          'urin': [('urin', True)],
          'urin-': [('urin', False)],
          'uriner': [('urin', False)],
          'urinerna': [('urin', False)],
          'urinernas': [('urin', False)],
          'uriners': [('urin', False)],
          'uringar': [('uring', False)],
          'uringarna': [('uring', False)],
          'uringarnas': [('uring', False)],
          'urins': [('urin', True)],
          'urins-': [('urin', False)],
          'urinvägar': [('urinvägar', True), ('urinväg', True)],
          'urinvägarna': [('urinvägar', True), ('urinväg', True)],
          'urinvägarnas': [('urinvägar', True), ('urinväg', True)],
          'urinvägars': [('urinvägar', True), ('urinväg', True)],
          'urinvägs': [('urinvägar', True), ('urinväg', True)],
          'urinvägs-': [('urinvägar', True), ('urinväg', True)],
          'urions': [('urion', False)],
          'uris-': [('uria', False)],
          'urisens': [('uris', False)],
          'urit-': [('urit', False)],
          'uritan': [('uritan', False)],
          'uriter': [('urit', False)],
          'uriterna': [('urit', False)],
          'uriters': [('urit', False)],
          'urits': [('urit', False)],
          'urk': [('urka', False)],
          'urk-': [('urka', False)],
          'urkan': [('urka', False)],
          'urkans': [('urka', False)],
          'urkarnas': [('urk', False)],
          'urkart': [('urkart', False)],
          'urkart-': [('urkart', False)],
          'urkarts': [('urkart', False)],
          'urkarts-': [('urkart', False)],
          'urkas': [('urka', False)],
          'urkel': [('urkla', False)],
          'urkel-': [('urkla', False)],
          'urklan': [('urkla', False)],
          'urklans': [('urkla', False)],
          'urknät': [('urknä', False)],
          'urkrets': [('urkrets', False)],
          'urks': [('urka', False)],
          'urks-': [('urka', False)],
          'urkunskaps-': [('urkunskap', False)],
          'urlandet': [('urland', False)],
          'urlandets': [('urlande', False)],
          'urmanden': [('urmand', False)],
          'urmandens': [('urmande', False)],
          'urmanens': [('urman', False)],
          'urmen': [('urm', False)],
          'urmes': [('urmes', False)],
          'urmet': [('urmet', False)],
          'urmets': [('urmet', False)],
          'urmoder-': [('urmoder', True)],
          'urmodern': [('urmoder', True)],
          'urmoderns': [('urmoder', True)],
          'urmoders': [('urmoder', True)],
          'urmoders-': [('urmoder', True)],
          'urmödrar': [('urmoder', True)],
          'urn': [('urna', False)],
          'urn-': [('urna', False)],
          'urna': [('urna', True)],
          'urnack': [('urnacke', False)],
          'urnacks': [('urnacke', False)],
          'urnacks-': [('urnacke', False)],
          'urnas': [('urna', True)],
          'urne': [('urna', True)],
          'urne-': [('urna', False)],
          'urnes': [('urne', False)],
          'urnes-': [('urne', False)],
          'urns': [('urna', True)],
          'urns-': [('urna', False)],
          'urområdet': [('urområde', False)],
          'uroms': [('urom', False)],
          'uroms-': [('urom', False)],
          'urona': [('uro', False)],
          'uronen': [('uron', False)],
          'uronens': [('uron', False)],
          'uroner': [('uron', False)],
          'uronerna': [('uron', False)],
          'uronernas': [('uron', False)],
          'uroners': [('uron', False)],
          'urons-': [('uron', False)],
          'uror': [('ura', False)],
          'urorna': [('ura', False)],
          'urornas': [('ura', False)],
          'urors': [('ura', False)],
          'urp': [('urpa', False)],
          'urp-': [('urpa', False)],
          'urps': [('urpa', False)],
          'urran': [('urra', False)],
          'urrar': [('urre', False)],
          'urrarna': [('urre', False)],
          'urrarnas': [('urre', False)],
          'urrars': [('urre', False)],
          'urras-': [('urra', False)],
          'urre': [('urre', False)],
          'urren': [('urre', False)],
          'urrier': [('urri', False)],
          'urrierna': [('urri', False)],
          'urriernas': [('urri', False)],
          'urriers': [('urri', False)],
          'urris': [('urri', False)],
          'urris-': [('urri', False)],
          'urrit': [('urri', False)],
          'urrits': [('urri', False)],
          'urs': [('ur', False)],
          'urs-': [('ur', False)],
          'ursar': [('ursare', False)],
          'ursar-': [('ursare', False)],
          'ursarens': [('ursare', False)],
          'ursarna': [('urs', False)],
          'ursarnas': [('urs', False)],
          'ursen': [('urs', False)],
          'urser': [('urser', False)],
          'ursers': [('urser', False)],
          'urskallens': [('urskalle', False)],
          'urskiften': [('urskift', False)],
          'urskiftets': [('urskift', False)],
          'urskris': [('urskri', True)],
          'ursor': [('ursor', False)],
          'ursors': [('ursor', False)],
          'urst-': [('urst', False)],
          'urstar': [('urst', False)],
          'urstarna': [('urst', False)],
          'urstarnas': [('urst', False)],
          'urstars': [('urst', False)],
          'ursten': [('urst', False)],
          'urstens': [('urste', False)],
          'urstudie-': [('urstudie', False)],
          'urstudiers': [('urstudie', False)],
          'urtagen': [('urtag', True)],
          'urtagens': [('urtag', True)],
          'urtaget': [('urtag', True)],
          'urtagets': [('urtag', True)],
          'urtan': [('urta', False)],
          'urtets': [('urt', False)],
          'urtis': [('urtis', False)],
          'urtsarna': [('urts', False)],
          'urtsarnas': [('urts', False)],
          'urtsen': [('urts', False)],
          'urtsens': [('urts', False)],
          'uru-': [('uru', False)],
          'uruer': [('uruer', False)],
          'uruerna': [('uruer', False)],
          'uruernas': [('uru', False)],
          'uruers': [('uruer', False)],
          'urum': [('urum', False)],
          'urum-': [('urum', False)],
          'urun': [('uru', False)],
          'uruns': [('uru', False)],
          'urus': [('urus', False)],
          'urus-': [('urus', False)],
          'urusar': [('urus', False)],
          'urusarna': [('urus', False)],
          'urusarnas': [('uru', False)],
          'urut': [('uru', False)],
          'uruts': [('uru', False)],
          'urvals': [('urval', False)],
          'urvas': [('urva', False)],
          'ury': [('ury', False)],
          'ury-': [('ury', False)],
          'uryggar': [('urygg', False)],
          'urys': [('ury', False)],
          'urämne': [('urämne', True)],
          'urättens': [('urätt', False)],
          'uråkar': [('uråkare', False)],
          'uråkarna': [('uråkare', False)],
          'uråkarnas': [('uråkare', False)],
          'us': [('us', False)],
          'us-': [('us', False)],
          'usage': [('usaga', False)],
          'usage-': [('usaga', False)],
          'usago': [('usaga', False)],
          'usago-': [('usaga', False)],
          'usalv': [('usalv', False)],
          'usalvs': [('usalv', False)],
          'usalvs-': [('usalv', False)],
          'usan': [('usan', False)],
          'usanden': [('usande', False)],
          'usandens': [('usande', False)],
          'usans': [('usans', True)],
          'usans-': [('usans', True)],
          'usar': [('us', False)],
          'usar-': [('usar', False)],
          'usaren': [('usare', False)],
          'usarens': [('usar', False)],
          'usarna': [('us', False)],
          'usars': [('us', False)],
          'usars-': [('usar', False)],
          'usch': [('usch', False)],
          'usch-': [('usch', False)],
          'uschen': [('usch', False)],
          'uschens': [('usch', False)],
          'uscher': [('usch', False)],
          'uschers': [('usch', False)],
          'use': [('usa', False)],
          'use-': [('usa', False)],
          'useer': [('useum', False)],
          'useerna': [('useum', False)],
          'useernas': [('useum', False)],
          'useffekt': [('useffekt', False)],
          'useffekt-': [('useffekt', False)],
          'useffekter': [('useffekt', False)],
          'useffekternas': [('useffekt', False)],
          'useffekters': [('useffekt', False)],
          'useffekts': [('useffekt', False)],
          'useffekts-': [('useffekt', False)],
          'usen': [('us', False)],
          'usendet': [('usende', False)],
          'usens': [('us', False)],
          'user': [('us', False)],
          'user-': [('user', False)],
          'usern': [('user', False)],
          'userna': [('us', False)],
          'usernas': [('us', False)],
          'userns': [('user', False)],
          'users': [('us', False)],
          'users-': [('user', False)],
          'uset': [('us', False)],
          'usets': [('us', False)],
          'usfadern': [('usfar', False)],
          'usfaders': [('usfar', False)],
          'usfars': [('usfar', False)],
          'usfars-': [('usfar', False)],
          'usfasoner': [('usfason', False)],
          'usfäder': [('usfar', False)],
          'usfäderna': [('usfar', False)],
          'usfäders': [('usfar', False)],
          'ushan': [('ushane', False)],
          'ushet': [('ushet', False)],
          'usierna': [('usi', False)],
          'usiers': [('usi', False)],
          'usik': [('usik', False)],
          'usik-': [('usik', False)],
          'usiken': [('usik', False)],
          'usiks': [('usik', False)],
          'usilen': [('usil', False)],
          'usilens': [('usil', False)],
          'usin': [('usi', False)],
          'usin-': [('usin', False)],
          'usinen': [('usin', False)],
          'usinens': [('usin', False)],
          'usins': [('usin', False)],
          'usis': [('usi', False)],
          'usis-': [('usi', False)],
          'usiter': [('usit', False)],
          'usiterna': [('usit', False)],
          'usiters': [('usit', False)],
          'usits': [('usit', False)],
          'usk': [('uske', False)],
          'usk-': [('uske', False)],
          'uskan': [('uska', False)],
          'uskans': [('uska', False)],
          'uskar': [('usker', False)],
          'uskar-': [('uskare', False)],
          'uskare': [('uskare', False)],
          'uskarens': [('uskare', False)],
          'uskarna': [('uske', False)],
          'uskarnas': [('uske', False)],
          'uskars': [('uske', False)],
          'uskat': [('uskat', False)],
          'uskat-': [('uskat', False)],
          'uskaten': [('uskat', False)],
          'uskatens': [('uskat', False)],
          'uskats': [('uskat', False)],
          'uskatts-': [('uskatt', False)],
          'uske': [('uske', False)],
          'uske-': [('uske', False)],
          'uskelsen': [('uskelsena', False)],
          'uskelsens': [('uskelsena', False)],
          'usken': [('uske', False)],
          'uskens': [('uske', False)],
          'usker': [('usker', False)],
          'uskers': [('usker', False)],
          'uskes': [('uske', False)],
          'uskes-': [('uske', False)],
          'uskets': [('usk', False)],
          'uskons': [('usko', False)],
          'uskor': [('usko', False)],
          'uskorna': [('usko', False)],
          'uskornas': [('usko', False)],
          'uskors': [('usko', False)],
          'uskungar': [('uskung', False)],
          'uskungarna': [('uskung', False)],
          'uskungarnas': [('uskung', False)],
          'uskungars': [('uskung', False)],
          'uskungen': [('uskung', False)],
          'uskungens': [('uskung', False)],
          'uskäll': [('uskälla', False)],
          'uskäll-': [('uskälla', False)],
          'uskälls': [('uskälla', False)],
          'uskälls-': [('uskälla', False)],
          'uskök': [('uskök', False)],
          'uskök-': [('uskök', False)],
          'usköks': [('uskök', False)],
          'usköks-': [('uskök', False)],
          'usköt-': [('usköt', False)],
          'usköten': [('usköt', False)],
          'uskötens': [('usköt', False)],
          'usköts': [('usköt', False)],
          'usköts-': [('usköt', False)],
          'usling': [('usling', True)],
          'usling-': [('usling', True)],
          'uslings': [('usling', True)],
          'uslings-': [('usling', True)],
          'usläng': [('uslänga', False)],
          'usläng-': [('uslänga', False)],
          'uslängs': [('uslänga', False)],
          'uslängs-': [('uslänga', False)],
          'uslån': [('uslån', False)],
          'uslåns': [('uslån', False)],
          'usmoder': [('usmor', False)],
          'usmoder-': [('usmor', False)],
          'usmor': [('usmor', False)],
          'usmors': [('usmor', False)],
          'usmuts': [('usmuts', False)],
          'usmödrar': [('usmor', False)],
          'usmödrarna': [('usmor', False)],
          'usmödrarnas': [('usmor', False)],
          'usmödrars': [('usmor', False)],
          'usnyckel': [('usnyckel', False)],
          'usnyckel-': [('usnyckel', False)],
          'usnyckels': [('usnyckel', False)],
          'usnyckels-': [('usnyckel', False)],
          'usnycklar': [('usnyckel', False)],
          'usnycklarna': [('usnyckel', False)],
          'usnycklarnas': [('usnyckel', False)],
          'usnycklars': [('usnyckel', False)],
          'usnåret': [('usnåret', False)],
          'usnårets': [('usnåret', False)],
          'usområdet': [('usområde', False)],
          'usor': [('usa', False)],
          'usorna': [('usa', False)],
          'usornas': [('usa', False)],
          'usors': [('usa', False)],
          'usovar': [('usovare', False)],
          'usovaren': [('usovare', False)],
          'uspol': [('uspol', False)],
          'uspol-': [('uspol', False)],
          'uspolen': [('uspol', False)],
          'uspolens': [('uspol', False)],
          'uspols': [('uspol', False)],
          'uspols-': [('uspol', False)],
          'usringar': [('usring', False)],
          'usringarna': [('usringare', False)],
          'usringarnas': [('usringare', False)],
          'uss': [('usse', False)],
          'uss-': [('uss', False)],
          'ussar': [('ussare', False)],
          'ussar-': [('ussare', False)],
          'ussarens': [('ussare', False)],
          'ussarna': [('uss', False)],
          'ussarnas': [('uss', False)],
          'ussars': [('usse', False)],
          'usse': [('usse', False)],
          'usse-': [('usse', False)],
          'ussen': [('usse', False)],
          'ussens': [('usse', False)],
          'usser': [('usse', False)],
          'usserna': [('usse', False)],
          'ussernas': [('usse', False)],
          'ussers': [('usse', False)],
          'ussets': [('uss', False)],
          'ussin': [('ussin', False)],
          'ussins': [('ussi', False)],
          'ussis-': [('ussi', False)],
          'usskalas': [('usskala', False)],
          'ussken': [('ussken', False)],
          'usskens': [('ussken', False)],
          'usskens-': [('ussken', False)],
          'usskurs': [('usskur', False)],
          'usskurs-': [('usskur', False)],
          'usslanden': [('usslande', False)],
          'usslandens': [('usslande', False)],
          'usslandet': [('usslande', False)],
          'ussle': [('ussla', False)],
          'ussle-': [('ussla', False)],
          'usslor': [('ussla', False)],
          'usslorna': [('ussla', False)],
          'usslornas': [('ussla', False)],
          'usslors': [('ussla', False)],
          'ust': [('ust', False)],
          'usta': [('usta', False)],
          'usta-': [('usta', False)],
          'ustak': [('ustak', False)],
          'ustaken': [('ustak', False)],
          'ustakens': [('ustak', False)],
          'ustaket': [('ustak', False)],
          'ustakets': [('ustak', False)],
          'ustaks': [('ustak', False)],
          'ustaks-': [('ustak', False)],
          'ustan': [('usta', False)],
          'ustans': [('usta', False)],
          'ustar': [('ust', False)],
          'ustar-': [('ustare', False)],
          'ustarna': [('ustare', False)],
          'ustarnas': [('ust', False)],
          'ustars': [('ust', False)],
          'ustas': [('usta', False)],
          'ustel': [('ustel', False)],
          'ustel-': [('ustel', False)],
          'ustels': [('ustel', False)],
          'ustels-': [('ustel', False)],
          'usten': [('ust', False)],
          'ustens': [('ust', False)],
          'uster': [('uster', False)],
          'usteri': [('usteri', False)],
          'usteri-': [('usteri', False)],
          'usterier': [('usteri', False)],
          'usterierna': [('usteri', False)],
          'usteriers': [('usteri', False)],
          'usteriet': [('usteri', False)],
          'usteris': [('usteri', False)],
          'usteris-': [('usteri', False)],
          'usterna': [('uster', False)],
          'usternas': [('uster', False)],
          'usters': [('uster', False)],
          'ustfiskar': [('ustfisk', False)],
          'ustfiskarnas': [('ustfisk', False)],
          'usti': [('usti', False)],
          'usti-': [('usti', False)],
          'ustika': [('ustika', False)],
          'ustikas': [('ustika', False)],
          'ustiker': [('ustiker', False)],
          'ustikerna': [('ustiker', False)],
          'ustikernas': [('ustiker', False)],
          'ustikers': [('ustiker', False)],
          'ustis': [('ustis', False)],
          'ustis-': [('ustis', False)],
          'uston': [('uston', False)],
          'ustons': [('uston', False)],
          'ustons-': [('uston', False)],
          'ustor': [('usta', False)],
          'ustors': [('usta', False)],
          'ustranden': [('ustrande', False)],
          'ustrandens': [('ustrande', False)],
          'ustrarnas': [('uster', False)],
          'ustrilandet': [('ustriland', False)],
          'ustrilandets': [('ustriland', False)],
          'ustringens': [('ustring', False)],
          'ustrun': [('ustru', False)],
          'ustruns': [('ustru', False)],
          'ustut': [('ustuta', False)],
          'ustut-': [('ustuta', False)],
          'ustuts': [('ustuta', False)],
          'ustuts-': [('ustuta', False)],
          'ustvinds': [('ustvind', False)],
          'ustvinds-': [('ustvind', False)],
          'ustårs': [('ustår', False)],
          'usul': [('usul', False)],
          'usul-': [('usul', False)],
          'usuls': [('usul', False)],
          'usuls-': [('usul', False)],
          'usvale': [('usvala', False)],
          'usvensk': [('usvenska', False)],
          'usvensk-': [('usvenska', False)],
          'usvägens': [('usväg', False)],
          'usvärdens': [('usvärd', False)],
          'usvärmar': [('usvärm', False)],
          'usvärmarna': [('usvärm', False)],
          'usvärmarnas': [('usvärm', False)],
          'usås': [('usås', False)],
          'usås-': [('usås', False)],
          'usögon': [('usöga', False)],
          'usören': [('usör', False)],
          'usörens': [('usör', False)],
          'ut': [('ut', False)],
          'ut-': [('ut', False)],
          'utagen': [('utagen', False)],
          'utagens': [('utagen', False)],
          'utalens': [('utal', False)],
          'utan': [('utan', False)],
          'utan-': [('utan', False)],
          'utanden': [('utande', False)],
          'utandens': [('utande', False)],
          'utangens': [('utang', False)],
          'utans': [('uta', False)],
          'utans-': [('utan', False)],
          'utants': [('utant', False)],
          'utar': [('ut', False)],
          'utaren': [('utare', False)],
          'utarna': [('ut', False)],
          'utarnas': [('ute', False)],
          'utars': [('ut', False)],
          'utasten': [('utasten', False)],
          'ute': [('uta', False)],
          'ute-': [('uta', False)],
          'uten': [('ut', False)],
          'utens': [('ut', False)],
          'uter': [('ut', False)],
          'uter-': [('uter', False)],
          'uteranden': [('uterande', False)],
          'uterandens': [('uterande', False)],
          'uteri': [('uterier', False)],
          'uteri-': [('uterier', False)],
          'uterier': [('uteri', False)],
          'uterierna': [('uteri', False)],
          'uteriernas': [('uteri', False)],
          'uteriers': [('uterier', False)],
          'uteriet': [('uterium', False)],
          'uteriets': [('uteri', False)],
          'uterits': [('uteri', False)],
          'utern': [('uter', False)],
          'uterna': [('ut', False)],
          'uternas': [('ut', False)],
          'uterns': [('uter', False)],
          'uters': [('ut', False)],
          'uters-': [('uter', False)],
          'utes': [('ute', False)],
          'utes-': [('ute', False)],
          'utet': [('ut', False)],
          'utfiskarna': [('utfisk', False)],
          'uthet': [('uthet', False)],
          'uthets': [('uthet', False)],
          'utiden': [('utid', False)],
          'utidens': [('utiden', False)],
          'utier': [('utier', False)],
          'utierna': [('utier', False)],
          'utiernas': [('utier', False)],
          'utiers': [('utier', False)],
          'utighets': [('utighet', False)],
          'utik': [('utik', False)],
          'utik-': [('utik', False)],
          'utiker': [('utik', False)],
          'utikerna': [('utik', False)],
          'utikernas': [('utik', False)],
          'utikers': [('utik', False)],
          'utiks': [('utik', False)],
          'utiks-': [('utik', False)],
          'utin': [('uti', False)],
          'utin-': [('utin', False)],
          'utinens': [('utin', False)],
          'utiner': [('utin', False)],
          'utinerna': [('utin', False)],
          'utinernas': [('utin', False)],
          'utiners': [('utin', False)],
          'utins': [('utin', False)],
          'utions-': [('ution', False)],
          'utis': [('uti', False)],
          'utiv': [('utiv', False)],
          'utiv-': [('utiv', False)],
          'utiven': [('utiv', False)],
          'utivens': [('utiv', False)],
          'utiver': [('utiv', False)],
          'utiverna': [('utiv', False)],
          'utivernas': [('utiv', False)],
          'utivers': [('utiv', False)],
          'utivet': [('utiv', False)],
          'utivs': [('utiv', False)],
          'utivs-': [('utiv', False)],
          'utjärns': [('utjärn', False)],
          'utjärns-': [('utjärn', False)],
          'utkikarnas': [('utkik', True)],
          'utlandet': [('utland', True)],
          'utler': [('utler', False)],
          'utlers': [('utler', False)],
          'utmåns': [('utmån', False)],
          'utmåns-': [('utmån', False)],
          'utoner': [('uton', False)],
          'utonerna': [('uton', False)],
          'utonernas': [('uton', False)],
          'utor': [('uta', False)],
          'utorer': [('utor', False)],
          'utorerna': [('utor', False)],
          'utorernas': [('utor', False)],
          'utorers': [('utor', False)],
          'utorn': [('utor', False)],
          'utorna': [('uta', False)],
          'utornas': [('uta', False)],
          'utorns': [('utor', False)],
          'utors': [('uta', False)],
          'utpengarnas': [('utpengar', False)],
          'utpressar': [('utpressare', True)],
          'utpressarna': [('utpressare', True)],
          'utrana': [('utrum', False)],
          'utranas': [('utrum', False)],
          'utranden': [('utrand', False)],
          'utrandens': [('utrand', False)],
          'utrapp': [('utrappa', False)],
          'utrapp-': [('utrappa', False)],
          'utrapps': [('utrappa', False)],
          'utrapps-': [('utrappa', False)],
          'utrar': [('ut', False)],
          'utrarna': [('uter', False)],
          'utrarnas': [('ut', False)],
          'utrars': [('ut', False)],
          'utras': [('utrum', False)],
          'utrers': [('utrum', False)],
          'utret': [('utrum', False)],
          'utrias': [('utria', False)],
          'utriner': [('utrino', False)],
          'utrinerna': [('utrino', False)],
          'utrinernas': [('utrino', False)],
          'utriners': [('utrino', False)],
          'utron': [('utron', False)],
          'utron-': [('utron', False)],
          'utrons': [('utron', False)],
          'utrum': [('utrum', True)],
          'utrum-': [('utrum', True)],
          'utrums': [('utrum', False)],
          'utrums-': [('utrum', False)],
          'uträt': [('uträ', False)],
          'uträts': [('uträ', False)],
          'uts': [('ut', False)],
          'uts-': [('ut', False)],
          'utsago': [('utsago', True), ('utsaga', True)],
          'utsago-': [('utsago', True), ('utsaga', True)],
          'utsar': [('utsare', False)],
          'utsar-': [('utsare', False)],
          'utsaren': [('utsare', False)],
          'utsarens': [('utsare', False)],
          'utsarna': [('utsare', False)],
          'utsarnas': [('uts', False)],
          'utsars': [('uts', False)],
          'utsen': [('ut', False)],
          'utsens': [('ut', False)],
          'utsiktens': [('utsikt', True)],
          'utskår-': [('utskåre', False)],
          'utsteg': [('utsteg', False)],
          'utsädes': [('utsäde', True)],
          'uttan': [('utta', False)],
          'uttarna': [('utt', False)],
          'uttarnas': [('utt', False)],
          'utte': [('utte', False)],
          'utte-': [('utta', False)],
          'uttens': [('utt', False)],
          'utter': [('utter', False)],
          'utters': [('utter', False)],
          'uttets': [('utt', False)],
          'utti': [('utti', False)],
          'uttidens': [('uttid', False)],
          'uttigheter': [('uttighet', False)],
          'uttigheterna': [('uttighet', False)],
          'uttigheternas': [('uttighet', False)],
          'uttigheters': [('uttighet', False)],
          'uttighets-': [('uttighet', False)],
          'uttina': [('utti', False)],
          'uttinas': [('utto', False)],
          'uttis': [('utti', False)],
          'uttit': [('utti', False)],
          'uttlanden': [('uttlande', False)],
          'uttlandens': [('uttlande', False)],
          'uttlandet': [('uttlande', False)],
          'utto': [('utto', False)],
          'uttrarnas': [('utter', False)],
          'utträden': [('utträde', True)],
          'utträdens': [('utträde', True)],
          'utträdet': [('utträde', True)],
          'utträdets': [('utträde', True)],
          'uttränas': [('utträd', False)],
          'utullar': [('utull', False)],
          'utum': [('utum', False)],
          'utum-': [('utum', False)],
          'utums': [('utum', False)],
          'uturer': [('uturum', False)],
          'uturerna': [('uturum', False)],
          'uturernas': [('uturum', False)],
          'uturers': [('utur', False)],
          'uturs': [('utur', False)],
          'utvägen': [('utväg', True)],
          'utvägens': [('utväg', True)],
          'utylen': [('utyl', False)],
          'utylens': [('utyl', False)],
          'uumsugarna': [('uumsug', False)],
          'uv': [('uv', False)],
          'uv-': [('uv', True)],
          'uvan': [('uva', False)],
          'uvans': [('uva', False)],
          'uvar': [('uv', False)],
          'uvar-': [('uvare', False)],
          'uvaren': [('uvare', False)],
          'uvarna': [('uv', False)],
          'uvarnas': [('uv', False)],
          'uvars': [('uv', False)],
          'uvas': [('uva', False)],
          'uvbitar': [('uvbit', False)],
          'uvbitarna': [('uvbit', False)],
          'uvbitarnas': [('uvbit', False)],
          'uve': [('uva', False)],
          'uve-': [('uva', False)],
          'uvel': [('uvel', False)],
          'uvel-': [('uvel', False)],
          'uvelen': [('uvel', False)],
          'uvelens': [('uvel', False)],
          'uvels': [('uvel', False)],
          'uvels-': [('uvel', False)],
          'uven': [('uv', False)],
          'uvens': [('uv', False)],
          'uverande': [('uverande', False)],
          'uverande-': [('uverande', False)],
          'uvern': [('uver', False)],
          'uverns': [('uver', False)],
          'uvers': [('uver', False)],
          'uvers-': [('uver', False)],
          'uvertets': [('uvert', False)],
          'uvets': [('uve', False)],
          'uvfiskarnas': [('uvfiskare', False)],
          'uvgas': [('uvgas', False)],
          'uvgas-': [('uvgas', False)],
          'uvier': [('uvium', False)],
          'uvierna': [('uvium', False)],
          'uviernas': [('uvium', False)],
          'uviers': [('uvium', False)],
          'uviet': [('uvium', False)],
          'uviets': [('uvium', False)],
          'uvis': [('uvis', False)],
          'uvis-': [('uvis', False)],
          'uvisen': [('uvis', False)],
          'uvisens': [('uvis', False)],
          'uvor': [('uva', False)],
          'uvorna': [('uva', False)],
          'uvornas': [('uva', False)],
          'uvors': [('uva', False)],
          'uvrar': [('uver', False)],
          'uvrarna': [('uver', False)],
          'uvret': [('uver', False)],
          'uvrets': [('uver', False)],
          'uvs': [('uv', False)],
          'uvs-': [('uv', False)],
          'uvsen': [('uvsena', False)],
          'uvungen': [('uvunge', False)],
          'uvungens': [('uvunge', False)],
          'uvärden': [('uvärde', False)],
          'uvärdens': [('uvärde', False)],
          'uvärdet': [('uvärde', False)],
          'uvös': [('uvös', False)],
          'ux': [('ux', False)],
          'ux-': [('ux', False)],
          'uxar': [('ux', False)],
          'uxarna': [('ux', False)],
          'uxarnas': [('ux', False)],
          'uxars': [('ux', False)],
          'uxen': [('ux', False)],
          'uxens': [('ux', False)],
          'uxer': [('ux', False)],
          'uxerna': [('ux', False)],
          'uxernas': [('ux', False)],
          'uxers': [('ux', False)],
          'uxet': [('ux', False)],
          'uxit': [('uxit', False)],
          'uxits': [('uxit', False)],
          'uzon': [('uzo', False)],
          'uzons': [('uzo', False)],
          'uzor': [('uza', False)],
          'uzorna': [('uza', False)],
          'uzornas': [('uza', False)],
          'uzors': [('uza', False)],
          'uzzis': [('uzzi', False)],
          'uéerna': [('ué', False)],
          'uéernas': [('ué', False)],
          'v': [('v', True)],
          'v-': [('v', True)],
          'va': [('va', False)],
          'va-': [('va', False)],
          'vaback': [('vaback', False)],
          'vaback-': [('vaback', False)],
          'vabacken': [('vaback', False)],
          'vabacks': [('vaback', False)],
          'vabb': [('vabb', True)],
          'vabb-': [('vabb', True)],
          'vabbar': [('vabbare', True), ('vabb', True)],
          'vabbarna': [('vabbare', True), ('vabb', True)],
          'vabbarnas': [('vabbare', True), ('vabb', True)],
          'vabbars': [('vabb', False)],
          'vabbens': [('vabb', False)],
          'vabbs': [('vabb', False)],
          'vabbs-': [('vabb', False)],
          'vabon': [('vabo', False)],
          'vabons': [('vabo', False)],
          'vabot': [('vabo', False)],
          'vack': [('vacka', False)],
          'vack-': [('vacka', False)],
          'vackarnas': [('vackare', False)],
          'vacke': [('vacka', False)],
          'vacke-': [('vacka', False)],
          'vacken': [('vack', False)],
          'vackens': [('vack', False)],
          'vacker': [('vack', False)],
          'vackers': [('vack', False)],
          'vacket': [('vack', False)],
          'vackets': [('vack', False)],
          'vacklan': [('vacklan', True)],
          'vacklandets': [('vacklande', True)],
          'vacklans': [('vacklan', True)],
          'vackor': [('vacka', False)],
          'vackorna': [('vacka', False)],
          'vackornas': [('vacka', False)],
          'vackors': [('vacka', False)],
          'vacks': [('vacka', False)],
          'vacks-': [('vack', False)],
          'vadar': [('vadare', True), ('vad', True)],
          'vadar-': [('vadare', True)],
          'vadarna': [('vadare', True), ('vad', True)],
          'vadarnas': [('vadare', True), ('vad', True)],
          'vadd': [('vadd', False)],
          'vaddar': [('vadd', True)],
          'vadds': [('vadd', True)],
          'vadds-': [('vadd', False)],
          'vader': [('vad', True)],
          'vader-': [('vader', False)],
          'vaders': [('vad', True)],
          'vadets': [('vad', True)],
          'vador': [('vad', True)],
          'vadorna': [('vad', True)],
          'vadornas': [('vad', True)],
          'vadors': [('vad', True)],
          'vados': [('vados', False)],
          'vadosens': [('vados', False)],
          'vafältet': [('vafält', False)],
          'vag': [('vaga', False)],
          'vag-': [('vaga', False)],
          'vagans': [('vagans', False)],
          'vagans-': [('vagans', False)],
          'vagg': [('vagga', True)],
          'vagg-': [('vagga', True)],
          'vagge': [('vagga', False)],
          'vagge-': [('vagga', True)],
          'vaggs': [('vagga', True)],
          'vaggs-': [('vagga', True)],
          'vagin': [('vagina', True)],
          'vagins': [('vagina', True)],
          'vagn': [('vagn', False)],
          'vagn-': [('vagn', False)],
          'vagnar': [('vagn', False)],
          'vagnarna': [('vagn', False)],
          'vagnarnas': [('vagn', False)],
          'vagnars': [('vagn', False)],
          'vagnen': [('vagn', False)],
          'vagnens': [('vagn', False)],
          'vagns': [('vagn', False)],
          'vagns-': [('vagn', False)],
          'vags': [('vaga', False)],
          'vags-': [('vaga', False)],
          'vaj': [('vaja', True), ('vaj', True)],
          'vaj-': [('vaja', True), ('vaj', True)],
          'vajans': [('vaja', True)],
          'vajas': [('vaja', True)],
          'vajer': [('vajer', True)],
          'vajers': [('vajer', True)],
          'vajor': [('vaja', True)],
          'vajrarnas': [('vajer', False)],
          'vajs': [('vaja', True), ('vaj', True)],
          'vajs-': [('vaja', True), ('vaj', True)],
          'vak': [('vak', True), ('vaka', True)],
          'vak-': [('vaka', True), ('vak', True)],
          'vaka': [('vaka', True)],
          'vakan': [('vaka', True)],
          'vakans': [('vaka', True), ('vakans', True)],
          'vakans-': [('vakans', True)],
          'vakar': [('vak', True), ('vakare', True)],
          'vakarna': [('vakare', True), ('vak', True)],
          'vakarnas': [('vakare', True), ('vak', True)],
          'vakas': [('vaka', False)],
          'vakets': [('vak', False)],
          'vakors': [('vaka', False)],
          'vaks': [('vaka', True), ('vak', True)],
          'vaks-': [('vak', True), ('vaka', True)],
          'vakter': [('vakt', False)],
          'vakters': [('vakt', False)],
          'val': [('val', True)],
          'val-': [('val', True)],
          'valan': [('vala', False)],
          'valandets': [('valande', False)],
          'valans': [('vala', False)],
          'valar': [('val', False)],
          'valar-': [('valare', False)],
          'valarens': [('valare', False)],
          'valarna': [('val', True)],
          'valarnas': [('val', True)],
          'valars': [('val', True)],
          'valas': [('vala', False)],
          'valater': [('valater', False)],
          'valaterna': [('valater', False)],
          'valaternas': [('valater', False)],
          'valaters': [('valater', False)],
          'valats-': [('valater', False)],
          'valdags': [('valdag', True)],
          'valdags-': [('valdag', True)],
          'vale-': [('vala', False)],
          'valen': [('val', True)],
          'valens': [('valens', True), ('val', True)],
          'vales': [('vale', False)],
          'vales-': [('vale', False)],
          'valet': [('val', False)],
          'valets': [('val', False)],
          'valgen': [('valg', False)],
          'valgs-': [('valg', False)],
          'valie-': [('valier', False)],
          'valierna': [('valier', False)],
          'valj': [('valj', False)],
          'valj-': [('valj', False)],
          'valjer': [('valjer', False)],
          'valjs': [('valj', False)],
          'valk': [('valk', True)],
          'valk-': [('valk', True)],
          'valkan': [('valka', False)],
          'valkans': [('valka', False)],
          'valkar': [('valk', True), ('valkare', True)],
          'valkarna': [('valkare', True), ('valk', True)],
          'valkarnas': [('valkare', True), ('valk', True)],
          'valks': [('valk', False)],
          'valks-': [('valk', False)],
          'vall': [('vall', False)],
          'vall-': [('vall', True)],
          'vallan': [('valla', False)],
          'vallanden': [('vallande', True)],
          'vallandens': [('vallande', False)],
          'vallandet': [('vallande', False)],
          'vallar': [('vallare', True), ('vall', True)],
          'vallarna': [('vallare', True), ('vall', True)],
          'vallarnas': [('vallare', True), ('vall', True)],
          'vallars': [('vall', False)],
          'vallen': [('vall', False)],
          'valler': [('vall', False)],
          'valler-': [('valler', False)],
          'vallerna': [('vall', False)],
          'vallernas': [('vall', False)],
          'vallers': [('vall', False)],
          'vallon': [('vallon', True)],
          'vallons': [('vallon', True)],
          'vallor': [('valla', True)],
          'vallorna': [('valla', True)],
          'valls': [('vall', False)],
          'valls-': [('vall', True)],
          'vallstaket': [('vallstaket', False)],
          'vallstakets': [('vallstaket', False)],
          'vallåt': [('vallåt', True)],
          'valmar': [('valmar', True)],
          'valmars': [('valmar', True)],
          'valmet': [('valm', False)],
          'valmets': [('valm', False)],
          'vals': [('vals', True), ('val', True)],
          'vals-': [('val', True), ('vals', True)],
          'valt': [('valta', False)],
          'valt-': [('valta', False)],
          'valtan': [('valta', False)],
          'valtans': [('valta', False)],
          'valtar': [('valtare', False)],
          'valtarna': [('valtare', False)],
          'valtarnas': [('valtare', False)],
          'valtor': [('valta', False)],
          'valtornas': [('valta', False)],
          'valtors': [('valta', False)],
          'valts': [('valta', False)],
          'valts-': [('valta', False)],
          'valv': [('valv', False)],
          'valv-': [('valv', False)],
          'valvs': [('valv', False)],
          'valvs-': [('valv', False)],
          'vam': [('vam', False)],
          'vam-': [('vam', False)],
          'vamen': [('vamen', False)],
          'vamens': [('vamen', False)],
          'vamers': [('vam', False)],
          'vamlandet': [('vamlande', False)],
          'vamp': [('vamp', False)],
          'vamp-': [('vamp', False)],
          'vampar': [('vamp', False)],
          'vamparna': [('vamp', False)],
          'vampen': [('vamp', False)],
          'vampens': [('vamp', False)],
          'vamps': [('vamp', False)],
          'vamps-': [('vamp', False)],
          'vams': [('vam', False)],
          'van': [('van', True)],
          'vana': [('vana', True)],
          'vanan': [('vana', False)],
          'vanans': [('vana', False)],
          'vanarna': [('van', False)],
          'vanarnas': [('van', False)],
          'vanas': [('vana', True)],
          'vanat': [('vana', False)],
          'vanats': [('vana', False)],
          'vand': [('vand', False)],
          'vanda': [('vandum', False)],
          'vandas': [('vandum', False)],
          'vanden': [('vande', False)],
          'vandens': [('vande', False)],
          'vandets': [('vande', False)],
          'vandrar': [('vandrare', False)],
          'vandrarna': [('vandrare', False)],
          'vandrarnas': [('vandrare', False)],
          'vands': [('vand', False)],
          'vands-': [('vand', False)],
          'vane': [('vana', True)],
          'vane-': [('vana', True)],
          'vanen': [('van', True)],
          'vanens': [('van', False)],
          'vaner': [('van', True)],
          'vanerna': [('van', True)],
          'vanernas': [('van', True)],
          'vaners': [('van', True)],
          'vang': [('vang', False)],
          'vang-': [('vang', False)],
          'vangen': [('vang', False)],
          'vangens': [('vang', False)],
          'vanger': [('vang', False)],
          'vangerna': [('vang', False)],
          'vangernas': [('vang', False)],
          'vangers': [('vang', False)],
          'vangs': [('vang', False)],
          'vangs-': [('vang', False)],
          'vank': [('vank', False)],
          'vank-': [('vank', True)],
          'vankar': [('vankare', False)],
          'vankar-': [('vankare', False)],
          'vankarna': [('vankare', False)],
          'vankarnas': [('vank', False)],
          'vankars': [('vank', False)],
          'vanken': [('vank', False)],
          'vankens': [('vank', False)],
          'vanker': [('vank', False)],
          'vankerna': [('vank', False)],
          'vankernas': [('vank', False)],
          'vankers': [('vank', False)],
          'vanks': [('vank', False)],
          'vanks-': [('vank', False)],
          'vann': [('vanna', True)],
          'vann-': [('vanna', True)],
          'vanne': [('vanna', True)],
          'vanne-': [('vanna', True)],
          'vannen': [('vanne', False)],
          'vannens': [('vanne', False)],
          'vanner': [('vann', False)],
          'vannerna': [('vann', False)],
          'vannernas': [('vann', False)],
          'vanners': [('vann', False)],
          'vannor': [('vanna', False)],
          'vannorna': [('vanna', False)],
          'vannornas': [('vanna', True)],
          'vannors': [('vanna', True)],
          'vanns': [('vanna', True)],
          'vanns-': [('vanna', True)],
          'vanor': [('vana', False)],
          'vanorna': [('vana', False)],
          'vanornas': [('vana', False)],
          'vanors': [('vana', True)],
          'vans': [('van', True)],
          'vans-': [('van', True)],
          'vansar': [('vans', False)],
          'vansarna': [('vans', False)],
          'vansars': [('vans', False)],
          'vansen': [('vans', False)],
          'vansens': [('vans', False)],
          'vanser': [('vans', False)],
          'vanserna': [('vans', False)],
          'vansernas': [('vans', False)],
          'vansers': [('vans', False)],
          'vant': [('vante', True), ('vant', True)],
          'vant-': [('vante', True), ('vant', True)],
          'vantar': [('vante', False)],
          'vantarna': [('vante', True)],
          'vantarnas': [('vante', False)],
          'vantars': [('vante', False)],
          'vantas': [('vantum', False)],
          'vante': [('vante', True)],
          'vante-': [('vantar', False)],
          'vanten': [('vante', True), ('vant', True)],
          'vantens': [('vante', True), ('vant', True)],
          'vanter': [('vant', False)],
          'vanterna': [('vant', True)],
          'vanternas': [('vant', True)],
          'vanters': [('vant', False)],
          'vantet': [('vant', True)],
          'vantets': [('vant', True)],
          'vantros': [('vantro', True)],
          'vants': [('vant', True), ('vante', True)],
          'vants-': [('vante', True), ('vant', True)],
          'vap-': [('vapa', False)],
          'vapan': [('vapa', False)],
          'vapans': [('vapa', False)],
          'vapas': [('vapa', False)],
          'vapen': [('vapen', False)],
          'vapens': [('vapen', False)],
          'vapnen': [('vapen', False)],
          'vapnens': [('vapen', False)],
          'var': [('vara', True), ('var', True)],
          'var-': [('var', True), ('vara', True)],
          'varan': [('varan', True), ('vara', True)],
          'varans': [('varan', True), ('vara', True)],
          'varar': [('varare', False)],
          'vararna': [('varare', False)],
          'vararnas': [('varare', False)],
          'varars': [('var', False)],
          'varas-': [('vara', True)],
          'varat': [('vara', True)],
          'varats': [('vara', True)],
          'vard': [('varde', True)],
          'vard-': [('varde', True)],
          'vardagen': [('vardag', True)],
          'vardagens': [('vardag', True)],
          'vardar': [('varde', True)],
          'vardarnas': [('varde', True)],
          'varden': [('varde', True)],
          'vardens': [('varde', True)],
          'varder': [('vard', False)],
          'varderna': [('vard', False)],
          'vardernas': [('vard', False)],
          'varders': [('vard', False)],
          'vards': [('varde', True)],
          'vards-': [('varde', True)],
          'vare': [('vare', False)],
          'varen': [('var', False)],
          'varens': [('vare', False)],
          'vares': [('vare', False)],
          'vargen': [('varg', False)],
          'vargens': [('varg', False)],
          'varian': [('varia', True)],
          'varians': [('varia', True), ('varians', True)],
          'varie': [('varie', False)],
          'varie-': [('varie', False)],
          'varier': [('varium', False)],
          'variernas': [('varium', False)],
          'varin': [('varin', False)],
          'varkar': [('vark', False)],
          'varkarna': [('vark', False)],
          'varmar': [('varm', False)],
          'varmarna': [('varm', False)],
          'varmarnas': [('varm', False)],
          'varn': [('varn', False)],
          'varna': [('ve', False)],
          'varnar': [('varn', False)],
          'varnarna': [('varn', False)],
          'varnarnas': [('varnare', False)],
          'varns': [('varn', False)],
          'varo': [('varo', False)],
          'varon': [('varo', False)],
          'varons': [('varo', False)],
          'varos': [('varo', False)],
          'varp': [('varpa', True), ('varp', True)],
          'varp-': [('varp', True), ('varpa', True)],
          'varpar': [('varp', True)],
          'varpars': [('varp', True)],
          'varps': [('varpa', True), ('varp', True)],
          'varps-': [('varpa', True), ('varp', True)],
          'varr': [('varr', False)],
          'varr-': [('varr', False)],
          'vars': [('var', True)],
          'varsan': [('varsan', False)],
          'varsans': [('varsan', False)],
          'varslen': [('varsel', False)],
          'varslens': [('varsel', True)],
          'varslet': [('varsel', False)],
          'varslets': [('varsel', False)],
          'vart': [('vart', False)],
          'vart-': [('vart', False)],
          'vartar': [('vart', False)],
          'vartars': [('vart', False)],
          'varten': [('vart', False)],
          'vartens': [('vart', False)],
          'varter': [('vart', False)],
          'varterna': [('vart', False)],
          'varters': [('vart', False)],
          'varts-': [('vart', False)],
          'varv': [('varv', False)],
          'varv-': [('varv', False)],
          'varvars': [('varv', False)],
          'varven': [('varv', False)],
          'varvens': [('varv', False)],
          'varvs': [('varv', False)],
          'varvs-': [('varv', False)],
          'vas': [('vase', True), ('vas', True)],
          'vas-': [('vase', True), ('vas', True)],
          'vasar': [('vase', True)],
          'vasaren': [('vasar', False)],
          'vasarna': [('vase', True)],
          'vasarnas': [('vase', False)],
          'vasars': [('vase', False)],
          'vase': [('vase', False)],
          'vasen': [('vas', True), ('vase', True)],
          'vasens': [('vase', True), ('vas', True)],
          'vask': [('vask', True)],
          'vask-': [('vask', True)],
          'vaskar': [('vask', True), ('vasker', True)],
          'vaskare': [('vaskare', False)],
          'vaskarna': [('vask', True), ('vasker', True)],
          'vaskarnas': [('vask', True), ('vasker', True)],
          'vaskars': [('vasker', True), ('vask', True)],
          'vasket': [('vask', True)],
          'vaskets': [('vask', True)],
          'vass': [('vass', True)],
          'vassar': [('vass', True)],
          'vassarna': [('vass', True)],
          'vassars': [('vass', False)],
          'vassen': [('vass', False)],
          'vassens': [('vass', False)],
          'vast-': [('vast', False)],
          'vastar': [('vast', False)],
          'vastarna': [('vast', False)],
          'vasten': [('vast', False)],
          'vata': [('vata', False)],
          'vatan': [('vata', False)],
          'vatar': [('vatar', False)],
          'vataren': [('vatar', False)],
          'vatas': [('vata', False)],
          'vatiden': [('vatiden', False)],
          'vatin': [('vatina', False)],
          'vatin-': [('vatina', False)],
          'vatins': [('vatina', False)],
          'vatins-': [('vatina', False)],
          'vation': [('vation', False)],
          'vationen': [('vation', False)],
          'vations': [('vation', False)],
          'vativets': [('vativ', False)],
          'vatman': [('vatman', False)],
          'vator': [('vator', False)],
          'vators': [('vator', False)],
          'vatt': [('vatt', False)],
          'vatt-': [('vatt', False)],
          'vatten': [('vatten', True)],
          'vattenrallar': [('vattenrall', True), ('vattenrallare', True)],
          'vattenrallarna': [('vattenrall', True), ('vattenrallare', True)],
          'vattenrallarnas': [('vattenrallare', True), ('vattenrall', True)],
          'vattens': [('vatten', False)],
          'vatter': [('vatt', False)],
          'vatters': [('vatt', False)],
          'vatts': [('vatt', False)],
          'vatts-': [('vatt', False)],
          'vavlingen': [('vavling', False)],
          'vavlingens': [('vavling', False)],
          'vback': [('vback', False)],
          'vback-': [('vback', False)],
          'vbackar': [('vback', False)],
          'vbackarna': [('vback', False)],
          'vbackarnas': [('vback', False)],
          'vbackars': [('vback', False)],
          'vbacken': [('vback', False)],
          'vbackens': [('vback', False)],
          'vbacks': [('vback', False)],
          'vbacks-': [('vback', False)],
          'vbagg': [('vbagge', False)],
          'vbagg-': [('vbagge', False)],
          'vbaggar': [('vbagge', False)],
          'vbaggarna': [('vbagge', False)],
          'vbaggarnas': [('vbagge', False)],
          'vbaggars': [('vbagge', False)],
          'vbaggen': [('vbagge', False)],
          'vbaggens': [('vbagge', False)],
          'vbaggs': [('vbagge', False)],
          'vbaggs-': [('vbagge', False)],
          'vbal': [('vbal', False)],
          'vbalen': [('vbal', False)],
          'vbalens': [('vbal', False)],
          'vbals': [('vbal', False)],
          'vbals-': [('vbal', False)],
          'vbanan': [('vbana', False)],
          'vbanans': [('vbana', False)],
          'vbandets': [('vband', False)],
          'vbane': [('vbana', False)],
          'vbane-': [('vbana', False)],
          'vbars': [('vbar', False)],
          'vben': [('vben', False)],
          'vbens': [('vben', False)],
          'vbens-': [('vben', False)],
          'vbit': [('vbit', False)],
          'vbitar': [('vbitare', False)],
          'vbitarna': [('vbitare', False)],
          'vbitarnas': [('vbitare', False)],
          'vbits': [('vbit', False)],
          'vbits-': [('vbit', False)],
          'vbloggar': [('vblogg', False)],
          'vbloggarna': [('vblogg', False)],
          'vbloggarnas': [('vblogg', False)],
          'vblås': [('vblås', False)],
          'vblås-': [('vblås', False)],
          'vblåsar': [('vblås', False)],
          'vblåsarna': [('vblås', False)],
          'vblåsarnas': [('vblås', False)],
          'vboj': [('vboj', False)],
          'vboj-': [('vboj', False)],
          'vbojar': [('vboj', False)],
          'vbojars': [('vboj', False)],
          'vbojs': [('vboj', False)],
          'vbojs-': [('vboj', False)],
          'vbolaget': [('vbolag', False)],
          'vbomb': [('vbomb', False)],
          'vbomber': [('vbomb', False)],
          'vbomberna': [('vbomb', False)],
          'vbombernas': [('vbomb', False)],
          'vbombers': [('vbomb', False)],
          'vbombs': [('vbomb', False)],
          'vbombs-': [('vbomb', False)],
          'vbor': [('vbo', False)],
          'vbors': [('vbo', False)],
          'vbroder': [('vbror', False)],
          'vbrodern': [('vbror', False)],
          'vbroderns': [('vbror', False)],
          'vbroders': [('vbror', False)],
          'vbroms': [('vbroms', False)],
          'vbromsar': [('vbroms', False)],
          'vbromsarna': [('vbroms', False)],
          'vbromsarnas': [('vbroms', False)],
          'vbrors': [('vbror', False)],
          'vbrors-': [('vbror', False)],
          'vbrytar': [('vbrytare', False)],
          'vbrytarna': [('vbrytare', False)],
          'vbrytarnas': [('vbrytare', False)],
          'vbräcks': [('vbräck', False)],
          'vbräcks-': [('vbräck', False)],
          'vbröder': [('vbror', False)],
          'vbröderna': [('vbror', False)],
          'vbrödernas': [('vbror', False)],
          'vbröders': [('vbror', False)],
          'vbälte': [('vbälte', False)],
          'vbåg': [('vbåge', False)],
          'vbåg-': [('vbåge', False)],
          'vbågs': [('vbåge', False)],
          'vbågs-': [('vbåge', False)],
          'vbön': [('vbön', False)],
          'vböns': [('vbön', False)],
          'vböns-': [('vbön', False)],
          'vcellens': [('vcell', False)],
          'vchoser': [('vchos', False)],
          'vchoserna': [('vchos', False)],
          'vchosernas': [('vchos', False)],
          'vchosers': [('vchos', False)],
          'vd': [('vd', False)],
          'vd-': [('vd', True)],
          'vdagar': [('vdag', False)],
          'vdagen': [('vdag', False)],
          'vdagens': [('vdag', False)],
          'vdamens': [('vdam', False)],
          'vdamer': [('vdam', False)],
          'vdanden': [('vdande', False)],
          'vdandens': [('vdande', False)],
          'vdans': [('vdag', False)],
          'vdar': [('vd', False)],
          'vdarna': [('vd', False)],
          'vdarnas': [('vd', True)],
          'vdars': [('vd', False)],
          'vdel': [('vdel', False)],
          'vdelandet': [('vdelande', False)],
          'vdels-': [('vdel', False)],
          'vden': [('vd', True)],
          'vdens': [('vd', True)],
          'vder': [('vd', False)],
          'vderna': [('vd', False)],
          'vdernas': [('vd', False)],
          'vders': [('vd', False)],
          'vding': [('vding', False)],
          'vding-': [('vding', False)],
          'vdingar': [('vding', False)],
          'vdingarna': [('vding', False)],
          'vdingarnas': [('vding', False)],
          'vdingars': [('vding', False)],
          'vdingen': [('vding', False)],
          'vdingens': [('vding', False)],
          'vdings': [('vding', False)],
          'vdings-': [('vding', False)],
          'vdocks-': [('vdocka', False)],
          'vdon': [('vdon', False)],
          'vdons': [('vdon', False)],
          'vdons-': [('vdon', False)],
          'vdramer': [('vdrama', False)],
          'vdramerna': [('vdrama', False)],
          'vdrivar': [('vdrivare', False)],
          'vdrivarna': [('vdrivare', False)],
          'vdrivarnas': [('vdrivare', False)],
          'vdroppar': [('vdroppar', False)],
          'vdropparna': [('vdroppar', False)],
          'vdropparnas': [('vdroppar', False)],
          'vdroppars': [('vdroppar', False)],
          'vdropps': [('vdroppar', False)],
          'vdropps-': [('vdroppar', False)],
          'vds': [('vd', False)],
          've': [('ve', False)],
          've-': [('ve', False)],
          'vea': [('vear', False)],
          'vea-': [('vear', False)],
          'vear': [('ve', False)],
          'vearna': [('ve', False)],
          'vearnas': [('vear', False)],
          'vears': [('vear', False)],
          'vecin': [('vecin', False)],
          'veck': [('veck', True), ('vecka', True)],
          'veck-': [('vecka', True), ('veck', True)],
          'vecken': [('veck', False)],
          'veckens': [('veck', False)],
          'vecko': [('vecka', False)],
          'veckor': [('vecka', False)],
          'veckorna': [('vecka', False)],
          'veckornas': [('vecka', False)],
          'veckors': [('vecka', False)],
          'veckoände': [('veckoände', True), ('veckoända', True)],
          'veckoände-': [('veckoände', True), ('veckoända', True)],
          'vecks': [('veck', True), ('vecka', True)],
          'vecks-': [('vecka', True), ('veck', True)],
          'veckände': [('veckände', True), ('veckända', True)],
          'veckände-': [('veckända', True), ('veckände', True)],
          'ved': [('ved', False)],
          'ved-': [('ved', False)],
          'vedan': [('veda', False)],
          'vedarnas': [('ved', False)],
          'vedback-': [('vedbacke', True)],
          'vedbacken': [('vedbacke', True)],
          'vedbacks': [('vedbacke', True)],
          'vedfången': [('vedfång', True)],
          'veds': [('ved', False)],
          'veds-': [('ved', False)],
          'vegan': [('vegan', True)],
          'vegans': [('vegan', True)],
          'vek': [('veke', True)],
          'vek-': [('veke', True)],
          'vekan': [('vekan', False)],
          'vekans': [('vekan', False)],
          'vekar': [('veke', True)],
          'vekarna': [('veke', True)],
          'vekarnas': [('veke', True)],
          'vekars': [('veke', True)],
          'veke': [('veke', True)],
          'veken': [('veke', True)],
          'vekens': [('veke', True)],
          'vekes': [('veke', True)],
          'veket': [('vek', False)],
          'vekets': [('vek', False)],
          'veks': [('veke', True)],
          'veks-': [('veke', True)],
          'vektiven': [('vektiv', False)],
          'vektivens': [('vektiv', False)],
          'vel': [('vele', True), ('vela', True)],
          'vel-': [('vele', True), ('vela', True)],
          'velanden': [('velande', True)],
          'velandens': [('velande', True)],
          'velandets': [('velande', True)],
          'velar': [('velar', True), ('vele', True)],
          'velar-': [('velar', True)],
          'velaren': [('velar', True)],
          'velarna': [('vele', True)],
          'velarnas': [('vele', True)],
          'velars': [('vele', True), ('velar', True)],
          'vele': [('vele', True), ('vela', True)],
          'velen': [('vele', True)],
          'velens': [('vele', True)],
          'velers': [('vel', False)],
          'velin': [('velin', False)],
          'vell': [('vell', False)],
          'vell-': [('vell', False)],
          'vellen': [('vell', False)],
          'veller': [('vell', False)],
          'vellerna': [('vell', False)],
          'vellernas': [('vell', False)],
          'vellers': [('vell', False)],
          'vells': [('vell', False)],
          'vells-': [('vell', False)],
          'vels': [('vela', True), ('vele', True)],
          'vels-': [('vela', True), ('vele', True)],
          'velsträcks': [('velsträck', False)],
          'velvinds': [('velvind', False)],
          'velvinds-': [('velvind', False)],
          'vemang': [('vemang', False)],
          'vemang-': [('vemang', False)],
          'vemangs': [('vemang', False)],
          'vemangs-': [('vemang', False)],
          'ven': [('ven', True)],
          'vena': [('ve', False)],
          'venas': [('ve', False)],
          'venden': [('vend', True)],
          'vendens': [('vend', True)],
          'vender': [('vender', True), ('vend', True)],
          'venderna': [('vender', True), ('vend', True)],
          'vendernas': [('vender', True), ('vend', True)],
          'venders': [('vend', True), ('vender', True)],
          'venheter': [('venhet', False)],
          'venheterna': [('venhet', False)],
          'venheternas': [('venhet', False)],
          'venheters': [('venhet', False)],
          'venhets': [('venhet', False)],
          'venhets-': [('venhet', False)],
          'vennernas': [('ven', False)],
          'vens': [('ven', True)],
          'vens-': [('ven', True)],
          'vensen': [('vens', False)],
          'vensens': [('vens', False)],
          'venser': [('vens', False)],
          'venserna': [('vens', False)],
          'vensernas': [('vens', False)],
          'vensers': [('vens', False)],
          'vensk': [('venska', False)],
          'vensk-': [('venska', False)],
          'vensken': [('vensk', False)],
          'vent': [('vent', False)],
          'venten': [('vent', False)],
          'ventens': [('vent', False)],
          'venter': [('vent', False)],
          'venterna': [('vent', False)],
          'venternas': [('vent', False)],
          'venters': [('vent', False)],
          'ventet': [('vent', False)],
          'vents-': [('vent', False)],
          'veoler': [('veol', False)],
          'veolerna': [('veol', False)],
          'veolernas': [('veol', False)],
          'veolers': [('veol', False)],
          'vep': [('vepa', True)],
          'vep-': [('vepa', True)],
          'vepan': [('vepa', True)],
          'vepans': [('vepa', True)],
          'vepar': [('vepare', False)],
          'veparna': [('vepare', False)],
          'vepe': [('vepa', True)],
          'veps': [('vepa', True)],
          'veps-': [('vepa', True)],
          'ver': [('ver', False)],
          'ver-': [('ver', False)],
          'verande': [('veranda', False)],
          'verande-': [('veranda', False)],
          'verans': [('verans', False)],
          'verben': [('verbena', True), ('verb', True)],
          'verbens': [('verbena', True), ('verb', True)],
          'verbet': [('verb', False)],
          'verdomarna': [('verdomare', False)],
          'verdos-': [('verdos', False)],
          'verens': [('verens', False)],
          'verfiskarnas': [('verfisk', False)],
          'veri': [('veri', False)],
          'veri-': [('veri', False)],
          'verier': [('veri', False)],
          'verierna': [('veri', False)],
          'veriers': [('veri', False)],
          'veriet': [('veri', False)],
          'verin': [('verin', False)],
          'veris': [('veri', False)],
          'veris-': [('veri', False)],
          'verit': [('veri', False)],
          'verk': [('verk', False)],
          'verk-': [('verk', True)],
          'verkan': [('verkan', False)],
          'verkans': [('verkan', False)],
          'verken': [('verk', False)],
          'verkens': [('verk', False)],
          'verket': [('verk', False)],
          'verkets': [('verk', True)],
          'verkningar': [('verkning', False)],
          'verkningarna': [('verkning', False)],
          'verkningarnas': [('verkning', False)],
          'verkningars': [('verkning', False)],
          'verks': [('verk', False)],
          'verks-': [('verk', False)],
          'verlack': [('verlack', False)],
          'verlåtar': [('verlåtare', False)],
          'verlåtarna': [('verlåt', False)],
          'verlåtarnas': [('verlåtare', False)],
          'verman': [('verman', False)],
          'vermans': [('verman', False)],
          'verna': [('ver', False)],
          'vernas': [('ver', False)],
          'verne': [('verna', False)],
          'verne-': [('verne', False)],
          'verner': [('vern', False)],
          'verners': [('vern', False)],
          'vernet': [('verne', False)],
          'vernets': [('verne', False)],
          'verorden': [('verord', False)],
          'verordens': [('verord', False)],
          'vers': [('vers', True)],
          'vers-': [('vers', False)],
          'versarna': [('vers', False)],
          'versarnas': [('vers', True)],
          'versen': [('vers', True)],
          'versens': [('vers', False)],
          'verser': [('vers', False)],
          'verserna': [('vers', False)],
          'versernas': [('vers', False)],
          'versers': [('vers', False)],
          'verst': [('verst', True)],
          'verst-': [('verst', True)],
          'versten': [('verst', True)],
          'verstens': [('verst', True)],
          'vertens': [('vert', False)],
          'vertet': [('vert', False)],
          'vertets': [('verte', False)],
          'verts': [('vert', False)],
          'verts-': [('vert', False)],
          'verv': [('verv', True)],
          'verv-': [('verv', True)],
          'verven': [('verv', True)],
          'vervens': [('verv', True)],
          'vervs': [('verv', True)],
          'vervs-': [('verv', True)],
          'vervärden': [('vervärde', False)],
          'vervärdens': [('vervärde', False)],
          'ves': [('ve', False)],
          'ves-': [('ve', False)],
          'vesen': [('f', False)],
          'vesens': [('f', False)],
          'veseriernas': [('veserie', False)],
          'veseriers': [('veserie', False)],
          'veskärmar': [('veskärm', False)],
          'vess': [('vess', False)],
          'vessens': [('vess', False)],
          'vester': [('vester', False)],
          'vesterns': [('vester', False)],
          'vesters': [('vester', False)],
          'vestis': [('vesti', False)],
          'vet': [('ve', False)],
          'vetar': [('vetare', False)],
          'vetarna': [('vetare', False)],
          'vete': [('vete', False)],
          'vete-': [('vete', False)],
          'vetebull': [('vetebulla', True), ('vetebulle', True)],
          'vetebull-': [('vetebulle', True), ('vetebulla', True)],
          'vetebulle': [('vetebulla', True), ('vetebulle', True)],
          'vetebulle-': [('vetebulla', True), ('vetebulle', True)],
          'vetebulls': [('vetebulla', True), ('vetebulle', True)],
          'vetebulls-': [('vetebulla', True), ('vetebulle', True)],
          'veten': [('vete', False)],
          'vetens': [('vete', False)],
          'vetes': [('vete', False)],
          'vetes-': [('vete', False)],
          'vetet': [('vete', False)],
          'vetin': [('vetin', False)],
          'veton': [('veto', True)],
          'vetons': [('veto', True)],
          'vetos': [('veto', True)],
          'vetron': [('vetron', False)],
          'vets': [('v', False)],
          'vets-': [('vete', False)],
          'vetsen': [('vets', False)],
          'vetsens': [('vets', False)],
          'vett': [('vette', True), ('vett', True)],
          'vett-': [('vette', True), ('vett', True)],
          'vettarna': [('vette', True)],
          'vettarnas': [('vette', True)],
          'vetten': [('vette', True)],
          'vettens': [('vette', True)],
          'vetter': [('vett', False)],
          'vetterna': [('vett', False)],
          'vetternas': [('vett', False)],
          'vetters': [('vett', False)],
          'vetts': [('vette', True), ('vett', True)],
          'vetts-': [('vette', True), ('vett', True)],
          'vev': [('vev', False)],
          'vev-': [('vev', True)],
          'vevarnas': [('vev', True)],
          'vevars': [('vev', False)],
          'vevs': [('vev', False)],
          'vevs-': [('vev', False)],
          'vfader': [('vfar', False)],
          'vfader-': [('vfar', False)],
          'vfadern': [('vfar', False)],
          'vfaderns': [('vfar', False)],
          'vfaders': [('vfar', False)],
          'vfaders-': [('vfar', False)],
          'vfar': [('vfar', False)],
          'vfar-': [('vfar', False)],
          'vfarmar': [('vfarm', False)],
          'vfarmarna': [('vfarm', False)],
          'vfarmarnas': [('vfarm', False)],
          'vfars': [('vfar', False)],
          'vfars-': [('vfar', False)],
          'vfel': [('vfel', False)],
          'vfels': [('vfel', False)],
          'vfels-': [('vfel', False)],
          'vfilen': [('vfil', False)],
          'vfilens': [('vfil', False)],
          'vfink': [('vfink', False)],
          'vfink-': [('vfink', False)],
          'vfinks': [('vfink', False)],
          'vfinks-': [('vfink', False)],
          'vfiskar': [('vfiskare', False)],
          'vfiskarna': [('vfiskare', False)],
          'vfiskarnas': [('vfisk', False)],
          'vfots': [('vfötter', False)],
          'vfots-': [('vfötter', False)],
          'vfyrar': [('vfyrare', False)],
          'vfyrarna': [('vfyrare', False)],
          'vfyrarnas': [('vfyrare', False)],
          'vfäder': [('vfar', False)],
          'vfäderna': [('vfar', False)],
          'vfädernas': [('vfar', False)],
          'vfäders': [('vfar', False)],
          'vförsäkringar': [('vförsäkring', False)],
          'vförsäkringarna': [('vförsäkring', False)],
          'vförsäkringarnas': [('vförsäkring', False)],
          'vförsäkringars': [('vförsäkring', False)],
          'vfötter': [('vfötter', False)],
          'vfötterna': [('vfötter', False)],
          'vfötternas': [('vfötter', False)],
          'vfötters': [('vfötter', False)],
          'vgamen': [('vgame', False)],
          'vgamens': [('vgame', False)],
          'vgamet': [('vgame', False)],
          'vgamets': [('vgame', False)],
          'vgarden': [('vgarde', False)],
          'vgardens': [('vgarde', False)],
          'vgas': [('vgaser', False)],
          'vgas-': [('vgaser', False)],
          'vgaser': [('vgaser', False)],
          'vgaserna': [('vgas', False)],
          'vgasernas': [('vgas', False)],
          'vgasers': [('vgas', False)],
          'vgiften': [('vgift', False)],
          'vgiftens': [('vgift', False)],
          'vgiftet': [('vgift', False)],
          'vgiftets': [('vgift', False)],
          'vgifts': [('vgift', False)],
          'vgifts-': [('vgift', False)],
          'vgods': [('vgods', False)],
          'vgods-': [('vgods', False)],
          'vgrens': [('vgren', False)],
          'vgryt': [('vgryta', False)],
          'vgryt-': [('vgryta', False)],
          'vgryts': [('vgryta', False)],
          'vgryts-': [('vgryta', False)],
          'vgubb': [('vgubbe', False)],
          'vgubbs': [('vgubbe', False)],
          'vgångar': [('vgång', False)],
          'vgångarna': [('vgång', False)],
          'vgångarnas': [('vgång', False)],
          'vgås': [('vgås', False)],
          'vgås-': [('vgås', False)],
          'vgåsen': [('vgås', False)],
          'vgåsens': [('vgås', False)],
          'vgåve-': [('vgåva', False)],
          'vgåvor': [('vgåva', False)],
          'vgåvors': [('vgåva', False)],
          'vgömme': [('vgömma', False)],
          'vgömme-': [('vgömma', False)],
          'vgöms': [('vgömma', False)],
          'vhalar': [('vhalare', False)],
          'vhandlar': [('vhandlare', False)],
          'vhandlarna': [('vhandlare', False)],
          'vhandlarnas': [('vhandlare', False)],
          'vheter': [('vhet', False)],
          'vheterna': [('vhet', False)],
          'vheternas': [('vhet', False)],
          'vheters': [('vhet', False)],
          'vhets': [('vhet', False)],
          'vhets-': [('vhet', False)],
          'vhundars': [('vhund', False)],
          'vhäfte': [('vhäfte', False)],
          'vhäften': [('vhäfte', False)],
          'vhäll': [('vhäll', False)],
          'vhälls': [('vhäll', False)],
          'vhälls-': [('vhäll', False)],
          'vhärskare': [('vhärskare', False)],
          'vhästarnas': [('vhäst', False)],
          'vhästars': [('vhäst', False)],
          'vhål': [('vhål', False)],
          'vhåls': [('vhål', False)],
          'vhåls-': [('vhål', False)],
          'vhökar': [('vhök', False)],
          'vhökarna': [('vhök', False)],
          'vhökarnas': [('vhök', False)],
          'vi': [('vi', False)],
          'vi-': [('vi', False)],
          'vialen': [('vial', False)],
          'vialens': [('vial', False)],
          'vian': [('vian', False)],
          'vian-': [('vian', False)],
          'vians': [('vian', False)],
          'viar': [('viar', False)],
          'viar-': [('viar', False)],
          'viarens': [('viar', False)],
          'viars': [('viar', False)],
          'vibb': [('vibb', True)],
          'vibbarnas': [('vibb', True)],
          'vibbars': [('vibb', True)],
          'vibbens': [('vibb', True)],
          'vibbs': [('vibb', True)],
          'vibbs-': [('vibb', True)],
          'vican': [('vica', False)],
          'vicans': [('vica', False)],
          'vicen': [('vice', False)],
          'vicens': [('vice', False)],
          'vichen': [('vich', False)],
          'vichens': [('vich', False)],
          'vick': [('vick', True)],
          'vick-': [('vick', True)],
          'vickels': [('vickel', True)],
          'vickelsen': [('vickelse', False)],
          'vicket': [('vick', True)],
          'vicklar': [('vickel', True)],
          'vicklarnas': [('vickel', True)],
          'vicks': [('vick', False)],
          'vicks-': [('vick', True)],
          'vicksanden': [('vicksand', False)],
          'vicksandens': [('vicksand', False)],
          'vida': [('vida', False)],
          'vidarnas': [('vid', False)],
          'vidas': [('vida', False)],
          'vidder': [('vidd', False)],
          'vidders': [('vidd', False)],
          'vide': [('vide', True)],
          'vide-': [('vide', False)],
          'viden': [('vide', True)],
          'vidender': [('vidend', False)],
          'videnders': [('vidend', False)],
          'videns': [('vide', True)],
          'videns-': [('videns', False)],
          'vider': [('vider', False)],
          'viders': [('vider', False)],
          'vides-': [('vide', False)],
          'videt': [('vide', False)],
          'videts': [('vide', False)],
          'vids': [('vide', True)],
          'vids-': [('vide', True)],
          'vie': [('vium', False)],
          'vie-': [('vium', False)],
          'viellerna': [('vielle', True)],
          'viellers': [('vielle', True)],
          'viemens': [('viem', False)],
          'vien': [('vi', False)],
          'viens': [('vi', False)],
          'viesarna': [('vie', False)],
          'viesarnas': [('vie', False)],
          'viet': [('vi', True)],
          'viets': [('vi', True)],
          'viftans': [('vifta', False)],
          'viftarnas': [('viftare', False)],
          'vifte': [('vifta', False)],
          'vifte-': [('vifta', False)],
          'vifts': [('vifta', False)],
          'vig': [('viga', False)],
          'vig-': [('viga', False)],
          'vigan': [('viga', False)],
          'viger': [('vig', False)],
          'vigernas': [('vig', False)],
          'vigets': [('vig', False)],
          'vigg': [('vigge', True), ('vigg', True)],
          'vigg-': [('vigg', True), ('vigge', True)],
          'viggar': [('vigge', True), ('vigg', True)],
          'viggarna': [('vigge', True), ('vigg', True)],
          'viggarnas': [('vigge', True), ('vigg', True)],
          'viggars': [('vigg', True), ('vigge', True)],
          'viggen': [('vigge', True), ('vigg', True)],
          'viggens': [('vigge', True), ('vigg', True)],
          'viggs': [('vigge', True), ('vigg', True)],
          'viggs-': [('vigge', True), ('vigg', True)],
          'vigheter': [('vighet', False)],
          'vigheterna': [('vighet', False)],
          'vigheternas': [('vighet', False)],
          'vigheters': [('vighet', False)],
          'vighets-': [('vighet', False)],
          'viglar': [('viglare', False)],
          'viglarna': [('viglare', False)],
          'viglarnas': [('viglare', False)],
          'vigs': [('viga', False)],
          'vigs-': [('viga', False)],
          'vik': [('vik', True)],
          'vik-': [('vik', True)],
          'vika': [('vika', False)],
          'vikan': [('vika', False)],
          'vikandens': [('vikande', False)],
          'vikans': [('vika', False)],
          'vikar': [('vik', True), ('vikare', True)],
          'vikarna': [('vik', True), ('vikare', True)],
          'vikarnas': [('vikare', True), ('vik', True)],
          'vikas': [('vika', False)],
          'viket': [('vik', False)],
          'vikets': [('vik', False)],
          'viks': [('vik', True)],
          'viks-': [('vik', True)],
          'viktar': [('vikt', False)],
          'viktarna': [('vikt', False)],
          'viktarnas': [('viktare', False)],
          'vikten': [('vikt', False)],
          'viktens': [('vikt', False)],
          'viktorie': [('viktoria', True)],
          'viktorie-': [('viktoria', True)],
          'vikts': [('vikt', False)],
          'vikts-': [('vikt', False)],
          'vil': [('vila', True)],
          'vil-': [('vila', True)],
          'vilandets': [('vilande', False)],
          'vildarnas': [('vilde', True)],
          'vildkatt': [('vildkatt', True), ('vildkatta', True)],
          'vildkatt-': [('vildkatta', True), ('vildkatt', True)],
          'vildkatts': [('vildkatta', True), ('vildkatt', True)],
          'vildkatts-': [('vildkatt', True), ('vildkatta', True)],
          'vilister': [('vilist', False)],
          'vilisters': [('vilist', False)],
          'vilje': [('vilja', False)],
          'vilje-': [('vilja', False)],
          'vill': [('villa', True)],
          'vill-': [('villa', True)],
          'villan': [('villa', False)],
          'villarna': [('villare', False)],
          'villarnas': [('villare', False)],
          'ville': [('villa', False)],
          'ville-': [('villa', False)],
          'villen': [('vill', False)],
          'viller': [('vill', False)],
          'villerna': [('vill', False)],
          'villernas': [('vill', False)],
          'villers': [('vill', False)],
          'villor': [('villa', False)],
          'villorna': [('villa', False)],
          'villornas': [('villa', False)],
          'villors': [('villa', False)],
          'vills': [('villa', True)],
          'vills-': [('villa', True)],
          'vilo-': [('vila', False)],
          'vils': [('vila', True)],
          'vils-': [('vila', True)],
          'vilt-': [('vilt', False)],
          'vilts': [('vilt', False)],
          'vilts-': [('vilt', False)],
          'vim': [('vimma', True)],
          'vim-': [('vimma', True)],
          'vimbor': [('vimba', True)],
          'vimborna': [('vimba', True)],
          'vimbornas': [('vimba', True)],
          'vimme': [('vimma', True)],
          'vimme-': [('vimma', True)],
          'vims': [('vimma', True)],
          'vims-': [('vimma', True)],
          'vin': [('vina', True), ('vin', True)],
          'vin-': [('vina', True), ('vin', True)],
          'vina': [('vina', True)],
          'vinandens': [('vinande', True)],
          'vinans': [('vina', True)],
          'vinar': [('vinare', True)],
          'vinar-': [('vinare', True)],
          'vinarens': [('vinare', True)],
          'vinarna': [('vinare', True)],
          'vinas': [('vina', True)],
          'vind': [('vinda', True), ('vind', True)],
          'vind-': [('vind', True), ('vinda', True)],
          'vindar': [('vind', False)],
          'vindarna': [('vind', False)],
          'vindarnas': [('vind', True)],
          'vindbloms-': [('vindblomma', True)],
          'vindlar': [('vindel', False)],
          'vindlarna': [('vindel', False)],
          'vindlarnas': [('vindel', True)],
          'vinds': [('vinda', True), ('vind', True)],
          'vinds-': [('vinda', True), ('vind', True)],
          'vinets': [('vin', False)],
          'ving': [('vinge', True), ('ving', True)],
          'ving-': [('ving', True), ('vinge', True)],
          'vingar': [('vinge', True), ('ving', True)],
          'vingarna': [('vinge', True), ('ving', True)],
          'vingarnas': [('ving', True), ('vinge', True)],
          'vingars': [('vinge', True), ('ving', True)],
          'vingel': [('vingel', True)],
          'vingel-': [('vingel', False)],
          'vingen': [('vinge', True), ('ving', True)],
          'vingens': [('vinge', True), ('ving', True)],
          'vinget': [('ving', False)],
          'vings': [('ving', True), ('vinge', True)],
          'vings-': [('ving', True), ('vinge', True)],
          'viniker': [('viniker', False)],
          'vinikerna': [('viniker', False)],
          'vinikernas': [('viniker', False)],
          'vinikers': [('viniker', False)],
          'vinister': [('vinist', False)],
          'vinisters': [('vinist', False)],
          'vink': [('vink', True)],
          'vinkar': [('vink', True)],
          'vinkarna': [('vink', True)],
          'vinkarnas': [('vink', True)],
          'vinkars': [('vink', True)],
          'vinker': [('vink', False)],
          'vinkerna': [('vink', False)],
          'vinkernas': [('vink', False)],
          'vinkers': [('vink', False)],
          'vinks': [('vink', False)],
          'vinn': [('vinna', False)],
          'vinn-': [('vinn', False)],
          'vinnar': [('vinnare', False)],
          'vinnarnas': [('vinnare', False)],
          'vinne': [('vinna', False)],
          'vinne-': [('vinna', False)],
          'vinnens': [('vinn', False)],
          'vinnet': [('vinn', False)],
          'vinns': [('vinn', False)],
          'vinns-': [('vinn', False)],
          'vins': [('vina', True), ('vin', True)],
          'vins-': [('vina', True), ('vin', True)],
          'vinscher': [('vinsch', True)],
          'vinschers': [('vinsch', True)],
          'vinsten': [('vinsten', True), ('vinst', True)],
          'vinstens': [('vinsten', True), ('vinst', True)],
          'vint': [('vint', False)],
          'vinter': [('vinter', True)],
          'vintern': [('vinter', False)],
          'vinterna': [('vint', False)],
          'vinternas': [('vint', False)],
          'vinterns': [('vinter', False)],
          'vinters': [('vinter', True)],
          'vints-': [('vint', False)],
          'viol': [('viol', True), ('viola', True)],
          'viol-': [('viola', True), ('viol', True)],
          'violer': [('viol', False)],
          'violerna': [('viol', False)],
          'violernas': [('viol', False)],
          'violers': [('viol', False)],
          'violin': [('violin', True)],
          'violins': [('violin', False)],
          'viols': [('viola', True), ('viol', True)],
          'viols-': [('viola', True), ('viol', True)],
          'vior': [('via', False)],
          'viorna': [('via', False)],
          'viornas': [('via', False)],
          'viors': [('via', False)],
          'viots': [('viot', False)],
          'vip': [('vip', True), ('vipa', True)],
          'vip-': [('vipa', True), ('vip', True)],
          'vipan': [('vipa', False)],
          'vipans': [('vipa', False)],
          'viparnas': [('vip', True)],
          'vipas': [('vipa', False)],
          'vipp': [('vipp', True), ('vippa', True)],
          'vipp-': [('vipp', True), ('vippa', True)],
          'vippar': [('vipp', True)],
          'vipparna': [('vipp', True)],
          'vippbräde': [('vippbräda', True), ('vippbräde', True)],
          'vippe': [('vippa', False)],
          'vippe-': [('vippa', True)],
          'vippen': [('vipp', True)],
          'vippens': [('vipp', True)],
          'vipps': [('vipp', True), ('vippa', True)],
          'vipps-': [('vipp', True), ('vippa', True)],
          'vips': [('vip', True), ('vipa', True)],
          'vips-': [('vip', True), ('vipa', True)],
          'vir': [('vira', True)],
          'vir-': [('vira', True)],
          'virarnas': [('virare', False)],
          'virer': [('vir', False)],
          'virerna': [('vir', False)],
          'virernas': [('vir', False)],
          'virers': [('vir', False)],
          'virkets': [('virke', False)],
          'virs': [('vira', True)],
          'virs-': [('vira', True)],
          'vis': [('vis', True), ('vi', True), ('visa', True), ('vise', True)],
          'vis-': [('vise', True), ('vis', True), ('visa', True)],
          'visa': [('visum', True), ('visa', True)],
          'visan': [('visa', False)],
          'visans': [('visa', False)],
          'visar': [('vise', True), ('visare', True)],
          'visarna': [('visare', True), ('vise', True)],
          'visarnas': [('vise', True), ('visare', True)],
          'visars': [('vise', True)],
          'visas': [('visum', True), ('visa', True)],
          'visationen': [('visation', False)],
          'visch': [('vischa', False)],
          'visch-': [('vischa', False)],
          'visdomar': [('visdom', False)],
          'visdomarna': [('visdom', False)],
          'visdomarnas': [('visdom', True)],
          'vise': [('vise', True), ('visa', True)],
          'visen': [('vise', True), ('vis', True)],
          'visens': [('vise', True), ('vis', True)],
          'viskan': [('viska', False)],
          'viskans': [('viska', False)],
          'viskar': [('viskare', False)],
          'viskarnas': [('viskare', True)],
          'viske': [('viska', True)],
          'viske-': [('viska', False)],
          'visman': [('visman', True)],
          'vismans': [('visman', True)],
          'vismer': [('vism', False)],
          'vismerna': [('vism', False)],
          'vismernas': [('vism', False)],
          'vismers': [('vism', False)],
          'visor': [('visa', True)],
          'visors': [('visa', True)],
          'visp': [('visp', False)],
          'visp-': [('visp', False)],
          'vispar': [('visper', True), ('visp', True)],
          'visparna': [('visper', True), ('visp', True)],
          'visparnas': [('visper', True), ('visp', True)],
          'vispars': [('visper', True), ('visp', True)],
          'vispens': [('visp', False)],
          'viss': [('viss', False)],
          'vissar': [('viss', False)],
          'vissars': [('viss', False)],
          'vissen': [('viss', False)],
          'vissens': [('viss', False)],
          'visser': [('viss', False)],
          'visserna': [('viss', False)],
          'vissernas': [('viss', False)],
          'vissers': [('viss', False)],
          'visslan': [('vissla', False)],
          'visslans': [('vissla', True)],
          'vist': [('viste', True)],
          'vist-': [('viste', True)],
          'vistarna': [('vist', False)],
          'visten': [('viste', True)],
          'vistens': [('viste', True)],
          'vister': [('vist', False)],
          'visterna': [('vist', False)],
          'visternas': [('vist', False)],
          'visters': [('vist', False)],
          'vistet': [('viste', True)],
          'vistets': [('viste', True)],
          'vistik': [('vistik', False)],
          'vistik-': [('vistik', False)],
          'vistiks': [('vistik', False)],
          'vit': [('vita', False)],
          'vit-': [('vita', False)],
          'vita': [('vita', False)],
          'vitan': [('vita', False)],
          'vitas': [('vita', True)],
          'vite': [('vite', True), ('vita', True)],
          'viten': [('vite', True)],
          'vitens': [('vite', True)],
          'viternas': [('vit', False)],
          'vites-': [('vite', False)],
          'vitet': [('vite', True)],
          'vitets': [('vite', True)],
          'vits': [('vite', True), ('vita', True), ('vits', True)],
          'vits-': [('vite', True), ('vits', True), ('vita', True)],
          'vitsar': [('vits', True), ('vitsare', True)],
          'vitsarna': [('vitsare', True), ('vits', True)],
          'vitsarnas': [('vitsare', True), ('vits', True)],
          'vitsen': [('vits', False)],
          'vitsens': [('vits', False)],
          'vitt': [('vitt', False)],
          'vitt-': [('vitt', False)],
          'vitter': [('vitter', False)],
          'vitter-': [('vitter', False)],
          'vittrarnas': [('vittrare', False)],
          'vitts': [('vitt', False)],
          'vium': [('vium', False)],
          'viums': [('vium', False)],
          'viv': [('viva', True), ('viv', True)],
          'viv-': [('viva', True), ('viv', True)],
          'vivalens': [('vivalens', False)],
          'vivets': [('viv', True)],
          'vivlar': [('vivel', True)],
          'vivlarna': [('vivel', True)],
          'vivlarnas': [('vivel', True)],
          'vivs': [('viva', True), ('viv', True)],
          'vivs-': [('viva', True), ('viv', True)],
          'vjan': [('vja', False)],
          'vjans': [('vja', False)],
          'vjets': [('vjet', False)],
          'vjus': [('vju', False)],
          'vjävlarna': [('vjävel', False)],
          'vjävlarnas': [('vjävel', False)],
          'vjävlars': [('vjävel', False)],
          'vkammar': [('vkammare', False)],
          'vkams': [('vkam', False)],
          'vkams-': [('vkam', False)],
          'vkan': [('vka', False)],
          'vkans': [('vka', False)],
          'vkart': [('vkarta', False)],
          'vkart-': [('vkarta', False)],
          'vkartan': [('vkarta', False)],
          'vkarts': [('vkarta', False)],
          'vkarts-': [('vkarta', False)],
          'vkas': [('vka', False)],
          'vkass': [('vkasse', False)],
          'vkasse': [('vkasse', False)],
          'vkasse-': [('vkasse', False)],
          'vkassen': [('vkasse', False)],
          'vkist-': [('vkista', False)],
          'vkistan': [('vkista', False)],
          'vkistans': [('vkista', False)],
          'vklasen': [('vklase', False)],
          'vklot': [('vklot', False)],
          'vklots': [('vklot', False)],
          'vklots-': [('vklot', False)],
          'vknippe': [('vknippe', False)],
          'vknippe-': [('vknippe', False)],
          'vknut': [('vknut', False)],
          'vknuts': [('vknut', False)],
          'vknuts-': [('vknut', False)],
          'vknät': [('vknä', False)],
          'vknäts': [('vknä', False)],
          'vkok': [('vkok', False)],
          'vkoks': [('vkok', False)],
          'vkoks-': [('vkok', False)],
          'vkomst-': [('vkomst', False)],
          'vkon': [('vko', False)],
          'vkons': [('vko', False)],
          'vkonst-': [('vkonst', False)],
          'vkonsterna': [('vkonst', False)],
          'vkonsternas': [('vkonst', False)],
          'vkonsters': [('vkonst', False)],
          'vkor': [('vko', False)],
          'vkoret': [('vkor', False)],
          'vkorets': [('vkor', False)],
          'vkors': [('vko', False)],
          'vkors-': [('vkor', False)],
          'vkos': [('vko', False)],
          'vkos-': [('vko', False)],
          'vkrafter': [('vkraft', False)],
          'vkrafterna': [('vkraft', False)],
          'vkrafternas': [('vkraft', False)],
          'vkrafters': [('vkraft', False)],
          'vkrafts': [('vkraft', False)],
          'vkrafts-': [('vkraft', False)],
          'vkramp': [('vkramp', False)],
          'vkramps': [('vkramp', False)],
          'vkramps-': [('vkramp', False)],
          'vkrets-': [('vkrets', False)],
          'vkrokarnas': [('vkrok', False)],
          'vkull': [('vkulla', False)],
          'vkull-': [('vkulla', False)],
          'vkulle': [('vkulla', False)],
          'vkulls': [('vkulla', False)],
          'vkulls-': [('vkulla', False)],
          'vkurs': [('vkurs', False)],
          'vkurs-': [('vkurs', False)],
          'vkyl': [('vkyl', False)],
          'vkyl-': [('vkyl', False)],
          'vkylar': [('vkylare', False)],
          'vkylarna': [('vkylare', False)],
          'vkylarnas': [('vkylare', False)],
          'vkyls-': [('vkyl', False)],
          'vkättar': [('vkätte', False)],
          'vkättarna': [('vkätte', False)],
          'vkättarnas': [('vkätte', False)],
          'vkök-': [('vkök', False)],
          'vköks': [('vkök', False)],
          'vköks-': [('vkök', False)],
          'vl': [('vle', False)],
          'vl-': [('vle', False)],
          'vlack': [('vlack', False)],
          'vlamp-': [('vlampa', False)],
          'vlamps': [('vlampa', False)],
          'vlamps-': [('vlampa', False)],
          'vlan': [('vla', False)],
          'vlanden': [('vlande', False)],
          'vlandena': [('vlande', False)],
          'vlandenas': [('vlande', False)],
          'vlandens': [('vlande', False)],
          'vlandet': [('vlande', False)],
          'vlandets': [('vlande', False)],
          'vlans': [('vla', False)],
          'vlans-': [('vlan', False)],
          'vlar-': [('vlar', False)],
          'vlaren': [('vlare', False)],
          'vlarens': [('vlar', False)],
          'vlars-': [('vlar', False)],
          'vlat': [('vlat', False)],
          'vlaten': [('vlat', False)],
          'vlatens': [('vlat', False)],
          'vlats': [('vlat', False)],
          'vlats-': [('vlat', False)],
          'vlav': [('vlave', False)],
          'vlav-': [('vlave', False)],
          'vlavar': [('vlave', False)],
          'vlavarna': [('vlave', False)],
          'vlavarnas': [('vlave', False)],
          'vlavars': [('vlave', False)],
          'vlave': [('vlave', False)],
          'vlaven': [('vlave', False)],
          'vlavens': [('vlave', False)],
          'vlavs': [('vlave', False)],
          'vlavs-': [('vlave', False)],
          'vlek': [('vlek', False)],
          'vlekar': [('vlek', False)],
          'vlekarna': [('vlek', False)],
          'vlekarnas': [('vlek', False)],
          'vleken': [('vlek', False)],
          'vlekens': [('vlek', False)],
          'vleks-': [('vlek', False)],
          'vlen': [('vle', False)],
          'vlens': [('vle', False)],
          'vler': [('vel', False)],
          'vlerna': [('vel', False)],
          'vlers': [('vel', False)],
          'vlet': [('vel', False)],
          'vlets': [('vel', False)],
          'vlettens': [('vlett', False)],
          'vligans': [('vliga', False)],
          'vlighets': [('vlighet', False)],
          'vlin': [('vlina', False)],
          'vlin-': [('vlina', False)],
          'vlina': [('vlina', False)],
          'vline': [('vlina', False)],
          'vlinge': [('vlinge', False)],
          'vlinge-': [('vlinge', False)],
          'vlinget': [('vlinge', False)],
          'vlinne': [('vlinne', False)],
          'vlinne-': [('vlinne', False)],
          'vlinnes': [('vlinne', False)],
          'vlinnes-': [('vlinne', False)],
          'vlist': [('vlist', False)],
          'vlist-': [('vlist', False)],
          'vlningar': [('vlan', False)],
          'vloggar': [('vlogg', True)],
          'vlopp': [('vlopp', False)],
          'vlopps': [('vlopp', False)],
          'vlopps-': [('vlopp', False)],
          'vlor': [('vla', False)],
          'vlorna': [('vla', False)],
          'vlornas': [('vla', False)],
          'vlors': [('vla', False)],
          'vls': [('vle', False)],
          'vls-': [('vle', False)],
          'vläggar': [('vläggare', False)],
          'vläggarna': [('vläggare', False)],
          'vläggarnas': [('vläggare', False)],
          'vländer': [('vland', False)],
          'vländerna': [('vland', False)],
          'vländernas': [('vland', False)],
          'vländers': [('vland', False)],
          'vläns': [('vläns', False)],
          'vläns-': [('vläns', False)],
          'vläsandens': [('vläsande', False)],
          'vläsarna': [('vläsare', False)],
          'vlåtar': [('vlåtare', False)],
          'vlåtarna': [('vlåtare', False)],
          'vlåtarnas': [('vlåtare', False)],
          'vlön': [('vlön', False)],
          'vm-': [('vm', False)],
          'vmack': [('vmacka', False)],
          'vmack-': [('vmacka', False)],
          'vmacks': [('vmacka', False)],
          'vmacks-': [('vmacka', False)],
          'vman': [('vman', False)],
          'vmannen': [('vman', False)],
          'vmannens': [('vman', False)],
          'vmans': [('vman', False)],
          'vmask': [('vmask', False)],
          'vmask-': [('vmask', False)],
          'vmatt': [('vmatta', False)],
          'vmatt-': [('vmatta', False)],
          'vmatte': [('vmatta', False)],
          'vmatte-': [('vmatta', False)],
          'vmatts': [('vmatta', False)],
          'vmatts-': [('vmatta', False)],
          'vmil': [('vmil', False)],
          'vmil-': [('vmil', False)],
          'vmils': [('vmil', False)],
          'vmixer': [('vmixer', False)],
          'vmixerna': [('vmixer', False)],
          'vmixernas': [('vmixer', False)],
          'vmixers': [('vmixer', False)],
          'vmoder': [('vmoder', False)],
          'vmoder-': [('vmor', False)],
          'vmodern': [('vmor', False)],
          'vmoderns': [('vmor', False)],
          'vmoders': [('vmor', False)],
          'vmoders-': [('vmor', False)],
          'vmojs': [('vmoj', False)],
          'vmojs-': [('vmoj', False)],
          'vmopp': [('vmopp', False)],
          'vmoppar': [('vmopp', False)],
          'vmopparna': [('vmopp', False)],
          'vmopparnas': [('vmopp', False)],
          'vmoppars': [('vmopp', False)],
          'vmoppen': [('vmopp', False)],
          'vmoppens': [('vmopp', False)],
          'vmopps': [('vmopp', False)],
          'vmopps-': [('vmopp', False)],
          'vmor': [('vmor', False)],
          'vmor-': [('vmor', False)],
          'vmors': [('vmor', False)],
          'vmors-': [('vmor', False)],
          'vmoss': [('vmossa', False)],
          'vmoss-': [('vmossa', False)],
          'vmosse': [('vmosse', False)],
          'vmyr': [('vmyr', False)],
          'vmyrs': [('vmyr', False)],
          'vmyrs-': [('vmyr', False)],
          'vmän': [('vman', False)],
          'vmäns': [('vman', False)],
          'vmån': [('vmåne', False)],
          'vmån-': [('vmåne', False)],
          'vmåns': [('vmåne', False)],
          'vmåns-': [('vmåne', False)],
          'vmödrar': [('vmoder', False)],
          'vmödrarna': [('vmoder', False)],
          'vmödrarnas': [('vmoder', False)],
          'vmödrars': [('vmoder', False)],
          'vn': [('v', False)],
          'vnader': [('vnad', False)],
          'vnaderna': [('vnad', False)],
          'vnadernas': [('vnad', False)],
          'vnaders': [('vnad', False)],
          'vnads': [('vnad', False)],
          'vnads-': [('vnad', False)],
          'vnanden': [('vnande', False)],
          'vningskostnader': [('vningskostnader', False)],
          'vningskostnaderna': [('vningskostnader', False)],
          'vningskostnadernas': [('vningskostnader', False)],
          'vningskostnaders': [('vningskostnader', False)],
          'vningskostnads': [('vningskostnader', False)],
          'vningskostnads-': [('vningskostnader', False)],
          'vnot': [('vnot', False)],
          'vnot-': [('vnot', False)],
          'vnots': [('vnot', False)],
          'vnots-': [('vnot', False)],
          'vns': [('v', False)],
          'vnyp': [('vnyp', False)],
          'vnyp-': [('vnyp', False)],
          'vnyps': [('vnyp', False)],
          'vnyps-': [('vnyp', False)],
          'vo': [('va', False)],
          'vo-': [('va', False)],
          'vode': [('vode', False)],
          'voden': [('vode', False)],
          'vodens': [('vode', False)],
          'vodes': [('vode', False)],
          'vodes-': [('vode', False)],
          'vofficerare': [('vofficer', False)],
          'vofficerares': [('vofficer', False)],
          'vofficerarna': [('vofficer', False)],
          'vofficerarnas': [('vofficer', False)],
          'voffla': [('voffla', True)],
          'vofflas': [('voffla', True)],
          'voffle': [('voffla', True)],
          'voffle-': [('voffla', True)],
          'vofflor': [('voffla', True)],
          'voke': [('voke', False)],
          'voke-': [('voke', False)],
          'voken': [('voke', False)],
          'vokens': [('voke', False)],
          'vokerna': [('voke', False)],
          'voli': [('voli', False)],
          'volins': [('voli', False)],
          'volis': [('voli', False)],
          'volit': [('voli', False)],
          'volits': [('voli', False)],
          'volm': [('volm', False)],
          'volmarnas': [('volm', True)],
          'volmen': [('volm', True)],
          'volms-': [('volm', True)],
          'volt-': [('volt', False)],
          'voltan': [('voltan', True), ('volta', True)],
          'voltans': [('voltan', True), ('volta', True)],
          'volts': [('volt', False)],
          'volts-': [('volt', False)],
          'volverande': [('volverande', False)],
          'volverande-': [('volverande', False)],
          'volvon': [('volvo', True)],
          'volvons': [('volvo', True)],
          'vomb': [('vomb', True)],
          'vomb-': [('vomb', True)],
          'vombar': [('vomb', True)],
          'vombarna': [('vomb', True)],
          'vombarnas': [('vomb', True)],
          'vomben': [('vomb', True)],
          'vombens': [('vomb', True)],
          'vombs': [('vomb', True)],
          'vombs-': [('vomb', True)],
          'vommarna': [('vom', True)],
          'vområdets': [('vområde', False)],
          'voms': [('vom', True)],
          'voms-': [('vom', True)],
          'von': [('vo', False)],
          'vons': [('von', False)],
          'vons-': [('von', False)],
          'vord': [('vord', False)],
          'vord-': [('vord', False)],
          'vorden': [('vord', False)],
          'vordens': [('vord', False)],
          'vords': [('vord', False)],
          'vorian': [('vorian', False)],
          'vorians': [('vorian', False)],
          'vormar': [('vorm', False)],
          'vormarnas': [('vorm', False)],
          'vorna': [('vo', False)],
          'vornas': [('vo', False)],
          'vos': [('vo', False)],
          'vosarna': [('vo', False)],
          'vosen': [('vo', False)],
          'vosens': [('vo', False)],
          'vosot': [('vosot', False)],
          'vosten': [('vosten', False)],
          'vostens': [('vosten', False)],
          'vot': [('vot', False)],
          'votidens': [('votid', False)],
          'vots': [('vo', False)],
          'vott': [('vott', False)],
          'vott-': [('vott', False)],
          'votten': [('vott', False)],
          'votter': [('vott', False)],
          'votterna': [('vott', False)],
          'votternas': [('vott', False)],
          'votters': [('vott', False)],
          'votts': [('vott', False)],
          'voucherna': [('voucher', True)],
          'vouchers': [('voucher', True)],
          'vous': [('vous', False)],
          'vpack': [('vpack', False)],
          'vpacken': [('vpack', False)],
          'vpackens': [('vpack', False)],
          'vpacks': [('vpack', False)],
          'vpacks-': [('vpack', False)],
          'vpelar': [('vpelare', False)],
          'vpelar-': [('vpelare', False)],
          'vpillerna': [('vpiller', False)],
          'vpillers': [('vpiller', False)],
          'vpojk': [('vpojke', False)],
          'vpojk-': [('vpojke', False)],
          'vpojks': [('vpojke', False)],
          'vpojks-': [('vpojke', False)],
          'vportarnas': [('vport', False)],
          'vpott': [('vpotta', False)],
          'vpott-': [('vpotta', False)],
          'vpotts': [('vpotta', False)],
          'vpotts-': [('vpotta', False)],
          'vpressar': [('vpress', False)],
          'vpressarna': [('vpress', False)],
          'vpressarnas': [('vpress', False)],
          'vradens': [('vrad', False)],
          'vrak': [('vrak', False)],
          'vrak-': [('vrak', False)],
          'vraken': [('vrak', False)],
          'vrakens': [('vrak', False)],
          'vraket': [('vrak', False)],
          'vrakets': [('vrak', False)],
          'vraks': [('vrak', False)],
          'vraks-': [('vrak', False)],
          'vran': [('vran', False)],
          'vrande': [('vrande', False)],
          'vrande-': [('vrande', False)],
          'vranden': [('vrande', False)],
          'vrandens': [('vrande', False)],
          'vrandet': [('vrande', False)],
          'vrans': [('vran', False)],
          'vrans-': [('vran', False)],
          'vrarnas': [('ver', False)],
          'vras-': [('vras', False)],
          'vrasen': [('vras', False)],
          'vred': [('vred', False)],
          'vred-': [('vred', False)],
          'vreden': [('vrede', True), ('vred', True)],
          'vredens': [('vred', True), ('vrede', True)],
          'vredet': [('vred', False)],
          'vredets': [('vred', False)],
          'vreds': [('vred', True)],
          'vreds-': [('vred', False)],
          'vremmar': [('vrem', False)],
          'vremmarna': [('vrem', False)],
          'vremmarnas': [('vrem', False)],
          'vrems': [('vrem', False)],
          'vrems-': [('vrem', False)],
          'vren': [('ver', False)],
          'vrens': [('ver', False)],
          'vrens-': [('vrens', False)],
          'vrers': [('ver', False)],
          'vrese': [('vresa', False)],
          'vrese-': [('vresa', False)],
          'vret': [('vret', True)],
          'vretar': [('vret', True)],
          'vretarna': [('vret', True)],
          'vrets': [('vret', True)],
          'vrets-': [('vret', True)],
          'vrickar': [('vrickare', False)],
          'vrickarna': [('vrickare', False)],
          'vrighets': [('vrighet', False)],
          'vriket': [('vrike', False)],
          'vrikets': [('vrike', False)],
          'vrim': [('vrim', False)],
          'vrims': [('vrim', False)],
          'vrims-': [('vrim', False)],
          'vringar': [('vring', False)],
          'vringarna': [('vring', False)],
          'vringarnas': [('vring', False)],
          'vrisk': [('vrisk', False)],
          'vrisk-': [('vrisk', False)],
          'vromans': [('vroman', False)],
          'vropen': [('vrop', False)],
          'vrops': [('vrop', False)],
          'vrull': [('vrulle', False)],
          'vrull-': [('vrulle', False)],
          'vrulle': [('vrulle', False)],
          'vrulle-': [('vrulle', False)],
          'vrulls': [('vrulle', False)],
          'vrulls-': [('vrulle', False)],
          'vrum': [('vrum', False)],
          'vrums-': [('vrum', False)],
          'vrusk': [('vruska', False)],
          'vrusk-': [('vruska', False)],
          'vräder': [('vräd', False)],
          'vräds-': [('vräd', False)],
          'vräknarnas': [('vräknare', False)],
          'vrängar': [('vrängare', False)],
          'vrängarna': [('vrängare', False)],
          'vrängarnas': [('vrängare', False)],
          'vråden': [('vråd', False)],
          'vråk': [('vråk', False)],
          'vråk-': [('vråk', False)],
          'vråkar': [('vråk', False)],
          'vråkarna': [('vråk', False)],
          'vråkars': [('vråk', False)],
          'vråken': [('vråk', False)],
          'vråkens': [('vråk', True)],
          'vråks': [('vråk', True)],
          'vråks-': [('vråk', True)],
          'vrål': [('vrål', False)],
          'vrål-': [('vrål', False)],
          'vrålens': [('vrål', False)],
          'vråls': [('vrål', True)],
          'vråls-': [('vrål', True)],
          'vrån': [('vrå', True)],
          'vråns': [('vrå', False)],
          'vs': [('v', True)],
          'vsalen': [('vsal', False)],
          'vsalens': [('vsal', False)],
          'vsats': [('vsats', False)],
          'vsats-': [('vsats', False)],
          'vsaxar': [('vsax', False)],
          'vsaxarna': [('vsax', False)],
          'vsaxarnas': [('vsax', False)],
          'vsel': [('vsel', False)],
          'vsel-': [('vsel', False)],
          'vsels': [('vsel', False)],
          'vsen': [('vs', False)],
          'vsens': [('vsena', False)],
          'vserfarenheter': [('vserfarenhet', False)],
          'vserfarenheterna': [('vserfarenhet', False)],
          'vserfarenheternas': [('vserfarenhet', False)],
          'vserfarenheters': [('vserfarenhet', False)],
          'vserfarenhets': [('vserfarenhet', False)],
          'vserfarenhets-': [('vserfarenhet', False)],
          'vset': [('vs', False)],
          'vsets': [('vs', False)],
          'vsfaktorer': [('vsfaktor', False)],
          'vsfaktorers': [('vsfaktor', False)],
          'vsfiskar': [('vsfisk', False)],
          'vsfiskarna': [('vsfisk', False)],
          'vsikten': [('vsikt', False)],
          'vsiktens': [('vsikt', False)],
          'vsilen': [('vsil', False)],
          'vsilens': [('vsil', False)],
          'vsis': [('vsis', False)],
          'vskallen': [('vskalle', False)],
          'vskallens': [('vskalle', False)],
          'vskaps-': [('vskap', False)],
          'vskedanden': [('vskedande', False)],
          'vskedandens': [('vskedande', False)],
          'vskeden': [('vsked', False)],
          'vskedens': [('vsked', False)],
          'vskedet': [('vsked', False)],
          'vskedets': [('vsked', False)],
          'vskiften': [('vskifte', False)],
          'vskiftens': [('vskifte', False)],
          'vskiftet': [('vskifte', False)],
          'vskiftets': [('vskifte', False)],
          'vskops': [('vskopa', False)],
          'vskops-': [('vskopa', False)],
          'vskrap': [('vskrap', False)],
          'vskraps': [('vskrap', False)],
          'vskraps-': [('vskrap', False)],
          'vskrik': [('vskrika', False)],
          'vskrik-': [('vskrika', False)],
          'vskriks': [('vskrika', False)],
          'vskriks-': [('vskrika', False)],
          'vskris': [('vskris', False)],
          'vskytten': [('vskytt', False)],
          'vskyttens': [('vskytt', False)],
          'vskäll': [('vskälla', False)],
          'vskäll-': [('vskälla', False)],
          'vskälls': [('vskälla', False)],
          'vskälls-': [('vskälla', False)],
          'vskärmar': [('vskärm', False)],
          'vskärmarnas': [('vskärm', False)],
          'vslag': [('vslag', False)],
          'vslagar': [('vslagare', False)],
          'vslagarna': [('vslagare', False)],
          'vslagarnas': [('vslagare', False)],
          'vslags': [('vslag', False)],
          'vslags-': [('vslag', False)],
          'vslandet': [('vsland', False)],
          'vslickar': [('vslickare', False)],
          'vslickarna': [('vslickare', False)],
          'vslickarnas': [('vslickare', False)],
          'vslid': [('vslida', False)],
          'vslid-': [('vslida', False)],
          'vslids': [('vslida', False)],
          'vslids-': [('vslida', False)],
          'vslotts': [('vslott', False)],
          'vsmodet': [('vsmod', False)],
          'vsmodets': [('vsmod', False)],
          'vsnäpp': [('vsnäppa', False)],
          'vsnäpp-': [('vsnäppa', False)],
          'vsnäpps': [('vsnäppa', False)],
          'vsnäpps-': [('vsnäppa', False)],
          'vsnåret': [('vsnåret', False)],
          'vsnårets': [('vsnåret', False)],
          'vsolvens': [('vsolv', False)],
          'vson': [('vson', False)],
          'vsons': [('vson', False)],
          'vspad': [('vspade', False)],
          'vspad-': [('vspade', False)],
          'vspads': [('vspade', False)],
          'vspads-': [('vspade', False)],
          'vsstans': [('vsstans', False)],
          'vstammar': [('vstam', False)],
          'vstammarna': [('vstam', False)],
          'vstammarnas': [('vstam', False)],
          'vstampen': [('vstamp', False)],
          'vstampens': [('vstamp', False)],
          'vstarter': [('vstart', False)],
          'vstarterna': [('vstart', False)],
          'vstarternas': [('vstart', False)],
          'vstarters': [('vstart', False)],
          'vsteg': [('vsteg', False)],
          'vsteg-': [('vsteg', False)],
          'vstegen': [('vsteg', False)],
          'vstegens': [('vsteg', False)],
          'vstegs': [('vsteg', False)],
          'vstegs-': [('vsteg', False)],
          'vstekar': [('vstek', False)],
          'vstekarna': [('vstek', False)],
          'vstekarnas': [('vstek', False)],
          'vsten': [('vsten', False)],
          'vstigar': [('vstigare', False)],
          'vstigarna': [('vstigare', False)],
          'vstigarnas': [('vstigare', False)],
          'vstol': [('vstol', False)],
          'vstol-': [('vstol', False)],
          'vstols': [('vstol', False)],
          'vstols-': [('vstol', False)],
          'vstoppar': [('vstopp', False)],
          'vstopparna': [('vstopp', False)],
          'vstruts': [('vstrut', False)],
          'vstruts-': [('vstrut', False)],
          'vsträna': [('vsträd', False)],
          'vstränas': [('vsträd', False)],
          'vstudie': [('vstudie', False)],
          'vstudie-': [('vstudium', False)],
          'vstudier': [('vstudie', False)],
          'vstudierna': [('vstudie', False)],
          'vstudiernas': [('vstudium', False)],
          'vstudiers': [('vstudium', False)],
          'vstump': [('vstump', False)],
          'vstump-': [('vstump', False)],
          'vstumps': [('vstump', False)],
          'vstumps-': [('vstump', False)],
          'vstycken': [('vstycke', False)],
          'vstyckena': [('vstycke', False)],
          'vstyckenas': [('vstycke', False)],
          'vstyckens': [('vstycke', False)],
          'vstycket': [('vstycke', False)],
          'vstyckets': [('vstycke', False)],
          'vstycks': [('vstycke', False)],
          'vstyren': [('vstyre', False)],
          'vstyrens': [('vstyre', False)],
          'vställandena': [('vställande', False)],
          'vställandenas': [('vställande', False)],
          'vställandens': [('vställande', False)],
          'vställen': [('vställ', False)],
          'vställens': [('vställ', False)],
          'vstället': [('vställ', False)],
          'vställets': [('vställ', False)],
          'vställningar': [('vställning', False)],
          'vställningarna': [('vställning', False)],
          'vställningarnas': [('vställning', False)],
          'vställningars': [('vställning', False)],
          'vställnings': [('vställning', False)],
          'vställnings-': [('vställning', False)],
          'vstövlars': [('vstövel', False)],
          'vsug': [('vsug', False)],
          'vsval': [('vsval', False)],
          'vsvalen': [('vsval', False)],
          'vsvalens': [('vsval', False)],
          'vsvals': [('vsval', False)],
          'vsvals-': [('vsval', False)],
          'vsvans': [('vsvans', False)],
          'vsvans-': [('vsvans', False)],
          'vsverken': [('vsverk', False)],
          'vsverkens': [('vsverk', False)],
          'vsverket': [('vsverk', False)],
          'vsverks': [('vsverk', False)],
          'vsverks-': [('vsverk', False)],
          'vsvikar': [('vsvik', False)],
          'vsvikarna': [('vsvik', False)],
          'vsvikarnas': [('vsvik', False)],
          'vsylt': [('vsylta', False)],
          'vsylt-': [('vsylta', False)],
          'vsylts': [('vsylta', False)],
          'vsylts-': [('vsylta', False)],
          'vsyre': [('vsyra', False)],
          'vsyre-': [('vsyra', False)],
          'vsändarna': [('vsändare', False)],
          'vsänke': [('vsänka', False)],
          'vsänks': [('vsänka', False)],
          'vsänks-': [('vsänka', False)],
          'vsörn': [('vsörn', False)],
          'vt': [('vt', False)],
          'vtagen': [('vtag', False)],
          'vtagens': [('vtag', False)],
          'vtaget': [('vtag', False)],
          'vtaggar': [('vtaggare', False)],
          'vtaggarna': [('vtaggare', False)],
          'vtaggarnas': [('vtaggare', False)],
          'vtaken': [('vtak', False)],
          'vtaket': [('vtak', False)],
          'vtalandenas': [('vtalande', False)],
          'vtalandens': [('vtalande', False)],
          'vtalen': [('vtal', False)],
          'vtalens': [('vtal', False)],
          'vtalet': [('vtal', False)],
          'vtant-': [('vtant', False)],
          'vten': [('vit', False)],
          'vtens': [('vit', False)],
          'vter': [('vt', False)],
          'vterna': [('vt', False)],
          'vternas': [('vt', False)],
          'vters': [('vt', False)],
          'vtestens': [('vtest', False)],
          'vtet': [('vit', False)],
          'vtets': [('vit', False)],
          'vtiden': [('vtid', False)],
          'vtider': [('vtid', False)],
          'vtiders': [('vtid', False)],
          'vtim': [('vtimme', False)],
          'vtim-': [('vtimme', False)],
          'vtittar': [('vtitt', False)],
          'vtittarna': [('vtitt', False)],
          'vtittarnas': [('vtitt', False)],
          'vtonerna': [('vton', False)],
          'vtrapp': [('vtrappa', False)],
          'vtrapp-': [('vtrappa', False)],
          'vtrapps': [('vtrappa', False)],
          'vtrapps-': [('vtrappa', False)],
          'vtrycken': [('vtryck', False)],
          'vtryckens': [('vtryck', False)],
          'vtrycket': [('vtryck', False)],
          'vtryckets': [('vtryck', False)],
          'vtrycks': [('vtryck', False)],
          'vtrycks-': [('vtryck', False)],
          'vträd': [('vträd', False)],
          'vträd-': [('vträd', False)],
          'vträde': [('vträde', False)],
          'vträden': [('vträd', False)],
          'vträdens': [('vträd', False)],
          'vträdet': [('vträd', False)],
          'vträdets': [('vträd', False)],
          'vträds': [('vträd', False)],
          'vträn': [('vträd', False)],
          'vträna': [('vträd', False)],
          'vtränas': [('vträd', False)],
          'vträns': [('vträd', False)],
          'vträt': [('vträ', False)],
          'vträts': [('vträ', False)],
          'vts': [('vt', False)],
          'vts-': [('vt', False)],
          'vtum': [('vtum', False)],
          'vtum-': [('vtum', False)],
          'vtummen': [('vtum', False)],
          'vtummens': [('vtum', False)],
          'vtums': [('vtum', False)],
          'vtums-': [('vtum', False)],
          'vturer': [('vtur', False)],
          'vturers': [('vtur', False)],
          'vturs': [('vtur', False)],
          'vturs-': [('vtur', False)],
          'vtving': [('vtving', False)],
          'vtvingar': [('vtving', False)],
          'vtvingars': [('vtving', False)],
          'vtvingen': [('vtving', False)],
          'vtänger': [('vtång', False)],
          'vtängers': [('vtång', False)],
          'vtåg': [('vtåg', False)],
          'vtågs': [('vtåg', False)],
          'vtågs-': [('vtåg', False)],
          'vtång': [('vtång', False)],
          'vtång-': [('vtång', False)],
          'vtången': [('vtång', False)],
          'vtångens': [('vtång', False)],
          'vtångs': [('vtång', False)],
          'vular': [('vular', False)],
          'vulars': [('vular', False)],
          'vulkans': [('vulkan', True)],
          'vulster': [('vulst', False)],
          'vulsters': [('vulst', False)],
          'vund': [('vund', False)],
          'vund-': [('vund', False)],
          'vunds': [('vund', False)],
          'vunds-': [('vund', False)],
          'vung': [('vung', False)],
          'vung-': [('vung', False)],
          'vungen': [('vung', False)],
          'vungens': [('vung', False)],
          'vungs': [('vung', False)],
          'vurmanden': [('vurmande', True)],
          'vurnas': [('vurna', False)],
          'vurne': [('vurna', False)],
          'vurstens': [('vurst', False)],
          'vval': [('vval', False)],
          'vvant': [('vvante', False)],
          'vvant-': [('vvante', False)],
          'vvante': [('vvante', False)],
          'vvanten': [('vvante', False)],
          'vvantens': [('vvante', False)],
          'vvants': [('vvante', False)],
          'vvants-': [('vvante', False)],
          'vvar': [('vve', False)],
          'vvarnas': [('vve', False)],
          'vvars': [('vve', False)],
          'vven': [('vve', False)],
          'vvens': [('vve', False)],
          'vvikar': [('vvikare', False)],
          'vvikarna': [('vvikare', False)],
          'vvikarnas': [('vvikare', False)],
          'vvis': [('vvisa', False)],
          'vvis-': [('vvisa', False)],
          'vvisa': [('vvisa', False)],
          'vvisar': [('vvisare', False)],
          'vvisarna': [('vvisare', False)],
          'vvisarnas': [('vvisare', False)],
          'vvisas': [('vvisa', False)],
          'vvise': [('vvisa', False)],
          'vvisor': [('vvisa', False)],
          'vvo': [('vvo', False)],
          'vvo-': [('vvo', False)],
          'vvons': [('vvo', False)],
          'vvor': [('vvo', False)],
          'vvors': [('vvo', False)],
          'vvot': [('vvo', False)],
          'vvägar': [('vväg', False)],
          'vvägarna': [('vväg', False)],
          'vvägarnas': [('vväg', False)],
          'vvägars': [('vväg', False)],
          'vvägs': [('vväg', False)],
          'vväxlar': [('vväxel', False)],
          'vväxlarna': [('vväxel', False)],
          'vväxlarnas': [('vväxel', False)],
          'vvågar': [('vvåg', False)],
          'vvågarna': [('vvåg', False)],
          'vvårdar': [('vvårdare', False)],
          'vvårdarna': [('vvårdare', False)],
          'vvårdarnas': [('vvård', False)],
          'vy': [('vy', True)],
          'vy-': [('vy', False)],
          'vyer': [('vy', False)],
          'vyerna': [('vy', False)],
          'vyernas': [('vy', False)],
          'vyers': [('vy', True)],
          'vyn': [('vy', False)],
          'vyns': [('vy', False)],
          'vyrers': [('vyr', False)],
          'vys': [('vy', False)],
          'vyx': [('vyxa', False)],
          'vyx-': [('vyxa', False)],
          'väckarnas': [('väckare', True)],
          'väcke': [('väcka', True)],
          'vädd': [('vädd', True)],
          'vädden': [('vädd', True)],
          'väddens': [('vädd', True)],
          'vädds': [('vädd', True)],
          'vädds-': [('vädd', True)],
          'väde': [('väde', False)],
          'väden': [('väde', False)],
          'vädens': [('väde', False)],
          'väder': [('väder', False)],
          'väderna': [('väder', False)],
          'vädernas': [('väder', False)],
          'väders': [('väder', False)],
          'vädes': [('väde', False)],
          'vädes-': [('väde', False)],
          'vädet': [('väde', False)],
          'väds': [('väde', False)],
          'väds-': [('väde', False)],
          'väft': [('väft', True)],
          'väft-': [('väft', True)],
          'väften': [('väft', True)],
          'väftens': [('väft', True)],
          'väfts': [('väft', True)],
          'väfts-': [('väft', True)],
          'väg': [('väg', False)],
          'väg-': [('väg', True)],
          'vägar': [('väg', True), ('vägare', True)],
          'vägarna': [('väg', True), ('vägare', True)],
          'vägarnas': [('väg', True), ('vägare', True)],
          'vägars': [('väg', True)],
          'vägen': [('väg', True)],
          'vägens': [('väg', False)],
          'vägg': [('vägg', False)],
          'vägg-': [('vägg', False)],
          'väggarna': [('vägg', False)],
          'väggarnas': [('vägg', False)],
          'väggs': [('vägg', False)],
          'väggs-': [('vägg', False)],
          'vägrar': [('vägrare', False)],
          'vägrarna': [('vägrare', True)],
          'vägren': [('vägren', True)],
          'vägrens': [('vägren', True)],
          'vägs': [('väg', True)],
          'vägs-': [('väg', True)],
          'väkarna': [('väkare', False)],
          'väkt': [('väkt', False)],
          'väkt-': [('väkt', True)],
          'väktarnas': [('väktare', True)],
          'väkten': [('väkt', True)],
          'väktens': [('väkt', False)],
          'väkts': [('väkt', False)],
          'väkts-': [('väkt', False)],
          'välden': [('väld', True), ('välde', True)],
          'väldens': [('väld', True), ('välde', True)],
          'välds': [('väld', False)],
          'välds-': [('väld', True)],
          'väll': [('väll', False)],
          'väll-': [('väll', False)],
          'vällanden': [('vällande', False)],
          'vällandena': [('vällande', False)],
          'vällandenas': [('vällande', False)],
          'vällandens': [('vällande', False)],
          'vällar': [('väll', False)],
          'vällars': [('väll', False)],
          'vällen': [('väll', False)],
          'vällningar': [('vällning', False)],
          'vällningarna': [('vällning', False)],
          'vällningarnas': [('vällning', False)],
          'vällningars': [('vällning', False)],
          'vällnings': [('vällning', False)],
          'vällnings-': [('vällning', False)],
          'välls': [('väll', False)],
          'välls-': [('väll', False)],
          'väls': [('väl', True)],
          'välskan': [('välska', False)],
          'välskans': [('välska', False)],
          'vält': [('välta', True), ('vält', True)],
          'vält-': [('vält', True), ('välta', True)],
          'vältar': [('vält', True)],
          'vältarna': [('vält', False)],
          'vältarnas': [('vält', True)],
          'vältars': [('vält', False)],
          'välte': [('välta', True)],
          'välte-': [('välta', True)],
          'välten': [('vält', True)],
          'vältens': [('vält', False)],
          'välts': [('vält', True), ('välta', True)],
          'välts-': [('vält', True), ('välta', True)],
          'väm': [('väm', False)],
          'vän': [('vän', False)],
          'vänd': [('vända', False)],
          'vänd-': [('vända', True)],
          'vändar': [('vände', False)],
          'vändarna': [('vände', False)],
          'vändarnas': [('vändare', False)],
          'vände': [('vända', False)],
          'vände-': [('vända', True)],
          'vänds': [('vända', False)],
          'vänds-': [('vända', False)],
          'väng': [('väng', False)],
          'vängar': [('väng', False)],
          'vängarna': [('väng', False)],
          'vängarnas': [('väng', False)],
          'vängen': [('väng', False)],
          'vängens': [('väng', False)],
          'vängs': [('väng', False)],
          'vängs-': [('väng', False)],
          'vännen': [('vän', False)],
          'vännens': [('vän', False)],
          'väns': [('vän', False)],
          'vänster': [('vänster', True)],
          'vänsters': [('vänster', False)],
          'väntan': [('väntan', False)],
          'värd': [('värd', False)],
          'värd-': [('värd', True)],
          'värdar': [('värd', True)],
          'värdarna': [('värd', False)],
          'värdars': [('värd', False)],
          'värden': [('värde', True), ('värd', True)],
          'värdens': [('värde', True), ('värd', True)],
          'värdet': [('värde', True)],
          'värdets': [('värde', False)],
          'värds': [('värd', False)],
          'värds-': [('värd', False)],
          'värgar': [('värg', False)],
          'värgarna': [('värg', False)],
          'värgarnas': [('värg', False)],
          'värgen': [('värg', False)],
          'värgens': [('värg', False)],
          'värgs': [('värg', False)],
          'värgs-': [('värg', False)],
          'värje': [('värja', True)],
          'värk': [('värk', False)],
          'värk-': [('värk', True)],
          'värkar': [('värk', True)],
          'värkarna': [('värk', False)],
          'värken': [('värk', False)],
          'värkens': [('värk', False)],
          'värks': [('värk', False)],
          'värks-': [('värk', False)],
          'värmen': [('värme', False)],
          'värmens': [('värme', False)],
          'värmets': [('värme', False)],
          'värn': [('värn', False)],
          'värn-': [('värn', False)],
          'värns': [('värn', True)],
          'värns-': [('värn', False)],
          'värt': [('värta', False)],
          'värt-': [('värta', False)],
          'värtanden': [('värtande', False)],
          'värtandens': [('värtande', False)],
          'värts': [('värta', False)],
          'värts-': [('värta', False)],
          'värv': [('värv', False)],
          'värv-': [('värv', False)],
          'värven': [('värv', True)],
          'värvens': [('värv', True)],
          'värvs': [('värv', False)],
          'värvs-': [('värv', True)],
          'väsen': [('väsen', False)],
          'väsendet': [('väsende', True)],
          'väsendets': [('väsende', False)],
          'väsens': [('väsen', False)],
          'väskorna': [('väska', False)],
          'väskornas': [('väska', False)],
          'väskors': [('väska', False)],
          'vässar': [('vässare', False)],
          'vässarna': [('vässare', False)],
          'vässarnas': [('vässare', False)],
          'väst-': [('väst', False)],
          'västan': [('västan', True)],
          'västans': [('västan', True)],
          'västarna': [('väst', False)],
          'västen': [('väst', True)],
          'västens': [('väst', False)],
          'väte': [('väte', False)],
          'väte-': [('väte', False)],
          'väten': [('väte', False)],
          'vätens': [('väte', False)],
          'vätet': [('väte', False)],
          'väts': [('väte', False)],
          'väts-': [('väte', False)],
          'vätt': [('vätte', True)],
          'vätt-': [('vätte', True)],
          'vättar': [('vätte', True)],
          'vättarna': [('vätte', True)],
          'vättarnas': [('vätte', True)],
          'vättars': [('vätte', True)],
          'vätte': [('vätte', True)],
          'vätte-': [('vätta', False)],
          'vätten': [('vätte', True)],
          'vättens': [('vätte', True)],
          'vätterskor': [('vätterska', False)],
          'vätterskorna': [('vätterska', False)],
          'vätterskornas': [('vätterska', False)],
          'vätterskors': [('vätterska', False)],
          'vätts': [('vätte', True)],
          'vätts-': [('vätte', True)],
          'väv': [('väv', False)],
          'väv-': [('väv', True)],
          'vävar': [('vävare', True), ('väv', True)],
          'vävar-': [('vävare', False)],
          'vävarna': [('väv', True), ('vävare', True)],
          'vävarnas': [('väv', True), ('vävare', True)],
          'väve': [('väve', False)],
          'väve-': [('väve', False)],
          'vävet': [('väve', False)],
          'växlar': [('växel', True), ('växlare', True)],
          'växlarna': [('växel', True), ('växlare', True)],
          'växlarnas': [('växlare', True), ('växel', True)],
          'vå': [('vå', False)],
          'vå-': [('vå', False)],
          'våd': [('våd', False)],
          'våd-': [('våd', True)],
          'våder': [('våd', True)],
          'våders': [('våd', True)],
          'våds': [('våd', True)],
          'våds-': [('våd', False)],
          'vågar': [('våg', True)],
          'vågarna': [('våg', True)],
          'vågarnas': [('våg', False)],
          'vågor': [('våg', False)],
          'vågorna': [('våg', False)],
          'vågornas': [('våg', False)],
          'vågors': [('våg', False)],
          'vål': [('våle', True)],
          'vål-': [('våle', True)],
          'vålar': [('våle', True)],
          'vålarna': [('våle', True)],
          'vålarnas': [('våle', True)],
          'vålars': [('våle', True)],
          'våle': [('våle', True)],
          'vålen': [('våle', True)],
          'vålens': [('våle', True)],
          'vålighets-': [('vålighet', False)],
          'vållan': [('vållan', False)],
          'vållans': [('vållan', False)],
          'våls': [('våle', True)],
          'våls-': [('våle', True)],
          'vån': [('vån', True)],
          'vånarna': [('vånare', False)],
          'vång': [('vång', False)],
          'vång-': [('vång', True)],
          'vångar': [('vång', True)],
          'vångarna': [('vång', True)],
          'vångarnas': [('vång', True)],
          'vångars': [('vång', True)],
          'vången': [('vång', True)],
          'vångens': [('vång', False)],
          'vångs': [('vång', False)],
          'vångs-': [('vång', False)],
          'våns': [('vån', True)],
          'vår': [('vår', False)],
          'vår-': [('vår', False)],
          'vårar': [('vår', True)],
          'vårarna': [('vår', False)],
          'vårarnas': [('vår', True)],
          'våras': [('våras', True)],
          'vård': [('vård', False)],
          'vård-': [('vård', True)],
          'vårdar': [('vård', True), ('vårdare', True)],
          'vårdarna': [('vårdare', True), ('vård', True)],
          'vårdarnas': [('vård', True), ('vårdare', True)],
          'vårder': [('vård', True)],
          'vårderna': [('vård', True)],
          'vårdernas': [('vård', True)],
          'vårders': [('vård', True)],
          'vårds': [('vård', False)],
          'vårds-': [('vård', False)],
          'vårs': [('vår', True)],
          'vårs-': [('vår', False)],
          'vås': [('vå', False)],
          'våtiden': [('våtiden', False)],
          'vöar': [('vö', False)],
          'vöarna': [('vö', False)],
          'vören': [('vör', False)],
          'vörens': [('vör', False)],
          'vörten': [('vört', True)],
          'vös': [('vö', False)],
          'vös-': [('vös', False)],
          'wa-': [('wa', False)],
          'wafer': [('wafer', True)],
          'wafers': [('wafer', True)],
          'wafersen': [('wafer', True)],
          'wagon': [('wagon', True)],
          'wagons': [('wagon', True)],
          'walk': [('walk', False)],
          'walk-': [('walk', False)],
          'walker': [('walk', False)],
          'walkers': [('walk', False)],
          'walkover': [('walkover', True)],
          'walkovers': [('walkover', True)],
          'walks': [('walk', False)],
          'wam': [('wam', False)],
          'wam-': [('wam', False)],
          'wamers': [('wam', False)],
          'wams': [('wam', False)],
          'wan': [('wa', False)],
          'wanden': [('wande', False)],
          'wandens': [('wande', False)],
          'wandets': [('wande', False)],
          'wandierna': [('wandier', False)],
          'wandiernas': [('wandier', False)],
          'wandiers': [('wandier', False)],
          'wanier': [('wanier', False)],
          'wanierna': [('wanier', False)],
          'waniernas': [('wanier', False)],
          'wans': [('wa', False)],
          'ward': [('ward', False)],
          'ward-': [('ward', False)],
          'wardar': [('ward', False)],
          'wardarna': [('ward', False)],
          'wardars': [('ward', False)],
          'warden': [('ward', False)],
          'wardens': [('ward', False)],
          'warder': [('ward', False)],
          'warderna': [('ward', False)],
          'wardernas': [('ward', False)],
          'warders': [('ward', False)],
          'wards': [('ward', False)],
          'wards-': [('ward', False)],
          'ware': [('ware', False)],
          'ware-': [('ware', False)],
          'waren': [('ware', False)],
          'warens': [('ware', False)],
          'wares': [('ware', False)],
          'wart': [('wart', False)],
          'wartar': [('wart', False)],
          'wartars': [('wart', False)],
          'wartens': [('wart', False)],
          'warterna': [('wart', False)],
          'warters': [('wart', False)],
          'was': [('wa', False)],
          'water': [('water', True)],
          'watt': [('watt', False)],
          'watt-': [('watt', False)],
          'watten': [('watt', False)],
          'watts': [('watt', False)],
          'ways': [('way', False)],
          'ways-': [('way', False)],
          'wc': [('wc', True)],
          'wcen': [('wc', True)],
          'wcens': [('wc', True)],
          'weben': [('web', True)],
          'weet': [('weet', False)],
          'wen': [('w', False)],
          'wens': [('w', False)],
          'wer': [('w', False)],
          'wers': [('w', False)],
          'western': [('western', True)],
          'westerna': [('western', True)],
          'westernas': [('western', True)],
          'westerns': [('western', False)],
          'wets': [('w', False)],
          'wförar': [('wförare', False)],
          'wförarna': [('wförare', False)],
          'wförarnas': [('wförare', False)],
          'whippet': [('whippet', True)],
          'whippets': [('whippet', True)],
          'wi-': [('wi', False)],
          'wichen': [('wich', False)],
          'wichens': [('wich', False)],
          'wier': [('wier', False)],
          'wierna': [('wi', False)],
          'wiernas': [('wi', False)],
          'wiers': [('wi', False)],
          'wikier': [('wiki', True)],
          'wikierna': [('wiki', True)],
          'wikiernas': [('wiki', True)],
          'wikiers': [('wiki', True)],
          'wikins': [('wiki', True)],
          'will': [('will', False)],
          'will-': [('will', False)],
          'willen': [('will', False)],
          'wills': [('will', False)],
          'wing': [('wing', False)],
          'wing-': [('wing', False)],
          'wingar': [('wing', False)],
          'wingarna': [('wing', False)],
          'wingarnas': [('wing', False)],
          'wingars': [('wing', False)],
          'wingen': [('wing', False)],
          'wingens': [('wing', False)],
          'wings': [('wing', False)],
          'wings-': [('wing', False)],
          'winister': [('winist', False)],
          'winisters': [('winist', False)],
          'wir': [('wire', True)],
          'wir-': [('wire', True)],
          'wirar': [('wire', True)],
          'wirarna': [('wire', True)],
          'wirars': [('wire', False)],
          'wire': [('wire', False)],
          'wire-': [('wire', False)],
          'wiren': [('wire', True)],
          'wirens': [('wire', False)],
          'wires': [('wire', False)],
          'wires-': [('wire', True)],
          'wirs': [('wire', True)],
          'wirs-': [('wire', True)],
          'wis': [('wi', False)],
          'wiskan': [('wiska', False)],
          'wiskans': [('wiska', False)],
          'wiske': [('wiska', False)],
          'wiske-': [('wiska', False)],
          'wist-': [('wist', False)],
          'wisten': [('wist', False)],
          'wistens': [('wist', False)],
          'wittrarnas': [('wittrare', False)],
          'wk-': [('wk', False)],
          'wken': [('wk', False)],
          'wkens': [('wk', False)],
          'wker': [('wk', False)],
          'wkerna': [('wk', False)],
          'wkernas': [('wk', False)],
          'wkers': [('wk', False)],
          'wks': [('wk', False)],
          'wl': [('wl', False)],
          'wl-': [('wl', False)],
          'wlanden': [('wlande', False)],
          'wlandena': [('wlande', False)],
          'wlandenas': [('wlande', False)],
          'wlandens': [('wlande', False)],
          'wlandet': [('wlande', False)],
          'wlandets': [('wlande', False)],
          'wlar': [('wlare', False)],
          'wlaren': [('wlare', False)],
          'wlarna': [('wlare', False)],
          'wlarnas': [('wlare', False)],
          'wlen': [('wl', False)],
          'wlens': [('wl', False)],
          'wler': [('wl', False)],
          'wlerna': [('wl', False)],
          'wlernas': [('wl', False)],
          'wlers': [('wl', False)],
          'wn': [('wn', False)],
          'wn-': [('wn', False)],
          'wnen': [('wn', False)],
          'wnens': [('wn', False)],
          'wner': [('wn', False)],
          'wnerier': [('wneri', False)],
          'wnerierna': [('wneri', False)],
          'wneriernas': [('wneri', False)],
          'wneriers': [('wneri', False)],
          'wnerna': [('wn', False)],
          'wnernas': [('wn', False)],
          'wners': [('wn', False)],
          'wns': [('w', False)],
          'wns-': [('wn', False)],
          'wnötter': [('wnöt', False)],
          'wnötterna': [('wnöt', False)],
          'wokarnas': [('wok', True)],
          'wor': [('wa', False)],
          'wors': [('wa', False)],
          'wouten': [('wout', False)],
          'woutens': [('wout', False)],
          'wouter': [('wout', False)],
          'wouterna': [('wout', False)],
          'wouternas': [('wout', False)],
          'wouters': [('wout', False)],
          'wprogrammet': [('wprogram', False)],
          'writer': [('writer', False)],
          'writers': [('writer', False)],
          'wrot': [('wrot', False)],
          'wroten': [('wrot', False)],
          'wrotens': [('wrot', False)],
          'wrots': [('wrot', False)],
          'wrots-': [('wrot', False)],
          'wrötter': [('wrot', False)],
          'wrötterna': [('wrot', False)],
          'wrötternas': [('wrot', False)],
          'wrötters': [('wrot', False)],
          'ws': [('w', False)],
          'ws-': [('w', False)],
          'wsen': [('w', False)],
          'wsens': [('w', False)],
          'wton': [('wton', False)],
          'wung': [('wung', False)],
          'wung-': [('wung', False)],
          'wungen': [('wung', False)],
          'wungens': [('wung', False)],
          'wungs': [('wung', False)],
          'wvärden': [('wvärd', False)],
          'wvärdens': [('wvärd', False)],
          'x': [('x', True)],
          'x-': [('x', True)],
          'x-systemet': [('x-system', False)],
          'xa': [('xa', False)],
          'xafen': [('xafen', False)],
          'xafens': [('xafen', False)],
          'xakter': [('xakt', False)],
          'xakters': [('xakt', False)],
          'xamen': [('xamen', False)],
          'xamens': [('xamen', False)],
          'xameter': [('xameter', False)],
          'xameters': [('xameter', False)],
          'xan': [('xa', False)],
          'xanden': [('xande', False)],
          'xandens': [('xande', False)],
          'xandets': [('xande', False)],
          'xandrin': [('xandrin', False)],
          'xans': [('xa', False)],
          'xar': [('xare', False)],
          'xar-': [('xare', False)],
          'xare': [('xare', False)],
          'xaren': [('xare', False)],
          'xarens': [('xare', False)],
          'xares': [('xare', False)],
          'xarmar': [('xarm', False)],
          'xarmarna': [('xarm', False)],
          'xarmarnas': [('xarm', False)],
          'xarna': [('xare', False)],
          'xarnas': [('xare', False)],
          'xars': [('xe', False)],
          'xas': [('xa', False)],
          'xation': [('xation', False)],
          'xationen': [('xation', False)],
          'xations': [('xation', False)],
          'xativets': [('xativ', False)],
          'xbarnsmodern': [('xbarnsmoder', False)],
          'xbarnsmoderns': [('xbarnsmoder', False)],
          'xbarnsmoders': [('xbarnsmoder', False)],
          'xbarnsmoders-': [('xbarnsmoder', False)],
          'xben': [('xben', False)],
          'xbens': [('xben', False)],
          'xbens-': [('xben', False)],
          'xbil': [('xbil', False)],
          'xbilar': [('xbil', False)],
          'xbilars': [('xbil', False)],
          'xbils': [('xbil', False)],
          'xbils-': [('xbil', False)],
          'xblom': [('xblomma', False)],
          'xblom-': [('xblomma', False)],
          'xbloms': [('xblomma', False)],
          'xbloms-': [('xblomma', False)],
          'xbomb': [('xbomb', False)],
          'xbomber': [('xbomb', False)],
          'xbomberna': [('xbomb', False)],
          'xbombernas': [('xbomb', False)],
          'xbombers': [('xbomb', False)],
          'xbombs': [('xbomb', False)],
          'xbombs-': [('xbomb', False)],
          'xbärs': [('xbär', False)],
          'xbärs-': [('xbär', False)],
          'xbön': [('xböna', False)],
          'xbön-': [('xböna', False)],
          'xböne': [('xböna', False)],
          'xböne-': [('xböna', False)],
          'xböns': [('xböna', False)],
          'xböns-': [('xböna', False)],
          'xcellens': [('xcellens', False)],
          'xcenter': [('xcenter', False)],
          'xcentrer': [('xcentrum', False)],
          'xcentrerna': [('xcentrum', False)],
          'xcentrernas': [('xcentrum', False)],
          'xcentrers': [('xcentrum', False)],
          'xcentret': [('xcentrum', False)],
          'xcentrets': [('xcentrum', False)],
          'xdans': [('xdans', False)],
          'xdock-': [('xdocka', False)],
          'xdocks-': [('xdocka', False)],
          'xe': [('xe', False)],
          'xe-': [('xe', False)],
          'xed': [('xed', False)],
          'xed-': [('xed', False)],
          'xeds': [('xed', False)],
          'xeget': [('xeget', False)],
          'xegets': [('xeget', False)],
          'xelkurs': [('xelkurs', False)],
          'xelställen': [('xelställ', False)],
          'xelställens': [('xelställ', False)],
          'xelstället': [('xelställ', False)],
          'xelställets': [('xelställ', False)],
          'xem': [('xem', False)],
          'xem-': [('xem', False)],
          'xemien': [('xemi', False)],
          'xemiens': [('xemi', False)],
          'xemis': [('xemi', False)],
          'xemplaren': [('xemplar', False)],
          'xems': [('xem', False)],
          'xen': [('x', True)],
          'xenhets': [('xenhet', False)],
          'xenhets-': [('xenhet', False)],
          'xens': [('x', True)],
          'xer-': [('xer', False)],
          'xerare': [('xerare', False)],
          'xerares': [('xerare', False)],
          'xerarna': [('xerare', False)],
          'xerarnas': [('xerare', False)],
          'xeri': [('xeri', False)],
          'xeri-': [('xeri', False)],
          'xerier': [('xeri', False)],
          'xerierna': [('xeri', False)],
          'xeriers': [('xeri', False)],
          'xeriet': [('xeri', False)],
          'xeris': [('xeri', False)],
          'xeris-': [('xeri', False)],
          'xerit': [('xeri', False)],
          'xers-': [('xer', False)],
          'xersarnas': [('xer', False)],
          'xes': [('xe', False)],
          'xes-': [('xe', False)],
          'xet': [('x', True)],
          'xets': [('x', False)],
          'xfilen': [('xfile', False)],
          'xfilens': [('xfile', False)],
          'xfiskar': [('xfisk', False)],
          'xfiskarna': [('xfisk', False)],
          'xfiskarnas': [('xfisk', False)],
          'xhets': [('xhet', False)],
          'xhets-': [('xhet', False)],
          'xhopar': [('xhop', False)],
          'xhoparna': [('xhop', False)],
          'xhäll': [('xhälla', False)],
          'xhäll-': [('xhälla', False)],
          'xhälls': [('xhälla', False)],
          'xhälls-': [('xhälla', False)],
          'xi': [('xi', False)],
          'xi-': [('xi', False)],
          'xidas': [('xidas', False)],
          'xiden': [('xid', False)],
          'xidens': [('xid', False)],
          'xids': [('xid', False)],
          'xien': [('xi', False)],
          'xiens': [('xi', False)],
          'xier': [('xi', False)],
          'xierna': [('xi', False)],
          'xiernas': [('xi', False)],
          'xiers': [('xi', False)],
          'xiet': [('xi', True)],
          'xigheter': [('xighet', False)],
          'xigheterna': [('xighet', False)],
          'xigheternas': [('xighet', False)],
          'xigheters': [('xighet', False)],
          'xighets-': [('xighet', False)],
          'xihets': [('xihets', False)],
          'xihets-': [('xihets', False)],
          'xiker': [('xiker', False)],
          'xikerna': [('xiker', False)],
          'xikernas': [('xiker', False)],
          'xikers': [('xiker', False)],
          'xill': [('xill', False)],
          'xill-': [('xill', False)],
          'xillen': [('xill', False)],
          'xiller': [('xill', False)],
          'xillerna': [('xill', False)],
          'xillernas': [('xill', False)],
          'xillers': [('xill', False)],
          'xills': [('xill', False)],
          'xills-': [('xill', False)],
          'ximer': [('xim', False)],
          'ximers': [('xim', False)],
          'xin': [('xi', True)],
          'xina': [('xi', True)],
          'xinas': [('xi', False)],
          'xinets': [('xin', False)],
          'xing': [('xing', False)],
          'xing-': [('xing', False)],
          'xingar': [('xing', False)],
          'xingarna': [('xing', False)],
          'xingarnas': [('xing', False)],
          'xingars': [('xing', False)],
          'xingen': [('xing', False)],
          'xingens': [('xing', False)],
          'xings': [('xing', False)],
          'xings-': [('xing', False)],
          'xinior': [('xinia', False)],
          'xiniors': [('xinia', False)],
          'xinis-': [('xinia', False)],
          'xins': [('xi', False)],
          'xion': [('xion', False)],
          'xionen': [('xion', False)],
          'xionens': [('xion', False)],
          'xioner': [('xion', False)],
          'xionerna': [('xion', False)],
          'xionernas': [('xion', False)],
          'xioners': [('xion', False)],
          'xions': [('xion', False)],
          'xis': [('xi', False)],
          'xis-': [('xi', False)],
          'xismer': [('xism', False)],
          'xismernas': [('xism', False)],
          'xist-': [('xist', False)],
          'xisten': [('xist', False)],
          'xistens': [('xist', False)],
          'xister': [('xist', False)],
          'xisterna': [('xist', False)],
          'xisternas': [('xist', False)],
          'xisters': [('xist', False)],
          'xit': [('xi', True)],
          'xiternas': [('xit', False)],
          'xits': [('xi', True)],
          'xkammar': [('xkam', False)],
          'xkams': [('xkam', False)],
          'xkams-': [('xkam', False)],
          'xkar': [('xkar', False)],
          'xkarens': [('xkar', False)],
          'xkaret': [('xkar', False)],
          'xkarets': [('xkar', False)],
          'xkars': [('xkar', False)],
          'xkars-': [('xkar', False)],
          'xkistan': [('xkista', False)],
          'xkistans': [('xkista', False)],
          'xkittlar': [('xkittel', False)],
          'xkittlarna': [('xkittel', False)],
          'xkittlarnas': [('xkittel', False)],
          'xklav': [('xklav', False)],
          'xklav-': [('xklav', False)],
          'xklaven': [('xklav', False)],
          'xklavens': [('xklav', False)],
          'xklaver': [('xklav', False)],
          'xklavers': [('xklav', False)],
          'xklavs': [('xklav', False)],
          'xkliniker': [('xklinik', False)],
          'xklinikerna': [('xklinik', False)],
          'xklinikernas': [('xklinik', False)],
          'xklinikers': [('xklinik', False)],
          'xklipp': [('xklipp', False)],
          'xklipps': [('xklipp', False)],
          'xklipps-': [('xklipp', False)],
          'xknät': [('xknä', False)],
          'xknäts': [('xknä', False)],
          'xkonst-': [('xkonst', False)],
          'xkonsternas': [('xkonst', False)],
          'xkonsters': [('xkonst', False)],
          'xkrafterna': [('xkraft', False)],
          'xkrafts': [('xkraft', False)],
          'xkrafts-': [('xkraft', False)],
          'xkret': [('xkret', False)],
          'xkrets': [('xkret', False)],
          'xkrets-': [('xkret', False)],
          'xkrokarnas': [('xkrok', False)],
          'xkurs': [('xkurs', False)],
          'xkurs-': [('xkurs', False)],
          'xlanden': [('xlande', False)],
          'xlandena': [('xlande', False)],
          'xlandenas': [('xlande', False)],
          'xlandens': [('xlande', False)],
          'xlandet': [('xlande', False)],
          'xlandets': [('xlande', False)],
          'xlaren': [('xlare', False)],
          'xlighets': [('xlighet', False)],
          'xlivs': [('xliv', False)],
          'xlivs-': [('xliv', False)],
          'xlust': [('xlust', False)],
          'xlöss': [('xlus', False)],
          'xlössen': [('xlus', False)],
          'xlössens': [('xlus', False)],
          'xmakar': [('xmakare', False)],
          'xmakarna': [('xmakare', False)],
          'xmakarnas': [('xmakare', False)],
          'xman': [('xman', False)],
          'xmannens': [('xman', False)],
          'xmaten': [('xmat', False)],
          'xmats': [('xmat', False)],
          'xmyt': [('xmyt', False)],
          'xmyts': [('xmyt', False)],
          'xmän': [('xman', False)],
          'xmäns': [('xman', False)],
          'xn': [('x', False)],
          'xn-': [('xn', False)],
          'xnanden': [('xnande', False)],
          'xnar': [('xen', False)],
          'xnarna': [('xen', False)],
          'xnarnas': [('xen', False)],
          'xnars': [('xen', False)],
          'xne-': [('xne', False)],
          'xnen': [('xen', False)],
          'xnens': [('xen', False)],
          'xnet': [('xne', False)],
          'xnets': [('xne', False)],
          'xns': [('x', False)],
          'xnäbb': [('xnäbb', False)],
          'xnäbb-': [('xnäbb', False)],
          'xnäbbs': [('xnäbb', False)],
          'xnäbbs-': [('xnäbb', False)],
          'xoplanet': [('xoplanet', False)],
          'xoplanets': [('xoplanet', False)],
          'xor': [('xa', False)],
          'xors': [('xa', False)],
          'xpack': [('xpack', False)],
          'xpack-': [('xpack', False)],
          'xpackar': [('xpack', False)],
          'xpackarna': [('xpack', False)],
          'xpackarnas': [('xpack', False)],
          'xpackars': [('xpack', False)],
          'xpacken': [('xpack', False)],
          'xpackens': [('xpack', False)],
          'xpacks': [('xpack', False)],
          'xpacks-': [('xpack', False)],
          'xpens': [('xpenser', False)],
          'xpens-': [('xpenser', False)],
          'xpenser': [('xpenser', False)],
          'xpenserna': [('xpenser', False)],
          'xpensernas': [('xpenser', False)],
          'xpensers': [('xpenser', False)],
          'xpo-': [('xpo', False)],
          'xponents': [('xponent', False)],
          'xponents-': [('xponent', False)],
          'xpor': [('xpo', False)],
          'xporna': [('xpo', False)],
          'xpornas': [('xpo', False)],
          'xpors': [('xpo', False)],
          'xporter': [('xport', False)],
          'xporterna': [('xport', False)],
          'xporternas': [('xport', False)],
          'xporters': [('xport', False)],
          'xproblemet': [('xproblem', False)],
          'xproblemets': [('xproblem', False)],
          'xprocessen': [('xprocess', False)],
          'xprocessens': [('xprocess', False)],
          'xrarnas': [('xer', False)],
          'xringar': [('xring', False)],
          'xringarna': [('xring', False)],
          'xringarnas': [('xring', False)],
          'xs': [('x', True)],
          'xside': [('xsida', False)],
          'xsides': [('xsida', False)],
          'xskatts-': [('xskatt', False)],
          'xskär': [('xskär', False)],
          'xskär-': [('xskär', False)],
          'xskärs': [('xskär', False)],
          'xskärs-': [('xskär', False)],
          'xslag': [('xslag', False)],
          'xslags': [('xslag', False)],
          'xslags-': [('xslag', False)],
          'xsnåret': [('xsnåret', False)],
          'xsnårets': [('xsnåret', False)],
          'xstekar': [('xstek', False)],
          'xstekarna': [('xstek', False)],
          'xstekarnas': [('xstek', False)],
          'xt': [('xt', False)],
          'xt-': [('xt', False)],
          'xtanden': [('xtande', False)],
          'xtandens': [('xtande', False)],
          'xtants': [('xtant', False)],
          'xtar': [('xt', False)],
          'xtarna': [('xt', False)],
          'xtars': [('xt', False)],
          'xtas': [('xtas', False)],
          'xtas-': [('xtas', False)],
          'xtasen': [('xtas', False)],
          'xtasens': [('xtas', False)],
          'xtax': [('xtaxa', False)],
          'xtax-': [('xtaxa', False)],
          'xten': [('xt', False)],
          'xtens': [('xt', False)],
          'xter': [('xt', False)],
          'xterna': [('xt', False)],
          'xternas': [('xt', False)],
          'xterns': [('xtern', False)],
          'xters': [('xt', False)],
          'xthet': [('xthet', False)],
          'xthets': [('xthet', False)],
          'xtider': [('xtid', False)],
          'xtiders': [('xtid', False)],
          'xtilen': [('xtil', False)],
          'xtilens': [('xtil', False)],
          'xtlandet': [('xtland', False)],
          'xtol': [('xtol', False)],
          'xtol-': [('xtol', False)],
          'xtolen': [('xtol', False)],
          'xtolens': [('xtol', False)],
          'xtols': [('xtol', False)],
          'xtpressarnas': [('xtpress', False)],
          'xtran': [('xtran', False)],
          'xtran-': [('xtran', False)],
          'xtrans': [('xtran', False)],
          'xtrans-': [('xtran', False)],
          'xtris': [('xtri', False)],
          'xtrots': [('xtrot', False)],
          'xtrots-': [('xtrot', False)],
          'xtrotter': [('xtrott', False)],
          'xtrotters': [('xtrott', False)],
          'xträd': [('xträd', False)],
          'xträden': [('xträd', False)],
          'xträdens': [('xträd', False)],
          'xträdet': [('xträd', False)],
          'xträdets': [('xträd', False)],
          'xträds': [('xträd', False)],
          'xträds-': [('xträd', False)],
          'xts': [('xt', False)],
          'xtställen': [('xtställe', False)],
          'xtstället': [('xtställe', False)],
          'xtur-': [('xtur', False)],
          'xturerna': [('xtur', False)],
          'xturernas': [('xtur', False)],
          'xturers': [('xtur', False)],
          'xturs': [('xtur', False)],
          'xtår': [('xtår', False)],
          'xtårs': [('xtår', False)],
          'xvar': [('xvara', False)],
          'xvar-': [('xvara', False)],
          'xvaran': [('xvara', False)],
          'xvarans': [('xvara', False)],
          'xveck': [('xvecka', False)],
          'xveck-': [('xvecka', False)],
          'xvecks': [('xvecka', False)],
          'xvecks-': [('xvecka', False)],
          'xvin': [('xvin', False)],
          'xvin-': [('xvin', False)],
          'xvins': [('xvin', False)],
          'xvins-': [('xvin', False)],
          'xygen': [('xygen', False)],
          'xygens': [('xygen', False)],
          'xögats': [('xöga', False)],
          'xögonens': [('xöga', False)],
          'y': [('y', True)],
          'y-': [('y', True)],
          'y-in': [('y-i', False)],
          'y-ina': [('y-i', False)],
          'y-inas': [('y-i', False)],
          'ya': [('ya', False)],
          'yals': [('yal', False)],
          'yals-': [('yal', False)],
          'yan': [('ya', False)],
          'yanden': [('yande', False)],
          'yandens': [('yande', False)],
          'yandets': [('yande', False)],
          'yandrins': [('yandri', False)],
          'yanens': [('yan', False)],
          'yanets': [('yan', False)],
          'yansen': [('yans', False)],
          'yansens': [('yans', False)],
          'yanser': [('yans', False)],
          'yanserna': [('yans', False)],
          'yansernas': [('yans', False)],
          'yansers': [('yans', False)],
          'yar': [('yare', False)],
          'yar-': [('yare', False)],
          'yard': [('yard', True)],
          'yard-': [('yard', True)],
          'yarden': [('yard', True)],
          'yardens': [('yard', True)],
          'yards': [('yard', True)],
          'yards-': [('yard', True)],
          'yare': [('yare', False)],
          'yaren': [('yar', False)],
          'yarens': [('yare', False)],
          'yares': [('yare', False)],
          'yarna': [('yare', False)],
          'yarnas': [('y', False)],
          'yars': [('y', False)],
          'yas': [('ya', False)],
          'yask': [('yaska', False)],
          'yask-': [('yaska', False)],
          'yatidens': [('yatid', False)],
          'yatiderna': [('yatid', False)],
          'yatidernas': [('yatid', False)],
          'yatids': [('yatid', False)],
          'yback': [('yback', False)],
          'yback-': [('yback', False)],
          'ybacken': [('yback', False)],
          'ybackens': [('yback', False)],
          'ybacks': [('yback', False)],
          'ybanan': [('ybana', False)],
          'ybanans': [('ybana', False)],
          'ybane': [('ybana', False)],
          'ybane-': [('ybana', False)],
          'ybarit': [('ybarit', False)],
          'ybarits': [('ybarit', False)],
          'ybars': [('ybar', False)],
          'ybb-': [('ybb', False)],
          'ybben': [('ybb', False)],
          'ybblen': [('ybble', False)],
          'ybblens': [('ybble', False)],
          'yblom': [('yblomma', False)],
          'yblom-': [('yblomma', False)],
          'ybloms': [('yblomma', False)],
          'ybloms-': [('yblomma', False)],
          'ybor': [('ybo', False)],
          'yborgen': [('yborg', False)],
          'yborgens': [('yborg', False)],
          'yborrar': [('yborre', False)],
          'yborrarna': [('yborre', False)],
          'yborrarnas': [('yborre', False)],
          'yborrars': [('yborre', False)],
          'yborren': [('yborre', False)],
          'yborrens': [('yborre', False)],
          'ybors': [('ybo', False)],
          'ybrons': [('ybrons', False)],
          'ybs': [('ybs', False)],
          'ybs-': [('ybs', False)],
          'ybyx': [('ybyxa', False)],
          'ybyx-': [('ybyxa', False)],
          'ybyxornas': [('ybyxa', False)],
          'ybåg': [('ybåge', False)],
          'ybåg-': [('ybåge', False)],
          'ybågs': [('ybåge', False)],
          'ybågs-': [('ybåge', False)],
          'ycat': [('ycat', False)],
          'ycat-': [('ycat', False)],
          'ycats': [('ycat', False)],
          'ycins': [('ycin', False)],
          'yck': [('yck', False)],
          'yck-': [('ycka', False)],
          'yckan': [('ycka', False)],
          'yckans': [('ycka', False)],
          'yckar': [('yckare', False)],
          'yckarna': [('yckare', False)],
          'yckarnas': [('yck', False)],
          'yckars': [('ycke', False)],
          'ycke': [('ycke', False)],
          'ycke-': [('ycke', False)],
          'ycken': [('ycke', False)],
          'yckena': [('ycke', False)],
          'yckenas': [('ycke', False)],
          'yckens': [('ycke', False)],
          'ycket': [('ycke', False)],
          'ycklanden': [('ycklande', False)],
          'ycklandens': [('ycklande', False)],
          'ycklandet': [('ycklande', False)],
          'ycklar': [('ycklare', False)],
          'ycko-': [('ycka', False)],
          'ycks': [('ycke', False)],
          'ycks-': [('ycka', False)],
          'yd': [('yd', False)],
          'yd-': [('yd', False)],
          'ydanden': [('ydande', False)],
          'ydandens': [('ydande', False)],
          'ydans-': [('ydan', False)],
          'ydar': [('ydare', False)],
          'ydaren': [('ydare', False)],
          'ydarna': [('ydare', False)],
          'ydarnas': [('ydare', False)],
          'ydd': [('ydda', False)],
          'ydd-': [('ydd', False)],
          'ydda': [('ydda', False)],
          'ydda-': [('ydda', False)],
          'yddans': [('ydda', False)],
          'yddar': [('yddare', False)],
          'yddarna': [('yddare', False)],
          'ydds': [('ydda', False)],
          'ydds-': [('ydda', False)],
          'yde': [('yda', False)],
          'yde-': [('yda', False)],
          'yden': [('yd', False)],
          'ydens': [('yd', False)],
          'yder': [('yd', False)],
          'yderits': [('yderi', False)],
          'yderna': [('yd', False)],
          'ydernas': [('yd', False)],
          'yders': [('yd', False)],
          'ydia': [('ydia', False)],
          'ydian': [('ydia', False)],
          'ydians': [('ydia', False)],
          'ydias': [('ydia', False)],
          'yding': [('yding', False)],
          'ydingar': [('yding', False)],
          'ydingarna': [('yding', False)],
          'ydingarnas': [('yding', False)],
          'ydingars': [('yding', False)],
          'ydingen': [('yding', False)],
          'ydingens': [('yding', False)],
          'ydings': [('yding', False)],
          'ydings-': [('yding', False)],
          'ydjan': [('ydja', False)],
          'ydjans': [('ydja', False)],
          'ydor': [('yda', False)],
          'ydorna': [('yda', False)],
          'ydornas': [('yda', False)],
          'ydors': [('yda', False)],
          'ydra': [('ydra', False)],
          'ydran': [('ydra', False)],
          'ydrans': [('ydra', False)],
          'ydras': [('ydra', False)],
          'ydriens': [('ydri', False)],
          'ydrinkar': [('ydrink', False)],
          'ydrinkarna': [('ydrink', False)],
          'ydrinkarnas': [('ydrink', False)],
          'ydrins': [('ydri', False)],
          'ydrorna': [('ydra', False)],
          'yds': [('yd', False)],
          'yds-': [('yd', False)],
          'ye': [('ye', False)],
          'ye-': [('ye', False)],
          'yeder': [('yeder', False)],
          'yeders': [('yeder', False)],
          'yeliner': [('yeliner', False)],
          'yeliners': [('yeliner', False)],
          'yem': [('yem', False)],
          'yem-': [('yem', False)],
          'yems': [('yem', False)],
          'yen': [('yen', True)],
          'yen-': [('yen', True)],
          'yena': [('yena', False)],
          'yenans': [('yena', False)],
          'yenas': [('yena', False)],
          'yendets': [('yende', False)],
          'yene': [('yena', False)],
          'yene-': [('yena', False)],
          'yennen': [('yenne', False)],
          'yennens': [('yenne', False)],
          'yenner': [('yenne', False)],
          'yennerna': [('yenne', False)],
          'yenners': [('yenne', False)],
          'yens': [('yen', True)],
          'yens-': [('yena', False)],
          'yer-': [('yer', False)],
          'yere': [('yere', False)],
          'yere-': [('yere', False)],
          'yeren': [('yere', False)],
          'yerens': [('yere', False)],
          'yers-': [('yer', False)],
          'yes': [('ye', False)],
          'yes-': [('ye', False)],
          'yester': [('yester', False)],
          'yestern': [('yester', False)],
          'yesters': [('yester', False)],
          'yestrar': [('yester', False)],
          'yeten': [('yeten', False)],
          'yeters': [('yeter', False)],
          'yets': [('y', False)],
          'yett': [('yett', False)],
          'yett-': [('yett', False)],
          'yetten': [('yett', False)],
          'yetter': [('yett', False)],
          'yetterna': [('yett', False)],
          'yetternas': [('yett', False)],
          'yetters': [('yett', False)],
          'yetts': [('yett', False)],
          'yetts-': [('yett', False)],
          'yf': [('yf', False)],
          'yf-': [('yf', False)],
          'yfen': [('yf', False)],
          'yfens': [('yf', False)],
          'yfer': [('yf', False)],
          'yferna': [('yf', False)],
          'yfernas': [('yf', False)],
          'yfers': [('yf', False)],
          'yffe': [('yffe', False)],
          'yffe-': [('yffe', False)],
          'yffen': [('yffe', False)],
          'yffet': [('yffe', False)],
          'yffets': [('yffe', False)],
          'yffs': [('yffe', False)],
          'yffs-': [('yffe', False)],
          'yfilis': [('yfilis', False)],
          'yfonis': [('yfoni', False)],
          'yfs-': [('yf', False)],
          'yftan': [('yfta', False)],
          'yfte': [('yfte', False)],
          'yften': [('yfte', False)],
          'yftens': [('yfte', False)],
          'yftet': [('yfte', False)],
          'yftets': [('yft', False)],
          'yfts': [('yfte', False)],
          'yfus': [('yfus', False)],
          'yfyndet': [('yfyndet', False)],
          'yfyndets': [('yfyndet', False)],
          'yfånen': [('yfåne', False)],
          'yfånens': [('yfåne', False)],
          'yg': [('yg', False)],
          'yg-': [('yg', False)],
          'ygan': [('yga', False)],
          'ygandens': [('ygande', False)],
          'ygans': [('yga', False)],
          'ygar': [('yg', False)],
          'ygaren': [('ygare', False)],
          'ygarna': [('yg', False)],
          'ygarnas': [('yg', False)],
          'ygars': [('yg', False)],
          'ygas': [('yga', False)],
          'ygate': [('ygata', False)],
          'ygate-': [('ygata', False)],
          'ygats': [('ygata', False)],
          'yge': [('yga', False)],
          'yge-': [('yga', False)],
          'ygel': [('ygel', False)],
          'ygel-': [('ygel', False)],
          'ygelsen': [('ygelse', False)],
          'ygelsens': [('ygelse', False)],
          'ygen': [('yg', False)],
          'ygen-': [('ygen', False)],
          'ygens': [('yg', False)],
          'yger': [('yg', False)],
          'ygerna': [('yg', False)],
          'ygernas': [('yg', False)],
          'ygers': [('yg', False)],
          'yget': [('yg', False)],
          'ygets': [('yg', False)],
          'yggarna': [('yggare', False)],
          'yggarnas': [('yggare', False)],
          'yggars': [('ygger', False)],
          'ygge': [('ygge', False)],
          'yggen': [('ygge', False)],
          'yggens': [('ygge', False)],
          'ygger': [('ygger', False)],
          'yggers': [('ygger', False)],
          'ygget': [('ygge', False)],
          'yggets': [('ygg', False)],
          'yggvar-': [('yggvara', False)],
          'yghets': [('yghet', False)],
          'ygien': [('ygien', False)],
          'ygiens': [('ygien', False)],
          'yglar': [('ygel', False)],
          'yglarna': [('ygel', False)],
          'yglarnas': [('ygel', False)],
          'yglars': [('ygel', False)],
          'yglott-': [('yglott', False)],
          'yglotts': [('yglott', False)],
          'ygnet': [('ygn', False)],
          'ygnets': [('ygn', False)],
          'ygon': [('ygon', False)],
          'ygonens': [('ygon', False)],
          'ygor': [('yga', False)],
          'ygorna': [('yga', False)],
          'ygornas': [('yga', False)],
          'ygors': [('yga', False)],
          'ygots': [('ygot', False)],
          'ygrafen': [('ygraf', False)],
          'ygrafens': [('ygraf', False)],
          'ygrulls-': [('ygrulle', False)],
          'ygryt': [('ygryta', False)],
          'ygryt-': [('ygryta', False)],
          'ygryts': [('ygryta', False)],
          'ygryts-': [('ygryta', False)],
          'ygs': [('yg', False)],
          'ygs-': [('yg', False)],
          'ygsflagg': [('ygsflagg', False)],
          'ygsflaggs': [('ygsflagg', False)],
          'yhets': [('yhet', False)],
          'yhus': [('yhus', False)],
          'yighets-': [('yighet', False)],
          'ying': [('ying', False)],
          'ying-': [('ying', False)],
          'yingar': [('ying', False)],
          'yingarna': [('ying', False)],
          'yingarnas': [('ying', False)],
          'yingars': [('ying', False)],
          'yingen': [('ying', False)],
          'yingens': [('ying', False)],
          'yings': [('ying', False)],
          'yings-': [('ying', False)],
          'yist-': [('yist', False)],
          'yisten': [('yist', False)],
          'yistens': [('yist', False)],
          'yister': [('yist', False)],
          'yisterna': [('yist', False)],
          'yisternas': [('yist', False)],
          'yisters': [('yist', False)],
          'yistik': [('yistik', False)],
          'yistik-': [('yistik', False)],
          'yistiker': [('yistik', False)],
          'yistikerna': [('yistik', False)],
          'yistikernas': [('yistik', False)],
          'yistikers': [('yistik', False)],
          'yistiks': [('yistik', False)],
          'yjan': [('yja', False)],
          'yjans': [('yja', False)],
          'yje': [('yja', False)],
          'yje-': [('yja', False)],
          'yjor': [('yja', False)],
          'yjorna': [('yja', False)],
          'yjornas': [('yja', False)],
          'yjors': [('yja', False)],
          'yk': [('yka', False)],
          'yk-': [('yk', False)],
          'ykan': [('yka', False)],
          'ykanden': [('ykande', False)],
          'ykans': [('yka', False)],
          'ykar': [('yk', False)],
          'ykar-': [('ykare', False)],
          'ykare': [('ykare', False)],
          'ykaren': [('ykare', False)],
          'ykarens': [('ykare', False)],
          'ykarna': [('yk', False)],
          'ykarnas': [('ykare', False)],
          'ykars': [('yk', False)],
          'ykas': [('yka', False)],
          'yke': [('yka', False)],
          'yke-': [('yka', False)],
          'ykel': [('ykel', False)],
          'ykel-': [('ykel', False)],
          'ykels': [('ykel', False)],
          'ykels-': [('ykel', False)],
          'yken': [('yk', False)],
          'ykens': [('yk', False)],
          'yker': [('yk', False)],
          'ykerits': [('ykeri', False)],
          'ykerna': [('yk', False)],
          'ykernas': [('yk', False)],
          'ykers': [('yk', False)],
          'yket': [('yk', False)],
          'ykets': [('yke', False)],
          'yklamen': [('yklamen', False)],
          'yklamens': [('yklamen', False)],
          'yklamer': [('yklamen', False)],
          'yklamerna': [('yklamen', False)],
          'yklamernas': [('yklamen', False)],
          'yklamers': [('yklamen', False)],
          'yklandets': [('yklande', False)],
          'yklar': [('ykel', False)],
          'yklarna': [('ykel', False)],
          'yklarnas': [('ykel', False)],
          'yklars': [('ykel', False)],
          'yklassiker': [('yklassiker', False)],
          'yklassikerna': [('yklassiker', False)],
          'yklassikernas': [('yklassiker', False)],
          'yklassikers': [('yklassiker', False)],
          'yklernas': [('ykel', False)],
          'ykling': [('ykling', False)],
          'ykling-': [('yklinga', False)],
          'yklings': [('yklinga', False)],
          'yklings-': [('ykling', False)],
          'yklister': [('yklist', False)],
          'yklisters': [('yklist', False)],
          'yklon': [('yklon', False)],
          'yklons': [('yklon', False)],
          'yklubb': [('yklubba', False)],
          'yklubb-': [('yklubba', False)],
          'yklubbs': [('yklubba', False)],
          'yklubbs-': [('yklubba', False)],
          'yklädes': [('ykläder', False)],
          'yklädes-': [('ykläder', False)],
          'ykniker': [('ykniker', False)],
          'yknikerna': [('ykniker', False)],
          'yknikernas': [('ykniker', False)],
          'yknikers': [('ykniker', False)],
          'ykningar': [('ykning', False)],
          'ykningarna': [('ykning', False)],
          'ykningarnas': [('ykning', False)],
          'ykningars': [('ykning', False)],
          'yknings': [('ykning', False)],
          'yknings-': [('ykning', False)],
          'ykol': [('ykol', False)],
          'ykol-': [('ykol', False)],
          'ykon': [('yko', False)],
          'ykons': [('yko', False)],
          'ykor': [('yka', False)],
          'ykorna': [('yka', False)],
          'ykornas': [('yka', False)],
          'ykors': [('yka', False)],
          'ykos': [('ykos', False)],
          'ykos-': [('ykos', False)],
          'ykrar': [('yker', False)],
          'ykrarna': [('yker', False)],
          'yks': [('yk', False)],
          'yks-': [('yke', False)],
          'ykta': [('ykta', False)],
          'yktan': [('ykta', False)],
          'yktans': [('ykta', False)],
          'yktas': [('ykta', False)],
          'ykte': [('ykte', False)],
          'ykte-': [('ykte', False)],
          'yktet': [('ykte', False)],
          'ykulor': [('ykula', False)],
          'ykulorna': [('ykula', False)],
          'ykulornas': [('ykula', False)],
          'ykulors': [('ykula', False)],
          'yl': [('yl', False)],
          'yl-': [('yl', False)],
          'ylan': [('yla', False)],
          'ylanden': [('ylande', False)],
          'ylandena': [('ylande', False)],
          'ylandenas': [('ylande', False)],
          'ylandens': [('ylande', False)],
          'ylandet': [('ylande', False)],
          'ylandets': [('ylande', False)],
          'ylans': [('yla', False)],
          'ylar': [('yl', False)],
          'ylaren': [('ylare', False)],
          'ylarnas': [('yl', False)],
          'ylars': [('yl', False)],
          'ylas': [('ylas', False)],
          'ylasen': [('ylas', False)],
          'ylasens': [('ylas', False)],
          'ylaser': [('ylas', False)],
          'ylasers': [('ylas', False)],
          'yle': [('yla', False)],
          'yle-': [('yla', False)],
          'ylen': [('yl', False)],
          'ylen-': [('ylen', False)],
          'ylens': [('yl', False)],
          'yler': [('yl', False)],
          'ylerna': [('yl', False)],
          'ylernas': [('yl', False)],
          'ylers': [('yl', False)],
          'ylesarnas': [('yle', False)],
          'ylesens': [('yle', False)],
          'ylet': [('yl', False)],
          'ylets': [('yl', False)],
          'ylfarnas': [('ylf', False)],
          'yli': [('yli', False)],
          'yli-': [('yli', False)],
          'ylien': [('yli', False)],
          'yliens': [('yli', False)],
          'ylighets': [('ylighet', False)],
          'ylin': [('yli', False)],
          'ylins': [('yli', False)],
          'ylis': [('yli', False)],
          'ylit': [('ylit', False)],
          'ylit-': [('ylit', False)],
          'yliten': [('ylit', False)],
          'ylitens': [('ylit', False)],
          'yliter': [('ylit', False)],
          'yliterna': [('ylit', False)],
          'yliternas': [('ylit', False)],
          'yliters': [('ylit', False)],
          'ylits': [('ylit', False)],
          'ylivs': [('yliv', False)],
          'ylivs-': [('yliv', False)],
          'ylke': [('ylke', False)],
          'ylken': [('ylke', False)],
          'ylkens': [('ylke', False)],
          'ylket': [('ylke', False)],
          'ylks': [('ylke', False)],
          'ylks-': [('ylke', False)],
          'yll': [('ylla', False)],
          'yll-': [('ylla', False)],
          'yllan': [('yllan', False)],
          'yllandet': [('ylland', False)],
          'yllandets': [('yllande', False)],
          'yllans': [('ylla', False)],
          'yllar': [('yllare', False)],
          'yllar-': [('yllare', False)],
          'yllarna': [('yll', False)],
          'yllarnas': [('yll', False)],
          'ylle': [('ylle', False)],
          'ylle-': [('ylle', False)],
          'yllen': [('yllen', False)],
          'yllena': [('ylle', False)],
          'yllenas': [('ylle', False)],
          'yllens': [('yll', False)],
          'yller': [('yller', False)],
          'yllerna': [('yller', False)],
          'yllers': [('yller', False)],
          'yllet': [('ylle', False)],
          'yllets': [('ylle', False)],
          'yllins-': [('yllin', False)],
          'yllis': [('yllis', False)],
          'yllon': [('yllo', False)],
          'yllons': [('yllo', False)],
          'yllos': [('yllo', False)],
          'ylls': [('ylla', False)],
          'ylls-': [('ylla', False)],
          'ylningar': [('ylning', False)],
          'ylningarna': [('ylning', False)],
          'ylningarnas': [('ylning', False)],
          'ylningars': [('ylning', False)],
          'ylnings': [('ylning', False)],
          'ylnings-': [('ylning', False)],
          'yloden': [('ylod', False)],
          'ylodens': [('ylod', False)],
          'ylon': [('ylon', False)],
          'ylonen': [('ylon', False)],
          'ylonens': [('ylon', False)],
          'yloner': [('ylon', False)],
          'ylonerna': [('ylon', False)],
          'ylonernas': [('ylon', False)],
          'yloners': [('ylon', False)],
          'ylonierna': [('ylonier', False)],
          'yloniers': [('ylonier', False)],
          'ylons': [('ylon', False)],
          'ylor': [('yla', False)],
          'ylorna': [('yla', False)],
          'ylornas': [('yla', False)],
          'ylors': [('yla', False)],
          'ylos': [('ylos', False)],
          'ylos-': [('ylos', False)],
          'ylosen': [('ylos', False)],
          'ylosens': [('ylos', False)],
          'yls': [('yl', False)],
          'yls-': [('yl', False)],
          'ylt': [('ylt', False)],
          'ylt-': [('ylta', False)],
          'yltan': [('ylta', False)],
          'yltans': [('ylta', False)],
          'yltar': [('yltare', False)],
          'yltarna': [('yltare', False)],
          'yltarnas': [('ylt', False)],
          'ylte': [('ylte', False)],
          'ylten': [('ylte', False)],
          'yltens': [('ylte', False)],
          'yltes': [('ylte', False)],
          'yltet': [('ylte', False)],
          'yltorna': [('ylta', False)],
          'ylts': [('ylta', False)],
          'ylts-': [('ylta', False)],
          'ylån': [('ylå', False)],
          'ylåns': [('ylå', False)],
          'ylås': [('ylå', False)],
          'ym': [('ym', False)],
          'ym-': [('ym', False)],
          'ymakar': [('ymakare', False)],
          'ymakarna': [('ymakare', False)],
          'ymakarnas': [('ymakare', False)],
          'ymaterialet': [('ymaterialet', False)],
          'ymaterialets': [('ymaterialet', False)],
          'ymatierna': [('ymation', False)],
          'ymatiernas': [('ymation', False)],
          'ymatten': [('ymatt', False)],
          'ymed': [('ymed', False)],
          'ymed-': [('ymed', False)],
          'ymeden': [('ymed', False)],
          'ymedens': [('ymed', False)],
          'ymeds': [('ymed', False)],
          'ymeds-': [('ymed', False)],
          'ymen': [('ym', False)],
          'ymens': [('ym', False)],
          'ymens-': [('ymen', False)],
          'ymer': [('ym', False)],
          'ymerer': [('ymer', False)],
          'ymererna': [('ymer', False)],
          'ymerernas': [('ymer', False)],
          'ymerers': [('ymer', False)],
          'ymerit': [('ymeri', False)],
          'ymerits': [('ymeri', False)],
          'ymerna': [('ym', False)],
          'ymernas': [('ym', False)],
          'ymers': [('ym', False)],
          'ymers-': [('ymer', False)],
          'ymet': [('ym', False)],
          'ymets': [('ym', False)],
          'ymikon': [('ymikon', False)],
          'ymikons': [('ymikon', False)],
          'ymin': [('ymi', False)],
          'ymins': [('ymi', False)],
          'ymlandets': [('ymlande', False)],
          'ymlarnas': [('ymmel', False)],
          'ymmarens': [('ymmare', False)],
          'ymmarnas': [('ymmare', False)],
          'ymme': [('ymme', False)],
          'ymmen': [('ymme', False)],
          'ymmer': [('ymmer', False)],
          'ymmernas': [('ymmer', False)],
          'ymmets': [('ymme', False)],
          'ympan': [('ympa', False)],
          'ympans': [('ympa', False)],
          'ympar': [('ymp', True)],
          'ympar-': [('ympare', False)],
          'ymparen': [('ympar', False)],
          'ymparens': [('ympare', False)],
          'ymparna': [('ymp', True)],
          'ymparnas': [('ymp', True)],
          'ympars': [('ymp', True)],
          'ympas': [('ympa', False)],
          'yms': [('ym', False)],
          'yms-': [('ym', False)],
          'ymtar': [('ymt', False)],
          'ymtarna': [('ymtare', False)],
          'ymtarnas': [('ymtare', False)],
          'ymus': [('ymus', False)],
          'ymån': [('ymå', False)],
          'ymåns': [('ymå', False)],
          'ymås': [('ymå', False)],
          'ymöss': [('ymössa', False)],
          'yn': [('yn', False)],
          'yn-': [('yn', False)],
          'yna': [('yna', False)],
          'ynanden': [('ynande', False)],
          'ynar': [('ynare', False)],
          'ynar-': [('ynare', False)],
          'ynaren': [('ynare', False)],
          'ynarens': [('ynare', False)],
          'ynarnas': [('ynare', False)],
          'ynas': [('yna', False)],
          'ynd': [('ynda', False)],
          'ynd-': [('ynda', False)],
          'ynda': [('ynda', False)],
          'yndan': [('yndan', False)],
          'yndans': [('ynda', False)],
          'yndar': [('yndare', False)],
          'yndar-': [('yndare', False)],
          'yndarens': [('yndare', False)],
          'yndarna': [('yndare', False)],
          'yndas': [('ynda', False)],
          'yndernas': [('ynd', False)],
          'yndet': [('yndeter', False)],
          'yndets': [('yndeter', False)],
          'ynds': [('ynda', False)],
          'ynds-': [('ynda', False)],
          'yne': [('yna', False)],
          'yne-': [('yna', False)],
          'ynen': [('yn', False)],
          'ynens': [('yn', False)],
          'yner': [('yn', False)],
          'ynerna': [('yn', False)],
          'ynernas': [('yn', False)],
          'yners': [('yn', False)],
          'ynes': [('ynes', False)],
          'ynesier': [('ynesier', False)],
          'ynesiernas': [('ynesier', False)],
          'ynesiers': [('ynesier', False)],
          'ynet': [('yn', False)],
          'yng': [('ynga', False)],
          'yng-': [('ynga', False)],
          'ynga': [('ynga', False)],
          'ynga-': [('ynga', False)],
          'yngan': [('ynga', False)],
          'yngans': [('ynga', False)],
          'yngas': [('ynga', False)],
          'yngets': [('yng', False)],
          'yngornas': [('ynga', False)],
          'yngors': [('ynga', False)],
          'yngs': [('ynga', False)],
          'yngs-': [('ynga', False)],
          'yni': [('ynia', False)],
          'yni-': [('ynia', False)],
          'ynie': [('ynia', False)],
          'ynis': [('ynia', False)],
          'ynjors': [('ynja', False)],
          'ynk': [('ynk', True)],
          'ynk-': [('ynk', True)],
          'ynkar': [('ynk', False)],
          'ynkarna': [('ynk', False)],
          'ynkarnas': [('ynk', False)],
          'ynke': [('ynke', False)],
          'ynkel': [('ynkla', False)],
          'ynkel-': [('ynkla', False)],
          'ynken': [('ynk', True)],
          'ynkens': [('ynk', True)],
          'ynkes': [('ynke', False)],
          'ynket': [('ynk', True)],
          'ynkets': [('ynk', True)],
          'ynklar': [('ynklare', False)],
          'ynklarna': [('ynklare', False)],
          'ynklarnas': [('ynklare', False)],
          'ynklor': [('ynkla', False)],
          'ynks': [('ynk', True)],
          'ynks-': [('ynk', True)],
          'ynn': [('ynna', False)],
          'ynn-': [('ynna', False)],
          'ynnan': [('ynna', False)],
          'ynnans': [('ynna', False)],
          'ynnarna': [('ynnare', False)],
          'ynnarnas': [('ynnare', False)],
          'ynne': [('ynne', False)],
          'ynne-': [('ynne', False)],
          'ynnens': [('ynne', False)],
          'ynnes': [('ynne', False)],
          'ynnes-': [('ynne', False)],
          'ynnet': [('ynne', False)],
          'ynning': [('ynning', False)],
          'ynningar': [('ynning', False)],
          'ynningarna': [('ynning', False)],
          'ynningarnas': [('ynning', False)],
          'ynningars': [('ynning', False)],
          'ynnings': [('ynning', False)],
          'ynnings-': [('ynning', False)],
          'ynns': [('ynne', False)],
          'ynns-': [('ynna', False)],
          'ynomen': [('ynom', False)],
          'ynomens': [('ynom', False)],
          'ynor': [('yna', False)],
          'ynorna': [('yna', False)],
          'ynornas': [('yna', False)],
          'ynors': [('yna', False)],
          'ynranden': [('ynrand', False)],
          'ynrandens': [('ynrand', False)],
          'yns': [('yn', False)],
          'yns-': [('yn', False)],
          'ynset': [('ynset', False)],
          'ynt-': [('ynt', False)],
          'ynta': [('ynta', False)],
          'yntan': [('ynta', False)],
          'yntar': [('ynt', False)],
          'yntar-': [('yntare', False)],
          'yntarens': [('yntare', False)],
          'yntarna': [('yntare', False)],
          'yntarnas': [('ynt', False)],
          'yntas': [('ynta', False)],
          'yntax-': [('yntax', False)],
          'yntet': [('yntet', False)],
          'yntets': [('ynt', False)],
          'ynts': [('ynt', False)],
          'yogans': [('yoga', True)],
          'yogas': [('yoga', True)],
          'yogen': [('yogen', False)],
          'yogens': [('yogen', False)],
          'yogier': [('yogi', True)],
          'yogierna': [('yogi', True)],
          'yogiers': [('yogi', True)],
          'yomen': [('yom', False)],
          'yomens': [('yom', False)],
          'yområdets': [('yområde', False)],
          'yoms': [('yom', False)],
          'yoms-': [('yom', False)],
          'yon': [('yo', False)],
          'yon-': [('yon', False)],
          'yonas': [('yo', False)],
          'yons': [('yo', False)],
          'yopins': [('yopi', False)],
          'yor': [('yo', False)],
          'yord': [('yord', False)],
          'yorden': [('yord', False)],
          'yordens': [('yord', False)],
          'yords': [('yord', False)],
          'yorna': [('yo', False)],
          'yornas': [('yo', False)],
          'yors': [('ya', False)],
          'yos': [('yo', False)],
          'yos-': [('yo', False)],
          'yosin': [('yosin', False)],
          'yot': [('yot', False)],
          'yote': [('yote', False)],
          'yote-': [('yote', False)],
          'yotekniker': [('yoteknik', False)],
          'yoteknikerna': [('yoteknik', False)],
          'yoteknikernas': [('yoteknik', False)],
          'yotes': [('yote', False)],
          'yotes-': [('yote', False)],
          'yots': [('yot', False)],
          'youten': [('yout', False)],
          'youtens': [('yout', False)],
          'youter': [('yout', False)],
          'youterna': [('yout', False)],
          'youternas': [('yout', False)],
          'youters': [('yout', False)],
          'yp': [('yp', False)],
          'yp-': [('yp', False)],
          'ypande': [('ypande', False)],
          'ypande-': [('ypande', False)],
          'ypar': [('ypare', False)],
          'ypar-': [('ypare', False)],
          'yparen': [('ypare', False)],
          'yparens': [('ypare', False)],
          'ypares': [('ypare', False)],
          'yparnas': [('ypare', False)],
          'ypars': [('yp', False)],
          'ype': [('ypa', False)],
          'ype-': [('ypa', False)],
          'ypen': [('yp', False)],
          'ypens': [('yp', False)],
          'yper': [('yp', False)],
          'yperiernas': [('yperi', False)],
          'yperiers': [('yperi', False)],
          'yperiets': [('yperi', False)],
          'yperit': [('yperit', False)],
          'yperits': [('yperi', False)],
          'yperna': [('yp', False)],
          'ypernas': [('yp', False)],
          'ypers': [('yp', False)],
          'ypet': [('yp', False)],
          'ypets': [('ype', False)],
          'ypin': [('ypi', False)],
          'ypin-': [('ypin', False)],
          'ypinnarnas': [('ypinne', False)],
          'ypinnens': [('ypinne', False)],
          'ypinns': [('ypinne', False)],
          'ypins': [('ypin', False)],
          'ypon': [('ypon', False)],
          'yponens': [('ypon', False)],
          'ypons': [('ypon', False)],
          'ypor': [('ypa', False)],
          'yporna': [('ypa', False)],
          'ypornas': [('ypa', False)],
          'ypors': [('ypa', False)],
          'ypos': [('ypos', False)],
          'ypos-': [('ypos', False)],
          'yposen': [('ypos', False)],
          'yposens': [('ypos', False)],
          'ypplanden': [('ypplande', False)],
          'ypplandens': [('ypplande', False)],
          'ypplandet': [('ypplande', False)],
          'ypropens': [('ypropen', False)],
          'yps': [('yp', False)],
          'yps-': [('yp', False)],
          'ypsens': [('yps', False)],
          'ypsin': [('ypsin', False)],
          'ypsins': [('ypsin', False)],
          'ypsons': [('ypso', False)],
          'ypt': [('ypta', False)],
          'ypt-': [('ypta', False)],
          'ypta': [('ypta', False)],
          'yptan': [('ypta', False)],
          'yptas': [('ypta', False)],
          'ypter': [('ypter', False)],
          'ypterna': [('ypter', False)],
          'ypternas': [('ypter', False)],
          'ypters': [('ypter', False)],
          'yptot': [('ypto', False)],
          'yptots': [('ypto', False)],
          'ypts': [('ypta', False)],
          'ypts-': [('ypta', False)],
          'ypöls': [('ypöl', False)],
          'ypöls-': [('ypöl', False)],
          'yr': [('yr', False)],
          'yr-': [('yr', False)],
          'yrack': [('yracka', False)],
          'yrack-': [('yracka', False)],
          'yracks': [('yracka', False)],
          'yracks-': [('yracka', False)],
          'yran': [('yra', False)],
          'yrande': [('yrande', False)],
          'yrande-': [('yrande', False)],
          'yranden': [('yrande', False)],
          'yrandens': [('yrande', False)],
          'yrandet': [('yrande', False)],
          'yrann': [('yrann', False)],
          'yrann-': [('yrann', False)],
          'yrannens': [('yrann', False)],
          'yranns-': [('yrann', False)],
          'yrans': [('yra', False)],
          'yrar': [('yr', False)],
          'yrarna': [('yr', False)],
          'yrarnas': [('yr', False)],
          'yrars': [('yr', False)],
          'yras': [('yra', False)],
          'yrassen': [('yrass', False)],
          'yrassens': [('yrass', False)],
          'yre': [('yra', False)],
          'yre-': [('yra', False)],
          'yren': [('yr', False)],
          'yrens': [('yr', False)],
          'yrer': [('yr', False)],
          'yrerna': [('yr', False)],
          'yrernas': [('yr', False)],
          'yret': [('yr', False)],
          'yrets': [('yr', False)],
          'yri': [('yri', False)],
          'yri-': [('yri', False)],
          'yrians': [('yria', False)],
          'yrias': [('yria', False)],
          'yridins': [('yridin', False)],
          'yrie': [('yria', False)],
          'yrie-': [('yrium', False)],
          'yrien': [('yri', False)],
          'yrier': [('yrier', False)],
          'yrierna': [('yrium', False)],
          'yriernas': [('yrier', False)],
          'yriers': [('yrier', False)],
          'yriet': [('yrium', False)],
          'yriets': [('yrium', False)],
          'yrighets': [('yrighet', False)],
          'yrik': [('yrik', False)],
          'yrik-': [('yrik', False)],
          'yriken': [('yrik', False)],
          'yrikens': [('yrik', False)],
          'yriks': [('yrik', False)],
          'yriks-': [('yrik', False)],
          'yrin': [('yri', False)],
          'yringar': [('yring', False)],
          'yringarna': [('yring', False)],
          'yringarnas': [('yring', False)],
          'yris': [('yri', False)],
          'yrisk': [('yriska', False)],
          'yrisk-': [('yriska', False)],
          'yrit-': [('yrit', False)],
          'yrits': [('yrit', False)],
          'yrjans': [('yrja', False)],
          'yrk': [('yrka', False)],
          'yrk-': [('yrka', False)],
          'yrkan': [('yrkan', True)],
          'yrkans': [('yrkan', True)],
          'yrkarnas': [('yrk', False)],
          'yrkas': [('yrka', False)],
          'yrke': [('yrke', False)],
          'yrken': [('yrke', False)],
          'yrkens': [('yrke', False)],
          'yrket': [('yrke', False)],
          'yrkott': [('yrkott', False)],
          'yrkottars': [('yrkott', False)],
          'yrkotten': [('yrkott', False)],
          'yrks': [('yrka', False)],
          'yrks-': [('yrka', False)],
          'yrlanden': [('yrland', False)],
          'yrlandens': [('yrland', False)],
          'yrlandet': [('yrland', False)],
          'yrlins': [('yrlina', False)],
          'yrn': [('yr', False)],
          'yrns': [('yr', False)],
          'yrol': [('yrol', False)],
          'yrol-': [('yrol', False)],
          'yrols': [('yrol', False)],
          'yromans': [('yroman', False)],
          'yrona': [('yro', False)],
          'yropen': [('yrop', False)],
          'yropens': [('yrop', False)],
          'yror': [('yra', False)],
          'yrorna': [('yra', False)],
          'yrornas': [('yra', False)],
          'yrors': [('yra', False)],
          'yros': [('yro', False)],
          'yrot': [('yro', False)],
          'yrots': [('yro', False)],
          'yrran': [('yrra', False)],
          'yrs': [('yr', False)],
          'yrs-': [('yr', False)],
          'yrsan': [('yrsa', False)],
          'yrsanden': [('yrsand', True)],
          'yrsandens': [('yrsand', True)],
          'yrsans': [('yrsa', False)],
          'yrsteg-': [('yrsteg', False)],
          'yrten': [('yrten', False)],
          'yrtens': [('yrten', False)],
          'yrtens-': [('yrten', False)],
          'yrtuts': [('yrtut', False)],
          'yrtuts-': [('yrtut', False)],
          'yrus': [('yrus', False)],
          'yrus-': [('yrus', False)],
          'yrån': [('yrå', False)],
          'yråns': [('yrå', False)],
          'ys': [('ys', False)],
          'ys-': [('ys', False)],
          'ysaker': [('ysak', False)],
          'ysanden': [('ysande', False)],
          'ysandens': [('ysande', False)],
          'ysans': [('ysa', False)],
          'ysar': [('y', False)],
          'ysaren': [('ysare', False)],
          'ysarnas': [('y', False)],
          'ysars': [('y', False)],
          'ysch': [('ysch', False)],
          'ysch-': [('ysch', False)],
          'yschan': [('yscha', False)],
          'yschen': [('ysch', False)],
          'yschens': [('ysch', False)],
          'yscher': [('ysch', False)],
          'yschers': [('ysch', False)],
          'yse': [('ysa', False)],
          'yse-': [('ysa', False)],
          'ysen': [('ys', False)],
          'ysena': [('yse', False)],
          'ysenas': [('yse', False)],
          'ysens': [('ys', False)],
          'yser': [('ys', False)],
          'yserier': [('yseri', False)],
          'yserierna': [('yseri', False)],
          'yseriernas': [('yseri', False)],
          'yseriers': [('yseri', False)],
          'yserna': [('ys', False)],
          'ysernas': [('ys', False)],
          'ysers': [('ys', False)],
          'yset': [('ys', False)],
          'ysfaktorer': [('ysfaktor', False)],
          'ysfaktorers': [('ysfaktor', False)],
          'ysier': [('ysier', False)],
          'ysierna': [('ysier', False)],
          'ysiernas': [('ysier', False)],
          'ysiers': [('ysier', False)],
          'ysik': [('ysik', False)],
          'ysik-': [('ysik', False)],
          'ysikens': [('ysik', False)],
          'ysiks': [('ysik', False)],
          'ysims': [('ysim', False)],
          'ysims-': [('ysim', False)],
          'ysin-': [('ysin', False)],
          'ysiner': [('ysin', False)],
          'ysinerna': [('ysin', False)],
          'ysinernas': [('ysin', False)],
          'ysiners': [('ysin', False)],
          'ysins': [('ysin', False)],
          'ysk': [('yska', False)],
          'ysk-': [('yska', False)],
          'yskan': [('yska', False)],
          'yskans': [('yska', False)],
          'yskar': [('ysk', False)],
          'yskarnas': [('ysk', False)],
          'yskars': [('ysk', False)],
          'ysken': [('ysk', False)],
          'yskens': [('ysk', False)],
          'yskon': [('yskon', False)],
          'yskons': [('yskon', False)],
          'yskor': [('yska', False)],
          'yskorna': [('yska', False)],
          'yskornas': [('yska', False)],
          'yskors': [('yska', False)],
          'yskotten': [('yskott', False)],
          'yskottens': [('yskott', False)],
          'yskrap': [('yskrapa', False)],
          'yskrap-': [('yskrapa', False)],
          'yskraps': [('yskrapa', False)],
          'yskraps-': [('yskrapa', False)],
          'yslag': [('yslag', False)],
          'yslags': [('yslag', False)],
          'yslags-': [('yslag', False)],
          'ysmet': [('ysm', False)],
          'ysmets': [('ysm', False)],
          'ysms': [('ysm', False)],
          'ysor': [('ysa', False)],
          'ysorna': [('ysa', False)],
          'ysornas': [('ysa', False)],
          'ysors': [('ysa', False)],
          'yss': [('yss', False)],
          'yss-': [('yss', False)],
          'yssar-': [('yssare', False)],
          'yssarens': [('yssare', False)],
          'yssarnas': [('yss', False)],
          'yssets': [('yss', False)],
          'ysslanden': [('ysslande', False)],
          'ysslandens': [('ysslande', False)],
          'ysslandet': [('ysslande', False)],
          'ysslar': [('ysslare', False)],
          'ysslarna': [('ysslare', False)],
          'ysslarnas': [('ysslare', False)],
          'yssle': [('yssla', False)],
          'yssle-': [('yssla', False)],
          'yst': [('yste', True)],
          'yst-': [('yste', True)],
          'ysta': [('ysta', False)],
          'ystan': [('ystan', False)],
          'ystans': [('ystan', False)],
          'ystans-': [('ystan', False)],
          'ystarter': [('ystart', False)],
          'ystarterna': [('ystart', False)],
          'ystarternas': [('ystart', False)],
          'ystarters': [('ystart', False)],
          'ystas': [('ysta', False)],
          'ystavar': [('ystavare', False)],
          'ystavarna': [('ystavare', False)],
          'ystavarnas': [('ystavare', False)],
          'yste': [('yste', True)],
          'ysten': [('yste', True)],
          'ystens': [('yste', True)],
          'yster': [('yster', False)],
          'ysteri': [('ysteri', False)],
          'ysteri-': [('ysteri', False)],
          'ysterie-': [('ysterium', False)],
          'ysterier': [('ysteri', False)],
          'ysterierna': [('ysteri', False)],
          'ysteriernas': [('ysterium', False)],
          'ysteriers': [('ysteri', False)],
          'ysteriet': [('ysteri', False)],
          'ysteriets': [('ysterium', False)],
          'ysterin': [('ysteri', False)],
          'ysterins': [('ysteri', False)],
          'ysteris': [('ysteri', False)],
          'ysteris-': [('ysteri', False)],
          'ysters': [('yster', False)],
          'ystet': [('yste', True)],
          'ystets': [('yste', True)],
          'ystiker': [('ystiker', False)],
          'ystikerna': [('ystiker', False)],
          'ystikernas': [('ystiker', False)],
          'ystikers': [('ystiker', False)],
          'ystnader': [('ystnad', False)],
          'ystnaderna': [('ystnad', False)],
          'ystnadernas': [('ystnad', False)],
          'ystnaders': [('ystnad', False)],
          'ystnads': [('ystnad', False)],
          'ystnads-': [('ystnad', False)],
          'ystole': [('ystole', False)],
          'ystole-': [('ystole', False)],
          'ystolen': [('ystole', False)],
          'ystolens': [('ystole', False)],
          'ystor': [('ysta', False)],
          'ystors': [('ysta', False)],
          'ystranden': [('ystrande', False)],
          'ystrandens': [('ystrande', False)],
          'ystrarnas': [('yster', False)],
          'ystringens': [('ystring', False)],
          'ystvind': [('ystvinda', False)],
          'ystyren': [('ystyren', False)],
          'ystyrens': [('ystyren', False)],
          'yställen': [('yställ', False)],
          'yställens': [('yställ', False)],
          'ystället': [('yställ', False)],
          'yställets': [('yställ', False)],
          'ysvensk': [('ysvenska', False)],
          'ysvensk-': [('ysvenska', False)],
          'yt': [('yta', False)],
          'yt-': [('yta', True)],
          'ytaken': [('ytak', False)],
          'ytaket': [('ytak', False)],
          'ytan': [('yta', False)],
          'ytanden': [('ytande', False)],
          'ytandens': [('ytande', False)],
          'ytans': [('yta', False)],
          'ytaren': [('ytare', False)],
          'ytarnas': [('ytare', False)],
          'ytars': [('yte', False)],
          'ytbitarna': [('ytbitar', False)],
          'ytbitars': [('ytbitar', False)],
          'ytbits': [('ytbitar', False)],
          'ytbits-': [('ytbitar', False)],
          'yte': [('yta', False)],
          'yte-': [('yta', False)],
          'yten': [('yt', False)],
          'ytens': [('yt', False)],
          'yter': [('yt', False)],
          'yter-': [('yter', False)],
          'yteranden': [('yterande', False)],
          'yterandens': [('yterande', False)],
          'yterier': [('yteri', False)],
          'yterierna': [('yteri', False)],
          'yteriernas': [('yteri', False)],
          'yteriets': [('yteri', False)],
          'yterits': [('yteri', False)],
          'ytern': [('yter', False)],
          'yterna': [('yt', False)],
          'yternas': [('yt', False)],
          'yterns': [('yter', False)],
          'yters': [('yt', False)],
          'ytes': [('yte', False)],
          'ytes-': [('yte', False)],
          'ytet': [('yt', False)],
          'ytets': [('yte', False)],
          'ytmins': [('ytmi', False)],
          'ytnäv-': [('ytnäve', False)],
          'ytnäve': [('ytnäve', False)],
          'ytnävs-': [('ytnäve', False)],
          'ytom-': [('ytom', False)],
          'yton': [('yton', False)],
          'ytoner': [('yton', False)],
          'ytonerna': [('yton', False)],
          'ytor': [('yta', False)],
          'ytorna': [('yta', False)],
          'ytornas': [('yta', False)],
          'ytors': [('yta', False)],
          'ytos': [('ytos', False)],
          'ytos-': [('ytos', False)],
          'ytrycken': [('ytryck', False)],
          'ytryckens': [('ytryck', False)],
          'ytrycket': [('ytryck', False)],
          'ytryckets': [('ytryck', False)],
          'ytrycks': [('ytryck', False)],
          'ytrycks-': [('ytryck', False)],
          'yts': [('yta', False)],
          'yts-': [('yta', True)],
          'ytsanden': [('ytsand', False)],
          'ytsandens': [('ytsand', False)],
          'ytsar': [('yts', False)],
          'ytsarnas': [('yts', False)],
          'ytsars': [('yts', False)],
          'ytt': [('ytta', False)],
          'ytt-': [('ytta', False)],
          'yttan': [('ytta', False)],
          'yttar': [('yttare', False)],
          'yttarna': [('ytt', False)],
          'yttarnas': [('ytt', False)],
          'ytte': [('ytte', False)],
          'ytte-': [('ytta', False)],
          'yttena': [('ytte', False)],
          'yttenas': [('ytte', False)],
          'ytter': [('ytter', True)],
          'ytteriers': [('ytteri', False)],
          'ytters': [('ytter', True)],
          'yttets': [('ytt', False)],
          'yttidens': [('yttid', False)],
          'yttigheter': [('yttighet', False)],
          'yttigheterna': [('yttighet', False)],
          'yttigheternas': [('yttighet', False)],
          'yttigheters': [('yttighet', False)],
          'yttighets-': [('yttighet', False)],
          'yttlandet': [('yttlande', False)],
          'ytto-': [('ytta', False)],
          'yttrarnas': [('ytter', True)],
          'ytts': [('ytta', False)],
          'ytts-': [('ytta', False)],
          'yttsaker': [('yttsak', False)],
          'yttsakerna': [('yttsak', False)],
          'yttsakernas': [('yttsak', False)],
          'yttsakers': [('yttsak', False)],
          'ytåg': [('ytåg', False)],
          'ytågs': [('ytåg', False)],
          'ytågs-': [('ytåg', False)],
          'yv': [('yv', False)],
          'yv-': [('yv', False)],
          'yval': [('yval', False)],
          'yvalen': [('yval', False)],
          'yvalens': [('yval', False)],
          'yvals': [('yval', False)],
          'yvals-': [('yval', False)],
          'yvar-': [('yvare', False)],
          'yvaren': [('yvare', False)],
          'yvarna': [('yv', False)],
          'yvarnas': [('yv', False)],
          'yvars': [('yv', False)],
          'yveck': [('yvecka', False)],
          'yveck-': [('yvecka', False)],
          'yvecks': [('yvecka', False)],
          'yvecks-': [('yvecka', False)],
          'yvel': [('yvel', False)],
          'yvel-': [('yvel', False)],
          'yvels': [('yvel', False)],
          'yvels-': [('yvel', False)],
          'yven': [('yv', False)],
          'yvens': [('yv', False)],
          'yvern': [('yver', False)],
          'yverns': [('yver', False)],
          'yvers': [('yver', False)],
          'yvers-': [('yver', False)],
          'yvfiskarnas': [('yvfiskare', False)],
          'yvlar': [('yvel', False)],
          'yvlar-': [('yvlare', False)],
          'yvlarens': [('yvlare', False)],
          'yvlarna': [('yvel', False)],
          'yvlarnas': [('yvel', False)],
          'yvlars': [('yvel', False)],
          'yvlingen': [('yvling', False)],
          'yvlingens': [('yvling', False)],
          'yvmoder': [('yvmor', False)],
          'yvmödrar': [('yvmor', False)],
          'yvmödrarna': [('yvmor', False)],
          'yvmödrarnas': [('yvmor', False)],
          'yvmödrars': [('yvmor', False)],
          'yvrar': [('yver', False)],
          'yvrarna': [('yver', False)],
          'yvs-': [('yv', False)],
          'yvägar': [('yväg', False)],
          'yvägarna': [('yväg', False)],
          'yvägarnas': [('yväg', False)],
          'yvärden': [('yvärde', False)],
          'yvärdens': [('yvärde', False)],
          'yx': [('yxa', True)],
          'yx-': [('yxa', True)],
          'yxar': [('yx', False)],
          'yxarna': [('yx', False)],
          'yxarnas': [('yx', False)],
          'yxars': [('yx', False)],
          'yxe': [('yxa', False)],
          'yxe-': [('yxa', False)],
          'yxen': [('yx', False)],
          'yxens': [('yx', False)],
          'yxer': [('yx', False)],
          'yxerna': [('yx', False)],
          'yxernas': [('yx', False)],
          'yxers': [('yx', False)],
          'yxorna': [('yxa', False)],
          'yxornas': [('yxa', False)],
          'yår': [('yår', False)],
          'yårs': [('yår', False)],
          'yårs-': [('yår', False)],
          'yéerna': [('yé', False)],
          'yéernas': [('yé', False)],
          'z': [('z', True)],
          'z-': [('z', True)],
          'za': [('za', False)],
          'za-': [('za', False)],
          'zak-': [('zak', False)],
          'zaks': [('zak', False)],
          'zan': [('za', False)],
          'zanden': [('zande', False)],
          'zandens': [('zande', False)],
          'zandets': [('zande', False)],
          'zanier': [('zanier', False)],
          'zanierna': [('zanier', False)],
          'zaniernas': [('zanier', False)],
          'zans': [('za', False)],
          'zar-': [('zare', False)],
          'zare': [('zare', False)],
          'zaren': [('zare', False)],
          'zarens': [('zare', False)],
          'zares': [('zare', False)],
          'zarin': [('zarin', False)],
          'zaron-': [('zaron', False)],
          'zarons': [('zaron', False)],
          'zars': [('z', False)],
          'zas': [('za', False)],
          'zation': [('zation', False)],
          'zbandets': [('zband', False)],
          'zdat': [('zdat', False)],
          'zdaten': [('zdat', False)],
          'zdatens': [('zdat', False)],
          'ze': [('ze', False)],
          'ze-': [('ze', False)],
          'zen': [('z', False)],
          'zenits': [('zenit', True)],
          'zens': [('z', False)],
          'zer': [('zer', False)],
          'zer-': [('zer', False)],
          'zeri': [('zeri', False)],
          'zeri-': [('zeri', False)],
          'zerie': [('zeria', False)],
          'zerie-': [('zeria', False)],
          'zerier': [('zeri', False)],
          'zerierna': [('zeri', False)],
          'zeriers': [('zeri', False)],
          'zeriet': [('zeri', False)],
          'zeris': [('zeri', False)],
          'zeris-': [('zeri', False)],
          'zerit': [('zeri', False)],
          'zers': [('zer', False)],
          'zers-': [('zer', False)],
          'zersarnas': [('zer', False)],
          'zersen': [('zer', False)],
          'zes': [('ze', False)],
          'zes-': [('ze', False)],
          'zetan': [('zeta', True)],
          'zetanas': [('zeta', True)],
          'zetans': [('zeta', True)],
          'zetats': [('zeta', True)],
          'zets': [('z', False)],
          'zett': [('zett', False)],
          'zett-': [('zett', False)],
          'zetten': [('zett', False)],
          'zetter': [('zett', False)],
          'zetterna': [('zett', False)],
          'zetternas': [('zett', False)],
          'zetters': [('zett', False)],
          'zetts': [('zett', False)],
          'zetts-': [('zett', False)],
          'ziden': [('zid', False)],
          'zidens': [('zid', False)],
          'zids': [('zid', False)],
          'zie': [('zia', False)],
          'zie-': [('zia', False)],
          'zier': [('zier', False)],
          'zierna': [('zier', False)],
          'zighets-': [('zighet', False)],
          'zin': [('zin', False)],
          'zink': [('zink', True)],
          'zins': [('zin', False)],
          'zior': [('zia', False)],
          'ziorna': [('zia', False)],
          'ziornas': [('zia', False)],
          'ziors': [('zia', False)],
          'zis-': [('zia', False)],
          'zisarna': [('zi', False)],
          'zisarnas': [('zi', False)],
          'zisen': [('zi', False)],
          'zisens': [('zi', False)],
          'ziskan': [('ziska', False)],
          'ziskans': [('ziska', False)],
          'ziske': [('ziska', False)],
          'ziske-': [('ziska', False)],
          'zismernas': [('zism', False)],
          'zist-': [('zist', False)],
          'zisten': [('zist', False)],
          'zistens': [('zist', False)],
          'zister': [('zist', False)],
          'zisterna': [('zist', False)],
          'zisternas': [('zist', False)],
          'zisters': [('zist', False)],
          'zjan': [('zjan', False)],
          'zjans': [('zjan', False)],
          'zlen': [('zle', False)],
          'zlens': [('zle', False)],
          'zlet': [('zle', False)],
          'zlets': [('zle', False)],
          'zlåt': [('zlåt', False)],
          'zn': [('z', True)],
          'zns': [('z', True)],
          'zoer': [('zo', False)],
          'zoerna': [('zo', False)],
          'zoernas': [('zo', False)],
          'zoers': [('zo', False)],
          'zokerits': [('zokerit', False)],
          'zol': [('zola', False)],
          'zol-': [('zola', False)],
          'zolan': [('zolan', False)],
          'zolans': [('zolan', False)],
          'zols': [('zola', False)],
          'zols-': [('zola', False)],
          'zomen': [('zom', False)],
          'zomens': [('zom', False)],
          'zoms': [('zom', False)],
          'zoms-': [('zom', False)],
          'zon': [('zon', True)],
          'zon-': [('zon', False)],
          'zona': [('zo', False)],
          'zonas': [('zo', False)],
          'zone': [('zone', False)],
          'zone-': [('zone', False)],
          'zonen': [('zon', True)],
          'zonens': [('zon', True)],
          'zones': [('zone', False)],
          'zons': [('zon', True)],
          'zons-': [('zon', False)],
          'zos': [('zo', False)],
          'zos-': [('zo', False)],
          'zots': [('zo', False)],
          'zrarnas': [('zer', False)],
          'zs': [('z', True)],
          'zt': [('z', True)],
          'zts': [('z', True)],
          'zurn': [('zur', False)],
          'zurns': [('zur', False)],
          'zy': [('zy', False)],
          'zy-': [('zy', False)],
          'zys': [('zy', False)],
          'zz': [('zz', False)],
          'zz-': [('zz', False)],
          'zzar': [('zz', False)],
          'zzarna': [('zz', False)],
          'zzarnas': [('zz', False)],
          'zze': [('zza', False)],
          'zze-': [('zza', False)],
          'zzer': [('zz', False)],
          'zzeri': [('zzeria', False)],
          'zzeri-': [('zzeria', False)],
          'zzeris': [('zzeria', False)],
          'zzeris-': [('zzeria', False)],
          'zzers': [('zz', False)],
          'zzi': [('zzi', False)],
          'zzi-': [('zzi', False)],
          'zzin': [('zzi', False)],
          'zzins': [('zzi', False)],
          'zzis': [('zzia', False)],
          'zzon': [('zzo', False)],
          'zzons': [('zzo', False)],
          'zzor': [('zza', False)],
          'zzorna': [('zza', False)],
          'zzornas': [('zza', False)],
          'zzors': [('zza', False)],
          'ángosar': [('ángos', False)],
          'ángosarnas': [('ángos', False)],
          'ángosars': [('ángos', False)],
          'äanden': [('äande', False)],
          'äandens': [('äande', False)],
          'äandets': [('äande', False)],
          'äbb': [('äbba', False)],
          'äbb-': [('äbb', False)],
          'äbbar': [('äbb', False)],
          'äbbarna': [('äbb', False)],
          'äbben': [('äbb', False)],
          'äbblar': [('äbblare', False)],
          'äbblarna': [('äbblare', False)],
          'äbblarnas': [('äbblare', False)],
          'äbblet': [('äbbel', False)],
          'äbblets': [('äbbel', False)],
          'äbbs': [('äbba', False)],
          'äbbs-': [('äbba', False)],
          'äbel': [('äbel', False)],
          'äbel-': [('äbel', False)],
          'äbels': [('äbel', False)],
          'äbels-': [('äbel', False)],
          'äben': [('äben', False)],
          'äbens': [('äben', False)],
          'äbens-': [('äben', False)],
          'äbis': [('äbis', False)],
          'äbis-': [('äbis', False)],
          'äbit': [('äbit', False)],
          'äbitar': [('äbit', False)],
          'äbits': [('äbit', False)],
          'äbits-': [('äbit', False)],
          'äblar': [('äbel', False)],
          'äblarna': [('äbel', False)],
          'äblarnas': [('äbel', False)],
          'äblessen': [('äbless', False)],
          'äblesser': [('äbless', False)],
          'äblesserna': [('äbless', False)],
          'äblessernas': [('äbless', False)],
          'äblessers': [('äbless', False)],
          'äbyx': [('äbyxa', False)],
          'äbyx-': [('äbyxa', False)],
          'äbyxornas': [('äbyxa', False)],
          'äcell': [('äcell', False)],
          'äck': [('äcka', False)],
          'äck-': [('äcka', False)],
          'äckan': [('äcka', False)],
          'äckans': [('äcka', False)],
          'äckar': [('äckare', False)],
          'äckarna': [('äckare', False)],
          'äckarnas': [('äck', False)],
          'äckelsens': [('äckelse', False)],
          'äcken': [('äcke', False)],
          'äckena': [('äcke', False)],
          'äckenas': [('äcke', False)],
          'äckens': [('äcke', False)],
          'äcker': [('äcker', False)],
          'äckerna': [('äcker', False)],
          'äckernas': [('äcker', False)],
          'äckers': [('äcker', False)],
          'äcket': [('äcke', False)],
          'äckets': [('äck', False)],
          'äckfiskar': [('äckfisk', False)],
          'äckfiskarnas': [('äckfisk', False)],
          'äckhamrar': [('äckhammare', False)],
          'äcklan': [('äckla', False)],
          'äcklanden': [('äcklande', True)],
          'äcklandens': [('äcklande', True)],
          'äcklandet': [('äcklande', False)],
          'äcklans': [('äckla', False)],
          'äcklar': [('äcklare', False)],
          'äcklarna': [('äckel', False)],
          'äcklarnas': [('äcklare', False)],
          'äckle': [('äckla', False)],
          'äckls': [('äckla', False)],
          'äcks': [('äcka', False)],
          'äcks-': [('äcka', False)],
          'äd': [('äd', False)],
          'äd-': [('äd', False)],
          'ädan': [('äda', False)],
          'ädanden': [('ädande', False)],
          'ädandens': [('ädande', False)],
          'ädans': [('äda', False)],
          'ädaren': [('ädare', False)],
          'ädarnas': [('ädare', False)],
          'ädd': [('ädda', False)],
          'ädd-': [('ädd', False)],
          'ädda': [('ädda', False)],
          'äddans': [('ädda', False)],
          'äddar': [('ädd', False)],
          'äddarna': [('ädd', False)],
          'äddarnas': [('ädd', False)],
          'ädde': [('ädde', False)],
          'ädde-': [('ädde', False)],
          'ädds': [('ädda', False)],
          'ädds-': [('ädda', False)],
          'äden': [('äd', False)],
          'ädens': [('äd', False)],
          'äder-': [('äder', False)],
          'äderits': [('äderi', False)],
          'ädern': [('äder', False)],
          'äderna': [('ad', False)],
          'äderns': [('äder', False)],
          'äders': [('ad', False)],
          'äders-': [('äder', False)],
          'ädet': [('äd', False)],
          'ädets': [('äde', False)],
          'ädhjälparnas': [('ädhjälp', False)],
          'ädis': [('ädisa', False)],
          'ädis-': [('ädisa', False)],
          'ädje': [('ädje', False)],
          'ädje-': [('ädje', False)],
          'ädocks': [('ädocka', False)],
          'ädor': [('äda', False)],
          'ädorna': [('äda', False)],
          'ädornas': [('äda', False)],
          'ädors': [('äda', False)],
          'ädrar': [('äder', False)],
          'ädrarna': [('äder', False)],
          'ädrars': [('äder', False)],
          'ädringar': [('ädring', False)],
          'ädringarnas': [('ädring', False)],
          'ädringars': [('ädring', False)],
          'ädrotens': [('ädrot', False)],
          'ädrots': [('ädrot', False)],
          'ädrots-': [('ädrot', False)],
          'ädskott': [('ädskotte', False)],
          'ädskotten': [('ädskotte', False)],
          'ädskottens': [('ädskotte', False)],
          'ädskotts-': [('ädskotte', False)],
          'ädslanden': [('ädslande', False)],
          'ädslandens': [('ädslande', False)],
          'ädslandet': [('ädslande', False)],
          'ädsle': [('ädsla', False)],
          'ädsle-': [('ädsla', False)],
          'ädslet': [('ädsel', False)],
          'äe': [('äx', False)],
          'äe-': [('äx', False)],
          'äendets': [('äende', False)],
          'äer': [('ä', False)],
          'äers': [('ä', False)],
          'äets': [('ä', False)],
          'äfer-': [('äfer', False)],
          'äferier': [('äferi', False)],
          'äferierna': [('äferi', False)],
          'äferiernas': [('äferi', False)],
          'äferiers': [('äferi', False)],
          'äffarnas': [('äff', False)],
          'äffel': [('äffla', False)],
          'äffel-': [('äffla', False)],
          'äffens': [('äff', False)],
          'äfflan': [('äffla', False)],
          'äfflans': [('äffla', False)],
          'äffle': [('äffla', False)],
          'äfflor': [('äffla', False)],
          'äfflorna': [('äffla', False)],
          'äfflornas': [('äffla', False)],
          'äfflors': [('äffla', False)],
          'äfilar': [('äfil', False)],
          'äfilarna': [('äfil', False)],
          'äfilarnas': [('äfil', False)],
          'äfilen': [('äfil', False)],
          'äfilens': [('äfil', False)],
          'äformar': [('äform', False)],
          'äformarna': [('äform', False)],
          'äformarnas': [('äform', False)],
          'äfs': [('äfsa', False)],
          'äfs-': [('äfs', False)],
          'äft': [('äfta', False)],
          'äft-': [('äfta', False)],
          'äftan': [('äfta', False)],
          'äftarnas': [('äft', False)],
          'äfts': [('äfta', False)],
          'äfts-': [('äfta', False)],
          'äg': [('äga', True)],
          'äg-': [('äga', True)],
          'ägan': [('äga', True)],
          'ägandens': [('ägande', False)],
          'ägans': [('äga', True)],
          'ägar': [('ägare', True)],
          'ägaren': [('ägare', False)],
          'ägarna': [('ägare', True)],
          'ägarnas': [('ägare', True)],
          'ägas': [('äga', False)],
          'ägate': [('ägata', False)],
          'ägate-': [('ägata', False)],
          'ägator': [('ägata', False)],
          'ägats': [('ägata', False)],
          'ägde': [('ägda', False)],
          'ägde-': [('ägda', False)],
          'äge': [('äga', False)],
          'äge-': [('äga', False)],
          'ägel': [('ägel', False)],
          'ägelsen': [('ägelse', False)],
          'ägelsens': [('ägelse', False)],
          'ägen-': [('ägen', False)],
          'ägens': [('äge', False)],
          'ägens-': [('ägen', False)],
          'ägeriernas': [('ägeri', False)],
          'ägerna': [('äger', False)],
          'ägernas': [('äger', False)],
          'ägers': [('äger', False)],
          'ägers-': [('äger', False)],
          'äget': [('äge', False)],
          'ägets': [('äge', False)],
          'ägg': [('ägg', True)],
          'ägg-': [('ägg', True)],
          'äggar': [('ägg', False)],
          'äggdags': [('äggdags', False)],
          'äggets': [('ägg', False)],
          'äggs': [('ägg', True)],
          'äggs-': [('ägg', True)],
          'ägkors': [('ägkors', False)],
          'ägla': [('ägla', False)],
          'äglagen': [('äglag', False)],
          'äglaget': [('äglag', False)],
          'äglagets': [('äglag', False)],
          'äglans': [('ägla', False)],
          'äglar': [('ägel', False)],
          'äglarna': [('ägel', False)],
          'äglarnas': [('ägel', False)],
          'äglars': [('ägel', False)],
          'äglas': [('ägla', False)],
          'äglors': [('ägla', False)],
          'ägnans': [('ägnan', False)],
          'ägner': [('ägen', False)],
          'ägnernas': [('ägen', False)],
          'ägners': [('ägen', False)],
          'ägnet': [('ägn', False)],
          'ägnets': [('ägn', False)],
          'ägo': [('äga', False)],
          'ägo-': [('äga', False)],
          'ägor': [('äga', False)],
          'ägorna': [('äga', True)],
          'ägornas': [('äga', False)],
          'ägors': [('äga', False)],
          'ägranden': [('ägrande', False)],
          'ägrandens': [('ägrande', False)],
          'ägrandet': [('ägrande', False)],
          'ägrandets': [('ägrande', False)],
          'ägrar': [('äger', False)],
          'ägrar-': [('ägrare', False)],
          'ägraren': [('ägrare', False)],
          'ägrarens': [('ägrare', False)],
          'ägrarna': [('äger', False)],
          'ägrarnas': [('ägrare', False)],
          'ägrars': [('äger', False)],
          'ägren': [('äger', False)],
          'ägrens': [('äger', False)],
          'ägs': [('äga', True)],
          'ägs-': [('äga', True)],
          'ähundars': [('ähund', False)],
          'ähus': [('ähus', False)],
          'ähäst': [('ähäst', False)],
          'ähästarnas': [('ähäst', False)],
          'äighets-': [('äighet', False)],
          'äist-': [('äist', False)],
          'äisten': [('äist', False)],
          'äistens': [('äist', False)],
          'äister': [('äist', False)],
          'äisterna': [('äist', False)],
          'äisternas': [('äist', False)],
          'äisters': [('äist', False)],
          'äistik': [('äistik', False)],
          'äistik-': [('äistik', False)],
          'äistiks': [('äistik', False)],
          'äjons': [('äjon', False)],
          'äkan': [('äka', False)],
          'äkanden': [('äkande', False)],
          'äkans': [('äka', False)],
          'äkar': [('äkare', False)],
          'äkar-': [('äkare', False)],
          'äkare': [('äkare', False)],
          'äkaren': [('äkare', False)],
          'äkarens': [('äkare', False)],
          'äkarna': [('äke', False)],
          'äkarnas': [('äkare', False)],
          'äkars': [('äke', False)],
          'äkas': [('äka', False)],
          'äke': [('äka', False)],
          'äke-': [('äka', False)],
          'äkel': [('äkel', False)],
          'äkel-': [('äkel', False)],
          'äkels-': [('äkel', False)],
          'äkelsen': [('äkelse', False)],
          'äkelsens': [('äkelse', False)],
          'äken-': [('äken', False)],
          'äkens-': [('äken', False)],
          'äket': [('äk', False)],
          'äkets': [('äke', False)],
          'äkl': [('äkla', False)],
          'äkl-': [('äkla', False)],
          'äklamp': [('äklamp', False)],
          'äklamps-': [('äklamp', False)],
          'äklan': [('äkla', False)],
          'äklandets': [('äklande', False)],
          'äklans': [('äkla', False)],
          'äklar': [('äkel', False)],
          'äklarna': [('äklare', False)],
          'äklarnas': [('äkel', False)],
          'äklars': [('äkel', False)],
          'äklas': [('äkla', False)],
          'äkling': [('äkling', False)],
          'äklings': [('äkling', False)],
          'äklings-': [('äkling', False)],
          'äklor': [('äkla', False)],
          'äklorna': [('äkla', False)],
          'äklornas': [('äkla', False)],
          'äklors': [('äkla', False)],
          'äkls-': [('äkla', False)],
          'äknarna': [('äkne', False)],
          'äknars': [('äkne', False)],
          'äkne': [('äkne', False)],
          'äknens': [('äkne', False)],
          'äkningar': [('äkning', False)],
          'äkningarna': [('äkning', False)],
          'äkningarnas': [('äkning', False)],
          'äkningars': [('äkning', False)],
          'äknings': [('äkning', False)],
          'äknings-': [('äkning', False)],
          'äkol-': [('äkol', False)],
          'äkols': [('äkol', False)],
          'äkols-': [('äkol', False)],
          'äkor': [('äka', False)],
          'äkorna': [('äka', False)],
          'äkornas': [('äka', False)],
          'äkors-': [('äkors', False)],
          'äkrans': [('äkran', False)],
          'äkrans-': [('äkran', False)],
          'äks': [('äke', False)],
          'äks-': [('äke', False)],
          'äkt': [('äkta', False)],
          'äkt-': [('äkta', False)],
          'äkta': [('äkta', False)],
          'äktan': [('äkta', False)],
          'äktans': [('äkta', False)],
          'äktar': [('äktare', False)],
          'äktar-': [('äktare', False)],
          'äktarens': [('äktare', False)],
          'äktarna': [('äktare', False)],
          'äktas': [('äkta', False)],
          'äkte': [('äkte', False)],
          'äkten': [('äkte', False)],
          'äktens': [('äkte', False)],
          'äkterierna': [('äkteri', False)],
          'äkteriernas': [('äkteri', False)],
          'äkteriers': [('äkteri', False)],
          'äkteriet': [('äkteri', False)],
          'äktet': [('äkte', False)],
          'äktets': [('äkt', False)],
          'äkts': [('äkta', False)],
          'äkttränas': [('äktträ', False)],
          'äl': [('äl', False)],
          'äl-': [('äl', False)],
          'älan': [('äla', False)],
          'älanden': [('älande', False)],
          'älandena': [('älande', False)],
          'älandenas': [('älande', False)],
          'älandens': [('älande', False)],
          'älandet': [('älande', False)],
          'älandets': [('älande', False)],
          'älans': [('äla', False)],
          'älans-': [('älan', False)],
          'älar': [('äl', False)],
          'älaren': [('älare', False)],
          'älarna': [('äl', False)],
          'älarnas': [('äl', False)],
          'älars': [('äl', False)],
          'älben': [('älben', False)],
          'älbens': [('älb', False)],
          'älde': [('älde', False)],
          'älde-': [('älde', False)],
          'älder': [('älder', False)],
          'älders': [('älder', False)],
          'äldet': [('älde', False)],
          'äldomar': [('äldom', False)],
          'äldomarna': [('äldom', False)],
          'äldrarnas': [('älder', False)],
          'älekar': [('älek', False)],
          'älekarna': [('älek', False)],
          'älekarnas': [('älek', False)],
          'äleken': [('älek', False)],
          'älekens': [('älek', False)],
          'äleks-': [('älek', False)],
          'älen': [('äl', False)],
          'älens': [('äl', False)],
          'äler': [('äl', False)],
          'älerna': [('äl', False)],
          'älernas': [('äl', False)],
          'älers': [('äl', False)],
          'älet': [('äl', False)],
          'älets': [('äl', False)],
          'älgar': [('älg', False)],
          'älgarna': [('älg', False)],
          'älgkors': [('älgko', True)],
          'älgångarna': [('älgångare', False)],
          'älgångarnas': [('älgångare', False)],
          'älgångs': [('älgång', False)],
          'älgångs-': [('älgång', False)],
          'älighets': [('älighet', False)],
          'älisk': [('äliska', False)],
          'älisk-': [('äliska', False)],
          'älk': [('älke', False)],
          'älk-': [('älke', False)],
          'älkar': [('älke', False)],
          'älkarna': [('älke', False)],
          'älkars': [('älke', False)],
          'älke': [('älke', False)],
          'älke-': [('älke', False)],
          'älken': [('älke', False)],
          'älkens': [('älke', False)],
          'älks': [('älke', False)],
          'älks-': [('älke', False)],
          'ällagen': [('ällage', False)],
          'ällan': [('ällan', False)],
          'ällandets': [('ällande', False)],
          'ällans': [('älla', False)],
          'ällar': [('ällare', False)],
          'ällar-': [('ällare', False)],
          'ällarna': [('äll', False)],
          'ällarnas': [('äll', False)],
          'ällars': [('älle', False)],
          'älle': [('älle', False)],
          'älle-': [('älle', False)],
          'ällena': [('älle', False)],
          'ällenas': [('älle', False)],
          'ällens': [('äll', False)],
          'äller': [('ällra', False)],
          'äller-': [('ällra', False)],
          'ället': [('älle', False)],
          'ällets': [('älle', False)],
          'ällkor': [('ällko', False)],
          'ällkors': [('ällko', False)],
          'ällmåns': [('ällmåns', False)],
          'ällstudie-': [('ällstudium', False)],
          'ällstudierna': [('ällstudium', False)],
          'ällstudiernas': [('ällstudium', False)],
          'ällstudiers': [('ällstudium', False)],
          'älmarnas': [('älm', False)],
          'älms': [('älm', False)],
          'älmåns-': [('älmåns', False)],
          'älningar': [('älning', False)],
          'älningarna': [('älning', False)],
          'älningarnas': [('älning', False)],
          'älningars': [('älning', False)],
          'älnings': [('älning', False)],
          'älnings-': [('älning', False)],
          'älor': [('äla', False)],
          'älorna': [('äla', False)],
          'älornas': [('äla', False)],
          'älors': [('äla', False)],
          'älp': [('älp', False)],
          'älpar-': [('älpare', False)],
          'älps': [('älp', False)],
          'äls': [('äls', False)],
          'äls-': [('äl', False)],
          'älsar-': [('älsare', False)],
          'älsarens': [('älsare', False)],
          'älsarnas': [('äls', False)],
          'älse': [('älse', False)],
          'älse-': [('älse', False)],
          'älsen': [('älsena', False)],
          'älsens': [('älsena', False)],
          'älsing': [('älsing', False)],
          'älsing-': [('älsing', False)],
          'älsingar': [('älsing', False)],
          'älsingarna': [('älsing', False)],
          'älsingarnas': [('älsing', False)],
          'älsingars': [('älsing', False)],
          'älsings': [('älsing', False)],
          'älsings-': [('älsing', False)],
          'ält': [('ält', False)],
          'ält-': [('älta', False)],
          'ältan': [('älta', False)],
          'ältans': [('älta', False)],
          'ältar': [('älte', False)],
          'ältarna': [('ältare', False)],
          'ältarnas': [('älte', False)],
          'ältars': [('älte', False)],
          'älte': [('älte', False)],
          'älte-': [('älte', False)],
          'älten': [('älte', False)],
          'ältens': [('älte', False)],
          'ältes': [('älte', False)],
          'ältet': [('älte', False)],
          'ältets': [('ält', False)],
          'ältorna': [('älta', False)],
          'ältros-': [('ältros', False)],
          'älts': [('älta', False)],
          'älts-': [('älta', False)],
          'älunge': [('älunge', False)],
          'älunge-': [('älunge', False)],
          'älv': [('älva', True), ('älv', True)],
          'älv-': [('älva', True), ('älv', True)],
          'älvan': [('älva', True)],
          'älvans': [('älva', False)],
          'älvars': [('älv', False)],
          'älvens': [('älv', False)],
          'älvor': [('älva', True)],
          'älvorna': [('älva', True)],
          'älvornas': [('älva', True)],
          'älvors': [('älva', True)],
          'älvs': [('älv', True), ('älva', True)],
          'älvs-': [('älv', True), ('älva', True)],
          'äm': [('ämma', False)],
          'äm-': [('äm', False)],
          'ämanden': [('ämande', False)],
          'ämar': [('ämare', False)],
          'ämar-': [('ämare', False)],
          'ämare': [('ämare', False)],
          'ämaren': [('ämare', False)],
          'ämarna': [('ämare', False)],
          'ämarnas': [('ämare', False)],
          'ämask': [('ämask', False)],
          'ämask-': [('ämask', False)],
          'ämbanden': [('ämband', False)],
          'ämbandens': [('ämband', False)],
          'ämbandet': [('ämband', False)],
          'ämbar': [('ämbar', True)],
          'ämbar-': [('ämbar', True)],
          'ämbaren': [('ämbar', True)],
          'ämen': [('äm', False)],
          'ämens': [('äm', False)],
          'ämer': [('äm', False)],
          'ämerna': [('äm', False)],
          'ämernas': [('äm', False)],
          'ämers': [('äm', False)],
          'ämet': [('äm', False)],
          'ämets': [('äm', False)],
          'ämjan': [('ämja', False)],
          'ämjans': [('ämja', False)],
          'äml': [('ämla', False)],
          'äml-': [('ämla', False)],
          'ämlarnas': [('ämmel', False)],
          'ämman': [('ämma', False)],
          'ämmarens': [('ämmare', False)],
          'ämmars': [('äm', False)],
          'ämme': [('ämme', False)],
          'ämmen': [('äm', False)],
          'ämmens': [('äm', False)],
          'ämmer': [('ämmer', False)],
          'ämmets': [('ämme', False)],
          'ämnar': [('ämnare', False)],
          'ämnarna': [('ämnare', False)],
          'ämne': [('ämne', False)],
          'ämnen': [('ämne', False)],
          'ämnens': [('ämne', False)],
          'ämnes': [('ämne', False)],
          'ämnes-': [('ämne', False)],
          'ämnet': [('ämne', False)],
          'ämo': [('ämma', False)],
          'ämo-': [('ämma', False)],
          'ämp': [('ämpa', False)],
          'ämp-': [('ämpa', False)],
          'ämpan': [('ämpa', False)],
          'ämpans': [('ämpa', False)],
          'ämpar': [('ämpare', False)],
          'ämpar-': [('ämpare', False)],
          'ämparens': [('ämpare', False)],
          'ämparna': [('ämpare', False)],
          'ämpars': [('ämpe', False)],
          'ämpas': [('ämpa', False)],
          'ämpe': [('ämpe', False)],
          'ämpe-': [('ämpe', False)],
          'ämpen': [('ämpe', False)],
          'ämpens': [('ämpe', False)],
          'ämpor': [('ämpor', False)],
          'ämporna': [('ämpor', False)],
          'ämpornas': [('ämpor', False)],
          'ämpors': [('ämpor', False)],
          'ämps': [('ämpa', False)],
          'ämps-': [('ämpa', False)],
          'äms': [('äm', False)],
          'äms-': [('äm', False)],
          'ämt': [('ämte', False)],
          'ämt-': [('ämte', False)],
          'ämtar': [('ämtare', False)],
          'ämtarna': [('ämtare', False)],
          'ämtarnas': [('ämtare', False)],
          'ämtars': [('ämte', False)],
          'ämten': [('ämte', False)],
          'ämtens': [('ämte', False)],
          'ämts': [('ämte', False)],
          'ämts-': [('ämte', False)],
          'än-': [('än', False)],
          'änader': [('änad', False)],
          'änaderna': [('änad', False)],
          'änadernas': [('änad', False)],
          'änaders': [('änad', False)],
          'änads': [('änad', False)],
          'änads-': [('änad', False)],
          'änagets': [('änage', False)],
          'änanden': [('änande', False)],
          'änar': [('änare', False)],
          'änar-': [('änare', False)],
          'änaren': [('änare', False)],
          'änarens': [('änare', False)],
          'änarnas': [('änare', False)],
          'änd': [('ände', True), ('ända', True)],
          'änd-': [('ände', True), ('ända', True)],
          'ända': [('ända', False)],
          'ändans': [('ända', False)],
          'ändar': [('ände', True)],
          'ändar-': [('ändare', False)],
          'ändarens': [('ändare', False)],
          'ändarna': [('ände', True)],
          'ändarnas': [('ände', False)],
          'ändars': [('ände', False)],
          'ändas': [('ända', False)],
          'ände': [('ända', True), ('ände', True)],
          'ände-': [('ända', True)],
          'änden': [('ände', False)],
          'ändena': [('ände', False)],
          'ändenas': [('ände', False)],
          'ändens': [('ände', False)],
          'änder': [('and', False)],
          'änderna': [('and', False)],
          'ändernas': [('and', False)],
          'änders': [('and', False)],
          'ändes': [('ände', False)],
          'ändes-': [('ände', False)],
          'ändet': [('ände', False)],
          'ändis-': [('ändis', False)],
          'ändos-': [('ändo', False)],
          'ändringarna': [('ändring', False)],
          'änds': [('ände', True), ('ända', True)],
          'änds-': [('ände', True), ('ända', True)],
          'ändsk': [('ändska', False)],
          'ändsk-': [('ändska', False)],
          'ändslandets': [('ändslande', False)],
          'änen': [('än', False)],
          'änens': [('än', False)],
          'äner': [('än', False)],
          'änerna': [('än', False)],
          'änernas': [('än', False)],
          'äners': [('än', False)],
          'änet': [('än', False)],
          'äng': [('äng', True)],
          'äng-': [('äng', True)],
          'änga': [('änga', False)],
          'änga-': [('änga', False)],
          'ängan': [('änga', False)],
          'ängans': [('änga', False)],
          'ängar': [('äng', True)],
          'ängar-': [('ängare', False)],
          'ängarens': [('ängare', False)],
          'ängarna': [('äng', True)],
          'ängarnas': [('äng', True)],
          'ängas': [('änga', False)],
          'änge': [('änge', False)],
          'ängen': [('äng', True)],
          'ängens': [('äng', True)],
          'änger': [('änger', True)],
          'ängerna': [('ång', False)],
          'ängernas': [('ång', False)],
          'ängers': [('änger', True)],
          'änges': [('änge', False)],
          'änges-': [('änge', False)],
          'änget': [('änge', False)],
          'ängets': [('äng', False)],
          'ängla': [('ängel', False)],
          'ängornas': [('änga', False)],
          'ängors': [('änga', False)],
          'ängrarnas': [('änger', False)],
          'ängs': [('äng', True)],
          'ängs-': [('äng', True)],
          'ängslandets': [('ängslande', True)],
          'ängslen': [('ängsel', False)],
          'ängslens': [('ängsel', False)],
          'ängslet': [('ängsle', False)],
          'ängslets': [('ängsel', False)],
          'ängsten': [('ängsten', False)],
          'ängtanden': [('ängtande', False)],
          'ängtandens': [('ängtande', False)],
          'änitet': [('änitet', False)],
          'änitets': [('änitet', False)],
          'änjors': [('änja', False)],
          'änk': [('änka', False)],
          'änk-': [('änka', False)],
          'änkar': [('änk', False)],
          'änkarna': [('änk', False)],
          'änkarnas': [('änk', False)],
          'änke': [('änka', True)],
          'änken': [('änke', False)],
          'änkens': [('änke', False)],
          'änker': [('änker', False)],
          'änkerna': [('änker', False)],
          'änkernas': [('änker', False)],
          'änkers': [('änker', False)],
          'änkes': [('änke', False)],
          'änket': [('änke', False)],
          'änkets': [('änk', False)],
          'änks': [('änka', False)],
          'änks-': [('änka', True)],
          'ännan': [('änna', False)],
          'ännans': [('änna', False)],
          'ännarna': [('ännare', False)],
          'ännarnas': [('ännare', False)],
          'änne': [('änne', False)],
          'änne-': [('änne', False)],
          'ännen': [('änne', True)],
          'ännens': [('änne', True)],
          'änner': [('än', False)],
          'ännerna': [('än', False)],
          'ännernas': [('än', False)],
          'änners': [('än', False)],
          'ännes': [('änne', False)],
          'ännes-': [('änne', False)],
          'ännet': [('änne', True)],
          'ännets': [('änne', True)],
          'änning': [('änning', False)],
          'änning-': [('änning', False)],
          'änningar': [('änning', False)],
          'änningarna': [('änning', False)],
          'änningarnas': [('änning', False)],
          'änningars': [('änning', False)],
          'ännings': [('änning', False)],
          'ännings-': [('änning', False)],
          'änns': [('änne', True)],
          'änns-': [('änne', True)],
          'äns-': [('än', False)],
          'änsa': [('änsa', False)],
          'änsarnas': [('äns', False)],
          'änsas': [('änsa', False)],
          'änsflagg': [('änsflagg', False)],
          'änsflaggs': [('änsflagg', False)],
          'änskans': [('änska', False)],
          'änskaper': [('änskap', False)],
          'änskaperna': [('änskap', False)],
          'änskapernas': [('änskap', False)],
          'änskapers': [('änskap', False)],
          'änskaps': [('änskap', False)],
          'änsko': [('änska', False)],
          'änskor': [('änska', False)],
          'änskorna': [('änska', False)],
          'änskornas': [('änska', False)],
          'änskors': [('änska', False)],
          'änslandet': [('änslande', False)],
          'änsle': [('änsla', False)],
          'änsle-': [('änsla', False)],
          'änst-': [('änst', False)],
          'änsten': [('änst', False)],
          'änstens': [('änst', False)],
          'änster': [('änst', False)],
          'änsterna': [('änst', False)],
          'änsternas': [('änst', False)],
          'änsters': [('änst', False)],
          'änstrans': [('änstran', False)],
          'änt-': [('änt', False)],
          'änta': [('änta', False)],
          'äntan': [('änta', False)],
          'äntans': [('äntan', False)],
          'äntas': [('änta', False)],
          'äntets': [('änt', False)],
          'äntrar': [('äntrare', False)],
          'äntrarna': [('äntrare', False)],
          'äntringarna': [('äntring', False)],
          'äntringarnas': [('äntring', True)],
          'änts': [('änt', False)],
          'äp': [('äp', False)],
          'äp-': [('äp', False)],
          'äpande': [('äpande', False)],
          'äpande-': [('äpande', False)],
          'äpen': [('äp', False)],
          'äpens': [('äp', False)],
          'äpet': [('äp', False)],
          'äpets': [('äp', False)],
          'äpinns': [('äpinne', False)],
          'äplin': [('äplina', False)],
          'äplin-': [('äplina', False)],
          'äplins': [('äplina', False)],
          'äplins-': [('äplina', False)],
          'äpluggar': [('äplugg', False)],
          'äpluggarna': [('äplugg', False)],
          'äpluggarnas': [('äplugg', False)],
          'äpnarna': [('äpnare', False)],
          'äportarnas': [('äport', False)],
          'äppar-': [('äppare', False)],
          'äpparnas': [('äpp', False)],
          'äpper': [('äpp', False)],
          'äppets': [('äpp', False)],
          'äpplen': [('äpple', False)],
          'äpplens': [('äpple', False)],
          'äpplets': [('äpple', False)],
          'äpring': [('äpring', False)],
          'äpringar': [('äpring', False)],
          'äpringarnas': [('äpring', False)],
          'äprings': [('äpring', False)],
          'äprings-': [('äpring', False)],
          'äps': [('äp', False)],
          'äps-': [('äp', False)],
          'äpskor': [('äpsko', False)],
          'äpskors': [('äpsko', False)],
          'äpsten': [('äpst', False)],
          'äpstens': [('äpst', False)],
          'äpärter': [('äpärter', False)],
          'äpärterna': [('äpärter', False)],
          'äpärternas': [('äpärter', False)],
          'äpärters': [('äpärter', False)],
          'äpärts': [('äpärter', False)],
          'äpärts-': [('äpärter', False)],
          'är': [('är', False)],
          'är-': [('är', False)],
          'äradena': [('ärad', False)],
          'äradenas': [('ärad', False)],
          'äradens': [('ärad', False)],
          'äradet': [('ärad', False)],
          'äramar': [('äram', False)],
          'äramarna': [('äram', False)],
          'ärams': [('äram', False)],
          'ärams-': [('äram', False)],
          'äran': [('ära', True)],
          'ärande': [('ärande', False)],
          'ärande-': [('ärande', False)],
          'äranden': [('ärande', False)],
          'ärandens': [('ärande', False)],
          'ärandet': [('ärande', False)],
          'ärans': [('ära', True)],
          'ärans-': [('äran', False)],
          'ärar': [('ärare', False)],
          'ärarna': [('ärare', False)],
          'ärarnas': [('är', False)],
          'ärars': [('är', False)],
          'äras': [('ära', False)],
          'ärasten': [('äraste', False)],
          'ärastens': [('äraste', False)],
          'ärbon': [('ärbo', False)],
          'ärbons': [('ärbo', False)],
          'ärbroder': [('ärbror', False)],
          'ärbrors': [('ärbror', False)],
          'ärbröderna': [('ärbror', False)],
          'ärbröders': [('ärbror', False)],
          'ärbön': [('ärböna', False)],
          'ärdarnas': [('ärd', False)],
          'ärde': [('ärde', False)],
          'ärde-': [('ärde', False)],
          'ärdet': [('ärde', False)],
          'ärdomarna': [('ärdom', False)],
          'ärdsdans': [('ärdsdans', False)],
          'ärdslandets': [('ärdslande', False)],
          'äre': [('ära', False)],
          'äre-': [('ära', False)],
          'ären': [('är', False)],
          'ärenden': [('ärende', False)],
          'ärendens': [('ärende', False)],
          'ärens': [('är', False)],
          'ärer': [('är', False)],
          'ärerna': [('är', False)],
          'ärernas': [('är', False)],
          'ärers': [('är', False)],
          'äret': [('är', False)],
          'ärets': [('är', False)],
          'ärfader-': [('ärfar', False)],
          'ärfadern': [('ärfar', False)],
          'ärfaderns': [('ärfar', False)],
          'ärfaders': [('ärfar', False)],
          'ärfar': [('ärfar', False)],
          'ärfar-': [('ärfar', False)],
          'ärfläck': [('ärfläcka', False)],
          'ärfrågan': [('ärfråga', False)],
          'ärfrågans': [('ärfråga', False)],
          'ärfäder': [('ärfar', False)],
          'ärfäders': [('ärfar', False)],
          'ärganden': [('ärgande', False)],
          'ärgar': [('ärgare', False)],
          'ärgarna': [('ärgare', False)],
          'ärgarnas': [('ärgare', False)],
          'ärge': [('ärge', False)],
          'ärgen': [('ärg', True)],
          'ärgens': [('ärg', True)],
          'ärget': [('ärge', False)],
          'ärgets': [('ärge', False)],
          'ärglandet': [('ärglande', False)],
          'ärglandets': [('ärglande', False)],
          'ärgs': [('ärg', True)],
          'ärgs-': [('ärg', True)],
          'äribb': [('äribba', False)],
          'äribb-': [('äribba', False)],
          'äribbs': [('äribba', False)],
          'äribbs-': [('äribba', False)],
          'ärie': [('ärie', False)],
          'ärie-': [('ärie', False)],
          'ärien': [('ärie', False)],
          'äriens': [('ärie', False)],
          'ärier': [('ärie', False)],
          'ärierna': [('ärie', False)],
          'äriernas': [('ärie', False)],
          'äriers': [('ärie', False)],
          'äries': [('ärie', False)],
          'äries-': [('ärie', False)],
          'ärighets': [('ärighet', False)],
          'äringar': [('äring', False)],
          'äringarna': [('äring', False)],
          'äringarnas': [('äring', False)],
          'äris': [('äris', False)],
          'äris-': [('äris', False)],
          'ärisarna': [('äris', False)],
          'ärisens': [('äris', False)],
          'ärj': [('ärja', False)],
          'ärj-': [('ärja', False)],
          'ärjans': [('ärja', False)],
          'ärjar': [('ärjare', False)],
          'ärjarna': [('ärjare', False)],
          'ärjs': [('ärja', False)],
          'ärjs-': [('ärja', False)],
          'ärkan': [('ärka', False)],
          'ärkans': [('ärka', False)],
          'ärkar': [('ärkare', False)],
          'ärkarna': [('ärkare', False)],
          'ärkarnas': [('ärk', False)],
          'ärkas': [('ärka', False)],
          'ärkass': [('ärkasse', False)],
          'ärkass-': [('ärkasse', False)],
          'ärkasse': [('ärkasse', False)],
          'ärkassens': [('ärkasse', False)],
          'ärke': [('ärke', False)],
          'ärke-': [('ärke', False)],
          'ärken': [('ärke', False)],
          'ärkens': [('ärke', False)],
          'ärket': [('ärke', False)],
          'ärkott-': [('ärkotte', False)],
          'ärkottar': [('ärkotte', False)],
          'ärkottarna': [('ärkotte', False)],
          'ärkottarnas': [('ärkotte', False)],
          'ärkottens': [('ärkotte', False)],
          'ärkotts': [('ärkotte', False)],
          'ärkotts-': [('ärkotte', False)],
          'ärl': [('ärla', False)],
          'ärl-': [('ärla', False)],
          'ärlandets': [('ärlande', False)],
          'ärleks': [('ärlek', False)],
          'ärls': [('ärla', False)],
          'ärls-': [('ärla', False)],
          'ärman': [('ärma', False)],
          'ärmandens': [('ärmande', False)],
          'ärmans': [('ärma', False)],
          'ärmar': [('ärm', True)],
          'ärmarna': [('ärm', True)],
          'ärmarnas': [('ärm', True)],
          'ärmbräde': [('ärmbräde', True), ('ärmbräda', True)],
          'ärme': [('ärme', False)],
          'ärme-': [('ärme', False)],
          'ärmen': [('ärm', False)],
          'ärmens': [('ärm', True)],
          'ärmes-': [('ärme', False)],
          'ärmet': [('ärme', False)],
          'ärmets': [('ärm', False)],
          'ärmoder': [('ärmor', False)],
          'ärmor': [('ärmor', False)],
          'ärmors': [('ärmor', False)],
          'ärmödrarna': [('ärmor', False)],
          'ärmödrarnas': [('ärmor', False)],
          'ärmödrars': [('ärmor', False)],
          'ärn': [('ärna', False)],
          'ärn-': [('ärna', False)],
          'ärnar': [('ärnare', False)],
          'ärnarna': [('ärnare', False)],
          'ärnarnas': [('ärn', False)],
          'ärne-': [('ärna', False)],
          'ärnekar': [('ärnek', False)],
          'ärnets': [('ärn', False)],
          'ärns': [('ärna', False)],
          'ärns-': [('ärna', False)],
          'äro': [('ära', False)],
          'äro-': [('ära', False)],
          'ärområdet': [('ärområde', False)],
          'äron': [('äron', False)],
          'äronen': [('äron', False)],
          'äronens': [('äron', False)],
          'ärons': [('äron', False)],
          'ärons-': [('äron', False)],
          'äror': [('ära', False)],
          'ärorna': [('ära', False)],
          'ärornas': [('ära', False)],
          'ärors': [('ära', False)],
          'ärp-': [('ärpe', False)],
          'ärpar': [('ärpe', False)],
          'ärparna': [('ärp', False)],
          'ärparnas': [('ärpe', False)],
          'ärpars': [('ärp', False)],
          'ärpe': [('ärpe', False)],
          'ärpe-': [('ärpe', False)],
          'ärpen': [('ärpe', False)],
          'ärpeng': [('ärpeng', False)],
          'ärpengarnas': [('ärpeng', False)],
          'ärpengars': [('ärpeng', False)],
          'ärpengs': [('ärpeng', False)],
          'ärpengs-': [('ärpeng', False)],
          'ärpens': [('ärpe', False)],
          'ärpes': [('ärpe', False)],
          'ärpes-': [('ärpe', False)],
          'ärps-': [('ärpe', False)],
          'ärr': [('ärr', True)],
          'ärr-': [('ärr', True)],
          'ärran': [('ärra', False)],
          'ärrems': [('ärrem', False)],
          'ärrev': [('ärrev', False)],
          'ärrevs-': [('ärrev', False)],
          'ärrs': [('ärr', False)],
          'ärrs-': [('ärr', True)],
          'ärs': [('är', False)],
          'ärs-': [('är', False)],
          'ärsan': [('ärsa', False)],
          'ärsans': [('ärsa', False)],
          'ärsarna': [('ärs', False)],
          'ärsarnas': [('ärs', False)],
          'ärsats': [('ärsa', False)],
          'ärsel': [('ärsele', False)],
          'ärsel-': [('ärsele', False)],
          'ärsels': [('ärsele', False)],
          'ärsels-': [('ärsele', False)],
          'ärsen': [('ärs', False)],
          'ärsets': [('ärs', False)],
          'ärskarnas': [('ärskare', False)],
          'ärskris': [('ärskri', False)],
          'ärsteg': [('ärstege', False)],
          'ärstegen': [('ärstege', False)],
          'ärstegens': [('ärstege', False)],
          'ärstegs': [('ärstege', False)],
          'ärstegs-': [('ärstege', False)],
          'ärsten': [('ärsten', False)],
          'ärstudie': [('ärstudium', False)],
          'ärstudier': [('ärstudium', False)],
          'ärstudierna': [('ärstudium', False)],
          'ärstudiernas': [('ärstudium', False)],
          'ärt': [('ärt', True)],
          'ärt-': [('ärt', True)],
          'ärtan': [('ärta', False)],
          'ärtarnas': [('ärt', False)],
          'ärter': [('ärt', True), ('ärta', True)],
          'ärterna': [('ärt', True), ('ärta', True)],
          'ärternas': [('ärta', True), ('ärt', True)],
          'ärters': [('ärta', True), ('ärt', True)],
          'ärträna': [('ärträ', False)],
          'ärträns': [('ärträ', False)],
          'ärts': [('ärt', True)],
          'ärts-': [('ärt', True)],
          'ärv': [('ärva', False)],
          'ärv-': [('ärva', False)],
          'ärvals': [('ärval', False)],
          'ärvar': [('ärv', False)],
          'ärvar-': [('ärvare', False)],
          'ärvarens': [('ärvare', False)],
          'ärvas': [('ärva', False)],
          'ärves': [('ärve', False)],
          'ärvs': [('ärva', False)],
          'ärvs-': [('ärva', False)],
          'äs': [('äs', False)],
          'äs-': [('äs', False)],
          'äsanden': [('äsande', False)],
          'äsandens': [('äsande', False)],
          'äsans': [('äsa', False)],
          'äsar': [('äs', False)],
          'äsaren': [('äsare', False)],
          'äsars': [('äs', False)],
          'äsch': [('äsch', False)],
          'äsch-': [('äsch', False)],
          'äschen': [('äsch', False)],
          'äschens': [('äsch', False)],
          'äscher': [('äsch', False)],
          'äschers': [('äsch', False)],
          'äse': [('äsa', False)],
          'äse-': [('äsa', False)],
          'äsekrets': [('äsekrets', False)],
          'äsekrets-': [('äsekrets', False)],
          'äsen': [('äs', False)],
          'äsen-': [('äsen', False)],
          'äsena': [('äsen', False)],
          'äsenas': [('äsen', False)],
          'äsens': [('äs', False)],
          'äsens-': [('äsen', False)],
          'äser': [('äs', False)],
          'äserna': [('äs', False)],
          'äsernas': [('äs', False)],
          'äsers': [('äs', False)],
          'äset': [('äs', False)],
          'äsets': [('äs', False)],
          'äsfiskar': [('äsfisk', False)],
          'äsfiskarna': [('äsfisk', False)],
          'äsidan': [('äsida', False)],
          'äsidans': [('äsida', False)],
          'äside-': [('äsida', False)],
          'äsides': [('äsida', False)],
          'äsk': [('äska', False)],
          'äsk-': [('äska', False)],
          'äskallen': [('äskalle', False)],
          'äskallens': [('äskalle', False)],
          'äskan': [('äska', False)],
          'äskans': [('äska', False)],
          'äskar': [('äsker', False)],
          'äskarna': [('äsker', False)],
          'äskarnas': [('äsk', False)],
          'äskars': [('äsker', False)],
          'äskeden': [('äsked', False)],
          'äskedens': [('äsked', False)],
          'äsken': [('äsk', False)],
          'äskens': [('äsk', False)],
          'äsker': [('äsker', False)],
          'äskers': [('äsker', False)],
          'äskets': [('äsk', False)],
          'äsklandets': [('äskland', False)],
          'äsko': [('äsko', False)],
          'äskor': [('äska', False)],
          'äskorna': [('äsko', False)],
          'äskornas': [('äsko', False)],
          'äskors': [('äsko', False)],
          'äskändar': [('äskände', False)],
          'äskändarna': [('äskände', False)],
          'äskändarnas': [('äskände', False)],
          'äslag': [('äslag', False)],
          'äslags': [('äslag', False)],
          'äslags-': [('äslag', False)],
          'äslips': [('äslip', False)],
          'äslips-': [('äslip', False)],
          'äslotts': [('äslott', False)],
          'äsm': [('äsma', False)],
          'äsm-': [('äsma', False)],
          'äsman': [('äsma', False)],
          'äsmans': [('äsma', False)],
          'äsmatt': [('äsmatta', False)],
          'äsmatt-': [('äsmatta', False)],
          'äsmatts': [('äsmatta', False)],
          'äsmatts-': [('äsmatta', False)],
          'äsnen': [('äsen', False)],
          'äsnip': [('äsnipa', False)],
          'äsnip-': [('äsnipa', False)],
          'äsnips': [('äsnipa', False)],
          'äsnips-': [('äsnipa', False)],
          'äsor': [('äsa', False)],
          'äsorna': [('äsa', False)],
          'äsornas': [('äsa', False)],
          'äsors': [('äsa', False)],
          'äspen': [('äsp', False)],
          'äspens': [('äsp', False)],
          'äspet': [('äsp', False)],
          'äspets': [('äsp', False)],
          'äsprit': [('äsprit', False)],
          'äsprits': [('äsprit', False)],
          'äsprits-': [('äsprit', False)],
          'äspån': [('äspån', False)],
          'äspåns': [('äspån', False)],
          'äspåns-': [('äspån', False)],
          'äsringar': [('äsring', False)],
          'äss': [('äss', True)],
          'äss-': [('äss', False)],
          'ässans': [('ässa', False)],
          'ässar': [('ässe', False)],
          'ässar-': [('ässare', False)],
          'ässarens': [('ässare', False)],
          'ässarna': [('äss', False)],
          'ässarnas': [('äss', False)],
          'ässars': [('ässe', False)],
          'ässel': [('ässla', False)],
          'ässel-': [('ässla', False)],
          'ässen': [('äss', True)],
          'ässens': [('äss', True)],
          'ässets': [('äss', True)],
          'ässle': [('ässla', False)],
          'ässle-': [('ässla', False)],
          'ässlor': [('ässla', False)],
          'ässlorna': [('ässla', False)],
          'ässlornas': [('ässla', False)],
          'ässlors': [('ässla', False)],
          'ässo-': [('ässa', False)],
          'äst': [('äst', False)],
          'ästa': [('ästa', False)],
          'ästa-': [('ästa', False)],
          'ästan': [('ästa', False)],
          'ästans': [('ästa', False)],
          'ästans-': [('ästan', False)],
          'ästar': [('äst', False)],
          'ästar-': [('ästare', False)],
          'ästarna': [('ästare', False)],
          'ästarnas': [('äst', False)],
          'ästars': [('äst', False)],
          'ästas': [('ästa', False)],
          'ästat': [('ästa', False)],
          'ästats': [('ästa', False)],
          'ästavarna': [('ästav', False)],
          'äste': [('äste', False)],
          'äste-': [('äste', False)],
          'ästen': [('äste', False)],
          'ästens': [('äste', False)],
          'äster': [('äster', False)],
          'ästeri': [('ästeri', False)],
          'ästeri-': [('ästeri', False)],
          'ästerier': [('ästeri', False)],
          'ästerierna': [('ästeri', False)],
          'ästeriers': [('ästeri', False)],
          'ästeriet': [('ästeri', False)],
          'ästeris': [('ästeri', False)],
          'ästeris-': [('ästeri', False)],
          'ästers': [('äster', False)],
          'ästet': [('äste', False)],
          'ästick': [('ästick', False)],
          'ästick-': [('ästick', False)],
          'ästicks': [('ästick', False)],
          'ästicks-': [('ästick', False)],
          'ästis': [('ästis', False)],
          'ästis-': [('ästis', False)],
          'ästjärn': [('ästjärn', False)],
          'ästjärns': [('ästjärn', False)],
          'ästjärns-': [('ästjärn', False)],
          'ästman': [('ästman', False)],
          'äston': [('äston', False)],
          'ästons': [('äston', False)],
          'ästons-': [('äston', False)],
          'ästor': [('ästa', False)],
          'ästors': [('ästa', False)],
          'ästranden': [('ästrande', False)],
          'ästrandens': [('ästrande', False)],
          'ästrarnas': [('äster', False)],
          'ästras': [('ästras', False)],
          'ästringens': [('ästring', False)],
          'ästrums': [('ästrum', False)],
          'ästuv': [('ästuva', False)],
          'ästuv-': [('ästuva', False)],
          'ästuvs': [('ästuva', False)],
          'ästuvs-': [('ästuva', False)],
          'ästvinds': [('ästvind', False)],
          'ästvinds-': [('ästvind', False)],
          'ästycken': [('ästycke', False)],
          'ästyckena': [('ästycke', False)],
          'ästyckenas': [('ästycke', False)],
          'ästyckens': [('ästycke', False)],
          'ästycket': [('ästycke', False)],
          'ästyckets': [('ästycke', False)],
          'ästycks': [('ästycke', False)],
          'ästänk': [('ästänka', False)],
          'ästänk-': [('ästänka', False)],
          'ästänks': [('ästänka', False)],
          'ästänks-': [('ästänka', False)],
          'äsvanor': [('äsvana', False)],
          'äsvanorna': [('äsvana', False)],
          'äsvanornas': [('äsvana', False)],
          'äsvanors': [('äsvana', False)],
          'äsvarvar': [('äsvarv', False)],
          'äsvarvarna': [('äsvarv', False)],
          'äsvarvarnas': [('äsvarv', False)],
          'äsving': [('äsvinge', False)],
          'äsving-': [('äsvinge', False)],
          'äsvingar': [('äsvinge', False)],
          'äsvingarna': [('äsvinge', False)],
          'äsvingarnas': [('äsvinge', False)],
          'äsvingars': [('äsvinge', False)],
          'äsvingen': [('äsvinge', False)],
          'äsvingens': [('äsvinge', False)],
          'äsvings': [('äsvinge', False)],
          'äsvings-': [('äsvinge', False)],
          'äsvärden': [('äsvärde', False)],
          'äsvärdens': [('äsvärde', False)],
          'äsvärdet': [('äsvärde', False)],
          'äsvärdets': [('äsvärde', False)],
          'äsänke': [('äsänka', False)],
          'äsänks': [('äsänka', False)],
          'äsänks-': [('äsänka', False)],
          'äsören': [('äsör', False)],
          'äsörens': [('äsör', False)],
          'ät': [('ät', False)],
          'ät-': [('äta', False)],
          'ätan': [('äta', False)],
          'ätana': [('äta', False)],
          'ätanas': [('äta', False)],
          'ätanden': [('ätande', False)],
          'ätandens': [('ätande', False)],
          'ätans': [('äta', False)],
          'ätaren': [('ätare', False)],
          'ätarnas': [('ätare', False)],
          'äte': [('äta', False)],
          'äte-': [('äta', False)],
          'äten': [('ät', False)],
          'ätens': [('ät', False)],
          'äter': [('ät', False)],
          'äter-': [('äter', False)],
          'äteranden': [('äterande', False)],
          'äterandens': [('äterande', False)],
          'äterier': [('äteri', False)],
          'äterierna': [('äteri', False)],
          'äteriernas': [('äteri', False)],
          'äteriets': [('äteri', False)],
          'äterits': [('äteri', False)],
          'ätern': [('äter', False)],
          'äterna': [('ät', False)],
          'äternas': [('ät', False)],
          'äterns': [('äter', False)],
          'äters': [('ät', False)],
          'äters-': [('äter', False)],
          'ätes': [('äte', False)],
          'ätes-': [('äte', False)],
          'ätet': [('ät', False)],
          'ätets': [('äte', False)],
          'äthet': [('äthet', False)],
          'äthets': [('äthet', False)],
          'ätighets': [('ätighet', False)],
          'ätor': [('äta', False)],
          'ätorna': [('äta', False)],
          'ätornas': [('äta', False)],
          'ätors': [('äta', False)],
          'ätort': [('ätort', False)],
          'ätorts': [('ätort', False)],
          'ätorts-': [('ätort', False)],
          'ätrall': [('ätrall', False)],
          'ätrall-': [('ätrall', False)],
          'ätralls': [('ätrall', False)],
          'ätralls-': [('ätrall', False)],
          'ätrar': [('äter', False)],
          'ätrarna': [('äter', False)],
          'ätrars': [('äter', False)],
          'ätressen': [('ätress', False)],
          'ätressens': [('ätress', False)],
          'ätrullarna': [('ätrullare', False)],
          'äts': [('ät', False)],
          'äts-': [('ät', False)],
          'ätskor': [('ätska', False)],
          'ätskorna': [('ätska', False)],
          'ätskornas': [('ätska', False)],
          'ätskors': [('ätska', False)],
          'ätsteg-': [('ätstege', False)],
          'ätstegen': [('ätstege', False)],
          'ätstegens': [('ätstege', False)],
          'ätstegs': [('ätstege', False)],
          'ätstegs-': [('ätstege', False)],
          'ätsticks': [('ätsticka', False)],
          'ätsvar': [('ätsvar', False)],
          'ätt': [('ätt', True)],
          'ätt-': [('ätt', True)],
          'ättan': [('ätta', False)],
          'ättar': [('ättare', False)],
          'ättarna': [('ätt', False)],
          'ättarnas': [('ätte', False)],
          'ättars': [('ätte', False)],
          'ätte': [('ätte', False)],
          'ätte-': [('ätte', False)],
          'ätten': [('ätt', True)],
          'ättena': [('ätte', False)],
          'ättenas': [('ätte', False)],
          'ättens': [('ätt', False)],
          'ätter': [('ätt', True)],
          'ätteriers': [('ätteri', False)],
          'ätterna': [('ätt', True)],
          'ätternas': [('ätt', True)],
          'ätters': [('ätt', True)],
          'ätters-': [('ätters', False)],
          'ätterskor': [('ättersko', False)],
          'ätterskorna': [('ättersko', False)],
          'ätterskornas': [('ättersko', False)],
          'ätterskors': [('ättersko', False)],
          'ättets': [('ätt', False)],
          'ättigheter': [('ättighet', False)],
          'ättigheterna': [('ättighet', False)],
          'ättigheternas': [('ättighet', False)],
          'ättigheters': [('ättighet', False)],
          'ättighets-': [('ättighet', False)],
          'ättlandets': [('ättland', False)],
          'ättrar': [('ättrare', False)],
          'ättrarna': [('ättrar', False)],
          'ättrarnas': [('ättrar', False)],
          'ättrars': [('ättrar', False)],
          'ätts': [('ätt', True)],
          'ätts-': [('ätt', True)],
          'ättställen': [('ättställ', False)],
          'ättstället': [('ättställ', False)],
          'ätugg': [('ätugg', False)],
          'ätuggs': [('ätugg', False)],
          'ätuggs-': [('ätugg', False)],
          'ätvar': [('ätvar', False)],
          'ätvar-': [('ätvar', False)],
          'ätving': [('ätvinge', False)],
          'ätving-': [('ätvinge', False)],
          'ätvingar': [('ätvinge', False)],
          'ätvingarna': [('ätvinge', False)],
          'ätvingarnas': [('ätvinge', False)],
          'ätvingars': [('ätvinge', False)],
          'ätvingen': [('ätvinge', False)],
          'ätvingens': [('ätvinge', False)],
          'ätvings': [('ätvinge', False)],
          'ätvings-': [('ätvinge', False)],
          'äull': [('äull', False)],
          'äulls': [('äull', False)],
          'äulls-': [('äull', False)],
          'ävan': [('ävan', False)],
          'ävans': [('ävan', False)],
          'ävans-': [('ävan', False)],
          'ävaran': [('ävara', False)],
          'ävarans': [('ävara', False)],
          'ävaren': [('ävare', False)],
          'ävarna': [('äv', False)],
          'ävarnas': [('äv', False)],
          'ävars': [('äv', False)],
          'ävas': [('äva', False)],
          'äve': [('äva', False)],
          'äve-': [('äva', False)],
          'äveck': [('äveck', False)],
          'äveck-': [('äveck', False)],
          'ävecks': [('äveck', False)],
          'ävecks-': [('äveck', False)],
          'ävel': [('ävel', False)],
          'ävel-': [('ävel', False)],
          'ävels': [('ävel', False)],
          'ävels-': [('ävel', False)],
          'även': [('äv', False)],
          'ävens': [('äv', False)],
          'äver': [('av', False)],
          'ävern': [('äver', False)],
          'äverna': [('av', False)],
          'ävernas': [('av', False)],
          'äverns': [('äver', False)],
          'ävers': [('av', False)],
          'ävers-': [('äver', False)],
          'ävet': [('äv', False)],
          'ävets': [('äve', False)],
          'ävgas': [('ävgas', False)],
          'ävgas-': [('ävgas', False)],
          'ävkammar': [('ävkam', False)],
          'ävlan': [('ävlan', True)],
          'ävlans': [('ävlan', False)],
          'ävlar-': [('ävlare', False)],
          'ävlarens': [('ävlare', False)],
          'ävlarna': [('ävel', False)],
          'ävlarnas': [('ävel', False)],
          'ävlars': [('ävel', False)],
          'ävlingen': [('ävling', False)],
          'ävlingens': [('ävling', False)],
          'ävor': [('äva', False)],
          'ävorna': [('äva', False)],
          'ävornas': [('äva', False)],
          'ävors': [('äva', False)],
          'ävrar': [('äver', False)],
          'ävrarna': [('äver', False)],
          'ävs': [('äv', False)],
          'ävs-': [('äv', False)],
          'ävärmar': [('ävärmare', False)],
          'ävärmarna': [('ävärmare', False)],
          'ävärmarnas': [('ävärmare', False)],
          'äx': [('äx', False)],
          'äx-': [('äx', False)],
          'äxe': [('äxa', False)],
          'äxe-': [('äxa', False)],
          'äxen': [('äx', False)],
          'äxens': [('äx', False)],
          'äxet': [('äx', False)],
          'äxlar': [('äxel', False)],
          'äxlarna': [('äxel', False)],
          'äxlarnas': [('äxel', False)],
          'äxorna': [('äxa', False)],
          'äxornas': [('äxa', False)],
          'å': [('å', True)],
          'å-': [('å', True)],
          'åa': [('åa', False)],
          'åals': [('åal', False)],
          'åals-': [('åal', False)],
          'åan': [('åa', False)],
          'åanden': [('åande', False)],
          'åandens': [('åande', False)],
          'åandets': [('åande', False)],
          'åans': [('åa', False)],
          'åar': [('å', True)],
          'åar-': [('åare', False)],
          'åare': [('åare', False)],
          'åaren': [('åare', False)],
          'åarens': [('åare', False)],
          'åares': [('åare', False)],
          'åarna': [('å', True)],
          'åarnas': [('å', False)],
          'åars': [('å', True)],
          'åas': [('åa', False)],
          'åb': [('åb', False)],
          'åb-': [('åb', False)],
          'åbandets': [('åband', False)],
          'åbas': [('åbas', False)],
          'åbasar': [('åbas', False)],
          'åbasars': [('åbas', False)],
          'åben': [('åb', False)],
          'åben-': [('åben', False)],
          'åbens': [('åb', False)],
          'åber': [('åb', False)],
          'åberna': [('åb', False)],
          'åbernas': [('åb', False)],
          'åbers': [('åb', False)],
          'åbil': [('åbil', False)],
          'åbil-': [('åbil', False)],
          'åbilar': [('åbil', False)],
          'åbils': [('åbil', False)],
          'åbils-': [('åbil', False)],
          'åbit': [('åbit', False)],
          'åbits': [('åbit', False)],
          'åbits-': [('åbit', False)],
          'åbond': [('åbonde', False)],
          'åbor': [('åbo', True)],
          'åborgar': [('åborgare', False)],
          'åborgarna': [('åborgare', False)],
          'åborgarnas': [('åborgare', False)],
          'åbors': [('åbo', False)],
          'åbroder': [('åbroder', False)],
          'åbrodern': [('åbroder', False)],
          'åbroderns': [('åbroder', False)],
          'åbroders': [('åbroder', False)],
          'åbröder': [('åbroder', False)],
          'åbröderna': [('åbroder', False)],
          'åbrödernas': [('åbroder', False)],
          'åbröders': [('åbroder', False)],
          'åbs': [('åb', False)],
          'åbyx': [('åbyxa', False)],
          'åbyx-': [('åbyxa', False)],
          'åbärs': [('åbär', False)],
          'åbärs-': [('åbär', False)],
          'åck': [('åck', False)],
          'åckets': [('åck', False)],
          'åcklanden': [('åcklande', False)],
          'åcklandens': [('åcklande', False)],
          'åcklandet': [('åcklande', False)],
          'åd': [('åda', True)],
          'åd-': [('åda', True)],
          'ådan': [('åda', True)],
          'ådanden': [('ådande', False)],
          'ådandens': [('ådande', False)],
          'ådans': [('åda', False)],
          'ådans-': [('ådan', False)],
          'ådar': [('åd', False)],
          'ådaren': [('ådare', False)],
          'ådarna': [('åd', False)],
          'ådarnas': [('ådare', False)],
          'ådars': [('åd', False)],
          'ådd-': [('ådd', False)],
          'åde': [('åda', False)],
          'åde-': [('åda', False)],
          'ådel': [('ådel', False)],
          'ådels': [('ådel', False)],
          'ådels-': [('ådel', False)],
          'åden': [('åd', False)],
          'ådens': [('åd', False)],
          'åder': [('åder', True), ('ådra', True)],
          'åder-': [('ådra', True), ('åder', True)],
          'åderits': [('åderi', False)],
          'ådern': [('åder', False)],
          'åderna': [('åd', False)],
          'ådernas': [('åd', False)],
          'åderns': [('åder', True)],
          'åders': [('åder', True)],
          'ådet': [('åd', False)],
          'ådevillens': [('ådevill', False)],
          'ådis': [('ådis', False)],
          'ådis-': [('ådis', False)],
          'ådomar': [('ådom', False)],
          'ådomarna': [('ådom', False)],
          'ådomarnas': [('ådom', False)],
          'ådomen': [('ådom', False)],
          'ådor': [('åda', False)],
          'ådorna': [('åda', False)],
          'ådornas': [('åda', False)],
          'ådors': [('åda', True)],
          'ådra': [('åder', True), ('ådra', True)],
          'ådran': [('åder', True), ('ådra', True)],
          'ådrans': [('ådra', True), ('åder', True)],
          'ådras': [('ådra', True), ('åder', True)],
          'ådre': [('åder', True), ('ådra', True)],
          'ådre-': [('ådra', True), ('åder', True)],
          'ådringar': [('ådring', True)],
          'ådringarnas': [('ådring', True)],
          'ådringars': [('ådring', True)],
          'ådrivar': [('ådrivare', False)],
          'ådrivarna': [('ådrivare', False)],
          'ådrivarnas': [('ådrivare', False)],
          'ådror': [('ådra', True), ('åder', True)],
          'ådrorna': [('åder', True), ('ådra', True)],
          'ådrornas': [('ådra', True), ('åder', True)],
          'ådrors': [('ådra', True), ('åder', True)],
          'ådrotens': [('ådrot', False)],
          'ådrots': [('ådrot', False)],
          'ådrots-': [('ådrot', False)],
          'åds': [('åda', True)],
          'åds-': [('åda', True)],
          'ådår': [('ådår', False)],
          'ådåren': [('ådår', False)],
          'ådårens': [('ådår', False)],
          'ådårs': [('ådår', False)],
          'ådårs-': [('ådår', False)],
          'åe': [('åa', False)],
          'åe-': [('åa', False)],
          'åeker': [('åeker', False)],
          'åen': [('å', False)],
          'åendets': [('ående', False)],
          'åens': [('å', False)],
          'åer': [('å', False)],
          'åers': [('å', False)],
          'åets': [('å', False)],
          'åffel': [('åffla', False)],
          'åffel-': [('åffla', False)],
          'åfflan': [('åffla', False)],
          'åfflans': [('åffla', False)],
          'åffle': [('åffla', False)],
          'åfflor': [('åffla', False)],
          'åfflorna': [('åffla', False)],
          'åfflornas': [('åffla', False)],
          'åfflors': [('åffla', False)],
          'åfiskar': [('åfisk', False)],
          'åfiskarna': [('åfisk', False)],
          'åfiskarnas': [('åfisk', False)],
          'åflin': [('åflin', False)],
          'åfräsarna': [('åfräs', False)],
          'åg': [('åg', False)],
          'åg-': [('åg', False)],
          'ågan': [('åga', False)],
          'ågandens': [('ågande', False)],
          'ågans': [('åga', False)],
          'ågans-': [('ågan', False)],
          'ågar': [('åg', False)],
          'ågaren': [('ågare', False)],
          'ågarna': [('åg', False)],
          'ågarnas': [('åge', False)],
          'ågars': [('åg', False)],
          'ågas': [('åga', False)],
          'ågate': [('ågata', False)],
          'ågate-': [('ågata', False)],
          'ågator': [('ågata', False)],
          'ågats': [('ågata', False)],
          'åge': [('åga', False)],
          'åge-': [('åga', False)],
          'ågel': [('ågel', False)],
          'ågel-': [('ågel', False)],
          'ågen': [('åg', False)],
          'ågens': [('åg', False)],
          'ågeriernas': [('ågeri', False)],
          'ågers': [('åger', False)],
          'ågers-': [('åger', False)],
          'åget': [('åg', False)],
          'ågets': [('åg', False)],
          'ågetter': [('åget', False)],
          'ågetterna': [('åget', False)],
          'åghets': [('åghet', False)],
          'åglandet': [('ågland', False)],
          'åglandets': [('ågland', False)],
          'åglar': [('ågel', False)],
          'åglarna': [('ågel', False)],
          'åglarnas': [('ågel', False)],
          'åglars': [('ågel', False)],
          'åglien': [('ågli', False)],
          'ågliens': [('ågli', False)],
          'åglinas': [('ågli', False)],
          'åglis': [('ågli', False)],
          'åglits': [('ågli', False)],
          'ågo': [('åga', False)],
          'ågo-': [('åga', False)],
          'ågor': [('åga', False)],
          'ågoris': [('ågoris', False)],
          'ågorna': [('åga', False)],
          'ågornas': [('åga', False)],
          'ågors': [('åga', False)],
          'ågrar': [('åger', False)],
          'ågrarna': [('åger', False)],
          'ågrars': [('åger', False)],
          'ågs': [('åg', False)],
          'ågs-': [('åg', False)],
          'ågtanden': [('ågtand', False)],
          'ågtandens': [('ågtand', False)],
          'ågångar': [('ågångare', False)],
          'ågångarna': [('ågång', False)],
          'ågångarnas': [('ågång', False)],
          'ågås': [('ågås', False)],
          'ågås-': [('ågås', False)],
          'ågåsen': [('ågås', False)],
          'ågåsens': [('ågås', False)],
          'åhack': [('åhacka', False)],
          'åhack-': [('åhacka', False)],
          'åhackor': [('åhackor', False)],
          'åhackorna': [('åhackor', False)],
          'åhackornas': [('åhackor', False)],
          'åhackors': [('åhackor', False)],
          'åhacks': [('åhacka', False)],
          'åhacks-': [('åhackor', False)],
          'åhake': [('åhake', False)],
          'åhake-': [('åhake', False)],
          'åhaken': [('åhake', False)],
          'åhakens': [('åhake', False)],
          'åhandlar': [('åhandlare', False)],
          'åhandlarna': [('åhandlare', False)],
          'åhandlarnas': [('åhandlare', False)],
          'åheter': [('åhet', False)],
          'åheterna': [('åhet', False)],
          'åheternas': [('åhet', False)],
          'åheters': [('åhet', False)],
          'åhets': [('åhet', False)],
          'åhets-': [('åhet', False)],
          'åholts': [('åholts', False)],
          'åholts-': [('åholts', False)],
          'åhundars': [('åhund', False)],
          'åhänget': [('åhäng', False)],
          'åhängets': [('åhäng', False)],
          'åhängs': [('åhäng', False)],
          'åhängs-': [('åhäng', False)],
          'åhåg': [('åhåga', True)],
          'åhåg-': [('åhåga', True)],
          'åhågs': [('åhåga', True)],
          'åhågs-': [('åhåga', True)],
          'åighets-': [('åighet', False)],
          'åis': [('åis', False)],
          'åiskan': [('åiska', False)],
          'åiskans': [('åiska', False)],
          'åjack': [('åjacka', False)],
          'åjack-': [('åjacka', False)],
          'åjacks': [('åjacka', False)],
          'åjacks-': [('åjacka', False)],
          'åk': [('åk', False)],
          'åk-': [('åk', False)],
          'åkallan': [('åkallan', True)],
          'åkallans': [('åkallan', True)],
          'åkallarna': [('åkallare', False)],
          'åkallarnas': [('åkallare', False)],
          'åkan': [('åka', False)],
          'åkanden': [('åkande', False)],
          'åkans': [('åka', False)],
          'åkar': [('åkare', True)],
          'åkar-': [('åkare', False)],
          'åkare': [('åkare', False)],
          'åkaren': [('åkare', False)],
          'åkarens': [('åkare', False)],
          'åkarna': [('åkare', True)],
          'åkarnas': [('åkare', True)],
          'åkars': [('åk', False)],
          'åkart': [('åkarta', False)],
          'åkart-': [('åkarta', False)],
          'åkarts': [('åkarta', False)],
          'åkarts-': [('åkarta', False)],
          'åkas': [('åka', False)],
          'åkdelar': [('åkdel', False)],
          'åkdelarna': [('åkdel', False)],
          'åkdelarnas': [('åkdel', False)],
          'åke-': [('åka', False)],
          'åken': [('åk', False)],
          'åkens': [('åk', False)],
          'åker': [('åker', True)],
          'åkerits': [('åkeri', True)],
          'åkerna': [('åk', False)],
          'åkernas': [('åk', False)],
          'åkers': [('åker', True)],
          'åkerärter': [('åkerärt', True)],
          'åkerärts': [('åkerärt', True)],
          'åkerärts-': [('åkerärt', True)],
          'åket': [('åk', False)],
          'åkfots': [('åkfötter', False)],
          'åklagarna': [('åklagare', False)],
          'åklapp': [('åklapp', True)],
          'åklapps': [('åklapp', True)],
          'åklapps-': [('åklapp', True)],
          'åklock': [('åklocka', False)],
          'åklädes': [('åkläder', False)],
          'åklädes-': [('åkläder', False)],
          'åkningar': [('åkning', False)],
          'åkningarna': [('åkning', False)],
          'åkningarnas': [('åkning', False)],
          'åkningars': [('åkning', False)],
          'åknings': [('åkning', False)],
          'åknings-': [('åkning', False)],
          'åkomponents': [('åkomponents', False)],
          'åkomponents-': [('åkomponents', False)],
          'åkoms-': [('åkomma', True)],
          'åkor': [('åka', False)],
          'åkorna': [('åka', False)],
          'åkornas': [('åka', False)],
          'åkors': [('åka', False)],
          'åkrar': [('åker', True)],
          'åkrarna': [('åker', False)],
          'åkrater': [('åkrat', False)],
          'åkraters': [('åkrat', False)],
          'åkrats': [('åkrat', False)],
          'åkrats-': [('åkrat', False)],
          'åkronan': [('åkrona', False)],
          'åkronans': [('åkrona', False)],
          'åkrons-': [('åkrona', False)],
          'åkröken': [('åkrök', True)],
          'åks': [('åk', False)],
          'åks-': [('åk', False)],
          'åkstak': [('åkstake', False)],
          'åkstakens': [('åkstake', False)],
          'åkstaks': [('åkstake', False)],
          'åkstaks-': [('åkstake', False)],
          'åkturs-': [('åktur', True)],
          'åkurr': [('åkurr', False)],
          'åkurr-': [('åkurr', False)],
          'åkurren': [('åkurr', False)],
          'åkurrens': [('åkurr', False)],
          'åkurrs': [('åkurr', False)],
          'åkurrs-': [('åkurr', False)],
          'åkurv': [('åkurva', False)],
          'åkurv-': [('åkurva', False)],
          'åkurvor': [('åkurva', False)],
          'åkurvorna': [('åkurva', False)],
          'åkurvornas': [('åkurva', False)],
          'åkurvors': [('åkurva', False)],
          'åkurvs': [('åkurva', False)],
          'åkurvs-': [('åkurva', False)],
          'åkusiner': [('åkusiner', False)],
          'åkusinerna': [('åkusiner', False)],
          'åkusinernas': [('åkusiner', False)],
          'åkusiners': [('åkusiner', False)],
          'åkusins': [('åkusiner', False)],
          'ål': [('ål', False)],
          'ål-': [('ål', False)],
          'ålag': [('ålaga', False)],
          'ålag-': [('ålaga', False)],
          'ålagans': [('ålaga', False)],
          'ålage': [('ålaga', False)],
          'ålage-': [('ålaga', False)],
          'ålagor': [('ålaga', False)],
          'ålagorna': [('ålaga', False)],
          'ålagornas': [('ålaga', False)],
          'ålagors': [('ålaga', False)],
          'ålags': [('ålaga', False)],
          'ålags-': [('ålaga', False)],
          'ålan': [('åla', False)],
          'ålanden': [('ålande', False)],
          'ålandena': [('ålande', False)],
          'ålandenas': [('ålande', True)],
          'ålandens': [('ålande', False)],
          'ålandet': [('ålande', False)],
          'ålandets': [('ålande', False)],
          'ålans': [('åla', False)],
          'ålaps': [('ålapa', False)],
          'ålaps-': [('ålapa', False)],
          'ålar': [('ål', False)],
          'ålaren': [('ålare', False)],
          'ålarna': [('ål', False)],
          'ålarnas': [('ål', True)],
          'ålars': [('ål', True)],
          'ålben': [('ålben', False)],
          'ålder': [('ålder', False)],
          'ålders': [('ålder', False)],
          'åldets': [('åld', False)],
          'åldomarnas': [('åldomare', False)],
          'åldos': [('åldos', False)],
          'åldrarnas': [('ålder', False)],
          'åle': [('åla', False)],
          'åle-': [('åla', False)],
          'ålen': [('ål', True)],
          'ålens': [('ål', False)],
          'åler': [('ål', False)],
          'ålerna': [('ål', False)],
          'ålernas': [('ål', False)],
          'ålers': [('ål', False)],
          'ålet': [('ål', False)],
          'ålets': [('ål', False)],
          'ålfiskarnas': [('ålfiskare', True)],
          'ålgångar': [('ålgång', False)],
          'ålgångarna': [('ålgång', False)],
          'ålgångarnas': [('ålgång', False)],
          'ålgångars': [('ålgång', False)],
          'ålgångs': [('ålgång', False)],
          'ålgångs-': [('ålgång', False)],
          'ålighets': [('ålighet', False)],
          'ålis': [('ålis', False)],
          'ålis-': [('ålis', False)],
          'ålisen': [('ålis', False)],
          'ålisens': [('ålis', False)],
          'ålknippe': [('ålknippe', False)],
          'ålkors': [('ålkors', False)],
          'ålkors-': [('ålkors', False)],
          'ålkrans': [('ålkran', False)],
          'ålkrans-': [('ålkran', False)],
          'åll': [('ålla', False)],
          'åll-': [('ålla', False)],
          'ållan': [('ålla', True)],
          'ållanden': [('ållande', True)],
          'ållandena': [('ållande', True)],
          'ållandenas': [('ållande', True)],
          'ållandens': [('ållande', True)],
          'ållandets': [('ållande', False)],
          'ållans': [('ålla', False)],
          'ållar': [('ållare', False)],
          'ållar-': [('ållare', False)],
          'ållarna': [('ålle', False)],
          'ållarnas': [('ållare', False)],
          'ållars': [('ålle', False)],
          'ålle': [('ålla', True)],
          'ålle-': [('ålla', True)],
          'ållen': [('ålle', False)],
          'ållens': [('åll', False)],
          'ålls': [('ålla', False)],
          'ålmarnas': [('ålm', False)],
          'ålms': [('ålm', False)],
          'ålmåns-': [('ålmåns', False)],
          'ålningar': [('ålning', False)],
          'ålningarna': [('ålning', False)],
          'ålningarnas': [('ålning', False)],
          'ålningars': [('ålning', False)],
          'ålnings': [('ålning', False)],
          'ålnings-': [('ålning', False)],
          'ålor': [('åla', False)],
          'ålorna': [('åla', False)],
          'ålornas': [('åla', False)],
          'ålors': [('åla', False)],
          'ålpengarna': [('ålpeng', False)],
          'åls': [('ål', False)],
          'åls-': [('ål', False)],
          'ålskens': [('ålskena', False)],
          'ålstick': [('ålstick', False)],
          'ålsticks-': [('ålstick', False)],
          'ålven': [('ålven', False)],
          'ålvägen': [('ålväg', False)],
          'ålvägens': [('ålväg', False)],
          'ålyte': [('ålyta', False)],
          'åm': [('åm', True)],
          'åm-': [('åm', False)],
          'åman': [('åman', False)],
          'åmanden': [('åmande', False)],
          'åmannen': [('åman', False)],
          'åmannens': [('åman', False)],
          'åmans': [('åman', False)],
          'åmar': [('åm', True)],
          'åmarna': [('åm', False)],
          'åmarnas': [('åm', True)],
          'åmars': [('åm', False)],
          'åmas': [('åma', False)],
          'åmatt': [('åmatta', False)],
          'åmatt-': [('åmatta', False)],
          'åmatte': [('åmatta', False)],
          'åmatte-': [('åmatta', False)],
          'åmatts': [('åmatta', False)],
          'åmatts-': [('åmatta', False)],
          'åme': [('åma', False)],
          'åme-': [('åma', False)],
          'åmen': [('åm', False)],
          'åmens': [('åm', True)],
          'åmes-': [('åmes', False)],
          'åmet': [('åm', False)],
          'åmets': [('åm', False)],
          'åmjölk': [('åmjölk', False)],
          'åmjölk-': [('åmjölk', False)],
          'åmjölken': [('åmjölk', False)],
          'åmjölkens': [('åmjölk', False)],
          'åmjölks': [('åmjölk', False)],
          'åmjölks-': [('åmjölk', False)],
          'åmmar': [('åm', False)],
          'åmmarna': [('åm', False)],
          'åmmarnas': [('åm', False)],
          'åmmars': [('åm', False)],
          'åmmen': [('åm', False)],
          'åmmens': [('åm', False)],
          'åmopp': [('åmoppe', False)],
          'åmopp-': [('åmoppe', False)],
          'åmoppar': [('åmoppe', False)],
          'åmopparna': [('åmoppe', False)],
          'åmopparnas': [('åmoppe', False)],
          'åmoppars': [('åmoppe', False)],
          'åmoppen': [('åmoppe', False)],
          'åmoppens': [('åmoppe', False)],
          'åmopps': [('åmoppe', False)],
          'åmopps-': [('åmoppe', False)],
          'åmor': [('åma', False)],
          'åmorna': [('åma', False)],
          'åmornas': [('åma', False)],
          'åmors': [('åma', False)],
          'åms': [('åm', False)],
          'åms-': [('åm', True)],
          'åmussel-': [('åmussla', False)],
          'åmynt': [('åmynt', False)],
          'åmynt-': [('åmynt', False)],
          'åmynts': [('åmynt', False)],
          'åmynts-': [('åmynt', False)],
          'åmys': [('åmys', False)],
          'åmys-': [('åmys', False)],
          'åmän': [('åman', False)],
          'åmäns': [('åman', False)],
          'ån': [('å', True)],
          'ån-': [('ån', False)],
          'ånader': [('ånad', False)],
          'ånaderna': [('ånad', False)],
          'ånadernas': [('ånad', False)],
          'ånaders': [('ånad', False)],
          'ånads': [('ånad', False)],
          'ånads-': [('ånad', False)],
          'ånanden': [('ånande', False)],
          'ånar': [('ånare', False)],
          'ånar-': [('ånare', False)],
          'ånaren': [('ånare', False)],
          'ånarens': [('ånare', False)],
          'ånarna': [('åne', False)],
          'ånarnas': [('ånare', False)],
          'ånars': [('åne', False)],
          'ånd': [('ånda', False)],
          'ånd-': [('ånda', False)],
          'ånda': [('ånda', False)],
          'åndans': [('ånda', False)],
          'åndar': [('åndare', False)],
          'åndar-': [('åndare', False)],
          'åndarens': [('åndare', False)],
          'åndarna': [('åndare', False)],
          'åndas': [('ånda', False)],
          'åndets': [('ånd', False)],
          'ånds': [('ånda', False)],
          'ånds-': [('ånda', False)],
          'åndslandet': [('åndsland', False)],
          'åne': [('åna', False)],
          'åne-': [('åne', False)],
          'ånen': [('ån', False)],
          'ånens': [('ån', False)],
          'åner': [('ån', False)],
          'ånerier': [('åneri', False)],
          'ånerierna': [('åneri', False)],
          'åneriernas': [('åneri', False)],
          'åneriers': [('åneri', False)],
          'ånerna': [('ån', False)],
          'ånernas': [('ån', False)],
          'åners': [('ån', False)],
          'ånet': [('ån', False)],
          'ånfälls': [('ånfälle', False)],
          'ånfälls-': [('ånfälle', False)],
          'ång': [('ånga', True)],
          'ång-': [('ånga', True)],
          'ånga': [('ånga', False)],
          'ånga-': [('ånga', False)],
          'ångan': [('ånga', False)],
          'ångans': [('ånga', False)],
          'ångar': [('ångare', False)],
          'ångar-': [('ångare', False)],
          'ångarens': [('ångare', False)],
          'ångarna': [('ångare', True)],
          'ångarnas': [('ångare', False)],
          'ångars': [('ånge', False)],
          'ångas': [('ånga', False)],
          'ånge': [('ånga', True)],
          'ånge-': [('ånga', True)],
          'ånger': [('ånger', False)],
          'ångers': [('ånger', True)],
          'ånges': [('ånge', False)],
          'ånges-': [('ånge', False)],
          'ångets': [('ång', False)],
          'ånglar': [('ånglare', False)],
          'ånglarna': [('ånglare', False)],
          'ånglarnas': [('ånglare', False)],
          'ångornas': [('ånga', True)],
          'ångors': [('ånga', True)],
          'ångs': [('ånga', True)],
          'ångs-': [('ånga', True)],
          'ångsdos': [('ångsdos', False)],
          'ångsdos-': [('ångsdos', False)],
          'ångside': [('ångsida', False)],
          'ångside-': [('ångsida', False)],
          'ångsides': [('ångsida', False)],
          'ångsställen': [('ångsställe', False)],
          'ångsstället': [('ångsställe', False)],
          'ångsställets': [('ångsställe', False)],
          'ångstanken': [('ångstanke', False)],
          'ångstens': [('ångst', False)],
          'ånkar': [('ånk', False)],
          'ånkarna': [('ånk', False)],
          'ånkarnas': [('ånk', False)],
          'ånkets': [('ånk', False)],
          'ånor': [('ånor', False)],
          'ånorna': [('åna', False)],
          'ånornas': [('ånor', False)],
          'ånors': [('åna', False)],
          'åns': [('å', True)],
          'åns-': [('ån', False)],
          'ånsarnas': [('åns', False)],
          'ånskans': [('ånska', False)],
          'ånsken': [('ånsken', False)],
          'ånskens-': [('ånsken', False)],
          'ånskor': [('ånska', False)],
          'ånskorna': [('ånska', False)],
          'ånskornas': [('ånska', False)],
          'ånskors': [('ånska', False)],
          'ånsug': [('ånsug', False)],
          'ånt-': [('ånt', False)],
          'ånträdets': [('ånträde', False)],
          'ånts': [('ånt', False)],
          'ånåret': [('ånår', False)],
          'ånårets': [('ånår', False)],
          'åor': [('åa', False)],
          'åord': [('åord', False)],
          'åorden': [('åord', False)],
          'åordens': [('åord', False)],
          'åords': [('åord', False)],
          'åors': [('åa', False)],
          'åp': [('åp', False)],
          'åp-': [('åp', False)],
          'åpakets': [('åpaket', False)],
          'åpande': [('åpande', False)],
          'åpande-': [('åpande', False)],
          'åpar': [('åp', False)],
          'åpar-': [('åpare', False)],
          'åparen': [('åpare', False)],
          'åparens': [('åpare', False)],
          'åpares': [('åpare', False)],
          'åparna': [('åp', False)],
          'åparnas': [('åpare', False)],
          'åpars': [('åp', False)],
          'åpe': [('åpa', False)],
          'åpe-': [('åpa', False)],
          'åpen': [('åp', False)],
          'åpengar': [('åpeng', False)],
          'åpengarna': [('åpeng', False)],
          'åpengarnas': [('åpeng', False)],
          'åpengars': [('åpeng', False)],
          'åpens': [('åp', False)],
          'åperiernas': [('åperi', False)],
          'åperiers': [('åperi', False)],
          'åperiets': [('åperi', False)],
          'åperits': [('åperi', False)],
          'åpet': [('åp', False)],
          'åpets': [('åp', False)],
          'åplanet': [('åplanet', False)],
          'åplanets': [('åplanet', False)],
          'åpojk': [('åpojke', False)],
          'åpojk-': [('åpojke', False)],
          'åpojks': [('åpojke', False)],
          'åpojks-': [('åpojke', False)],
          'åpor': [('åpa', False)],
          'åporna': [('åpa', False)],
          'åpornas': [('åpa', False)],
          'åpors': [('åpa', False)],
          'åps': [('åp', False)],
          'åps-': [('åp', False)],
          'åpuk': [('åpuk', False)],
          'åpuk-': [('åpuk', False)],
          'åpukar': [('åpuk', False)],
          'åpukarna': [('åpuk', False)],
          'åpukarnas': [('åpuk', False)],
          'åpukars': [('åpuk', False)],
          'åpuken': [('åpuk', False)],
          'åpukens': [('åpuk', False)],
          'åpuks': [('åpuk', False)],
          'åpuks-': [('åpuk', False)],
          'år': [('åra', True), ('år', True)],
          'år-': [('åra', True)],
          'årake': [('åraka', False)],
          'åraks': [('åraka', False)],
          'åraks-': [('åraka', False)],
          'åran': [('åra', False)],
          'åranda': [('åranda', False)],
          'årandans': [('åranda', False)],
          'årandas': [('åranda', False)],
          'årande': [('årande', False)],
          'årande-': [('årande', False)],
          'åranden': [('årande', False)],
          'årandens': [('årande', False)],
          'årandet': [('årande', False)],
          'årans': [('åra', False)],
          'årar': [('år', False)],
          'årarna': [('åre', False)],
          'årarnas': [('åre', False)],
          'årars': [('år', False)],
          'åras': [('åra', False)],
          'årbens': [('årben', False)],
          'årbete': [('årbete', False)],
          'årbeten': [('årbete', False)],
          'årbetens': [('årbete', False)],
          'årbäckens': [('årbäck', False)],
          'årda': [('årda', False)],
          'årdan': [('årda', False)],
          'årdans': [('årda', False)],
          'årdarnas': [('ård', False)],
          'årdas': [('årda', False)],
          'årder': [('årder', True)],
          'årderna': [('årder', True)],
          'årdernas': [('årder', True)],
          'årders': [('årder', True)],
          'årdsbön': [('årdsböna', False)],
          'årdsböns-': [('årdsböna', False)],
          'årdslanden': [('årdsland', False)],
          'årdslandens': [('årdsland', False)],
          'årdslandet': [('årdsland', False)],
          'årdvar': [('årdvar', False)],
          'årdvar-': [('årdvar', False)],
          'åre': [('åra', False)],
          'åre-': [('åra', False)],
          'åren': [('år', False)],
          'årens': [('år', False)],
          'årer': [('år', False)],
          'årerna': [('år', False)],
          'årernas': [('år', False)],
          'årers': [('år', False)],
          'året': [('år', False)],
          'årets': [('år', False)],
          'årfötter': [('årfot', True)],
          'årfötterna': [('årfot', True)],
          'årfötternas': [('årfot', True)],
          'årfötters': [('årfot', True)],
          'årighets': [('årighet', False)],
          'åringar': [('åring', False)],
          'åringarna': [('åring', False)],
          'åringarnas': [('åring', False)],
          'åris': [('åris', False)],
          'åris-': [('åris', False)],
          'årkors': [('årkors', False)],
          'årmodet': [('årmod', False)],
          'årmodets': [('årmod', False)],
          'årna': [('å', False)],
          'årnas': [('å', False)],
          'åropen': [('årop', False)],
          'årops': [('årop', False)],
          'åror': [('åra', False)],
          'årorna': [('åra', False)],
          'årornas': [('åra', False)],
          'årors': [('åra', False)],
          'årrems': [('årrem', False)],
          'års': [('åra', True), ('år', True)],
          'års-': [('åra', True), ('år', True)],
          'årskallens': [('årskalle', False)],
          'årsskiftet': [('årsskifte', False)],
          'årsskiftets': [('årsskifte', True)],
          'årstråt': [('årstrå', False)],
          'årsäkringarna': [('årsäkring', False)],
          'årsäkringarnas': [('årsäkring', False)],
          'årt': [('årta', False)],
          'årt-': [('årta', False)],
          'årtagets': [('årtag', True)],
          'årtan': [('årta', False)],
          'årtbitar': [('årtbitare', False)],
          'årtbitarna': [('årtbitare', False)],
          'årtbitarnas': [('årtbitare', False)],
          'årten': [('årten', False)],
          'årtens': [('årten', False)],
          'årts': [('årta', False)],
          'årts-': [('årta', False)],
          'årull': [('årull', False)],
          'årullen': [('årull', False)],
          'årullens': [('årull', False)],
          'årulls': [('årull', False)],
          'årulls-': [('årull', False)],
          'årämne': [('årämne', False)],
          'åräv': [('åräv', False)],
          'årävs': [('åräv', False)],
          'ås': [('å', True), ('ås', True)],
          'ås-': [('å', True), ('ås', True)],
          'åsaker': [('åsak', False)],
          'åsakerna': [('åsak', False)],
          'åsakernas': [('åsak', False)],
          'åsakers': [('åsak', False)],
          'åsalvs-': [('åsalva', False)],
          'åsanden': [('åsande', False)],
          'åsandens': [('åsande', False)],
          'åsans': [('åsa', False)],
          'åsar': [('ås', True)],
          'åsaren': [('åsare', False)],
          'åsarna': [('ås', True)],
          'åsarnas': [('ås', True)],
          'åsars': [('ås', False)],
          'åse': [('åsa', False)],
          'åse-': [('åsa', False)],
          'åsen': [('ås', False)],
          'åsens': [('ås', False)],
          'åser': [('ås', False)],
          'åserier': [('åseri', False)],
          'åserierna': [('åseri', False)],
          'åseriernas': [('åseri', False)],
          'åseriers': [('åseri', False)],
          'åserna': [('ås', False)],
          'åsernas': [('ås', False)],
          'åsers': [('ås', False)],
          'åset': [('ås', False)],
          'åsets': [('ås', False)],
          'åsid': [('åsida', False)],
          'åsid-': [('åsida', False)],
          'åside': [('åsida', False)],
          'åside-': [('åsida', False)],
          'åsids': [('åsida', False)],
          'åsikten': [('åsikt', False)],
          'åsiktens': [('åsikt', False)],
          'åsjukan': [('åsjuka', False)],
          'åsk': [('åska', True)],
          'åsk-': [('åska', True)],
          'åskan': [('åska', True)],
          'åskans': [('åska', True)],
          'åskar': [('åsk', False)],
          'åskarnas': [('åsk', False)],
          'åskars': [('åsk', False)],
          'åsken': [('åsk', False)],
          'åskens': [('åsk', False)],
          'åskiftet': [('åskift', False)],
          'åskiftets': [('åskift', False)],
          'åskor': [('åska', True)],
          'åskorna': [('åska', False)],
          'åskornas': [('åska', False)],
          'åskors': [('åska', True)],
          'åskrak': [('åskrak', False)],
          'åskrak-': [('åskrak', False)],
          'åskrakar': [('åskrak', False)],
          'åskrakarna': [('åskrak', False)],
          'åskrakarnas': [('åskrak', False)],
          'åskrakars': [('åskrak', False)],
          'åskraken': [('åskrak', False)],
          'åskrakens': [('åskrak', False)],
          'åskraks': [('åskrak', False)],
          'åskraks-': [('åskrak', False)],
          'åskris': [('åskris', False)],
          'åslag': [('åslag', False)],
          'åslags': [('åslag', False)],
          'åslags-': [('åslag', False)],
          'åslantar': [('åslantar', False)],
          'åslantarna': [('åslantar', False)],
          'åslantarnas': [('åslantar', False)],
          'åslantars': [('åslantar', False)],
          'åslants': [('åslantar', False)],
          'åslants-': [('åslantar', False)],
          'åsmulor': [('åsmulor', False)],
          'åsmulorna': [('åsmulor', False)],
          'åsmulornas': [('åsmulor', False)],
          'åsmulors': [('åsmulor', False)],
          'åsnor': [('åsna', False)],
          'åsnors': [('åsna', True)],
          'åsnäpp': [('åsnäppa', False)],
          'åsnäpp-': [('åsnäppa', False)],
          'åsnäpps': [('åsnäppa', False)],
          'åsnäpps-': [('åsnäppa', False)],
          'åsnåret': [('åsnåret', False)],
          'åsnårets': [('åsnåret', False)],
          'åsop': [('åsop', False)],
          'åsop-': [('åsop', False)],
          'åsopar': [('åsop', False)],
          'åsops': [('åsop', False)],
          'åsops-': [('åsop', False)],
          'åsor': [('åsa', False)],
          'åsorna': [('åsa', False)],
          'åsornas': [('åsa', False)],
          'åsors': [('åsa', False)],
          'åspets': [('åspets', False)],
          'åspets-': [('åspets', False)],
          'åsprit': [('åsprit', False)],
          'åsprits': [('åsprit', False)],
          'åsprits-': [('åsprit', False)],
          'åst': [('åst', False)],
          'åstans': [('åstad', False)],
          'åstavarna': [('åstav', False)],
          'åste': [('åste', False)],
          'åste-': [('åste', False)],
          'åsten': [('åsten', False)],
          'åstens': [('åst', False)],
          'åster': [('åster', False)],
          'åsters': [('åster', False)],
          'åstet': [('åste', False)],
          'åstol': [('åstol', False)],
          'åstols': [('åstol', False)],
          'åstols-': [('åstol', False)],
          'åstranden': [('åstrande', False)],
          'åstrandens': [('åstrande', False)],
          'åstyrkan': [('åstyrka', False)],
          'åställen': [('åställ', False)],
          'åställens': [('åställ', False)],
          'åstället': [('åställ', False)],
          'åställets': [('åställ', False)],
          'åsvennar': [('åsven', False)],
          'åsvennarna': [('åsven', False)],
          'åsvennarnas': [('åsven', False)],
          'åsvennars': [('åsven', False)],
          'åsvennen': [('åsven', False)],
          'åsvennens': [('åsven', False)],
          'åsyre': [('åsyra', False)],
          'åsyre-': [('åsyra', False)],
          'åsysslor': [('åsysslor', False)],
          'åsysslorna': [('åsysslor', False)],
          'åsysslornas': [('åsysslor', False)],
          'åsysslors': [('åsysslor', False)],
          'åsäden': [('åsäd', False)],
          'åsädens': [('åsäd', False)],
          'åsädes': [('åsäd', False)],
          'åsäds': [('åsäd', False)],
          'åsäds-': [('åsäd', False)],
          'åsögonen': [('åsögon', False)],
          'åsögonens': [('åsögon', False)],
          'åsögons': [('åsögon', False)],
          'åsören': [('åsör', False)],
          'åsörens': [('åsör', False)],
          'åt': [('åt', False)],
          'åt-': [('åt', True)],
          'åtalandenas': [('åtalande', True)],
          'åtalandens': [('åtalande', False)],
          'åtalen': [('åtal', False)],
          'åtalens': [('åtal', False)],
          'åtalet': [('åtal', False)],
          'åtan': [('åta', False)],
          'åtanden': [('åtande', False)],
          'åtandens': [('åtande', False)],
          'åtans': [('åta', False)],
          'åtar': [('åt', False)],
          'åtaren': [('åtare', False)],
          'åtarna': [('åt', False)],
          'åtars': [('åt', False)],
          'åtarv': [('åtarve', False)],
          'åtarv-': [('åtarve', False)],
          'åtarvens': [('åtarve', False)],
          'åtarvs': [('åtarve', False)],
          'åtarvs-': [('åtarve', False)],
          'åte': [('åta', False)],
          'åte-': [('åta', False)],
          'åteln': [('åtel', False)],
          'åtelns': [('åtel', False)],
          'åtels': [('åtel', True)],
          'åtels-': [('åtel', True)],
          'åten': [('åt', False)],
          'åtens': [('åt', False)],
          'åter': [('åt', False)],
          'återanden': [('återande', False)],
          'återandens': [('återande', False)],
          'återna': [('åt', False)],
          'åternas': [('åt', False)],
          'åters': [('åt', False)],
          'återskor': [('återska', False)],
          'återskorna': [('återska', False)],
          'återskornas': [('återska', False)],
          'återskors': [('återska', False)],
          'åtes': [('åte', False)],
          'åtes-': [('åte', False)],
          'åtet': [('åt', False)],
          'åtets': [('åt', False)],
          'åthet': [('åthet', False)],
          'åthets': [('åthet', False)],
          'åtiden': [('åtid', False)],
          'åtidens': [('åtiden', False)],
          'åtimmarna': [('åtimmarna', False)],
          'åtimmarnas': [('åtimmarna', False)],
          'åtir': [('åtira', False)],
          'åtir-': [('åtira', False)],
          'åtirs': [('åtira', False)],
          'åtirs-': [('åtira', False)],
          'åtlandets': [('åtlande', False)],
          'åtlar': [('åtel', False)],
          'åtlarna': [('åtel', True)],
          'åtlarnas': [('åtel', False)],
          'åtman': [('åtma', False)],
          'åton': [('åton', False)],
          'åtoner': [('åton', False)],
          'åtonerna': [('åton', False)],
          'åtonernas': [('åton', False)],
          'åtor': [('åta', False)],
          'åtorna': [('åta', False)],
          'åtornas': [('åta', False)],
          'åtors': [('åta', False)],
          'åtrum': [('åtrum', False)],
          'åtrums': [('åtrum', False)],
          'åtrums-': [('åtrum', False)],
          'åträt': [('åträ', False)],
          'åträts': [('åträ', False)],
          'åts': [('åt', False)],
          'åts-': [('åt', False)],
          'åtsteg': [('åtsteg', False)],
          'ått': [('åtta', False)],
          'ått-': [('åtta', False)],
          'åttan': [('åtta', False)],
          'åtte-': [('åtta', False)],
          'åttens': [('ått', False)],
          'åtter': [('åtter', False)],
          'åtteriers': [('åtteri', False)],
          'åtters': [('åtter', False)],
          'åttets': [('ått', False)],
          'åttigheter': [('åttighet', False)],
          'åttigheterna': [('åttighet', False)],
          'åttigheternas': [('åttighet', False)],
          'åttigheters': [('åttighet', False)],
          'åttighets-': [('åttighet', False)],
          'åtto': [('åtto', False)],
          'åttrarnas': [('åtter', False)],
          'åtts': [('åtta', False)],
          'åtts-': [('åtta', False)],
          'åtungs': [('åtunga', False)],
          'åtår': [('åtår', False)],
          'åtårs': [('åtår', False)],
          'åtårs-': [('åtår', False)],
          'åung': [('åungar', False)],
          'åung-': [('åungar', False)],
          'åungar': [('åungar', False)],
          'åungarna': [('åungar', False)],
          'åungarnas': [('åungar', False)],
          'åungars': [('åungar', False)],
          'åunges': [('åungar', False)],
          'åunges-': [('åungar', False)],
          'åungs': [('åungar', False)],
          'åungs-': [('åungar', False)],
          'åupparnas': [('åuppare', False)],
          'åv': [('åv', False)],
          'åv-': [('åva', False)],
          'åvacks-': [('åvacka', False)],
          'åval-': [('åval', False)],
          'åvalarna': [('åval', False)],
          'åvalarnas': [('åval', False)],
          'åvalars': [('åval', False)],
          'åvalen': [('åval', False)],
          'åvalens': [('åval', False)],
          'åvals': [('åval', False)],
          'åvals-': [('åval', False)],
          'åvan': [('åva', False)],
          'åvans': [('åva', False)],
          'åvar': [('åv', False)],
          'åvar-': [('åvara', False)],
          'åvaran': [('åvara', False)],
          'åvarans': [('åvara', False)],
          'åvarna': [('åv', False)],
          'åvarnas': [('åve', False)],
          'åvars': [('åv', False)],
          'åvas': [('åva', False)],
          'åven': [('åv', False)],
          'åvens': [('åv', False)],
          'åverande': [('åverande', False)],
          'åverande-': [('åverande', False)],
          'åving': [('åvinge', False)],
          'åving-': [('åvinge', False)],
          'åvingar': [('åvinge', False)],
          'åvingarna': [('åvinge', False)],
          'åvingarnas': [('åvinge', False)],
          'åvingars': [('åvinge', False)],
          'åvingen': [('åvinge', False)],
          'åvingens': [('åvinge', False)],
          'åvings': [('åvinge', False)],
          'åvings-': [('åvinge', False)],
          'åvornas': [('åvor', False)],
          'åvs': [('åv', False)],
          'åvs-': [('åv', False)],
          'åväsendet': [('åväsen', False)],
          'åväsendets': [('åväsen', False)],
          'åzon': [('åzon', False)],
          'åärt-': [('åärt', False)],
          'åärts-': [('åärt', False)],
          'çon': [('çon', False)],
          'çons': [('çon', False)],
          'ègen': [('ège', False)],
          'ègens': [('ège', False)],
          'èger': [('ège', False)],
          'ègers': [('ège', False)],
          'èmen': [('ème', False)],
          'èmens': [('ème', False)],
          'èmer': [('ème', False)],
          'èmerna': [('ème', False)],
          'èmernas': [('ème', False)],
          'èmers': [('ème', False)],
          'èmes': [('ème', False)],
          'èmes-': [('ème', False)],
          'èpen': [('èpe', False)],
          'èpens': [('èpe', False)],
          'èperna': [('èpe', False)],
          'èpernas': [('èpe', False)],
          'èpers': [('èpe', False)],
          'édramer': [('édrama', False)],
          'édramerna': [('édrama', False)],
          'éen': [('é', False)],
          'éens': [('é', False)],
          'éer': [('é', False)],
          'éers': [('é', False)],
          'éets': [('é', False)],
          'égivar': [('égivare', False)],
          'égivarna': [('égivare', False)],
          'égivarnas': [('égivare', False)],
          'éhästarnas': [('éhäst', False)],
          'éhästars': [('éhäst', False)],
          'ékår': [('ékår', False)],
          'ékåren': [('ékår', False)],
          'ékårens': [('ékår', False)],
          'ékårs': [('ékår', False)],
          'ékårs-': [('ékår', False)],
          'élan': [('élan', True)],
          'élan-': [('élan', True)],
          'élans': [('élan', True)],
          'én': [('é', False)],
          'éns': [('é', False)],
          'éproblemet': [('éproblem', False)],
          'ér': [('ér', False)],
          'ér-': [('ér', False)],
          'éren': [('ér', False)],
          'érens': [('ér', False)],
          'éret': [('ér', False)],
          'érets': [('ér', False)],
          'érock': [('érock', False)],
          'érockar': [('érock', False)],
          'érockarna': [('érock', False)],
          'érockarnas': [('érock', False)],
          'érs': [('ér', False)],
          'és': [('é', False)],
          'és-': [('és', False)],
          'ésen': [('és', False)],
          'ésens': [('és', False)],
          'éser': [('és', False)],
          'éserna': [('és', False)],
          'ésernas': [('és', False)],
          'ésers': [('és', False)],
          'ésprut': [('éspruta', False)],
          'ésprut-': [('éspruta', False)],
          'éspruts': [('éspruta', False)],
          'éspruts-': [('éspruta', False)],
          'ét': [('é', False)],
          'étenten': [('étente', False)],
          'étentens': [('étente', False)],
          'éts': [('é', False)],
          'évin': [('évin', False)],
          'évins': [('évin', False)],
          'évins-': [('évin', False)],
          'évärden': [('évärd', False)],
          'évärdens': [('évärd', False)],
          'évärmar': [('évärmare', False)],
          'évärmarna': [('évärmare', False)],
          'évärmarnas': [('évärmare', False)],
          'êpen': [('êpe', False)],
          'êpens': [('êpe', False)],
          'êperna': [('êpe', False)],
          'êpernas': [('êpe', False)],
          'êpers': [('êpe', False)],
          'êten': [('ête', False)],
          'êtens': [('ête', False)],
          'êter': [('ête', False)],
          'êterna': [('ête', False)],
          'êternas': [('ête', False)],
          'êters': [('ête', False)],
          'êtes': [('ête', False)],
          'êtes-': [('ête', False)],
          'ñora': [('ñora', False)],
          'ñoran': [('ñora', False)],
          'ñorans': [('ñora', False)],
          'ñoras': [('ñora', False)],
          'ñorit': [('ñorita', False)],
          'ñorit-': [('ñorita', False)],
          'ñorits': [('ñorita', False)],
          'ñoror': [('ñora', False)],
          'ñororna': [('ñora', False)],
          'ñorornas': [('ñora', False)],
          'ñorors': [('ñora', False)],
          'ôten': [('ôte', False)],
          'ôtens': [('ôte', False)],
          'ôter': [('ôte', False)],
          'ôterna': [('ôte', False)],
          'ôternas': [('ôte', False)],
          'ôters': [('ôte', False)],
          'ôtes': [('ôte', False)],
          'ôtes-': [('ôte', False)],
          'öalg': [('öalg', False)],
          'öalgens': [('öalg', False)],
          'öalgs': [('öalg', False)],
          'öalgs-': [('öalg', False)],
          'öanden': [('öande', False)],
          'öandens': [('öande', False)],
          'öandets': [('öande', False)],
          'öar': [('ö', True)],
          'öar-': [('öare', False)],
          'öare': [('öare', False)],
          'öaren': [('öare', False)],
          'öarens': [('öare', False)],
          'öares': [('öare', False)],
          'öarna': [('ö', True)],
          'öarnas': [('ö', False)],
          'öars': [('ö', False)],
          'öban': [('öba', False)],
          'öbans': [('öba', False)],
          'öbas': [('öba', False)],
          'öbe': [('öba', False)],
          'öbe-': [('öba', False)],
          'öbel': [('öbel', False)],
          'öbel-': [('öbel', False)],
          'öbels': [('öbel', False)],
          'öbels-': [('öbel', False)],
          'öbil': [('öbil', False)],
          'öbilars': [('öbil', False)],
          'öbils': [('öbil', False)],
          'öbils-': [('öbil', False)],
          'öblernas': [('öbel', False)],
          'öbor': [('öbo', True)],
          'öborna': [('öbo', True)],
          'öbornas': [('öbo', True)],
          'öborr': [('öborre', False)],
          'öborr-': [('öborre', False)],
          'öborrar': [('öborre', False)],
          'öborrarna': [('öborre', False)],
          'öborrarnas': [('öborre', False)],
          'öborrars': [('öborre', False)],
          'öborren': [('öborre', False)],
          'öborrens': [('öborre', False)],
          'öborrs': [('öborre', False)],
          'öborrs-': [('öborre', False)],
          'öbors': [('öbo', True)],
          'öborst': [('öborste', False)],
          'öborst-': [('öborste', False)],
          'öborsten': [('öborste', False)],
          'öborstens': [('öborste', False)],
          'öbräds': [('öbräda', False)],
          'öbräds-': [('öbräda', False)],
          'öbärs': [('öbär', False)],
          'öbärs-': [('öbär', False)],
          'öcken': [('öcken', False)],
          'öckens': [('öcken', False)],
          'öcker': [('ok', False)],
          'öckerna': [('ok', False)],
          'öckernas': [('ok', False)],
          'öckers': [('ok', False)],
          'öd': [('öd', False)],
          'öd-': [('öd', False)],
          'ödan': [('öda', False)],
          'ödanden': [('ödande', False)],
          'ödandens': [('ödande', False)],
          'ödankar': [('ödankare', False)],
          'ödankarna': [('ödankare', False)],
          'ödankarnas': [('ödankare', False)],
          'ödans': [('öda', False)],
          'ödar': [('ödare', False)],
          'ödaren': [('ödare', False)],
          'ödarnas': [('ödare', False)],
          'ödars': [('öd', False)],
          'ödben': [('ödbena', False)],
          'ödbens-': [('ödbena', False)],
          'ödbit': [('ödbit', False)],
          'ödder': [('ödder', False)],
          'ödders': [('ödder', False)],
          'öde': [('öde', True)],
          'öde-': [('öda', False)],
          'ödel': [('ödel', False)],
          'ödels': [('ödel', False)],
          'ödels-': [('ödel', False)],
          'ödemens': [('ödem', True)],
          'öden': [('öde', True)],
          'ödens': [('öde', True)],
          'öder': [('öd', False)],
          'öder-': [('öder', False)],
          'ödern': [('öder', False)],
          'öderns': [('öder', False)],
          'ödet': [('öde', True)],
          'ödets': [('öde', False)],
          'öding': [('öding', False)],
          'öding-': [('öding', False)],
          'ödingar': [('öding', False)],
          'ödingarna': [('öding', False)],
          'ödingarnas': [('öding', False)],
          'ödingars': [('öding', False)],
          'ödingen': [('öding', False)],
          'ödingens': [('öding', False)],
          'ödings': [('öding', False)],
          'ödings-': [('öding', False)],
          'ödis': [('ödis', False)],
          'ödis-': [('ödis', False)],
          'ödlar': [('ödel', False)],
          'ödlarna': [('ödel', False)],
          'ödlarnas': [('ödel', False)],
          'ödlars': [('ödel', False)],
          'ödo': [('öda', False)],
          'ödomar': [('ödom', False)],
          'ödomarna': [('ödom', False)],
          'ödomarnas': [('ödom', False)],
          'ödomen': [('ödom', False)],
          'ödor': [('öda', False)],
          'ödorna': [('öda', False)],
          'ödornas': [('öda', False)],
          'ödors': [('öda', False)],
          'ödringar': [('ödring', False)],
          'ödringarnas': [('ödring', False)],
          'ödringars': [('ödring', False)],
          'ödriv': [('ödriva', False)],
          'ödriv-': [('ödriva', False)],
          'ödrive': [('ödriva', False)],
          'ödrive-': [('ödriva', False)],
          'ödrivs': [('ödriva', False)],
          'ödrivs-': [('ödriva', False)],
          'ödropp': [('ödroppe', False)],
          'ödropp-': [('ödroppe', False)],
          'ödroppars': [('ödroppe', False)],
          'ödropps': [('ödroppe', False)],
          'ödropps-': [('ödroppe', False)],
          'öds': [('öd', False)],
          'öds-': [('öd', False)],
          'ödsdagar': [('ödsdag', False)],
          'ödsdagarna': [('ödsdag', False)],
          'ödsdagarnas': [('ödsdag', False)],
          'ödsdagars': [('ödsdag', False)],
          'ödsdags': [('ödsdag', False)],
          'ödsdomar': [('ödsdom', False)],
          'ödsdomarna': [('ödsdom', False)],
          'ödsdomarnas': [('ödsdom', False)],
          'ödskallen': [('ödskalle', False)],
          'ödslanden': [('ödslande', False)],
          'ödslandens': [('ödslande', True)],
          'ödslandet': [('ödslande', False)],
          'ödspotts': [('ödspotta', False)],
          'ödstalet': [('ödstal', False)],
          'ödträn': [('ödträd', False)],
          'ödträns': [('ödträd', False)],
          'ödår': [('ödår', False)],
          'ödåren': [('ödår', False)],
          'ödårens': [('ödår', False)],
          'ödårs': [('ödår', False)],
          'ödårs-': [('ödår', False)],
          'öe': [('öe', False)],
          'öe-': [('öe', False)],
          'öendets': [('öende', False)],
          'öer': [('ö', False)],
          'öers': [('ö', False)],
          'öes': [('öe', False)],
          'öets': [('ö', False)],
          'öfiskar': [('öfisk', False)],
          'öfiskarna': [('öfisk', False)],
          'öfiskarnas': [('öfisk', False)],
          'öfjäll': [('öfjäll', False)],
          'öfjäll-': [('öfjäll', False)],
          'öfjälls': [('öfjäll', False)],
          'öfjälls-': [('öfjäll', False)],
          'öflott': [('öflotta', False)],
          'öflott-': [('öflotta', False)],
          'öflotte': [('öflotta', False)],
          'öflotts': [('öflotta', False)],
          'öflotts-': [('öflotta', False)],
          'öfte': [('öfte', False)],
          'öften': [('öfte', False)],
          'öftens': [('öfte', False)],
          'öftet': [('öfte', False)],
          'ög': [('ög', False)],
          'ög-': [('ög', False)],
          'ögaltar': [('ögaltare', False)],
          'ögaltarna': [('ögaltare', False)],
          'ögaltarnas': [('ögaltare', False)],
          'ögandens': [('ögande', False)],
          'ögar': [('ög', False)],
          'ögaren': [('ögare', False)],
          'ögarna': [('ög', False)],
          'ögarnas': [('ög', False)],
          'ögars': [('ög', False)],
          'ögas': [('öga', False)],
          'ögas-': [('öga', False)],
          'ögat': [('öga', True)],
          'ögats': [('öga', True)],
          'ögel': [('ögel', False)],
          'ögen': [('ög', False)],
          'ögens': [('ög', False)],
          'ögerkrokar': [('ögerkrok', False)],
          'ögerkrokarna': [('ögerkrok', False)],
          'ögerkrokars': [('ögerkrok', False)],
          'ögerkroks': [('ögerkrok', False)],
          'ögerkroks-': [('ögerkrok', False)],
          'ögers': [('öger', False)],
          'ögers-': [('öger', False)],
          'öget': [('ög', False)],
          'ögets': [('ög', False)],
          'öggar': [('ögg', False)],
          'ögglans': [('ögglans', False)],
          'öghets': [('öghet', False)],
          'ögiftet': [('ögift', False)],
          'ögiftets': [('ögift', False)],
          'ögifts': [('ögift', False)],
          'ögifts-': [('ögift', False)],
          'ögkor': [('ögkor', False)],
          'ögkors': [('ögkor', False)],
          'ögkors-': [('ögkor', False)],
          'ögla': [('ögla', True)],
          'öglandet': [('ögland', False)],
          'öglandets': [('ögland', False)],
          'öglans': [('ögla', True)],
          'öglas': [('ögla', False)],
          'öglen': [('ögel', False)],
          'öglens': [('ögel', False)],
          'öglors': [('ögla', True)],
          'ögnar': [('ögnare', False)],
          'ögnarna': [('ögnare', False)],
          'ögnarnas': [('ögnare', False)],
          'ögnerna': [('ögn', False)],
          'ögnernas': [('ögn', False)],
          'ögners': [('ögn', False)],
          'ögon': [('öga', False)],
          'ögon-': [('öga', False)],
          'ögondropps': [('ögondroppar', True), ('ögondropp', True)],
          'ögondropps-': [('ögondroppar', True), ('ögondropp', True)],
          'ögonen': [('öga', True)],
          'ögonens': [('öga', True)],
          'ögons': [('öga', True)],
          'ögrev': [('ögrev', False)],
          'ögreven': [('ögrev', False)],
          'ögrevens': [('ögrev', False)],
          'ögrevs': [('ögrev', False)],
          'ögrevs-': [('ögrev', False)],
          'ögräns': [('ögräns', False)],
          'ögräns-': [('ögräns', False)],
          'ögs': [('ög', False)],
          'ögs-': [('ög', False)],
          'ögubbs': [('ögubbe', False)],
          'ögömme': [('ögömme', False)],
          'ögöms-': [('ögömme', False)],
          'öheter': [('öhet', False)],
          'öheterna': [('öhet', False)],
          'öheternas': [('öhet', False)],
          'öheters': [('öhet', False)],
          'öhets': [('öhet', False)],
          'öhets-': [('öhet', False)],
          'öhipps-': [('öhippa', False)],
          'öhn': [('öhn', False)],
          'öhästarnas': [('öhäst', False)],
          'öhästars': [('öhäst', False)],
          'öing': [('öing', False)],
          'öing-': [('öing', False)],
          'öingar': [('öing', False)],
          'öingarna': [('öing', False)],
          'öingarnas': [('öing', False)],
          'öingars': [('öing', False)],
          'öingen': [('öing', False)],
          'öingens': [('öing', False)],
          'öings': [('öing', False)],
          'öings-': [('öing', False)],
          'öiskan': [('öiska', False)],
          'öiskans': [('öiska', False)],
          'öiske': [('öiska', False)],
          'öiske-': [('öiska', False)],
          'öj': [('öj', False)],
          'öj-': [('öj', False)],
          'öjan': [('öja', False)],
          'öjans': [('öja', False)],
          'öjaren': [('öjare', False)],
          'öjars': [('öj', False)],
          'öjdar': [('öjdare', False)],
          'öje': [('öja', False)],
          'öje-': [('öja', False)],
          'öjen': [('öj', False)],
          'öjens': [('öj', False)],
          'öjet': [('öje', False)],
          'öjets': [('öje', False)],
          'öjlar': [('öjel', False)],
          'öjlarna': [('öjel', False)],
          'öjlarnas': [('öjel', False)],
          'öjor': [('öja', False)],
          'öjorna': [('öja', False)],
          'öjornas': [('öja', False)],
          'öjors': [('öja', False)],
          'öjs-': [('öj', False)],
          'öjsar': [('öjs', False)],
          'ök': [('ök', False)],
          'ök-': [('ök', False)],
          'ökan': [('ökan', False)],
          'ökanden': [('ökande', False)],
          'ökans': [('ökan', False)],
          'ökans-': [('ökan', False)],
          'ökar': [('ök', False)],
          'ökar-': [('ökare', False)],
          'ökare': [('ökare', False)],
          'ökaren': [('ökare', False)],
          'ökarens': [('ökare', False)],
          'ökarna': [('ök', False)],
          'ökarnas': [('ökare', False)],
          'ökars': [('ök', False)],
          'ökas': [('öka', False)],
          'ökas-': [('öka', False)],
          'ökat': [('öka', False)],
          'ökats': [('öka', False)],
          'öke': [('öka', False)],
          'öke-': [('öka', False)],
          'ökel': [('ökel', False)],
          'ökel-': [('ökel', False)],
          'ökelsen': [('ökelse', False)],
          'ökelsens': [('ökelse', False)],
          'öken': [('öken', True), ('ök', True)],
          'öken-': [('öken', False)],
          'ökens': [('öken', True), ('ök', True)],
          'ökens-': [('öken', False)],
          'ökerits': [('ökeri', False)],
          'öket': [('ök', False)],
          'ökets': [('ök', True)],
          'öklar': [('ökel', False)],
          'öklarna': [('ökel', False)],
          'öklarnas': [('ökel', False)],
          'öklars': [('ökel', False)],
          'öklock': [('öklocka', False)],
          'öklot': [('öklot', False)],
          'öklots': [('öklot', False)],
          'öklots-': [('öklot', False)],
          'öknar': [('öken', False)],
          'öknatt': [('öknatt', False)],
          'öknatten': [('öknatt', False)],
          'öknattens': [('öknatt', False)],
          'öknatts': [('öknatt', False)],
          'öknatts-': [('öknatt', False)],
          'öknen': [('öken', False)],
          'ökningar': [('ökning', False)],
          'ökningarna': [('ökning', False)],
          'ökningarnas': [('ökning', False)],
          'ökningars': [('ökning', False)],
          'öknings': [('ökning', False)],
          'öknings-': [('ökning', False)],
          'ökon': [('öko', False)],
          'ökons': [('öko', False)],
          'ökor': [('öko', False)],
          'ökorna': [('öka', False)],
          'ökornas': [('öka', False)],
          'ökors': [('öka', False)],
          'ökos': [('öko', False)],
          'ökos-': [('öko', False)],
          'ökott': [('ökotta', False)],
          'ökott-': [('ökotta', False)],
          'ökotte': [('ökotta', False)],
          'ökotte-': [('ökotta', False)],
          'ökotts': [('ökotta', False)],
          'ökotts-': [('ökotta', False)],
          'ökringar': [('ökring', False)],
          'ökringars': [('ökring', False)],
          'öks': [('ök', False)],
          'öks-': [('ök', False)],
          'ökstaken': [('ökstak', False)],
          'öksvägens': [('öksvägen', False)],
          'ökungar': [('ökunge', False)],
          'ökungarna': [('ökunge', False)],
          'ökungarnas': [('ökunge', False)],
          'ökungars': [('ökunge', False)],
          'ökungen': [('ökunge', False)],
          'ökungens': [('ökunge', False)],
          'ökuret': [('ökur', False)],
          'ökurets': [('ökur', False)],
          'ökurs': [('ökurs', False)],
          'ökurs-': [('ökurs', False)],
          'öl': [('öl', False)],
          'öl-': [('öl', False)],
          'ölanden': [('ölande', False)],
          'ölandena': [('ölande', False)],
          'ölandenas': [('ölande', False)],
          'ölandens': [('ölande', False)],
          'ölandet': [('ölande', False)],
          'ölandets': [('ölande', False)],
          'ölar': [('öl', False)],
          'ölaren': [('ölare', False)],
          'ölarna': [('öl', False)],
          'ölarnas': [('öl', False)],
          'ölars': [('öl', False)],
          'ölback': [('ölback', True)],
          'ölback-': [('ölback', True)],
          'ölbackar': [('ölback', True)],
          'ölbackarna': [('ölback', True)],
          'ölbacks-': [('ölback', True)],
          'ölegans': [('ölega', False)],
          'ölege': [('ölega', False)],
          'ölen': [('öl', False)],
          'ölens': [('öl', False)],
          'öler': [('öl', False)],
          'ölerna': [('öl', False)],
          'ölernas': [('öl', False)],
          'ölers': [('öl', True)],
          'ölet': [('öl', False)],
          'ölets': [('öl', False)],
          'ölfen': [('ölfena', False)],
          'ölfens': [('ölfena', False)],
          'ölighets': [('ölighet', False)],
          'ölj': [('ölja', False)],
          'ölj-': [('ölja', False)],
          'öljans': [('ölja', False)],
          'ölje': [('ölje', False)],
          'öljen': [('ölje', False)],
          'öljens': [('ölje', False)],
          'öljs': [('ölja', False)],
          'öljs-': [('ölje', False)],
          'ölkars': [('ölke', False)],
          'ölke': [('ölke', False)],
          'öll': [('ölla', False)],
          'öll-': [('ölla', False)],
          'öllans': [('ölla', False)],
          'ölls': [('ölla', False)],
          'ölls-': [('ölla', False)],
          'öln': [('ölna', False)],
          'öln-': [('ölna', False)],
          'ölnarna': [('ölnare', False)],
          'ölningar': [('ölning', False)],
          'ölningarna': [('ölning', False)],
          'ölningarnas': [('ölning', False)],
          'ölningars': [('ölning', False)],
          'ölnings': [('ölning', False)],
          'ölnings-': [('ölning', False)],
          'ölns': [('ölna', False)],
          'ölns-': [('ölna', False)],
          'ölon': [('ölon', False)],
          'ölonen': [('ölon', False)],
          'ölonens': [('ölon', False)],
          'ölons': [('ölon', False)],
          'ölost': [('ölost', True)],
          'ölost-': [('ölost', True)],
          'ölp': [('ölp', False)],
          'ölparnas': [('ölp', False)],
          'ölps': [('ölp', False)],
          'öls': [('öl', False)],
          'öls-': [('öl', False)],
          'ölskens': [('ölskena', False)],
          'ölstons': [('ölsto', False)],
          'ölt': [('ölt', False)],
          'öluffar': [('öluff', True)],
          'öluffarna': [('öluff', True)],
          'öluffarnas': [('öluff', True)],
          'ölunge': [('ölunge', False)],
          'ölunge-': [('ölunge', False)],
          'ölvan': [('ölva', False)],
          'ölvans': [('ölva', False)],
          'ölykt-': [('ölykta', False)],
          'ölykts': [('ölykta', False)],
          'öm': [('öm', False)],
          'öm-': [('öm', False)],
          'ömanden': [('ömande', False)],
          'ömannen': [('öman', False)],
          'ömannens': [('öman', False)],
          'ömar': [('ömare', False)],
          'ömar-': [('ömare', False)],
          'ömare': [('ömare', False)],
          'ömaren': [('ömare', False)],
          'ömarna': [('ömare', False)],
          'ömarnas': [('ömare', False)],
          'ömen': [('öme', False)],
          'ömens': [('öme', False)],
          'ömes': [('öme', False)],
          'ömes-': [('öme', False)],
          'ömet': [('öme', False)],
          'ömets': [('öme', False)],
          'ömil': [('ömil', False)],
          'ömil-': [('ömil', False)],
          'ömils': [('ömil', False)],
          'ömin': [('ömina', False)],
          'ömin-': [('ömina', False)],
          'öminister': [('öminister', False)],
          'öministers': [('öminister', False)],
          'öminors': [('ömina', False)],
          'ömins': [('ömina', False)],
          'ömins-': [('ömina', False)],
          'ömman': [('ömma', False)],
          'ömmar': [('öm', False)],
          'ömmarens': [('ömmare', False)],
          'ömmarna': [('öm', False)],
          'ömmarnas': [('öm', False)],
          'ömmars': [('öm', False)],
          'ömmens': [('öm', False)],
          'ömmet': [('öm', False)],
          'ömmets': [('ömme', False)],
          'ömos': [('ömos', False)],
          'ömos-': [('ömos', False)],
          'öms': [('öm', False)],
          'öms-': [('öm', False)],
          'ömställen': [('ömställe', False)],
          'ömstället': [('ömställe', False)],
          'ömställets': [('ömställe', False)],
          'ömän': [('öman', False)],
          'ömäns': [('öman', False)],
          'ön': [('ö', True)],
          'ön-': [('ön', False)],
          'öna': [('öna', False)],
          'önanden': [('önande', False)],
          'önar': [('önare', False)],
          'önar-': [('önare', False)],
          'önaren': [('önare', False)],
          'önarens': [('önare', False)],
          'önarna': [('ön', False)],
          'önarnas': [('önare', False)],
          'önars': [('ön', False)],
          'önas': [('öna', False)],
          'önben': [('önbena', False)],
          'önbens-': [('önbena', False)],
          'önbetet': [('önbete', False)],
          'önbetets': [('önbete', False)],
          'önder': [('onde', False)],
          'önderna': [('onde', False)],
          'öndernas': [('onde', False)],
          'önders': [('onde', False)],
          'öndringarna': [('öndring', False)],
          'öne': [('öna', False)],
          'öne-': [('öna', False)],
          'önen': [('ön', False)],
          'önens': [('ön', False)],
          'öner': [('ön', False)],
          'önerna': [('ön', False)],
          'önernas': [('on', False)],
          'öners': [('ön', False)],
          'önet': [('ön', False)],
          'önika': [('önika', False)],
          'önkull': [('önkulla', False)],
          'önkull-': [('önkulla', False)],
          'önkulle': [('önkulla', False)],
          'önkulle-': [('önkulla', False)],
          'önn': [('önn', False)],
          'önn-': [('önn', False)],
          'önnar': [('önn', False)],
          'önnarnas': [('önn', False)],
          'önnars': [('önn', False)],
          'önnen': [('önn', False)],
          'önor': [('öna', False)],
          'önorna': [('öna', False)],
          'önornas': [('öna', False)],
          'önors': [('öna', False)],
          'öns': [('ö', True)],
          'önsarnas': [('öns', False)],
          'önsets': [('öns', False)],
          'önskan': [('önskan', False)],
          'önskans': [('önskan', True)],
          'önsorden': [('önsord', False)],
          'önsordens': [('önsord', False)],
          'önt-': [('önt', False)],
          'öntar': [('önt', False)],
          'öntarnas': [('önt', False)],
          'önts': [('önt', False)],
          'önyte': [('önyta', False)],
          'öofficerare': [('öofficer', False)],
          'öofficerares': [('öofficer', False)],
          'öofficerarna': [('öofficer', False)],
          'öofficerarnas': [('öofficer', False)],
          'öormar': [('öorm', False)],
          'öormarna': [('öorm', False)],
          'öormarnas': [('öorm', False)],
          'öp': [('öp', False)],
          'öp-': [('öp', False)],
          'öpande': [('öpande', False)],
          'öpande-': [('öpande', False)],
          'öpar': [('öpare', False)],
          'öpar-': [('öpare', False)],
          'öparen': [('öpare', False)],
          'öparens': [('öpare', False)],
          'öpares': [('öpare', False)],
          'öparnas': [('öpare', False)],
          'öpelsen': [('öpelse', False)],
          'öpelsens': [('öpelse', False)],
          'öpen': [('öp', False)],
          'öpen-': [('öpen', False)],
          'öpenn': [('öpen', False)],
          'öpenns': [('öpen', False)],
          'öpens': [('öp', False)],
          'öpens-': [('öpen', False)],
          'öperiernas': [('öperi', False)],
          'öperiers': [('öperi', False)],
          'öperiets': [('öperi', False)],
          'öperits': [('öperi', False)],
          'öpet': [('öp', False)],
          'öpets': [('öp', False)],
          'öphets-': [('öphets', False)],
          'öpis': [('öpis', False)],
          'öpis-': [('öpis', False)],
          'öpkurs-': [('öpkurs', False)],
          'öplants': [('öplanta', False)],
          'öplants-': [('öplanta', False)],
          'öplin': [('öplina', False)],
          'öplin-': [('öplina', False)],
          'öplins': [('öplina', False)],
          'öplins-': [('öplina', False)],
          'öpmask': [('öpmaska', False)],
          'öpnar': [('öpen', False)],
          'öpnarnas': [('öpen', False)],
          'öpor': [('öpa', False)],
          'öporna': [('öpa', False)],
          'öpornas': [('öpa', False)],
          'öpors': [('öpa', False)],
          'öpostar': [('öpost', False)],
          'öpostarna': [('öpost', False)],
          'öpostarnas': [('öpost', False)],
          'öpplanden': [('öpplande', False)],
          'öpplandens': [('öpplande', False)],
          'öpplandet': [('öpplande', False)],
          'öpplar': [('öpplare', False)],
          'öpplarna': [('öpplare', False)],
          'öpplarnas': [('öpplare', False)],
          'öpring': [('öpring', False)],
          'öpringar': [('öpring', False)],
          'öpringarnas': [('öpring', False)],
          'öprings': [('öpring', False)],
          'öprings-': [('öpring', False)],
          'öproblemet': [('öproblem', False)],
          'öps': [('öp', False)],
          'öps-': [('öp', False)],
          'öpslagar': [('öpslag', False)],
          'öpslagarna': [('öpslag', False)],
          'öpslagarnas': [('öpslag', False)],
          'öpsteg': [('öpsteg', False)],
          'öpsteg-': [('öpsteg', False)],
          'öpstegens': [('öpsteg', False)],
          'öpstegs-': [('öpsteg', False)],
          'ör': [('ör', False)],
          'ör-': [('ör', False)],
          'öran': [('öra', False)],
          'örande': [('örande', False)],
          'örande-': [('örande', False)],
          'öranden': [('örande', False)],
          'örandens': [('örande', False)],
          'örandet': [('örande', False)],
          'örans': [('öra', False)],
          'örar': [('örare', False)],
          'örars': [('ör', False)],
          'öras': [('öra', False)],
          'öras-': [('öra', False)],
          'örbön': [('örböna', False)],
          'örböns': [('örbön', False)],
          'örböns-': [('örbön', False)],
          'örda': [('örda', False)],
          'ördan': [('örda', False)],
          'ördans': [('örda', False)],
          'ördar': [('ördare', False)],
          'ördarna': [('ördare', False)],
          'ördarnas': [('örd', False)],
          'ördas': [('örda', False)],
          'ördets': [('örd', False)],
          'ördomarna': [('ördom', False)],
          'öre': [('öre', True)],
          'öre-': [('öre', True)],
          'ören': [('öre', True), ('ör', True)],
          'örens': [('öre', True), ('ör', True)],
          'örer': [('ör', False)],
          'örerna': [('ör', False)],
          'örernas': [('ör', False)],
          'örers': [('ör', False)],
          'örese': [('öresa', False)],
          'örese-': [('öresa', False)],
          'öret': [('öre', True)],
          'örets': [('öre', False)],
          'örfader': [('örfader', False)],
          'örfaders-': [('örfader', False)],
          'örfarenhets': [('örfarenhet', False)],
          'örfarenhets-': [('örfarenhet', False)],
          'örfäderna': [('örfader', False)],
          'örfädernas': [('örfader', False)],
          'örighets': [('örighet', False)],
          'öringar': [('öring', False)],
          'öringarna': [('öring', False)],
          'öringarnas': [('öring', False)],
          'örips': [('öripa', False)],
          'örips-': [('öripa', False)],
          'örjan': [('örjan', False)],
          'örjans': [('örja', False)],
          'örjar': [('örjare', False)],
          'örjarna': [('örjare', False)],
          'örjarnas': [('örj', False)],
          'örjets': [('örj', False)],
          'örjs': [('örj', False)],
          'örjs-': [('örj', False)],
          'örkarnas': [('örk', False)],
          'örke': [('örke', False)],
          'örke-': [('örke', False)],
          'örker': [('örker', False)],
          'örkerna': [('örker', False)],
          'örkernas': [('örker', False)],
          'örkers': [('örker', False)],
          'örket': [('örke', False)],
          'örklädes': [('örkläde', False)],
          'örkunskaps': [('örkunskaper', False)],
          'örlandets': [('örlande', True)],
          'örlogsflagg': [('örlogsflagga', True), ('örlogsflagg', True)],
          'örlogsflaggs': [('örlogsflagga', True), ('örlogsflagg', True)],
          'örlogsflaggs-': [('örlogsflagg', True), ('örlogsflagga', True)],
          'örmåns': [('örmån', False)],
          'örn': [('örn', True)],
          'örn-': [('örn', True)],
          'örna': [('ö', False)],
          'örnar': [('örn', True)],
          'örnarna': [('örn', True)],
          'örnarnas': [('örn', False)],
          'örnas': [('ö', False)],
          'örnbräknen': [('örnbräkne', True), ('örnbräken', True)],
          'örnbräknens': [('örnbräkne', True), ('örnbräken', True)],
          'örne': [('örne', False)],
          'örne-': [('örna', False)],
          'örnekarna': [('örnekare', False)],
          'örnekarnas': [('örnekare', False)],
          'örnen': [('örn', True)],
          'örnens': [('örn', True)],
          'örnes': [('örne', False)],
          'örnes-': [('örne', False)],
          'örnet': [('örne', False)],
          'örnets': [('örn', False)],
          'örns': [('örn', True)],
          'örns-': [('örn', True)],
          'öron': [('öra', False)],
          'öron-': [('öra', False)],
          'örons': [('öra', False)],
          'öror': [('öra', False)],
          'örorna': [('öra', False)],
          'örornas': [('öra', False)],
          'örors': [('öra', False)],
          'örrs': [('örr', False)],
          'örs': [('ör', False)],
          'örs-': [('ör', False)],
          'örsar': [('örsare', False)],
          'örsar-': [('örsare', False)],
          'örsarens': [('örsare', False)],
          'örsarna': [('örs', False)],
          'örsarnas': [('örsare', False)],
          'örsen': [('örs', False)],
          'örsfasonerna': [('örsfason', False)],
          'örsfasonernas': [('örsfason', False)],
          'örsfasoners': [('örsfason', False)],
          'örsikten': [('örsikt', False)],
          'örsiktens': [('örsikt', False)],
          'örskor': [('örska', False)],
          'örskorna': [('örska', False)],
          'örskornas': [('örska', False)],
          'örskors': [('örska', False)],
          'örsle': [('örsla', False)],
          'örsle-': [('örsla', False)],
          'örsopp': [('örsopp', False)],
          'örsopp-': [('örsopp', False)],
          'örsopps': [('örsopp', False)],
          'örsopps-': [('örsopp', False)],
          'örst-': [('örst', False)],
          'örstanden': [('örstande', False)],
          'örstandens': [('örstande', False)],
          'örsten': [('örst', False)],
          'örstens': [('örst', False)],
          'örstudie-': [('örstudie', False)],
          'örstudiers': [('örstudie', False)],
          'örstövel': [('örstövel', False)],
          'örstövel-': [('örstövel', False)],
          'örstövels': [('örstövel', False)],
          'örstövels-': [('örstövel', False)],
          'örstövlar': [('örstövel', False)],
          'örstövlarna': [('örstövel', False)],
          'örstövlarnas': [('örstövel', False)],
          'örsåt': [('örsåt', False)],
          'örsåt-': [('örsåt', False)],
          'örsåtens': [('örsåt', False)],
          'örtar': [('örtare', False)],
          'örtar-': [('örtare', False)],
          'örtarens': [('örtare', False)],
          'örtarna': [('örtare', False)],
          'örtarnas': [('ört', False)],
          'örte': [('örte', False)],
          'örten': [('ört', True)],
          'örtens': [('ört', True)],
          'örtet': [('örte', False)],
          'örtets': [('ört', False)],
          'örts': [('ört', True)],
          'örts-': [('ört', True)],
          'örvanten': [('örvant', False)],
          'örvantens': [('örvant', False)],
          'örvants-': [('örvant', False)],
          'örvar': [('örvar', False)],
          'örvaren': [('örvar', False)],
          'örvars': [('örvar', False)],
          'örvis': [('örvisa', False)],
          'örvis-': [('örvisa', False)],
          'örvlandet': [('örvlande', False)],
          'örvlandets': [('örvlande', False)],
          'örån': [('örå', False)],
          'öråns': [('örå', False)],
          'örös': [('örös', False)],
          'örös-': [('örös', False)],
          'örösen': [('örös', False)],
          'örösens': [('örös', False)],
          'örövar': [('örövare', False)],
          'örövarna': [('örövare', False)],
          'örövarnas': [('örövare', False)],
          'ös': [('ös', True), ('ö', True)],
          'ös-': [('ö', True), ('ös', True)],
          'ösanden': [('ösande', False)],
          'ösandens': [('ösande', False)],
          'ösans': [('ösa', False)],
          'ösar': [('ös', False)],
          'ösaren': [('ösare', False)],
          'ösarna': [('ösare', False)],
          'ösarnas': [('ösare', False)],
          'ösars': [('ös', False)],
          'öse': [('ösa', False)],
          'öse-': [('ösa', False)],
          'ösen': [('ös', False)],
          'ösen-': [('ösen', False)],
          'ösena': [('öse', False)],
          'ösenas': [('öse', False)],
          'ösens': [('ös', False)],
          'ösens-': [('ösen', False)],
          'öser': [('ös', False)],
          'öserna': [('ös', False)],
          'ösernas': [('ös', False)],
          'ösers': [('ös', False)],
          'öset': [('ös', True)],
          'ösets': [('ös', True)],
          'öshet': [('öshet', False)],
          'ösidan': [('ösida', False)],
          'öside-': [('ösida', False)],
          'ösjukan': [('ösjuka', False)],
          'ösk': [('öska', False)],
          'ösk-': [('öske', False)],
          'öskal': [('öskal', False)],
          'öskals': [('öskal', False)],
          'öskals-': [('öskal', False)],
          'öskan': [('öska', False)],
          'öskans': [('öska', False)],
          'öskar': [('öskar', True)],
          'öskaren': [('öskar', True)],
          'öskarens': [('öskar', True)],
          'öskars': [('öskar', True)],
          'öskars-': [('öskar', True)],
          'öskat': [('öskata', False)],
          'öskat-': [('öskata', False)],
          'öskate': [('öskata', False)],
          'öskats': [('öskata', False)],
          'öskats-': [('öskata', False)],
          'öske': [('öske', False)],
          'ösken': [('öske', False)],
          'öskena': [('öske', False)],
          'öskenas': [('öske', False)],
          'öskens': [('öske', False)],
          'öskes': [('öske', False)],
          'ösket': [('öske', False)],
          'ösko': [('ösko', False)],
          'öskor': [('öska', False)],
          'öskorna': [('ösko', False)],
          'öskornas': [('ösko', False)],
          'öskors': [('ösko', False)],
          'öskoter': [('öskoter', False)],
          'öskottar': [('öskottare', False)],
          'öskottarna': [('öskottare', False)],
          'öskottarnas': [('öskottare', False)],
          'öskullarnas': [('öskulle', False)],
          'öskullen': [('öskulle', False)],
          'öslag': [('öslag', False)],
          'öslags': [('öslag', False)],
          'öslags-': [('öslag', False)],
          'ösnacks': [('ösnack', False)],
          'ösnacks-': [('ösnack', False)],
          'öson': [('öson', False)],
          'ösons': [('öson', False)],
          'ösor': [('ösa', False)],
          'ösorna': [('ösa', False)],
          'ösornas': [('ösa', False)],
          'ösors': [('ösa', False)],
          'ösrycknings': [('ösryckning', False)],
          'ösrycknings-': [('ösryckning', False)],
          'öss': [('össa', False)],
          'öss-': [('össa', False)],
          'össans': [('össa', False)],
          'össar': [('össe', False)],
          'össars': [('össe', False)],
          'össe': [('össe', False)],
          'össen': [('us', False)],
          'össens': [('us', False)],
          'össets': [('öss', False)],
          'öst': [('öst', False)],
          'öst-': [('öst', True)],
          'östa': [('östa', False)],
          'östackar': [('östack', False)],
          'östackarna': [('östack', False)],
          'östackarnas': [('östack', False)],
          'östan': [('östan', True)],
          'östans': [('östan', False)],
          'östans-': [('östan', False)],
          'östar-': [('östare', False)],
          'östarnas': [('öst', False)],
          'östars': [('öst', False)],
          'östas': [('östa', False)],
          'östdags': [('östdag', False)],
          'östens': [('öst', False)],
          'öster': [('öster', True)],
          'östers': [('öster', True)],
          'östfiskarna': [('östfiskare', False)],
          'östjärn': [('östjärn', False)],
          'östjärns': [('östjärn', False)],
          'östjärns-': [('östjärn', False)],
          'östor': [('östa', False)],
          'östormar': [('östorm', False)],
          'östors': [('östa', False)],
          'östron': [('östron', True)],
          'östrons': [('östron', True)],
          'östrus': [('östrus', True)],
          'östrus-': [('östrus', True)],
          'öställen': [('öställ', False)],
          'öställens': [('öställ', False)],
          'östället': [('öställ', False)],
          'öställets': [('öställ', False)],
          'öständer': [('öständer', False)],
          'öständerna': [('öständer', False)],
          'öständernas': [('öständer', False)],
          'öständers': [('öständer', False)],
          'östövlars': [('östövel', False)],
          'ösäden': [('ösäd', False)],
          'ösädens': [('ösäd', False)],
          'ösädes': [('ösäd', False)],
          'ösäds': [('ösäd', False)],
          'ösäds-': [('ösäd', False)],
          'ösåt': [('ösåte', False)],
          'ösåt-': [('ösåte', False)],
          'ösåtar': [('ösåte', False)],
          'ösåtarna': [('ösåte', False)],
          'ösåtarnas': [('ösåte', False)],
          'ösåtars': [('ösåte', False)],
          'ösåten': [('ösåte', False)],
          'ösåtens': [('ösåte', False)],
          'ösåts': [('ösåte', False)],
          'ösåts-': [('ösåte', False)],
          'öt': [('öt', False)],
          'öt-': [('öta', False)],
          'ötan': [('öta', False)],
          'ötanden': [('ötande', False)],
          'ötandens': [('ötande', False)],
          'ötans': [('öta', False)],
          'ötar': [('öt', False)],
          'ötaren': [('ötare', False)],
          'ötarna': [('öt', False)],
          'ötars': [('öt', False)],
          'öte': [('öta', False)],
          'öte-': [('öta', False)],
          'öten': [('öt', False)],
          'ötens': [('öt', False)],
          'öter': [('ot', False)],
          'öterna': [('ot', False)],
          'öternas': [('ot', False)],
          'öters': [('ot', False)],
          'öterskor': [('öterska', False)],
          'öterskorna': [('öterska', False)],
          'öterskornas': [('öterska', False)],
          'öterskors': [('öterska', False)],
          'ötes': [('öter', False)],
          'ötes-': [('öter', False)],
          'ötesten': [('ötesten', False)],
          'ötestens': [('ötesten', False)],
          'ötet': [('öt', False)],
          'ötets': [('öte', False)],
          'öthaken': [('öthake', False)],
          'öthet': [('öthet', False)],
          'öthets': [('öthet', False)],
          'ötighets': [('ötighet', False)],
          'ötillgångar': [('ötillgång', False)],
          'ötillgångarna': [('ötillgång', False)],
          'ötillgångarnas': [('ötillgång', False)],
          'ötillgångars': [('ötillgång', False)],
          'ötillgångs': [('ötillgång', False)],
          'ötillgångs-': [('ötillgång', False)],
          'ötman': [('ötma', False)],
          'ötomten': [('ötomt', False)],
          'ötomtens': [('ötomt', False)],
          'ötor': [('öta', False)],
          'ötork': [('ötork', False)],
          'ötorkarnas': [('ötork', False)],
          'ötorna': [('öta', False)],
          'ötornas': [('öta', False)],
          'ötors': [('öta', False)],
          'ötrum': [('ötrum', False)],
          'ötrums': [('ötrum', False)],
          'ötrums-': [('ötrum', False)],
          'öträd': [('öträd', False)],
          'öträd-': [('öträd', False)],
          'öträden': [('öträd', False)],
          'öträdens': [('öträd', False)],
          'öträdet': [('öträd', False)],
          'öträdets': [('öträd', False)],
          'öträds': [('öträd', False)],
          'öträn': [('öträd', False)],
          'öträna': [('öträd', False)],
          'ötränas': [('öträd', False)],
          'öträns': [('öträd', False)],
          'öts': [('öt', False)],
          'öts-': [('öt', False)],
          'ötsaks': [('ötsak', False)],
          'ötsaks-': [('ötsak', False)],
          'ötsk': [('ötska', False)],
          'ötsk-': [('ötska', False)],
          'ötskor': [('ötska', False)],
          'ötskorna': [('ötska', False)],
          'ötskornas': [('ötska', False)],
          'ötskors': [('ötska', False)],
          'ött': [('ötta', False)],
          'ött-': [('ötta', False)],
          'öttan': [('ötta', False)],
          'öttarna': [('ött', False)],
          'öttarnas': [('ött', False)],
          'öttben': [('öttben', False)],
          'öttbens': [('öttben', False)],
          'öttbens-': [('öttben', False)],
          'ötte-': [('ötta', False)],
          'öttens': [('ött', False)],
          'öttets': [('ött', False)],
          'öttighets-': [('öttighet', False)],
          'öttrar': [('otter', False)],
          'öttrarna': [('otter', False)],
          'öttrarnas': [('otter', False)],
          'öttrars': [('otter', False)],
          'ötts': [('ötta', False)],
          'ötts-': [('ötta', False)],
          'öttsidan': [('öttsida', False)],
          'öttsidans': [('öttsida', False)],
          'ötvivlar': [('ötvivel', False)],
          'ötvivlarna': [('ötvivel', False)],
          'ötvivlarnas': [('ötvivel', False)],
          'öv': [('öv', False)],
          'öv-': [('öv', False)],
          'övallar': [('övall', False)],
          'övallarna': [('övall', False)],
          'övallarnas': [('övall', False)],
          'övalls-': [('övall', False)],
          'övan': [('övan', False)],
          'övana': [('övana', False)],
          'övane-': [('övana', False)],
          'övanors': [('övana', False)],
          'övans-': [('övan', False)],
          'övar': [('öv', False)],
          'övar-': [('övare', False)],
          'övaren': [('övare', False)],
          'övarna': [('övare', False)],
          'övarnas': [('öv', False)],
          'övars': [('öv', False)],
          'övel': [('övel', False)],
          'övel-': [('övel', False)],
          'övelen': [('övel', False)],
          'övelens': [('övel', False)],
          'övels': [('övel', False)],
          'öven': [('öv', False)],
          'övens': [('öv', False)],
          'överlåtarna': [('överlåtare', True)],
          'övern': [('över', False)],
          'överns': [('över', False)],
          'övers': [('över', False)],
          'övers-': [('över', False)],
          'överst': [('överste', True)],
          'överst-': [('överste', False)],
          'översten': [('överste', False)],
          'överstens': [('överste', True)],
          'övet': [('öv', False)],
          'övinsten': [('övinst', False)],
          'övinstens': [('övinst', False)],
          'övinter': [('övinter', False)],
          'övinters': [('övinter', False)],
          'övitas': [('övita', False)],
          'övite': [('övita', False)],
          'övits': [('övita', False)],
          'övits-': [('övita', False)],
          'övlar': [('övel', False)],
          'övlarna': [('övel', False)],
          'övlarnas': [('övel', False)],
          'övlingen': [('övling', False)],
          'övlingens': [('övling', False)],
          'övmosse': [('övmossa', False)],
          'övrar': [('över', False)],
          'övrarna': [('över', False)],
          'övrarnas': [('övrare', False)],
          'övs': [('öv', False)],
          'övs-': [('öv', False)],
          'övsugar': [('övsug', False)],
          'övsugarna': [('övsug', False)],
          'övsugarnas': [('övsug', False)],
          'övägs-': [('öväg', False)],
          'övändar': [('övändare', False)],
          'övändarna': [('övändare', False)],
          'ük-': [('ük', False)],
          'üks': [('ük', False)],
          'üslin': [('üsli', False)],
          'üslins': [('üsli', False)]},
 'NOUN_ADJ': {'t': [('d', False)], 'ästa': [('ra', False)], 'ättre': [('ra', False)]},
 'NOUN_ADV': {'er': [('ycket', False)],
              'mindre': [('lite', True)],
              'minst': [('lite', True)],
              're': [('e', False)],
              'st': [('e', False)]},
 'NOUN_DET': {'var': [('vara', True), ('var', True)]},
 'NOUN_NOUN': {'er': [('', False)],
               'gar': [('gar', False)],
               'ingar': [('an', False)],
               'mn': [('mn', False)],
               'n': [('', False)],
               'ägar': [('äg', False)],
               'änder': [('and', False)]},
 'NOUN_VERB': {'anns': [('innas', False)],
               'des': [('', False)],
               'dras': [('dra', True)],
               'eg': [('iga', False)],
               'er': [('a', False)],
               'ev': [('iva', False)],
               'gs': [('gas', False)],
               'ks': [('kas', False)],
               'las': [('la', False)],
               'ls': [('la', False)],
               'lär': [('lära', True)],
               'nas': [('na', False)],
               'nnas': [('nnas', False)],
               'ns': [('nas', False)],
               'ogs': [('a', False)],
               'r': [('', False)],
               'rdras': [('rdras', False)],
               'satt': [('sätta', True), ('sitta', True)],
               'sköts': [('skjuta', True), ('sköta', True)],
               'tas': [('ta', True)],
               'ts': [('', False)],
               'tt': [('da', False)],
               'vs': [('va', False)],
               'är': [('vara', True)],
               'åg': [('e', False)],
               'öd': [('yda', False)]},
 'NUM': {'-': [('a', False)],
         '0-': [('0-', False)],
         '1)': [('1)', True), ('1', True)],
         '2)': [('2)', True)],
         '3)': [('3)', True)],
         '4)': [('4)', True)],
         '5)': [('5)', True)],
         '6)': [('6)', True)],
         '7)': [('7)', True)],
         'a-': [('a', False)],
         'e-': [('e', False)],
         'fjärde': [('fyra', True)],
         'fjärdes': [('fyra', True)],
         'i-': [('i', False)],
         'järde': [('tta', False)],
         'järdes': [('tta', False)],
         'l-': [('l', False)],
         'lls': [('ll', False)],
         'ls': [('ls', False)],
         'm-': [('m', False)],
         'n-': [('n', False)],
         'o-': [('o', False)],
         'r': [('ra', False)],
         's': [('', False)],
         'tannat': [('annan', False)],
         'tannats': [('annan', False)],
         'tt': [('n', False)],
         'tt-': [('n', False)],
         'tts': [('n', False)],
         'u-': [('u', False)],
         'v-': [('v', False)],
         'x-': [('x', False)],
         'å-': [('å', False)],
         'ått': [('åtta', True)],
         'ått-': [('åtta', True)]},
 'NUM_ADJ': {'are': [('', False)]},
 'NUM_NOUN': {'en': [('', False)],
              'erna': [('', False)],
              'rdran': [('dran', False)],
              'rs': [('rs', False)],
              'änderna': [('and', False)],
              'års': [('år', True)]},
 'NUM_VERB': {'ns': [('nas', False)], 'r': [('', False)], 's': [('', False)], 'är': [('vara', True)]},
 'PART_ADJ': {'ättre': [('ra', False)]},
 'PART_ADV': {'längre': [('länge', True), ('lång', True)],
              'mindre': [('lite', True), ('liten', True)],
              'minst': [('lite', True)]},
 'PART_DET': {'t': [('', False)]},
 'PART_VERB': {'an': [('unna', False)],
               'as': [('as', False)],
               'las': [('la', False)],
               'nas': [('na', False)],
               'nnas': [('nnas', False)],
               'ns': [('nas', False)],
               'r': [('', False)],
               'ts': [('mas', False)],
               'tt': [('da', False)],
               'vas': [('va', False)],
               'är': [('vara', True)]},
 'PRON': {'-': [('', False)],
          'Eder': [('Ni', True)],
          'Edert': [('Ni', True)],
          'Edra': [('Ni', True)],
          'Er': [('Ni', True)],
          'Era': [('Ni', True)],
          'Eran': [('Ni', True)],
          'Erat': [('Ni', True)],
          'Ert': [('Ni', True)],
          'a': [('', False)],
          'adana': [('an', False)],
          'aderas': [('endera', False)],
          'an': [('an', False)],
          'andra': [('annan', True)],
          'andras': [('annan', True)],
          'ans': [('an', False)],
          'at': [('an', False)],
          'ats': [('an', False)],
          'da': [('da', False)],
          'dadera': [('dadera', False)],
          'daderas': [('dadera', False)],
          'dan': [('n', False)],
          'danas': [('n', False)],
          'dans': [('n', False)],
          'dant': [('n', False)],
          'dants': [('n', False)],
          'das': [('da', False)],
          'de': [('de', True)],
          'dem': [('de', True)],
          'den': [('den', True)],
          'denne': [('denna', True)],
          'dennes': [('denna', True)],
          'dens': [('den', True)],
          'densamme': [('densamma', True)],
          'densammes': [('densamma', True)],
          'dera': [('dera', False)],
          'deras': [('de', True)],
          'desamma': [('densamma', True)],
          'desammas': [('densamma', True)],
          'detsamma': [('densamma', True)],
          'detsammas': [('densamma', True)],
          'dmånga': [('dmånga', False)],
          'dom': [('de', True)],
          'e': [('a', False)],
          'eder': [('ni', True)],
          'ederas': [('edera', False)],
          'edert': [('ni', True)],
          'edra': [('ni', True)],
          'ej': [('u', False)],
          'em': [('em', False)],
          'emånga': [('emånga', False)],
          'emångas': [('emånga', False)],
          'en': [('man', True)],
          'ena': [('ena', True)],
          'enas': [('ena', True)],
          'ene': [('ena', True)],
          'enes': [('ena', True)],
          'enne': [('on', False)],
          'ennes': [('on', False)],
          'ens': [('man', True)],
          'er': [('ni', True)],
          'era': [('ni', True)],
          'eran': [('ni', True)],
          'eras': [('ycken', False)],
          'erat': [('ni', True)],
          'ers': [('ycken', False)],
          'ert': [('ni', True)],
          'es': [('a', False)],
          'est': [('ycken', False)],
          'esta': [('ycken', False)],
          'estas': [('ycken', False)],
          'este': [('ycken', False)],
          'estes': [('ycken', False)],
          'ests': [('ycken', False)],
          'et': [('en', False)],
          'etdera': [('etdera', False)],
          'etderas': [('endera', False)],
          'ets': [('en', False)],
          'fen': [('folk', True)],
          'fens': [('folk', True)],
          'fler': [('mången', True)],
          'flera': [('mången', True), ('flera', True)],
          'fleras': [('mången', True), ('flera', True)],
          'flers': [('mången', True)],
          'flest': [('mången', True)],
          'flesta': [('mången', True)],
          'flestas': [('mången', True)],
          'flests': [('mången', True)],
          'gadera': [('gendera', False)],
          'gaderas': [('gondera', False)],
          'ge': [('ge', False)],
          'gen': [('gen', False)],
          'gens': [('gen', False)],
          'ges': [('ge', False)],
          'getdera': [('gendera', False)],
          'gra': [('gon', False)],
          'gras': [('gon', False)],
          'gt': [('gen', False)],
          'gts': [('gen', False)],
          'hen': [('hen', True)],
          'hens': [('hen', True)],
          'ig': [('u', False)],
          'iga': [('ig', False)],
          'igas': [('ig', False)],
          'igt': [('ig', False)],
          'igts': [('ig', False)],
          'ika': [('ik', False)],
          'in': [('u', False)],
          'ina': [('u', False)],
          'ins': [('in', False)],
          'issa': [('issa', False)],
          'itt': [('u', False)],
          'je': [('je', False)],
          'jes': [('je', False)],
          'ka': [('ken', False)],
          'kadera': [('kendera', False)],
          'kas': [('k', False)],
          'ken': [('ken', False)],
          'kens': [('ken', False)],
          'ketdera': [('kendera', False)],
          'knas': [('ken', False)],
          'las': [('l', False)],
          'lidan': [('lik', False)],
          'lidana': [('lik', False)],
          'lidanas': [('lig', False)],
          'lidans': [('lig', False)],
          'lidant': [('lig', False)],
          'lidants': [('lik', False)],
          'lig': [('lig', False)],
          'lkas': [('lken', False)],
          'mans': [('mans', False)],
          'mej': [('jag', True)],
          'mer': [('mycken', True)],
          'mera': [('mycken', True)],
          'mig': [('jag', True)],
          'min': [('jag', True)],
          'mina': [('jag', True)],
          'mitt': [('jag', True)],
          'mlidan': [('mlig', False)],
          'mlidana': [('mlig', False)],
          'mlidants': [('mlig', False)],
          'mt': [('mt', False)],
          'mts': [('mt', False)],
          'många': [('mången', True)],
          'mångas': [('mången', True)],
          'na': [('en', False)],
          'nas': [('n', False)],
          'nde': [('nda', False)],
          'nderas': [('ndera', False)],
          'ne': [('en', False)],
          'nes': [('en', False)],
          'nga': [('ngen', False)],
          'ngaderas': [('ngendera', False)],
          'ngas': [('ngen', False)],
          'nn': [('nn', False)],
          'nna': [('nna', False)],
          'nnas': [('nna', False)],
          'nns': [('nn', False)],
          'nsamma': [('nsamma', False)],
          'nvars': [('nvar', False)],
          'nån': [('någon', True)],
          'nåns': [('någon', True)],
          'om': [('', False)],
          'on': [('on', False)],
          'onom': [('an', False)],
          'ons': [('on', False)],
          'oss': [('vi', True)],
          'ot': [('on', False)],
          'otderas': [('ondera', False)],
          'ots': [('on', False)],
          'pa': [('pa', False)],
          'pas': [('pa', False)],
          'randra': [('randra', False)],
          'randras': [('randra', False)],
          'rdan': [('rdan', False)],
          'rdana': [('rdan', False)],
          'rdanas': [('rdan', False)],
          'rdans': [('rdan', False)],
          'rdant': [('rdan', False)],
          'rdants': [('rdan', False)],
          'rderas': [('rdera', False)],
          'rig': [('rig', False)],
          'rsin': [('rsin', False)],
          'rsina': [('rsin', False)],
          'rsitt': [('rsin', False)],
          'rtdera': [('rdera', False)],
          's': [('', False)],
          'samma': [('samma', True)],
          'sammas': [('samma', True)],
          'samme': [('samma', False)],
          'sammes': [('samma', False)],
          'se': [('se', False)],
          'sej': [('sig', True)],
          'sig': [('sig', True)],
          'sin': [('sig', True)],
          'sina': [('sig', True)],
          'sitt': [('sig', True)],
          'själva': [('själva', True), ('själv', True)],
          'självas': [('själva', True), ('själv', True)],
          'slidanas': [('slik', True)],
          'slidans': [('slik', True)],
          'slidant': [('slik', True)],
          'som': [('som', True)],
          'ss': [('n', False)],
          'ssa': [('nna', False)],
          'ssas': [('nna', False)],
          'st': [('st', False)],
          'sts': [('st', False)],
          't': [('', False)],
          'tannat': [('annan', False)],
          'tannats': [('annan', False)],
          'tdensamme': [('tdensamme', False)],
          'tdensammes': [('tdensamme', False)],
          'tdera': [('ndera', False)],
          'tderas': [('dera', False)],
          'tdesamma': [('tdensamme', False)],
          'tdesammas': [('tdensamme', False)],
          'tdetsamma': [('tdensamme', False)],
          'tdetsammas': [('tdensamme', False)],
          'te': [('te', False)],
          'tenda': [('enda', False)],
          'tendas': [('enda', False)],
          'tendaste': [('endaste', False)],
          'tendastes': [('endaste', False)],
          'tes': [('te', False)],
          'tet': [('tet', False)],
          'tetderas': [('tetdera', False)],
          'tets': [('tet', False)],
          'tfler': [('tfler', False)],
          'tflera': [('tflera', False)],
          'ts': [('', False)],
          'tt': [('n', False)],
          'tta': [('nna', False)],
          'ttas': [('nna', False)],
          'ttdera': [('ndera', False)],
          'ttderas': [('ndera', False)],
          'tts': [('n', False)],
          'udan': [('udan', False)],
          'udana': [('udan', False)],
          'udanas': [('udan', False)],
          'udans': [('udan', False)],
          'udant': [('udan', False)],
          'udants': [('udan', False)],
          'vars': [('vars', True), ('var', True)],
          'ylidanas': [('ylik', False)],
          'ylidans': [('ylik', False)],
          'ylidant': [('ylik', False)],
          'ådana': [('ån', False)],
          'ågadera': [('ågondera', False)],
          'ån': [('ån', False)],
          'åna': [('ån', False)],
          'åns': [('ån', False)],
          'år': [('i', False)],
          'åra': [('i', False)],
          'åran': [('i', False)],
          'årat': [('i', False)],
          'årt': [('i', False)],
          'åt': [('ågon', False)],
          'åts': [('ågon', False)]},
 'PRON_ADJ': {'t': [('d', False)], 'värsta': [('ond', True)], 'ättre': [('ra', False)]},
 'PRON_ADV': {'er': [('ycket', False)], 'mindre': [('lite', True)], 'st': [('e', False)]},
 'PRON_NOUN': {'a': [('um', False)],
               'ar': [('', False)],
               'dern': [('r', False)],
               'far': [('far', True)],
               'äder': [('ar', False)],
               'ötterna': [('ot', False)]},
 'PRON_VERB': {'ad': [('e', False)],
               'an': [('unna', False)],
               'anns': [('innas', False)],
               'as': [('as', False)],
               'ats': [('a', False)],
               'att': [('itta', False)],
               'atts': [('ätta', False)],
               'de': [('a', False)],
               'des': [('nas', False)],
               'ds': [('da', False)],
               'er': [('a', False)],
               'gits': [('', False)],
               'las': [('la', False)],
               'lär': [('lära', True)],
               'nas': [('na', False)],
               'pats': [('pas', False)],
               'r': [('', False)],
               's': [('as', False)],
               'tas': [('ta', True)],
               'tt': [('da', False)],
               'ttas': [('ttas', False)],
               'vs': [('va', False)],
               'är': [('vara', True)]},
 'PROPN': {"'": [('', False)],
           '-': [('', False)],
           '-Lis': [('-Lis', False)],
           '.s': [('.', False)],
           '4s': [('4', False)],
           '7s': [('7', False)],
           '8s': [('8', False)],
           ':s': [('', False)],
           'Aar': [('Aar', True)],
           'Aars': [('Aar', True)],
           'Abbas': [('Abba', True), ('Abbas', True)],
           'Abels': [('Abel', True)],
           'Adis': [('Adis', True)],
           'Adnan': [('Adna', True), ('Adnan', True)],
           'Adnans': [('Adna', True), ('Adnan', True)],
           'Ador': [('Ada', True)],
           'Adors': [('Ada', True)],
           'Agnar': [('Agne', True)],
           'Agnes': [('Agne', True), ('Agnes', True)],
           'Aidas': [('Aida', True)],
           'Alan': [('Alan', True)],
           'Alans': [('Alan', True)],
           'Alean': [('Alea', True)],
           'Aleans': [('Alea', True)],
           'Alinor': [('Alina', True)],
           'Alinors': [('Alina', True)],
           'Allan': [('Alla', True), ('Allan', True)],
           'Allans': [('Alla', True), ('Allan', True)],
           'Allas': [('Alla', True)],
           'Alman': [('Alma', True)],
           'Almans': [('Alma', True)],
           'Alvar': [('Alve', True), ('Alvar', True)],
           'Alvars': [('Alvar', True), ('Alve', True)],
           'Amars': [('Amar', True)],
           'Amers': [('Amer', True)],
           'Amilian': [('Amilia', True)],
           'Amilians': [('Amilia', True)],
           'Amos': [('Amos', True)],
           'Ana': [('Ana', True)],
           'Anas': [('Anas', True), ('Ana', True)],
           'Anderna': [('Anderna', True)],
           'Anders': [('Anders', True)],
           'Andreas': [('Andrea', True), ('Andreas', True)],
           'Andréas': [('Andréa', True), ('Andréas', True)],
           'Andrés': [('André', True), ('Andrés', True)],
           'Anes': [('Anes', True)],
           'Anesar': [('Anes', True)],
           'Annan': [('Anna', True)],
           'Annans': [('Anna', True)],
           'Annes': [('Anne', True)],
           'Annis': [('Anni', True)],
           'Anor': [('Ana', True)],
           'Anors': [('Ana', True)],
           'Antar': [('Ante', True)],
           'Antarna': [('Ante', True)],
           'Antarnas': [('Ante', True)],
           'Antes': [('Ante', True)],
           'Anyan': [('Anya', True)],
           'Anyans': [('Anya', True)],
           'Aras': [('Aras', True)],
           'Ares': [('Ares', True)],
           'Argos': [('Argo', True)],
           'Arnar': [('Arne', False)],
           'Arnarna': [('Arne', False)],
           'Arnarnas': [('Arne', False)],
           'Arnes': [('Arne', False)],
           'As': [('A', False)],
           'Aseas': [('Asea', True)],
           'Assar': [('Assar', True)],
           'Assars': [('Assar', True)],
           'Astan': [('Asta', True)],
           'Astans': [('Asta', True)],
           'Astor': [('Astor', True), ('Asta', True)],
           'Astors': [('Astor', True), ('Asta', True)],
           'Atles': [('Atle', True)],
           'Avor': [('Ava', True)],
           'Avors': [('Ava', True)],
           'Aylan': [('Ayla', True)],
           'Aylans': [('Ayla', True)],
           'Bells': [('Bell', True)],
           'Ben': [('Ben', True)],
           'Bens': [('Ben', True)],
           'Birks': [('Birks', True), ('Birk', True)],
           'Bonniers': [('Bonniers', True), ('Bonnier', True)],
           'Bos': [('Bo', True)],
           'Bs': [('B', True)],
           'Caesars': [('Caesar', True)],
           'Callas': [('Callas', True)],
           'Cannes': [('Cannes', True)],
           'Carlos': [('Carlos', True), ('Carlo', True)],
           'Ceasars': [('Ceasar', True)],
           'Cesar': [('Cesar', True)],
           'Clas': [('Clas', True)],
           'Colas': [('Cola', False)],
           'Collins': [('Collin', True), ('Collins', True)],
           'Cs': [('C', False)],
           'César': [('César', True)],
           'Dakar': [('Dakar', True)],
           'Dakars': [('Dakar', True)],
           'Dallas': [('Dallas', True)],
           'Danan': [('Dana', True)],
           'Danans': [('Dana', True)],
           'Darian': [('Darian', True)],
           'Darians': [('Darian', True)],
           'Dean': [('Dean', True)],
           'Deans': [('Dean', True)],
           'Dickens': [('Dickens', True)],
           'Diman': [('Dima', True)],
           'Dimans': [('Dima', True)],
           'Ds': [('D', False)],
           'Ebbas': [('Ebba', True)],
           'Eddan': [('Edda', True), ('Eddan', True)],
           'Eddans': [('Edda', True), ('Eddan', True)],
           'Eddas': [('Edda', True)],
           'Edor': [('Eda', True)],
           'Edors': [('Eda', True)],
           'Efars': [('Efe', True)],
           'Eilan': [('Eila', True)],
           'Eilans': [('Eila', True)],
           'Eilas': [('Eila', True)],
           'Einar': [('Einar', True)],
           'Einars': [('Einar', True)],
           'Eiran': [('Eira', True)],
           'Eirans': [('Eira', True)],
           'Elias': [('Elia', True), ('Elias', True)],
           'Elinor': [('Elina', True), ('Elinor', True)],
           'Elinors': [('Elina', True), ('Elinor', True)],
           'Elins': [('Elin', True)],
           'Elis': [('Elis', True), ('Eli', True)],
           'Ellan': [('Ella', True)],
           'Ellans': [('Ella', True)],
           'Ellas': [('Ella', True)],
           'Elles': [('Elle', True)],
           'Ellis': [('Elli', True), ('Ellis', True)],
           'Elman': [('Elma', True)],
           'Elmans': [('Elma', True)],
           'Elor': [('Ela', True)],
           'Elors': [('Ela', True)],
           'Elsan': [('Elsa', True)],
           'Elsans': [('Elsa', True)],
           'Emilian': [('Emilia', True)],
           'Emilians': [('Emilia', True)],
           'Emman': [('Emma', True)],
           'Emmans': [('Emma', True)],
           'Emor': [('Ema', True)],
           'Emors': [('Ema', True)],
           'Enar': [('Enar', True)],
           'Enars': [('Enar', True)],
           'Enes': [('Enes', True)],
           'Enesar': [('Enes', True)],
           'Ensar': [('Ensar', True)],
           'Enyan': [('Enya', True)],
           'Enyans': [('Enya', True)],
           'Erles': [('Erle', True)],
           'Ernan': [('Erna', True)],
           'Ernans': [('Erna', True)],
           'Eros': [('Eros', True)],
           'Erzan': [('Erza', True)],
           'Erzans': [('Erza', True)],
           'Es': [('E', False)],
           'Esman': [('Esma', True)],
           'Esmans': [('Esma', True)],
           'Evan': [('Evan', True), ('Eva', True)],
           'Evans': [('Evan', True), ('Eva', True)],
           'Evor': [('Eva', True)],
           'Evors': [('Eva', True)],
           'Fior': [('Fia', True)],
           'Fiors': [('Fia', True)],
           'Fos': [('Fo', True)],
           'Frans': [('Frans', True)],
           'Fs': [('F', False)],
           'Gais': [('Gais', True)],
           'Georgar': [('Georg', True), ('George', True)],
           'Georgarna': [('George', True), ('Georg', True)],
           'Georgarnas': [('George', True), ('Georg', True)],
           'Georgars': [('Georg', True), ('George', True)],
           'Georges': [('George', True), ('Georges', True)],
           'Glorian': [('Gloria', True)],
           'Glorians': [('Gloria', True)],
           'Gs': [('G', False)],
           'Haléns': [('Haléns', True)],
           'Hanan': [('Hana', True), ('Hanan', True)],
           'Hanans': [('Hana', True), ('Hanan', True)],
           'Hannes': [('Hannes', True)],
           'Hans': [('Hans', True)],
           'Harts': [('Harts', True)],
           'Hedes': [('Hede', True)],
           'Hellas': [('Hellas', True)],
           'Hodan': [('Hoda', True)],
           'Hodans': [('Hoda', True)],
           'Hs': [('H', False)],
           'Idor': [('Ida', True)],
           'Idors': [('Ida', True)],
           'Ilman': [('Ilma', True)],
           'Ilmans': [('Ilma', True)],
           'Iman': [('Iman', True)],
           'Imans': [('Iman', True)],
           'Ina': [('Ina', True)],
           'Ines': [('Ines', True)],
           'Ingvar': [('Ingvar', True)],
           'Inor': [('Ina', True)],
           'Inors': [('Ina', True)],
           'Ios': [('Io', True)],
           'Iran': [('Iran', True)],
           'Irans': [('Iran', True)],
           'Iris': [('Iris', True)],
           'Irjan': [('Irja', True)],
           'Irjans': [('Irja', True)],
           'Irman': [('Irma', True)],
           'Irmans': [('Irma', True)],
           'Is': [('I', True)],
           'Isars': [('Isar', True)],
           'Isis': [('Isis', True)],
           'Ivan': [('Ivan', True)],
           'Ivans': [('Ivan', True)],
           'Ivar': [('Ivar', True)],
           'Janan': [('Jana', True)],
           'Janans': [('Jana', True)],
           'Janars': [('Jan', True)],
           'Janes': [('Jane', True)],
           'Jean': [('Jean', True)],
           'Jeans': [('Jean', True)],
           'Jens': [('Jens', True)],
           'Jesus': [('Jesu', True), ('Jesus', True)],
           'Joan': [('Joan', True)],
           'Joans': [('Joan', True)],
           'Jonas': [('Jona', True), ('Jonas', True)],
           'Jonis': [('Joni', True)],
           'Jrs': [('Jr', True)],
           'Jrs-': [('Jr', True)],
           'Js': [('J', False)],
           'Juan': [('Juan', True)],
           'Juans': [('Juan', True)],
           'Julian': [('Julian', True), ('Julia', True)],
           'Julians': [('Julian', True), ('Julia', True)],
           'Junior': [('Junia', True), ('Junior', True)],
           'Juniors': [('Junia', True), ('Junior', True)],
           'Junis': [('Juni', True)],
           'Jöns': [('Jöns', True)],
           'Kadar': [('Kadar', True)],
           'Kamas': [('Kama', True)],
           'Kansas': [('Kansas', True)],
           'Karos': [('Karo', True)],
           'Kates': [('Kate', True)],
           'Kaylor': [('Kayla', True)],
           'Kaylors': [('Kayla', True)],
           'Kesos': [('Keso', True)],
           'Kian': [('Kian', True)],
           'Kians': [('Kian', True)],
           'Kiels': [('Kiel', True)],
           'Kiran': [('Kira', True)],
           'Kirans': [('Kira', True)],
           'Klas': [('Klas', True)],
           'Ks': [('K', False)],
           'Kvists': [('Kvist', True)],
           'Lanan': [('Lana', True)],
           'Lanans': [('Lana', True)],
           'Lar': [('Louie', True)],
           'Laran': [('Lara', True)],
           'Larans': [('Lara', True)],
           'Larna': [('Louie', True)],
           'Larnas': [('Louie', True)],
           'Lars': [('Louie', True), ('Lars', True)],
           'Larsons': [('Larson', True)],
           'Lejan': [('Leja', True)],
           'Lejans': [('Leja', True)],
           'Lenan': [('Lena', True)],
           'Lenans': [('Lena', True)],
           'Leonor': [('Leona', True)],
           'Leonors': [('Leona', True)],
           'Leos': [('Leos', True), ('Leo', True)],
           'Levis': [('Levi', True), ('Levis', True)],
           'Lias': [('Lias', True), ('Lia', True)],
           'Lilian': [('Lilian', True)],
           'Lilians': [('Lilian', True)],
           'Lior': [('Lia', True)],
           'Liors': [('Lia', True)],
           'Lis': [('Li', False)],
           'Livan': [('Liva', True)],
           'Livans': [('Liva', True)],
           'Lorens': [('Loren', True)],
           'Los': [('Lo', True)],
           'Lottorna': [('Lotta', True)],
           'Lottornas': [('Lotta', True)],
           'Louis': [('Loui', True), ('Louis', True)],
           'Lovar': [('Love', True)],
           'Lovarna': [('Love', True)],
           'Lovarnas': [('Love', True)],
           'Lovars': [('Love', True)],
           'Ls': [('L', False)],
           'Lucas': [('Luca', True), ('Lucas', True)],
           'Luis': [('Luis', True)],
           'Lukas': [('Luka', True), ('Lukas', True)],
           'Magnes': [('Magne', True)],
           'Majan': [('Maja', True)],
           'Majans': [('Maja', True)],
           'Maltar': [('Malte', True)],
           'Manar': [('Manar', True)],
           'Marcos': [('Marcos', True), ('Marco', True)],
           'Maris': [('Mari', True)],
           'Mars': [('Mars', True)],
           'Mattis': [('Mattis', True), ('Matti', True)],
           'Mayan': [('Maya', True)],
           'Mayans': [('Maya', True)],
           'Mejan': [('Meja', True)],
           'Mejans': [('Meja', True)],
           'Mikar': [('Mike', True)],
           'Mikarna': [('Mike', True)],
           'Mikarnas': [('Mike', True)],
           'Mikars': [('Mike', True)],
           'Milan': [('Mila', True), ('Milan', True)],
           'Milans': [('Mila', True), ('Milan', True)],
           'Milas': [('Mila', True)],
           'Milian': [('Milian', True), ('Milia', True)],
           'Milians': [('Milian', True), ('Milia', True)],
           'Millers': [('Miller', True)],
           'Milles': [('Milles', True), ('Mille', True)],
           'Milos': [('Milo', True), ('Milos', True)],
           'Mior': [('Mia', True)],
           'Miors': [('Mia', True)],
           'Miran': [('Mira', True), ('Miran', True)],
           'Mirans': [('Mira', True), ('Miran', True)],
           'Modos': [('Modo', True)],
           'Monan': [('Mona', True)],
           'Monans': [('Mona', True)],
           'Monas': [('Mona', True)],
           'Moor': [('Moa', True)],
           'Moors': [('Moa', True)],
           'Moras': [('Mora', True)],
           'Moses': [('Mose', True), ('Moses', True)],
           'Myran': [('Myra', True)],
           'Myrans': [('Myra', True)],
           'Nadan': [('Nada', True)],
           'Nadans': [('Nada', True)],
           'Nathan': [('Nathan', True)],
           'Nathans': [('Nathan', True)],
           'Nells': [('Nell', True)],
           'Nemis': [('Nemi', True)],
           'Neros': [('Nero', True)],
           'Nikolas': [('Nikola', True), ('Nikolas', True)],
           'Nilos': [('Nilo', True)],
           'Nils': [('Nils', True)],
           'Nissan': [('Nissan', True)],
           'Nissans': [('Nissan', True)],
           'Noor': [('Noa', True), ('Noor', True)],
           'Noors': [('Noa', True), ('Noor', True)],
           'Nor': [('Nor', True)],
           'Norar': [('Nore', True)],
           'Norarna': [('Nore', True)],
           'Norarnas': [('Nore', True)],
           'Noras': [('Nora', True)],
           'Nors': [('Nor', True)],
           'Ns': [('N', False)],
           'Olins': [('Olin', True)],
           'Olles': [('Olle', True)],
           'Oman': [('Oman', True)],
           'Omans': [('Oman', True)],
           'Omars': [('Omar', True)],
           'Os': [('O', False)],
           'Otis': [('Otis', True)],
           'Ovars': [('Ove', True)],
           'Owars': [('Owe', True)],
           'Perus': [('Peru', True)],
           'Pior': [('Pia', True)],
           'Piors': [('Pia', True)],
           'Ps': [('P', False)],
           'Qs': [('Q', True)],
           'Raman': [('Rama', True), ('Raman', True)],
           'Ramans': [('Rama', True), ('Raman', True)],
           'Ramas': [('Rama', True)],
           'Ramis': [('Rami', True)],
           'Ramses': [('Ramses', True)],
           'Ras': [('Ra', True)],
           'Reis': [('Reis', True)],
           'Rheas': [('Rhea', True)],
           'Ritan': [('Rita', True)],
           'Ritans': [('Rita', True)],
           'Roberts': [('Roberts', True), ('Robert', True)],
           'Romas': [('Roma', True)],
           'Ronalds': [('Ronald', True)],
           'Ronis': [('Roni', True)],
           'Roos': [('Roos', True)],
           'Roses': [('Rose', True)],
           'Rs': [('R', False)],
           'Rubens': [('Ruben', True), ('Rubens', True)],
           'Runar': [('Rune', True)],
           'Runarna': [('Rune', True)],
           'Runarnas': [('Rune', True)],
           'Runes': [('Rune', True)],
           'Ryan': [('Ryan', True)],
           'Ryans': [('Ryan', True)],
           'Sachs': [('Sachs', True)],
           'Sagan': [('Saga', True), ('Sagan', True)],
           'Sagans': [('Saga', True), ('Sagan', True)],
           'Sakarias': [('Sakarias', True)],
           'Salman': [('Salman', True), ('Salma', True)],
           'Salmans': [('Salman', True), ('Salma', True)],
           'Salos': [('Salo', True)],
           'Samis': [('Sami', True)],
           'Sams': [('Sam', True)],
           'Sanan': [('Sana', True)],
           'Sanans': [('Sana', True)],
           'Saran': [('Sara', True)],
           'Sarans': [('Sara', True)],
           'Sayers': [('Sayers', True)],
           'Sean': [('Sean', True)],
           'Seans': [('Sean', True)],
           'Shams': [('Shams', True)],
           'Sidar': [('Sid', True)],
           'Sidars': [('Sid', True)],
           'Siljan': [('Siljan', True)],
           'Siljans': [('Siljan', True)],
           'Siris': [('Siri', True)],
           'Smillan': [('Smilla', True)],
           'Smillans': [('Smilla', True)],
           'Sotos': [('Soto', False)],
           'Ss': [('S', False)],
           'Stellan': [('Stella', True), ('Stellan', True)],
           'Stellans': [('Stella', True), ('Stellan', True)],
           'Stones': [('Stones', True), ('Stone', True)],
           'Sts-': [('St', True)],
           'Sturars': [('Sture', True)],
           'Sunar': [('Sune', True)],
           'Sunarna': [('Sune', True)],
           'Sunarnas': [('Sune', True)],
           'Sunes': [('Sune', True)],
           'Svan': [('Svan', True)],
           'Svans': [('Svan', True)],
           'Svantes': [('Svante', True)],
           'Taran': [('Tara', True)],
           'Tarans': [('Tara', True)],
           'Tells': [('Tell', True)],
           'Teodorar': [('Teodor', True)],
           'Teodorarna': [('Teodor', True)],
           'Teodorarnas': [('Teodor', True)],
           'Theas': [('Thea', True)],
           'Thomas': [('Thomas', True)],
           'Timos': [('Timo', True)],
           'Titos': [('Tito', True)],
           'Tizian': [('Tizian', True)],
           'Tizians': [('Tizian', True)],
           'Todor': [('Todor', True)],
           'Todors': [('Todor', True)],
           'Tones': [('Tone', True)],
           'Tonis': [('Toni', True)],
           'Tor': [('Tor', True)],
           'Toran': [('Tora', True)],
           'Torans': [('Tora', True)],
           'Torar': [('Tore', True)],
           'Torarna': [('Tore', True)],
           'Torarnas': [('Tore', True)],
           'Toras': [('Tora', True)],
           'Tors': [('Tor', True)],
           'Ts': [('T', True)],
           'Turar': [('Ture', True)],
           'Turarna': [('Ture', True)],
           'Turarnas': [('Ture', True)],
           'Tuvan': [('Tuva', True)],
           'Tuvans': [('Tuva', True)],
           'Tyran': [('Tyra', True)],
           'Tyrans': [('Tyra', True)],
           'Ullan': [('Ulla', True)],
           'Ullans': [('Ulla', True)],
           'Ullas': [('Ulla', True)],
           'Umor': [('Uma', True)],
           'Umors': [('Uma', True)],
           'Unnis': [('Unni', True)],
           'Us': [('U', False)],
           'Veran': [('Vera', True)],
           'Verans': [('Vera', True)],
           'Vidan': [('Vida', True)],
           'Vidans': [('Vida', True)],
           'Vidar': [('Vide', True), ('Vidar', True)],
           'Vidarna': [('Vide', True)],
           'Vidarnas': [('Vide', True)],
           'Vidars': [('Vide', True), ('Vidar', True)],
           'Vidas': [('Vida', True)],
           'Vides': [('Vide', True)],
           'Villiams': [('Villiam', True)],
           'Viran': [('Vira', True)],
           'Virans': [('Vira', True)],
           'Waltar': [('Walt', True)],
           'Waltarna': [('Walt', True)],
           'Waltarnas': [('Walt', True)],
           'Waltars': [('Walt', True)],
           'Weran': [('Wera', True)],
           'Werans': [('Wera', True)],
           'Williams': [('William', True), ('Williams', True)],
           'Ws': [('W', False)],
           'Xs': [('X', False)],
           'Yaran': [('Yara', True)],
           'Yarans': [('Yara', True)],
           'Yasar': [('Yasar', True)],
           'Yngvars': [('Yngve', True)],
           'Zakarias': [('Zakarias', True), ('Zakaria', True)],
           'Zaran': [('Zara', True)],
           'Zarans': [('Zara', True)],
           'Zekar': [('Zeke', True)],
           'Zekarna': [('Zeke', True)],
           'Zekarnas': [('Zeke', True)],
           'Zekars': [('Zeke', True)],
           'Zeus': [('Zeus', True)],
           'Zolas': [('Zola', True)],
           'a-Lis': [('a-Li', False)],
           'aabs': [('aab', False)],
           'aars': [('a', False)],
           'aas': [('aa', False)],
           'aban': [('aban', False)],
           'abans': [('aban', False)],
           'abels': [('abel', False)],
           'abis': [('abis', False)],
           'ables': [('able', False)],
           'abs': [('abs', False)],
           'acar': [('ac', False)],
           'acarna': [('ac', False)],
           'acarnas': [('ac', False)],
           'acas': [('acas', False)],
           'achs': [('ach', False)],
           'acus': [('acus', False)],
           'adan': [('adan', False)],
           'adans': [('adan', False)],
           'adar': [('ad', False)],
           'adarna': [('ad', False)],
           'adarnas': [('ad', False)],
           'adars': [('adar', False)],
           'aders': [('ader', False)],
           'ades': [('ades', False)],
           'adian': [('adia', False)],
           'adians': [('adia', False)],
           'adias': [('adia', False)],
           'ador': [('ada', False)],
           'adors': [('ada', False)],
           'ados': [('ados', False)],
           'ads': [('ad', False)],
           'adts': [('adt', False)],
           'adus': [('adus', False)],
           'aelan': [('aela', False)],
           'aelans': [('aela', False)],
           'aemis': [('aemi', False)],
           'aeres': [('aere', False)],
           'aesar': [('aesar', False)],
           'aesars': [('aes', False)],
           'aeus': [('aeus', False)],
           'afors': [('afa', False)],
           'agan': [('agan', False)],
           'agans': [('agan', False)],
           'agar': [('age', False)],
           'agars': [('age', False)],
           'agnars': [('agnar', False)],
           'agnes': [('agnes', True)],
           'agor': [('aga', False)],
           'agors': [('aga', False)],
           'agos': [('agos', False)],
           'ahman': [('ahma', False)],
           'ahmans': [('ahma', False)],
           'ahms': [('ahms', False)],
           'aidan': [('aida', False)],
           'aidans': [('aida', False)],
           'aidar': [('aid', False)],
           'aidars': [('aid', False)],
           'aidas': [('aida', False)],
           'ailan': [('aila', False)],
           'ailans': [('aila', False)],
           'ailas': [('aila', False)],
           'aiman': [('aima', False)],
           'aimans': [('aima', False)],
           'aior': [('aia', False)],
           'aiors': [('aia', False)],
           'aios': [('aios', False)],
           'ais': [('ai', False)],
           'aistos': [('aistos', False)],
           'aits': [('ait', False)],
           'ajan': [('ajan', False)],
           'ajans': [('ajan', False)],
           'ajar': [('aj', False)],
           'ajarna': [('aj', False)],
           'ajarnas': [('aj', False)],
           'akar': [('ak', False)],
           'akarna': [('ak', False)],
           'akarnas': [('ak', False)],
           'akars': [('ak', False)],
           'alar': [('al', False)],
           'alarna': [('alarna', False)],
           'alarnas': [('alarna', False)],
           'alaus': [('alau', False)],
           'aldor': [('aldor', False)],
           'aldors': [('aldor', False)],
           'alds': [('alds', False)],
           'ales': [('ales', False)],
           'alian': [('alia', False)],
           'alians': [('alia', False)],
           'alias': [('alia', False)],
           'alins': [('alin', False)],
           'allas': [('alla', False)],
           'alles': [('alle', False)],
           'allos': [('allo', False)],
           'almar': [('almar', False)],
           'almers': [('almers', False)],
           'alos': [('alos', False)],
           'als': [('al', False)],
           'altar': [('altar', False)],
           'altarna': [('alte', False)],
           'altarnas': [('alte', False)],
           'altars': [('alte', False)],
           'altas': [('alta', False)],
           'aléns': [('alén', False)],
           'amar': [('am', False)],
           'amarna': [('am', False)],
           'amarnas': [('am', False)],
           'amas': [('amas', False)],
           'ames': [('ames', False)],
           'amillan': [('amilla', False)],
           'amillans': [('amilla', False)],
           'amis': [('amis', False)],
           'ammar': [('ammar', False)],
           'amor': [('ama', False)],
           'amors': [('ama', False)],
           'ams': [('ams', True), ('am', True)],
           'amses': [('amse', False)],
           'an': [('an', False)],
           'ana': [('ana', False)],
           'anan': [('anan', False)],
           'anans': [('anan', False)],
           'anar': [('an', False)],
           'anarna': [('an', False)],
           'anarnas': [('an', False)],
           'anars': [('anar', False)],
           'ancan': [('anca', False)],
           'ancans': [('anca', False)],
           'andar': [('andar', False)],
           'andars': [('and', False)],
           'anes': [('anes', False)],
           'angs': [('ang', False)],
           'ankan': [('anka', False)],
           'ankans': [('anka', False)],
           'annan': [('anna', False)],
           'annans': [('anna', False)],
           'annar': [('anne', False)],
           'annes': [('anne', False)],
           'annis': [('anni', False)],
           'anois': [('anoi', False)],
           'anor': [('ana', False)],
           'anors': [('ana', False)],
           'ans': [('an', False)],
           'ansars': [('ans', False)],
           'ansas': [('ansa', False)],
           'antar': [('ante', False)],
           'antarna': [('ante', False)],
           'antarnas': [('ante', False)],
           'antes': [('ante', False)],
           'anus': [('anus', False)],
           'anyan': [('anya', False)],
           'anyans': [('anya', False)],
           'anyar': [('anyar', False)],
           'apan': [('apan', False)],
           'apans': [('apan', False)],
           'apolis': [('apolis', False)],
           'ar': [('', False)],
           'aran': [('aran', False)],
           'arans': [('aran', False)],
           'arar': [('ar', False)],
           'ararna': [('ar', False)],
           'ararnas': [('ar', False)],
           'argos': [('argo', False)],
           'arian': [('aria', False)],
           'arians': [('aria', False)],
           'arias': [('aria', False)],
           'aris': [('aris', False)],
           'arkos': [('arko', False)],
           'arks': [('ark', False)],
           'arna': [('', False)],
           'arnas': [('', False)],
           'arnes': [('arne', False)],
           'aror': [('ara', False)],
           'arors': [('ara', False)],
           'aros': [('aros', False)],
           'arsons': [('arsons', False)],
           'arts': [('art', False)],
           'as': [('as', False)],
           'as-': [('as', False)],
           'asan': [('asan', False)],
           'asans': [('asan', False)],
           'asar': [('as', False)],
           'asarna': [('as', False)],
           'asarnas': [('as', False)],
           'asars': [('asar', False)],
           'asian': [('asia', False)],
           'asians': [('asia', False)],
           'asias': [('asia', False)],
           'asins': [('asin', False)],
           'asons': [('ason', False)],
           'astor': [('astor', False)],
           'astors': [('astor', False)],
           'asts': [('ast', False)],
           'asus': [('asus', False)],
           'atan': [('atan', False)],
           'atans': [('atan', False)],
           'atar': [('atar', False)],
           'athan': [('atha', False)],
           'athans': [('atha', False)],
           'atlas': [('atla', False)],
           'atman': [('atma', False)],
           'atmans': [('atma', False)],
           'ator': [('ata', False)],
           'atorna': [('ata', False)],
           'atornas': [('ata', False)],
           'ators': [('ata', False)],
           'ats': [('ats', False)],
           'atts': [('att', False)],
           'atus': [('atus', False)],
           'audar': [('aude', False)],
           'audarna': [('aude', False)],
           'audarnas': [('aude', False)],
           'auers': [('auer', False)],
           'auras': [('aura', False)],
           'aurus': [('auru', False)],
           'aus': [('au', False)],
           'avar': [('av', False)],
           'avarna': [('av', False)],
           'avarnas': [('av', False)],
           'avars': [('av', False)],
           'avor': [('ava', False)],
           'avors': [('ava', False)],
           'awan': [('awan', False)],
           'awans': [('awan', False)],
           'ayan': [('ayan', False)],
           'ayans': [('ayan', False)],
           'ayers': [('ayer', False)],
           'aylan': [('ayla', False)],
           'aylans': [('ayla', False)],
           'aylor': [('aylor', False)],
           'aylors': [('aylor', False)],
           'azan': [('azan', False)],
           'azans': [('azan', False)],
           'azar': [('az', False)],
           'azars': [('az', False)],
           'bagos': [('bago', False)],
           'bamas': [('bama', False)],
           'ban': [('ba', False)],
           'banars': [('ban', False)],
           'bans': [('ba', False)],
           'bar': [('be', False)],
           'baran': [('bara', False)],
           'barans': [('bara', False)],
           'barna': [('be', False)],
           'barnas': [('be', False)],
           'bars': [('b', False)],
           'bas': [('ba', False)],
           'basars': [('bas', False)],
           'bats': [('bat', False)],
           'bbars': [('bbe', False)],
           'bbles': [('bble', False)],
           'bborna': [('bba', False)],
           'bbornas': [('bba', False)],
           'bells': [('bell', False)],
           'bels': [('bels', False)],
           'ben': [('ben', False)],
           'bens': [('ben', False)],
           'bes': [('be', False)],
           'bgs-': [('bg', False)],
           'bian': [('bian', False)],
           'bians': [('bian', False)],
           'bias': [('bias', False)],
           'binars': [('bin', False)],
           'bis': [('bi', False)],
           'blers': [('bler', False)],
           'blins': [('blin', False)],
           'borna': [('borna', False)],
           'bornas': [('borna', False)],
           'boros': [('boro', False)],
           'bos': [('bo', False)],
           'botos': [('boto', False)],
           'bs': [('b', False)],
           'bs-': [('bs', False)],
           'bsons': [('bson', False)],
           'budas': [('buda', False)],
           'cagos': [('cago', False)],
           'can': [('ca', False)],
           'cans': [('ca', False)],
           'car': [('ce', False)],
           'carna': [('ce', False)],
           'carnas': [('ce', False)],
           'cars': [('c', False)],
           'cas': [('ca', False)],
           'ceros': [('cero', False)],
           'ces': [('ce', False)],
           'chan': [('chan', False)],
           'chans': [('chan', False)],
           'cheas': [('chea', False)],
           'chor': [('cha', False)],
           'chors': [('cha', False)],
           'chos': [('chos', False)],
           'cior': [('cia', False)],
           'ciors': [('cia', False)],
           'cits': [('cit', False)],
           'ckan': [('ckan', False)],
           'ckans': [('ckan', False)],
           'ckar': [('ck', False)],
           'ckarna': [('ck', False)],
           'ckarnas': [('ck', False)],
           'ckars': [('ck', False)],
           'clas': [('clas', False)],
           'conis': [('coni', False)],
           'cos': [('co', False)],
           'cps-': [('cp', True)],
           'cs': [('c', False)],
           'csons': [('cson', False)],
           'dams': [('dam', False)],
           'dan': [('da', False)],
           'danars': [('dan', False)],
           'danes': [('dane', False)],
           'dans': [('da', False)],
           'dar': [('de', False)],
           'dars': [('d', False)],
           'das': [('da', False)],
           'ddas': [('ddas', False)],
           'ddor': [('dda', False)],
           'ddors': [('dda', False)],
           'dds': [('dd', False)],
           'delan': [('dela', False)],
           'delans': [('dela', False)],
           'deles': [('dele', False)],
           'delis': [('deli', False)],
           'dells': [('dell', False)],
           'den': [('den', False)],
           'dens': [('den', False)],
           'derna': [('derna', False)],
           'des': [('de', False)],
           'deus': [('deus', False)],
           'dgars': [('dgar', False)],
           'dian': [('dian', False)],
           'dians': [('dian', False)],
           'dias': [('dias', False)],
           'dides': [('dide', False)],
           'diers': [('dier', False)],
           'dinars': [('din', False)],
           'dingar': [('ding', False)],
           'dingarna': [('ding', False)],
           'dingarnas': [('ding', False)],
           'dinnan': [('dinnan', False)],
           'dinnans': [('dinnan', False)],
           'dior': [('dia', False)],
           'diors': [('dia', False)],
           'diran': [('dira', False)],
           'dirans': [('dira', False)],
           'dis': [('di', False)],
           'dits': [('dit', False)],
           'djan': [('dja', False)],
           'dlers': [('dler', False)],
           'dls': [('dl', False)],
           'dman': [('dman', False)],
           'dmans': [('dman', False)],
           'dna': [('dna', False)],
           'dnesars': [('dnesar', False)],
           'dnor': [('dna', False)],
           'dnors': [('dna', False)],
           'dns': [('dn', False)],
           'donas': [('dona', False)],
           'doran': [('dora', False)],
           'dorans': [('dora', False)],
           'dorars': [('dor', False)],
           'doras': [('dora', False)],
           'dos': [('do', False)],
           'dous': [('dous', False)],
           'drias': [('dria', False)],
           'dris': [('dris', False)],
           'dror': [('dra', False)],
           'drors': [('dra', False)],
           'ds': [('ds', False)],
           'ds-': [('ds', False)],
           'dsons': [('dson', False)],
           'dtar': [('dt', False)],
           'dtarna': [('dt', False)],
           'dtarnas': [('dt', False)],
           'dtars': [('dt', False)],
           'duros': [('duro', False)],
           'dwan': [('dwan', False)],
           'dwans': [('dwan', False)],
           'dyar': [('dy', False)],
           'ean': [('ea', False)],
           'eanor': [('eanor', False)],
           'eanors': [('eanor', False)],
           'eans': [('ea', False)],
           'eas': [('ea', False)],
           'easar': [('easar', False)],
           'easars': [('eas', False)],
           'eatan': [('eata', False)],
           'eatans': [('eata', False)],
           'eats': [('eat', False)],
           'ebar': [('eb', False)],
           'ebarna': [('eb', False)],
           'ebarnas': [('eb', False)],
           'ebbles': [('ebbles', False)],
           'ecar': [('ec', False)],
           'ecarna': [('ec', False)],
           'ecarnas': [('ec', False)],
           'eckan': [('ecka', False)],
           'eckans': [('ecka', False)],
           'eckar': [('eckar', False)],
           'eckars': [('eckar', False)],
           'edar': [('ed', False)],
           'edarna': [('ed', False)],
           'edarnas': [('ed', False)],
           'eddan': [('edda', False)],
           'eddans': [('edda', False)],
           'eddas': [('edda', False)],
           'eders': [('eder', False)],
           'edes': [('edes', False)],
           'edias': [('edia', False)],
           'eds': [('ed', False)],
           'eeds': [('eeds', False)],
           'eeles': [('eele', False)],
           'een': [('een', False)],
           'eens': [('een', False)],
           'ees': [('ee', False)],
           'efan': [('efan', False)],
           'efans': [('efan', False)],
           'efar': [('ef', False)],
           'efarna': [('ef', False)],
           'efarnas': [('ef', False)],
           'egels': [('egel', False)],
           'egor': [('ega', False)],
           'egors': [('ega', False)],
           'ehrus': [('ehru', False)],
           'eilan': [('eila', False)],
           'eilans': [('eila', False)],
           'eilas': [('eila', False)],
           'einar': [('eine', False)],
           'einarna': [('eine', False)],
           'einarnas': [('eine', False)],
           'eior': [('eia', False)],
           'eiors': [('eia', False)],
           'eis': [('ei', False)],
           'ejan': [('ejan', False)],
           'ejans': [('ejan', False)],
           'ejar': [('ej', False)],
           'ejarna': [('ej', False)],
           'ejarnas': [('ej', False)],
           'ekar': [('ek', False)],
           'ekarna': [('ek', False)],
           'ekarnas': [('ek', False)],
           'ekars': [('ek', False)],
           'eklas': [('ekla', False)],
           'elan': [('elan', False)],
           'elans': [('elan', False)],
           'elar': [('el', False)],
           'elarna': [('el', False)],
           'elarnas': [('el', False)],
           'eles': [('eles', False)],
           'elian': [('elia', False)],
           'elians': [('elia', False)],
           'elias': [('elia', False)],
           'elings': [('eling', False)],
           'elinor': [('elina', False)],
           'elinors': [('elina', False)],
           'elins': [('elin', False)],
           'ellan': [('ella', False)],
           'ellans': [('ella', False)],
           'ellas': [('ella', False)],
           'elles': [('elle', False)],
           'ellis': [('elli', False)],
           'ellos': [('ello', False)],
           'ells': [('ells', False)],
           'elman': [('elma', False)],
           'elmans': [('elma', False)],
           'elmars': [('elm', False)],
           'elor': [('ela', False)],
           'elors': [('ela', False)],
           'els': [('el', False)],
           'eléns': [('elén', False)],
           'eman': [('eman', False)],
           'emans': [('eman', False)],
           'emars': [('emar', False)],
           'emers': [('emer', False)],
           'emis': [('emis', False)],
           'ems': [('em', False)],
           'ena': [('ena', False)],
           'enan': [('enan', False)],
           'enans': [('enan', False)],
           'enar': [('en', False)],
           'enarna': [('en', False)],
           'enarnas': [('en', False)],
           'enes': [('enes', False)],
           'enis': [('enis', False)],
           'ennan': [('enna', False)],
           'ennans': [('enna', False)],
           'ennes': [('enne', False)],
           'enor': [('ena', False)],
           'enors': [('ena', False)],
           'enos': [('enos', False)],
           'ensars': [('ens', False)],
           'entars': [('ent', False)],
           'entos': [('ento', False)],
           'enus': [('enus', False)],
           'eodor': [('eodor', False)],
           'eodorar': [('eodore', False)],
           'eodorarna': [('eodore', False)],
           'eodorarnas': [('eodore', False)],
           'eodorars': [('eodor', False)],
           'eodors': [('eodor', False)],
           'eonan': [('eona', False)],
           'eonans': [('eona', False)],
           'eonas': [('eona', False)],
           'eonor': [('eonor', False)],
           'eonors': [('eonor', False)],
           'eorges': [('eorges', False)],
           'eos': [('eo', False)],
           'eran': [('eran', False)],
           'erans': [('eran', False)],
           'erar': [('er', False)],
           'erarna': [('er', False)],
           'erarnas': [('er', False)],
           'erdan': [('erda', False)],
           'erdans': [('erda', False)],
           'eres': [('eres', False)],
           'erias': [('eria', False)],
           'erks': [('erk', False)],
           'ernes': [('erne', False)],
           'eror': [('era', False)],
           'erors': [('era', False)],
           'eros': [('eros', False)],
           'ers': [('er', False)],
           'erstedts': [('erstedt', False)],
           'erts': [('ert', False)],
           'erus': [('erus', False)],
           'es': [('es', False)],
           'es-': [('es', False)],
           'esar': [('es', False)],
           'esarna': [('es', False)],
           'esarnas': [('es', False)],
           'esars': [('esar', False)],
           'escus': [('escu', False)],
           'esian': [('esia', False)],
           'esians': [('esia', False)],
           'esias': [('esia', False)],
           'esis': [('esis', False)],
           'esons': [('eson', False)],
           'esos': [('esos', False)],
           'essan': [('essa', False)],
           'essans': [('essa', False)],
           'estor': [('estor', False)],
           'estors': [('estor', False)],
           'ests': [('est', False)],
           'esus': [('esus', False)],
           'etar': [('et', False)],
           'etarna': [('et', False)],
           'etarnas': [('et', False)],
           'etars': [('et', False)],
           'ethan': [('etha', False)],
           'ethans': [('etha', False)],
           'etias': [('etia', False)],
           'etor': [('eta', False)],
           'etorna': [('eta', False)],
           'etornas': [('eta', False)],
           'etors': [('eta', False)],
           'etran': [('etra', False)],
           'etrans': [('etra', False)],
           'etros': [('etro', False)],
           'ettan': [('etta', False)],
           'ettans': [('etta', False)],
           'ettis': [('etti', False)],
           'etts': [('ett', False)],
           'etus': [('etus', False)],
           'eus': [('eu', False)],
           'ewar': [('ew', False)],
           'ewarna': [('ew', False)],
           'ewarnas': [('ew', False)],
           'ewis': [('ewis', False)],
           'ews': [('ews', False)],
           'eyar': [('ey', False)],
           'eyers': [('eyer', False)],
           'eylan': [('eyla', False)],
           'eylans': [('eyla', False)],
           'eås': [('eå', False)],
           'fan': [('fa', False)],
           'fans': [('fa', False)],
           'far': [('fe', False)],
           'faris': [('fari', False)],
           'farna': [('fe', False)],
           'farnas': [('fe', False)],
           'fars': [('f', False)],
           'fas': [('fa', False)],
           'fats': [('fat', False)],
           'fes': [('fe', False)],
           'feus': [('feus', False)],
           'ffan': [('ffan', False)],
           'ffans': [('ffan', False)],
           'ffars': [('ffe', False)],
           'filas': [('fila', False)],
           'fior': [('fia', False)],
           'fiors': [('fia', False)],
           'fis': [('fi', False)],
           'fman': [('fman', False)],
           'fmans': [('fman', False)],
           'folds': [('fold', False)],
           'fons': [('fons', False)],
           'fors': [('fors', False)],
           'fos': [('fo', False)],
           'fos-': [('fo', False)],
           'fps-': [('fp', True)],
           'fs': [('f', False)],
           'fsons': [('fson', False)],
           'ftan': [('ftan', False)],
           'ftans': [('ftan', False)],
           'gales': [('gale', False)],
           'gan': [('ga', False)],
           'gans': [('ga', False)],
           'gar': [('gar', False)],
           'garna': [('ge', False)],
           'garnas': [('ge', False)],
           'gars': [('g', False)],
           'gas': [('ga', False)],
           'gdis': [('gdis', False)],
           'gdor': [('gda', False)],
           'gdors': [('gda', False)],
           'gelan': [('gela', False)],
           'gelans': [('gela', False)],
           'gellan': [('gellan', False)],
           'gellans': [('gellan', False)],
           'gels': [('gels', False)],
           'gen': [('gen', False)],
           'genes': [('gene', False)],
           'gens': [('gen', False)],
           'gernes': [('gernes', True)],
           'ges': [('ge', False)],
           'ggar': [('gge', False)],
           'ggars': [('gge', False)],
           'ggs': [('ggs', False)],
           'ggvar': [('ggve', False)],
           'ghes': [('ghes', False)],
           'gian': [('gian', False)],
           'gians': [('gian', False)],
           'gis': [('gi', False)],
           'gitan': [('gita', False)],
           'gitans': [('gita', False)],
           'gits': [('git', False)],
           'glas': [('glas', False)],
           'glor': [('gla', False)],
           'glors': [('gla', False)],
           'gman': [('gman', False)],
           'gmans': [('gman', False)],
           'gmars': [('gmar', False)],
           'gna': [('gna', False)],
           'gnar': [('gnar', False)],
           'gnars': [('gne', False)],
           'gns': [('gn', False)],
           'gnus': [('gnus', False)],
           'golas': [('gola', False)],
           'gor': [('gor', False)],
           'gorars': [('gor', False)],
           'gors': [('gor', False)],
           'gos': [('go', False)],
           'gran': [('gran', False)],
           'grans': [('gran', False)],
           'gs': [('g', False)],
           'gs-': [('gs', False)],
           'gtar': [('gt', False)],
           'gtarna': [('gt', False)],
           'gtarnas': [('gt', False)],
           'gtars': [('gt', False)],
           'gvars': [('gve', False)],
           'halds': [('hald', False)],
           'hals': [('hals', False)],
           'hams': [('ham', False)],
           'han': [('ha', False)],
           'hanars': [('han', False)],
           'handen': [('hand', True), ('handen', True)],
           'hannes': [('hannes', False)],
           'hans': [('ha', False)],
           'harias': [('harias', False)],
           'hars': [('h', False)],
           'has': [('ha', False)],
           'hds': [('hd', False)],
           'hds-': [('hd', False)],
           'heas': [('heas', False)],
           'hells': [('hell', False)],
           'hen': [('hen', False)],
           'hens': [('hen', False)],
           'heodorars': [('heodore', False)],
           'herna': [('herna', False)],
           'hes': [('he', False)],
           'heus': [('heus', False)],
           'hias': [('hias', False)],
           'hiles': [('hile', False)],
           'hillers': [('hiller', False)],
           'hior': [('hia', False)],
           'hiors': [('hia', False)],
           'his': [('hi', False)],
           'hlers': [('hler', False)],
           'hlian': [('hlia', False)],
           'hlians': [('hlia', False)],
           'hlias': [('hlia', False)],
           'hlins': [('hlin', False)],
           'hls': [('hl', False)],
           'hléns': [('hlén', False)],
           'hman': [('hman', False)],
           'hmans': [('hman', False)],
           'hmor': [('hma', False)],
           'hmors': [('hma', False)],
           'hms': [('hm', False)],
           'hns': [('hn', False)],
           'holds': [('hold', False)],
           'homas': [('homa', False)],
           'hor': [('hor', False)],
           'horar': [('hore', False)],
           'horarna': [('hore', False)],
           'horarnas': [('hore', False)],
           'hors': [('hor', False)],
           'hos': [('ho', False)],
           'hrar': [('hr', False)],
           'hrarna': [('hr', False)],
           'hrarnas': [('hr', False)],
           'hris': [('hris', False)],
           'hror': [('hra', False)],
           'hrors': [('hra', False)],
           'hrs': [('hr', False)],
           'hrus': [('hrus', False)],
           'hs': [('h', False)],
           'hs-': [('hs', False)],
           'hsons': [('hson', False)],
           'hules': [('hule', False)],
           'hurar': [('hure', False)],
           'hurarna': [('hure', False)],
           'hurarnas': [('hure', False)],
           'hyar': [('hy', False)],
           'hyran': [('hyra', False)],
           'hyrans': [('hyra', False)],
           'iagos': [('iago', False)],
           'ialarna': [('ial', False)],
           'ialarnas': [('ial', False)],
           'iamis': [('iami', False)],
           'iams': [('iam', False)],
           'ian': [('ia', False)],
           'ianan': [('iana', False)],
           'ianans': [('iana', False)],
           'ianars': [('ian', False)],
           'ians': [('ia', False)],
           'iaran': [('iara', False)],
           'iarans': [('iara', False)],
           'iars': [('i', False)],
           'ias': [('ia', False)],
           'iasars': [('ias', False)],
           'iats': [('iat', False)],
           'ibels': [('ibel', False)],
           'ibias': [('ibia', False)],
           'iborna': [('iba', False)],
           'ibornas': [('iba', False)],
           'icar': [('ic', False)],
           'icarna': [('ic', False)],
           'icarnas': [('ic', False)],
           'ichan': [('icha', False)],
           'ichans': [('icha', False)],
           'ichs': [('ich', False)],
           'ickar': [('icke', False)],
           'ickarna': [('icke', False)],
           'ickarnas': [('icke', False)],
           'ickars': [('icke', False)],
           'ickens': [('icken', False)],
           'icus': [('icus', False)],
           'idan': [('idan', False)],
           'idans': [('idan', False)],
           'idarna': [('id', False)],
           'idarnas': [('id', False)],
           'idas': [('idas', False)],
           'iddas': [('idda', False)],
           'iders': [('ider', False)],
           'ides': [('ides', False)],
           'idor': [('ida', False)],
           'idorar': [('idor', False)],
           'idorarna': [('idor', False)],
           'idorarnas': [('idor', False)],
           'idors': [('ida', False)],
           'idous': [('idou', False)],
           'ids': [('id', False)],
           'idts': [('idt', False)],
           'iedes': [('iede', False)],
           'ielan': [('iela', False)],
           'ielans': [('iela', False)],
           'iels': [('iels', False)],
           'ien': [('ien', False)],
           'iens': [('ien', False)],
           'ierna': [('ierna', False)],
           'ieros': [('iero', False)],
           'ies': [('ie', False)],
           'ifar': [('if', False)],
           'ifarna': [('if', False)],
           'ifarnas': [('if', False)],
           'igan': [('igan', False)],
           'igans': [('igan', False)],
           'igar': [('ig', False)],
           'igarna': [('ig', False)],
           'igarnas': [('ig', False)],
           'igellan': [('igella', False)],
           'igellans': [('igella', False)],
           'ignes': [('igne', False)],
           'iis': [('ii', False)],
           'ijan': [('ija', False)],
           'ikan': [('ikan', False)],
           'ikans': [('ikan', False)],
           'ikar': [('ik', False)],
           'ikarna': [('ik', False)],
           'ikarnas': [('ik', False)],
           'ikars': [('ik', False)],
           'ilan': [('ilan', False)],
           'ilans': [('ilan', False)],
           'ilar': [('il', False)],
           'ilarna': [('il', False)],
           'ilarnas': [('il', False)],
           'ilas': [('ilas', False)],
           'ildar': [('ilde', False)],
           'ildarna': [('ilde', False)],
           'ildarnas': [('ilde', False)],
           'ilers': [('iler', False)],
           'iles': [('iles', False)],
           'iliams': [('iliam', False)],
           'ilian': [('ilia', False)],
           'ilians': [('ilia', False)],
           'ilias': [('ilia', False)],
           'iljan': [('ilja', False)],
           'iljans': [('ilja', False)],
           'illan': [('illa', False)],
           'illans': [('illa', False)],
           'illas': [('illa', False)],
           'illers': [('illers', False)],
           'illes': [('ille', False)],
           'illos': [('illo', False)],
           'ilman': [('ilma', False)],
           'ilmans': [('ilma', False)],
           'ilor': [('ila', False)],
           'ilors': [('ila', False)],
           'ils': [('il', False)],
           'iman': [('iman', False)],
           'imans': [('iman', False)],
           'imar': [('im', False)],
           'imarna': [('im', False)],
           'imarnas': [('im', False)],
           'imers': [('imer', False)],
           'imes': [('imes', False)],
           'immars': [('immie', False)],
           'imor': [('ima', False)],
           'imors': [('ima', False)],
           'imos': [('imos', False)],
           'ims': [('im', False)],
           'in': [('in', False)],
           'ina': [('ina', False)],
           'inar': [('in', False)],
           'inarna': [('in', False)],
           'inarnas': [('in', False)],
           'inars': [('ine', False)],
           'indars': [('ind', False)],
           'indes': [('inde', False)],
           'ingar': [('ingar', False)],
           'ingarna': [('ingarna', False)],
           'ingarnas': [('ingarna', False)],
           'ingars': [('ing', False)],
           'ings': [('ing', False)],
           'innan': [('inna', False)],
           'innans': [('inna', False)],
           'innis': [('inni', False)],
           'inor': [('ina', False)],
           'inors': [('ina', False)],
           'ins': [('in', False)],
           'inus': [('inus', False)],
           'iolan': [('iola', False)],
           'iolans': [('iola', False)],
           'iolas': [('iola', False)],
           'iolds': [('iold', False)],
           'ionan': [('iona', False)],
           'ionans': [('iona', False)],
           'ionas': [('iona', False)],
           'ionen': [('ionen', False)],
           'ionens': [('ionen', False)],
           'iones': [('ione', False)],
           'ionis': [('ioni', False)],
           'ior': [('ior', False)],
           'iors': [('ior', False)],
           'ios': [('io', False)],
           'iottar': [('iott', False)],
           'iottarna': [('iott', False)],
           'iottarnas': [('iott', False)],
           'iottars': [('iott', False)],
           'ipar': [('ip', False)],
           'iparna': [('ip', False)],
           'iparnas': [('ip', False)],
           'ipios': [('ipio', False)],
           'iques': [('ique', False)],
           'irar': [('ir', False)],
           'irarna': [('ir', False)],
           'irarnas': [('ir', False)],
           'iris': [('iris', False)],
           'irnan': [('irna', False)],
           'irnans': [('irna', False)],
           'iror': [('ira', False)],
           'irors': [('ira', False)],
           'irs': [('ir', False)],
           'is': [('is', False)],
           'is-': [('is', False)],
           'isar': [('is', False)],
           'isarna': [('is', False)],
           'isarnas': [('is', False)],
           'isian': [('isia', False)],
           'isians': [('isia', False)],
           'isias': [('isia', False)],
           'isons': [('ison', False)],
           'issan': [('issa', False)],
           'issans': [('issa', False)],
           'istar': [('iste', False)],
           'istarna': [('iste', False)],
           'istarnas': [('iste', False)],
           'istars': [('iste', False)],
           'istos': [('isto', False)],
           'ists': [('ist', False)],
           'itan': [('itan', False)],
           'itans': [('itan', False)],
           'itor': [('ita', False)],
           'itorna': [('ita', False)],
           'itornas': [('ita', False)],
           'itors': [('ita', False)],
           'itos': [('itos', False)],
           'ittan': [('itta', False)],
           'ittans': [('itta', False)],
           'itts': [('itt', False)],
           'itus': [('itus', False)],
           'itys': [('ity', False)],
           'ivan': [('ivan', False)],
           'ivans': [('ivan', False)],
           'ivor': [('iva', False)],
           'ivors': [('iva', False)],
           'iwan': [('iwan', False)],
           'iwans': [('iwan', False)],
           'izar': [('iz', False)],
           'izars': [('iz', False)],
           'izian': [('izia', False)],
           'izians': [('izia', False)],
           'jams': [('jam', False)],
           'jan': [('jan', True)],
           'janan': [('jana', False)],
           'janans': [('jana', False)],
           'jans': [('ja', False)],
           'jar': [('je', False)],
           'jarna': [('je', False)],
           'jarnas': [('je', False)],
           'jaros': [('jaro', False)],
           'jars': [('j', False)],
           'jas': [('ja', False)],
           'jdor': [('jda', False)],
           'jdors': [('jda', False)],
           'jean': [('jean', True)],
           'jells': [('jell', False)],
           'jen': [('jen', False)],
           'jens': [('jen', False)],
           'jes': [('je', False)],
           'jis': [('ji', False)],
           'jkins': [('jkin', False)],
           'jlor': [('jla', False)],
           'jlors': [('jla', False)],
           'jmor': [('jma', False)],
           'jmors': [('jma', False)],
           'jodor': [('jodor', False)],
           'jodors': [('jodor', False)],
           'jos': [('jo', False)],
           'js': [('j', False)],
           'kan': [('ka', False)],
           'kans': [('ka', False)],
           'kansas': [('kansas', False)],
           'kar': [('ke', False)],
           'karias': [('karias', False)],
           'karna': [('ke', False)],
           'karnas': [('ke', False)],
           'kars': [('kar', False)],
           'kas': [('ka', False)],
           'kedes': [('kede', False)],
           'ken': [('ken', False)],
           'kenes': [('kene', False)],
           'kens': [('ken', False)],
           'kerna': [('kerna', False)],
           'kes': [('ke', False)],
           'kiles': [('kile', False)],
           'killes': [('killes', False)],
           'kingar': [('king', False)],
           'kingarna': [('king', False)],
           'kingarnas': [('king', False)],
           'kins': [('kins', False)],
           'kis': [('ki', False)],
           'kitan': [('kita', False)],
           'kitans': [('kita', False)],
           'kkar': [('kk', False)],
           'kkarna': [('kk', False)],
           'kkarnas': [('kk', False)],
           'kkars': [('kk', False)],
           'klas': [('klas', False)],
           'kles': [('kles', False)],
           'klins': [('klin', False)],
           'klockan': [('klocka', False)],
           'klor': [('kla', False)],
           'klors': [('kla', False)],
           'kman': [('kman', False)],
           'kmans': [('kman', False)],
           'kogens': [('kogen', False)],
           'kolas': [('kola', False)],
           'konen': [('konen', False)],
           'konens': [('konen', False)],
           'kos': [('ko', False)],
           'krates': [('krates', False)],
           'ks': [('k', False)],
           'ks-': [('ks', False)],
           'ksons': [('kson', False)],
           'ktis': [('ktis', False)],
           'kvarna': [('kvarna', False)],
           'kvarnas': [('kvarna', False)],
           'kvists': [('kvist', False)],
           'kyar': [('ky', False)],
           'ladars': [('lad', False)],
           'laes': [('laes', False)],
           'laesar': [('laes', False)],
           'lais': [('lais', False)],
           'lalarna': [('lal', False)],
           'lalarnas': [('lal', False)],
           'lamas': [('lama', False)],
           'lan': [('la', False)],
           'lanan': [('lana', False)],
           'lanans': [('lana', False)],
           'lanars': [('lan', False)],
           'landar': [('land', False)],
           'lans': [('la', False)],
           'lar': [('le', False)],
           'laran': [('lara', False)],
           'larans': [('lara', False)],
           'larna': [('le', False)],
           'larnas': [('le', False)],
           'lars': [('l', False)],
           'las': [('la', False)],
           'lasars': [('las', False)],
           'lats': [('lat', False)],
           'laus': [('laus', False)],
           'lazar': [('lazar', False)],
           'lazars': [('lazar', False)],
           'lberts': [('lbert', False)],
           'lborna': [('lba', False)],
           'lbornas': [('lba', False)],
           'ldar': [('ld', False)],
           'ldarna': [('ld', False)],
           'ldarnas': [('ld', False)],
           'ldars': [('lde', False)],
           'lders': [('lder', False)],
           'ldor': [('lda', False)],
           'ldors': [('lda', False)],
           'lds': [('ld', False)],
           'ldts': [('ldt', False)],
           'lean': [('lean', False)],
           'leans': [('lean', False)],
           'len': [('len', False)],
           'lenan': [('lena', False)],
           'lenans': [('lena', False)],
           'lenes': [('lene', False)],
           'lens': [('len', False)],
           'lerna': [('lerna', False)],
           'les': [('le', False)],
           'levis': [('levi', False)],
           'lfar': [('lf', False)],
           'lfarna': [('lf', False)],
           'lfarnas': [('lf', False)],
           'lgar': [('lge', False)],
           'lgars': [('lge', False)],
           'lgor': [('lga', False)],
           'lgors': [('lga', False)],
           'lian': [('lian', False)],
           'lians': [('lian', False)],
           'lias': [('lias', False)],
           'lidan': [('lida', False)],
           'lidans': [('lida', False)],
           'lidar': [('lid', False)],
           'lidars': [('lid', False)],
           'lidas': [('lida', False)],
           'liers': [('lier', False)],
           'likan': [('lika', False)],
           'likans': [('lika', False)],
           'linars': [('lin', False)],
           'lings': [('lings', False)],
           'linor': [('linor', False)],
           'linors': [('linor', False)],
           'lior': [('lia', False)],
           'liors': [('lia', False)],
           'lips': [('lip', False)],
           'lis': [('li', False)],
           'lkan': [('lkan', False)],
           'lkans': [('lkan', False)],
           'lkars': [('lke', False)],
           'llars': [('lle', False)],
           'llers': [('ller', False)],
           'llins': [('llin', False)],
           'llips': [('llips', False)],
           'llis': [('llis', False)],
           'llor': [('lla', False)],
           'llors': [('lla', False)],
           'llos': [('llos', False)],
           'lls': [('ll', False)],
           'llus': [('llus', False)],
           'lléns': [('llén', False)],
           'lman': [('lman', False)],
           'lmans': [('lman', False)],
           'lmar': [('lm', False)],
           'lmarna': [('lm', False)],
           'lmarnas': [('lm', False)],
           'lmars': [('lmar', False)],
           'lmers': [('lmer', False)],
           'lmor': [('lma', False)],
           'lmors': [('lma', False)],
           'lms': [('lm', False)],
           'lms-': [('lm', False)],
           'ln': [('ln', False)],
           'lna': [('lna', False)],
           'lningar': [('lningar', False)],
           'lnor': [('lna', False)],
           'lnors': [('lna', False)],
           'lns': [('ln', False)],
           'lonas': [('lona', False)],
           'lones': [('lone', False)],
           'loran': [('lora', False)],
           'lorans': [('lora', False)],
           'loras': [('lora', False)],
           'lorian': [('lorian', False)],
           'lorians': [('lorian', False)],
           'los': [('lo', False)],
           'lottorna': [('lotta', False)],
           'lottornas': [('lotta', False)],
           'ls-': [('ls', False)],
           'lsan': [('lsan', False)],
           'lsans': [('lsan', False)],
           'lsar': [('ls', False)],
           'lsarna': [('ls', False)],
           'lsarnas': [('ls', False)],
           'lseas': [('lsea', False)],
           'lsons': [('lson', False)],
           'lsus': [('lsus', False)],
           'ltan': [('ltan', False)],
           'ltans': [('ltan', False)],
           'ltas': [('ltas', False)],
           'ltzar': [('ltzar', False)],
           'ltzars': [('ltzar', False)],
           'lulus': [('lulu', False)],
           'lus': [('lu', False)],
           'lvis': [('lvis', False)],
           'lvor': [('lva', False)],
           'lvors': [('lva', False)],
           'lyas': [('lyas', False)],
           'länderna': [('länder', False)],
           'madars': [('mad', False)],
           'man': [('ma', False)],
           'manars': [('man', False)],
           'mandus': [('mandus', False)],
           'manes': [('mane', False)],
           'mans': [('ma', False)],
           'mar': [('mar', False)],
           'maran': [('mara', False)],
           'marans': [('mara', False)],
           'marks': [('marks', False)],
           'marna': [('mie', False)],
           'marnas': [('mie', False)],
           'mars': [('m', False)],
           'marsons': [('marson', False)],
           'mas': [('ma', False)],
           'mayan': [('maya', False)],
           'mayans': [('maya', False)],
           'mbias': [('mbia', False)],
           'melan': [('mela', False)],
           'melans': [('mela', False)],
           'melis': [('meli', False)],
           'men': [('men', False)],
           'menes': [('mene', False)],
           'mens': [('men', False)],
           'mes': [('me', False)],
           'mian': [('mian', False)],
           'mians': [('mian', False)],
           'milan': [('mila', False)],
           'milans': [('mila', False)],
           'milas': [('mila', False)],
           'miles': [('mile', False)],
           'milian': [('milian', False)],
           'milians': [('milian', False)],
           'millan': [('millan', False)],
           'millans': [('millan', False)],
           'minars': [('min', False)],
           'miran': [('mira', False)],
           'mirans': [('mira', False)],
           'mis': [('mi', False)],
           'mlers': [('mler', False)],
           'mls': [('ml', False)],
           'mman': [('mman', False)],
           'mmans': [('mman', False)],
           'mmar': [('mmie', False)],
           'mmars': [('mmar', False)],
           'mmers': [('mmer', False)],
           'mmor': [('mma', False)],
           'mmors': [('mma', False)],
           'mn': [('mn', False)],
           'mnden': [('mnden', False)],
           'mns': [('mn', False)],
           'monan': [('mona', False)],
           'monans': [('mona', False)],
           'monas': [('mona', False)],
           'mones': [('mone', False)],
           'mor': [('mor', False)],
           'moras': [('mora', False)],
           'mors': [('mor', False)],
           'mos': [('mo', False)],
           'moses': [('mose', False)],
           'mous': [('mous', False)],
           'mran': [('mran', False)],
           'mrans': [('mran', False)],
           'mrars': [('mre', False)],
           'ms-': [('ms', False)],
           'msons': [('mson', False)],
           'mudars': [('mud', False)],
           'myar': [('my', False)],
           'más': [('más', False)],
           'n': [('n', True)],
           'nabs': [('nab', False)],
           'namas': [('nama', False)],
           'names': [('name', False)],
           'nams': [('nam', False)],
           'nan': [('na', False)],
           'nanars': [('nan', False)],
           'nans': [('na', False)],
           'narna': [('ne', False)],
           'narnas': [('ne', False)],
           'nars': [('n', False)],
           'nas': [('na', False)],
           'nasars': [('nas', False)],
           'nathan': [('nathan', False)],
           'nathans': [('nathan', False)],
           'ncan': [('ncan', False)],
           'ncans': [('ncan', False)],
           'ncars': [('nce', False)],
           'nchs': [('nch', False)],
           'ndar': [('nd', False)],
           'ndarna': [('nd', False)],
           'ndarnas': [('nd', False)],
           'nders': [('nder', False)],
           'ndes': [('ndes', False)],
           'ndias': [('ndia', False)],
           'ndor': [('nda', False)],
           'ndors': [('nda', False)],
           'nds': [('nd', False)],
           'ndts': [('ndt', False)],
           'ndus': [('ndus', False)],
           'nelis': [('neli', False)],
           'nells': [('nell', False)],
           'nen': [('nen', False)],
           'nens': [('nen', False)],
           'nerna': [('nerna', False)],
           'nes': [('ne', False)],
           'nesar': [('nesar', False)],
           'nesars': [('nes', False)],
           'nglas': [('ngla', False)],
           'ngor': [('nga', False)],
           'ngors': [('nga', False)],
           'ngvar': [('ngve', False)],
           'ngvars': [('ngvar', False)],
           'niels': [('niel', False)],
           'nikan': [('nika', False)],
           'nikans': [('nika', False)],
           'nilas': [('nila', False)],
           'nilos': [('nilo', False)],
           'nils': [('nils', True)],
           'ningar': [('ning', False)],
           'ningarna': [('ning', False)],
           'ningarnas': [('ning', False)],
           'ningars': [('ningar', False)],
           'nior': [('nia', False)],
           'niors': [('nia', False)],
           'nis': [('ni', False)],
           'nitan': [('nita', False)],
           'nitans': [('nita', False)],
           'nitos': [('nito', False)],
           'njan': [('nja', False)],
           'nkan': [('nkan', False)],
           'nkans': [('nkan', False)],
           'nkars': [('nke', False)],
           'nlis': [('nlis', False)],
           'nman': [('nman', False)],
           'nmans': [('nman', False)],
           'nmarks': [('nmark', False)],
           'nmars': [('nmar', False)],
           'nn': [('nn', False)],
           'nna': [('nna', False)],
           'nnar': [('nnar', False)],
           'nnars': [('nne', False)],
           'nnesar': [('nnes', False)],
           'nningars': [('nning', False)],
           'nnis': [('nnis', False)],
           'nnor': [('nna', False)],
           'nnors': [('nna', False)],
           'nns': [('nn', False)],
           'nnyars': [('nny', False)],
           'nois': [('nois', False)],
           'noran': [('nora', False)],
           'norans': [('nora', False)],
           'noras': [('nora', False)],
           'nos': [('no', False)],
           'ns-': [('ns', False)],
           'nsar': [('ns', False)],
           'nsarna': [('ns', False)],
           'nsarnas': [('ns', False)],
           'nsars': [('nsar', False)],
           'nsins': [('nsin', False)],
           'nsons': [('nson', False)],
           'nsts': [('nst', False)],
           'ntar': [('nt', False)],
           'ntarna': [('nt', False)],
           'ntarnas': [('nt', False)],
           'ntars': [('nte', False)],
           'nthan': [('ntha', False)],
           'nthans': [('ntha', False)],
           'ntings': [('nting', False)],
           'ntos': [('ntos', False)],
           'ntus': [('ntus', False)],
           'nus': [('nu', False)],
           'nyan': [('nyan', False)],
           'nyans': [('nyan', False)],
           'nyar': [('ny', False)],
           'nyars': [('nyar', False)],
           'nzar': [('nz', False)],
           'nzars': [('nz', False)],
           'näs': [('näs', False)],
           'oalds': [('oald', False)],
           'oams': [('oam', False)],
           'oan': [('oa', False)],
           'oans': [('oa', False)],
           'oar': [('oar', False)],
           'oars': [('oar', False)],
           'oas': [('oa', False)],
           'obar': [('ob', False)],
           'obarna': [('ob', False)],
           'obarnas': [('ob', False)],
           'obels': [('obel', False)],
           'obos': [('obos', False)],
           'ochs': [('och', False)],
           'ockar': [('ocke', False)],
           'ockarna': [('ocke', False)],
           'ockarnas': [('ocke', False)],
           'ockars': [('ocke', False)],
           'ockens': [('ocken', False)],
           'odan': [('odan', False)],
           'odans': [('odan', False)],
           'odarna': [('odarna', False)],
           'odarnas': [('odarna', False)],
           'odars': [('ode', False)],
           'odor': [('oda', False)],
           'odors': [('oda', False)],
           'odos': [('odos', False)],
           'ods': [('od', False)],
           'oells': [('oell', False)],
           'oen': [('oen', False)],
           'oens': [('oen', False)],
           'oes': [('oe', False)],
           'ofar': [('of', False)],
           'ofarna': [('of', False)],
           'ofarnas': [('of', False)],
           'ogan': [('ogan', False)],
           'ogans': [('ogan', False)],
           'ogenes': [('ogenes', False)],
           'ogens': [('ogens', False)],
           'ognes': [('ogne', False)],
           'ohan': [('ohan', False)],
           'ohans': [('ohan', False)],
           'oinar': [('oine', False)],
           'oinarna': [('oine', False)],
           'oinarnas': [('oine', False)],
           'oits': [('oit', False)],
           'olaes': [('olae', False)],
           'olais': [('olai', False)],
           'olan': [('olan', False)],
           'olans': [('olan', False)],
           'olas': [('olas', False)],
           'oldars': [('old', False)],
           'olds': [('olds', False)],
           'olinor': [('olina', False)],
           'olinors': [('olina', False)],
           'olins': [('olin', False)],
           'olles': [('olle', False)],
           'ollos': [('ollo', False)],
           'olor': [('ola', False)],
           'olors': [('ola', False)],
           'ols': [('ol', False)],
           'oman': [('oman', False)],
           'omans': [('oman', False)],
           'omar': [('om', False)],
           'omarna': [('om', False)],
           'omarnas': [('om', False)],
           'omas': [('omas', False)],
           'oms': [('om', False)],
           'on': [('on', False)],
           'ona': [('ona', False)],
           'onalds': [('onalds', False)],
           'onan': [('onan', False)],
           'onans': [('onan', False)],
           'onar': [('on', False)],
           'onarna': [('on', False)],
           'onarnas': [('on', False)],
           'ondars': [('ond', False)],
           'onen': [('on', False)],
           'onens': [('on', False)],
           'ones': [('ones', False)],
           'ongs': [('ong', False)],
           'onis': [('onis', False)],
           'onnan': [('onna', False)],
           'onnans': [('onna', False)],
           'onnes': [('onne', False)],
           'onor': [('ona', False)],
           'onors': [('ona', False)],
           'ons': [('on', False)],
           'onsars': [('ons', False)],
           'ontos': [('onto', False)],
           'onyan': [('onya', False)],
           'onyans': [('onya', False)],
           'oods': [('oods', False)],
           'oor': [('oor', False)],
           'oors': [('oor', False)],
           'oos': [('oo', False)],
           'opos': [('opos', False)],
           'ops': [('ops', False)],
           'or': [('a', False)],
           'oran': [('oran', False)],
           'orans': [('oran', False)],
           'orar': [('or', False)],
           'orarna': [('or', False)],
           'orarnas': [('or', False)],
           'orars': [('ore', False)],
           'oras': [('oras', False)],
           'oreas': [('orea', False)],
           'orens': [('orens', False)],
           'orges': [('orge', False)],
           'orian': [('oria', False)],
           'orians': [('oria', False)],
           'orias': [('oria', False)],
           'oris': [('oris', False)],
           'orks': [('ork', False)],
           'orna': [('a', False)],
           'ornas': [('a', False)],
           'oror': [('ora', False)],
           'orors': [('ora', False)],
           'oros': [('oros', False)],
           'ors': [('a', False)],
           'orts': [('ort', False)],
           'orus': [('orus', False)],
           'orés': [('oré', False)],
           'os': [('os', False)],
           'os-': [('os', False)],
           'osar': [('os', False)],
           'osarna': [('os', False)],
           'osarnas': [('os', False)],
           'otar': [('ot', False)],
           'otarna': [('ot', False)],
           'otarnas': [('ot', False)],
           'otars': [('ot', False)],
           'otos': [('otos', False)],
           'ottan': [('otta', False)],
           'ottans': [('otta', False)],
           'ottar': [('otte', False)],
           'ottarna': [('otte', False)],
           'ottarnas': [('otte', False)],
           'ottars': [('otte', False)],
           'ottis': [('otti', False)],
           'ottorna': [('ottorna', False)],
           'ottornas': [('ottorna', False)],
           'otts': [('ott', False)],
           'oudars': [('oud', False)],
           'ous': [('ou', False)],
           'ovar': [('ov', False)],
           'ovarna': [('ov', False)],
           'ovarnas': [('ov', False)],
           'ovars': [('ov', False)],
           'ovis': [('ovis', False)],
           'ovor': [('ova', False)],
           'ovors': [('ova', False)],
           'owars': [('owe', False)],
           'oyar': [('oy', False)],
           'pan': [('pa', False)],
           'pans': [('pa', False)],
           'par': [('par', False)],
           'parna': [('pe', False)],
           'parnas': [('pe', False)],
           'pars': [('p', False)],
           'pas': [('pa', False)],
           'pats': [('pat', False)],
           'pen': [('pen', False)],
           'pens': [('pen', False)],
           'perna': [('perna', False)],
           'pes': [('pe', False)],
           'phan': [('phan', False)],
           'phans': [('phan', False)],
           'phias': [('phia', False)],
           'phis': [('phis', False)],
           'pian': [('pian', False)],
           'pians': [('pian', False)],
           'pios': [('pios', False)],
           'pis': [('pi', False)],
           'pks-': [('pk', False)],
           'plan': [('plan', False)],
           'plans': [('plan', False)],
           'plers': [('pler', False)],
           'plings': [('pling', False)],
           'plins': [('plin', False)],
           'polds': [('pold', False)],
           'polis': [('poli', False)],
           'pos': [('po', False)],
           'ppar': [('ppe', False)],
           'ppars': [('ppe', False)],
           'pras': [('pras', False)],
           'prs': [('pr', False)],
           'ps': [('p', False)],
           'ps-': [('ps', False)],
           'psons': [('pson', False)],
           'pstars': [('pstars', False)],
           'ques': [('ques', False)],
           'qvists': [('qvist', False)],
           'rabis': [('rabi', False)],
           'rados': [('rado', False)],
           'rahman': [('rahman', False)],
           'rahmans': [('rahman', False)],
           'raldor': [('ralda', False)],
           'raldors': [('ralda', False)],
           'ralds': [('rald', False)],
           'raltars': [('raltar', False)],
           'rams': [('ram', False)],
           'ran': [('ra', False)],
           'ranars': [('ran', False)],
           'rans': [('ra', False)],
           'rar': [('re', False)],
           'raris': [('rari', False)],
           'rarna': [('re', False)],
           'rarnas': [('re', False)],
           'rars': [('r', False)],
           'ras': [('ra', False)],
           'rasars': [('ras', False)],
           'rates': [('rate', False)],
           'rbels': [('rbel', False)],
           'rberts': [('rbert', False)],
           'rcar': [('rc', False)],
           'rcarna': [('rc', False)],
           'rcarnas': [('rc', False)],
           'rcus': [('rcus', False)],
           'rdan': [('rdan', False)],
           'rdanes': [('rdanes', False)],
           'rdans': [('rdan', False)],
           'rdar': [('rd', False)],
           'rdarna': [('rd', False)],
           'rdarnas': [('rd', False)],
           'rdor': [('rda', False)],
           'rdors': [('rda', False)],
           'rds': [('rd', False)],
           'reasar': [('reas', False)],
           'rells': [('rell', False)],
           'ren': [('ren', False)],
           'renan': [('rena', False)],
           'renans': [('rena', False)],
           'renes': [('rene', False)],
           'rens': [('ren', False)],
           'reres': [('rere', False)],
           'rerna': [('rerna', False)],
           'reros': [('rero', False)],
           'res': [('re', False)],
           'rews': [('rew', False)],
           'rgan': [('rgan', False)],
           'rgans': [('rgan', False)],
           'rgels': [('rgel', False)],
           'rges': [('rges', False)],
           'rgos': [('rgos', False)],
           'rgs-': [('rg', False)],
           'rian': [('rian', False)],
           'rians': [('rian', False)],
           'ridan': [('rida', False)],
           'ridans': [('rida', False)],
           'ridar': [('rid', False)],
           'ridars': [('rid', False)],
           'ridas': [('rida', False)],
           'riels': [('riel', False)],
           'riers': [('rier', False)],
           'riis': [('riis', False)],
           'rikan': [('rika', False)],
           'rikans': [('rika', False)],
           'rinars': [('rin', False)],
           'ringars': [('ringar', False)],
           'rior': [('ria', False)],
           'riors': [('ria', False)],
           'ris': [('ri', False)],
           'ritan': [('rita', False)],
           'ritans': [('rita', False)],
           'rits': [('rit', False)],
           'rjan': [('rjan', False)],
           'rjans': [('rjan', False)],
           'rjars': [('rje', False)],
           'rkan': [('rkan', False)],
           'rkans': [('rkan', False)],
           'rkar': [('rk', False)],
           'rkarna': [('rk', False)],
           'rkarnas': [('rk', False)],
           'rkars': [('rk', False)],
           'rlar': [('rl', False)],
           'rlarna': [('rl', False)],
           'rlarnas': [('rl', False)],
           'rleans': [('rleans', False)],
           'rles': [('rles', False)],
           'rlings': [('rling', False)],
           'rlins': [('rlin', False)],
           'rlor': [('rla', False)],
           'rlors': [('rla', False)],
           'rls': [('rl', False)],
           'rländerna': [('rländerna', False)],
           'rléns': [('rlén', False)],
           'rman': [('rman', False)],
           'rmans': [('rman', False)],
           'rmes': [('rmes', False)],
           'rmor': [('rma', False)],
           'rmors': [('rma', False)],
           'rms': [('rm', False)],
           'rn': [('rn', False)],
           'rna': [('rna', False)],
           'rnan': [('rnan', False)],
           'rnans': [('rnan', False)],
           'rnar': [('rn', False)],
           'rnarna': [('rn', False)],
           'rnarnas': [('rn', False)],
           'rnars': [('rne', False)],
           'rnelis': [('rnelis', False)],
           'rnor': [('rna', False)],
           'rnors': [('rna', False)],
           'rns': [('rn', False)],
           'rnus': [('rnus', False)],
           'rodarna': [('rode', False)],
           'rodarnas': [('rode', False)],
           'rogens': [('rogen', False)],
           'rolan': [('rola', False)],
           'rolans': [('rola', False)],
           'rolas': [('rola', False)],
           'rolds': [('rold', False)],
           'ronas': [('rona', False)],
           'rones': [('rone', False)],
           'ror': [('ror', False)],
           'roran': [('rora', False)],
           'rorans': [('rora', False)],
           'roras': [('rora', False)],
           'rors': [('ror', False)],
           'ros': [('ro', False)],
           'roses': [('rose', False)],
           'rottan': [('rottan', False)],
           'rottans': [('rottan', False)],
           'rques': [('rque', False)],
           'rrars': [('rre', False)],
           'rris': [('rris', False)],
           'rrs': [('rr', False)],
           'rs-': [('rs', False)],
           'rsar': [('rs', False)],
           'rsarna': [('rs', False)],
           'rsarnas': [('rs', False)],
           'rsons': [('rson', False)],
           'rstedts': [('rstedts', False)],
           'rtar': [('rt', False)],
           'rtarna': [('rt', False)],
           'rtarnas': [('rt', False)],
           'rtars': [('rt', False)],
           'rtes': [('rtes', False)],
           'rthan': [('rtha', False)],
           'rthans': [('rtha', False)],
           'rtis': [('rtis', False)],
           'rtor': [('rta', False)],
           'rtorna': [('rta', False)],
           'rtornas': [('rta', False)],
           'rtors': [('rta', False)],
           'rturar': [('rtur', False)],
           'rturarna': [('rtur', False)],
           'rturarnas': [('rtur', False)],
           'rudas': [('ruda', False)],
           'ruls': [('ruls', False)],
           'runars': [('run', False)],
           'rus': [('ru', False)],
           'rvars': [('rve', False)],
           'rwens': [('rwen', False)],
           'ryan': [('ryan', False)],
           'ryans': [('ryan', False)],
           'ryar': [('ry', False)],
           'rzan': [('rzan', False)],
           'rzans': [('rzan', False)],
           'résars': [('rés', False)],
           's': [('s', True)],
           's-': [('', False)],
           'samas': [('sama', False)],
           'san': [('sa', False)],
           'sanars': [('san', False)],
           'sandars': [('sandar', False)],
           'sans': [('sa', False)],
           'sar': [('sar', False)],
           'sarna': [('se', False)],
           'sarnas': [('se', False)],
           'sars': [('s', False)],
           'sas': [('sa', False)],
           'sats': [('sat', False)],
           'saurus': [('saurus', False)],
           'scar': [('scar', False)],
           'scars': [('scar', False)],
           'schs': [('sch', False)],
           'scus': [('scus', False)],
           'seas': [('seas', False)],
           'seles': [('sele', False)],
           'sells': [('sell', False)],
           'sen': [('sen', False)],
           'sens': [('sen', False)],
           'ses': [('se', False)],
           'sesars': [('ses', False)],
           'setts': [('setts', False)],
           'seus': [('seus', False)],
           'sgars': [('sgar', False)],
           'shor': [('sha', False)],
           'shors': [('sha', False)],
           'sian': [('sian', False)],
           'sians': [('sian', False)],
           'sias': [('sias', False)],
           'sidor': [('sidor', False)],
           'sidors': [('sidor', False)],
           'sikan': [('sika', False)],
           'sikans': [('sika', False)],
           'sinars': [('sin', False)],
           'sins': [('sins', False)],
           'sior': [('sia', False)],
           'siors': [('sia', False)],
           'sis': [('si', False)],
           'sits': [('sit', False)],
           'skan': [('skan', False)],
           'skans': [('skan', False)],
           'skar': [('skar', False)],
           'skarna': [('skarna', False)],
           'skarnas': [('skarna', False)],
           'sklockan': [('sklockan', False)],
           'slan': [('slan', False)],
           'slans': [('slan', False)],
           'slers': [('sler', False)],
           'slings': [('sling', False)],
           'sman': [('sman', False)],
           'smans': [('sman', False)],
           'smarks': [('smark', False)],
           'smor': [('sma', False)],
           'smors': [('sma', False)],
           'soris': [('sori', False)],
           'sos': [('so', False)],
           'spars': [('spar', False)],
           'sror': [('sra', False)],
           'srors': [('sra', False)],
           'ss': [('ss', False)],
           'ss-': [('ss', False)],
           'ssan': [('ssan', False)],
           'ssans': [('ssan', False)],
           'ssar': [('sse', False)],
           'ssars': [('sse', False)],
           'ssins': [('ssin', False)],
           'ssis': [('ssis', False)],
           'ssons': [('sson', False)],
           'ssus': [('ssus', False)],
           'stan': [('stan', False)],
           'stans': [('stan', False)],
           'star': [('st', False)],
           'starna': [('st', False)],
           'starnas': [('st', False)],
           'stars': [('st', False)],
           'stedts': [('stedt', False)],
           'stles': [('stle', False)],
           'storna': [('sta', False)],
           'stornas': [('sta', False)],
           'stran': [('stra', False)],
           'strans': [('stra', False)],
           'stros': [('stro', False)],
           'stus': [('stus', False)],
           'stys': [('sty', False)],
           'sées': [('sées', False)],
           'tagnes': [('tagne', False)],
           'tagos': [('tago', False)],
           'talarna': [('tal', False)],
           'talarnas': [('tal', False)],
           'tams': [('tam', False)],
           'tan': [('ta', False)],
           'tanars': [('tan', False)],
           'tans': [('ta', False)],
           'tar': [('te', False)],
           'tarkos': [('tarkos', False)],
           'tarna': [('te', False)],
           'tarnas': [('te', False)],
           'taros': [('taro', False)],
           'tars': [('tar', False)],
           'tas': [('ta', False)],
           'tasars': [('tas', False)],
           'telis': [('teli', False)],
           'tells': [('tell', False)],
           'ten': [('ten', False)],
           'tenes': [('tene', False)],
           'tens': [('ten', False)],
           'terna': [('terna', False)],
           'tes': [('te', False)],
           'teus': [('teus', False)],
           'than': [('than', False)],
           'thans': [('than', False)],
           'thor': [('tha', False)],
           'thors': [('tha', False)],
           'tian': [('tian', False)],
           'tians': [('tian', False)],
           'tias': [('tias', False)],
           'tilas': [('tila', False)],
           'timan': [('tima', False)],
           'timans': [('tima', False)],
           'tinars': [('tin', False)],
           'tings': [('tings', False)],
           'tis': [('ti', False)],
           'tjan': [('tja', False)],
           'tlars': [('tle', False)],
           'tlas': [('tlas', False)],
           'tlers': [('tler', False)],
           'tles': [('tles', False)],
           'tls': [('tl', False)],
           'tman': [('tman', False)],
           'tmandus': [('tmandu', False)],
           'tmans': [('tman', False)],
           'tmes': [('tmes', False)],
           'tmor': [('tma', False)],
           'tmors': [('tma', False)],
           'tna': [('tna', False)],
           'tolds': [('told', False)],
           'tones': [('tone', False)],
           'tor': [('tor', False)],
           'torars': [('tor', False)],
           'tors': [('tor', False)],
           'tos': [('to', False)],
           'tran': [('tran', False)],
           'trans': [('tran', False)],
           'treas': [('trea', False)],
           'tror': [('tra', False)],
           'trors': [('tra', False)],
           'trs': [('tr', False)],
           'trus': [('trus', False)],
           'ts': [('t', False)],
           'ts-': [('ts', False)],
           'tsar': [('ts', False)],
           'tsarna': [('ts', False)],
           'tsarnas': [('ts', False)],
           'tsins': [('tsin', False)],
           'tsons': [('tson', False)],
           'ttan': [('ttan', False)],
           'ttans': [('ttan', False)],
           'ttles': [('ttle', False)],
           'ttor': [('tta', False)],
           'ttorna': [('tta', False)],
           'ttornas': [('tta', False)],
           'ttors': [('tta', False)],
           'ttys': [('tty', False)],
           'turar': [('ture', False)],
           'turarna': [('ture', False)],
           'turarnas': [('ture', False)],
           'turars': [('tur', False)],
           'turos': [('turo', False)],
           'tus': [('tu', False)],
           'tys': [('tys', False)],
           'tzar': [('tz', False)],
           'tzars': [('tz', False)],
           'uador': [('uador', False)],
           'uadors': [('uador', False)],
           'uan': [('ua', False)],
           'uans': [('ua', False)],
           'uar': [('uar', False)],
           'uaris': [('uari', False)],
           'uars': [('uar', False)],
           'uas': [('ua', False)],
           'uatus': [('uatu', False)],
           'ubar': [('ub', False)],
           'ubarna': [('ub', False)],
           'ubarnas': [('ub', False)],
           'uberts': [('ubert', False)],
           'uchos': [('ucho', False)],
           'uchs': [('uch', False)],
           'udan': [('udan', False)],
           'udans': [('udan', False)],
           'udar': [('ud', False)],
           'udarna': [('ud', False)],
           'udarnas': [('ud', False)],
           'udars': [('ude', False)],
           'udas': [('udas', False)],
           'uders': [('uder', False)],
           'udian': [('udia', False)],
           'udians': [('udia', False)],
           'udias': [('udia', False)],
           'uds': [('ud', False)],
           'ueens': [('ueens', False)],
           'uen': [('uen', False)],
           'uens': [('uen', False)],
           'uers': [('uers', False)],
           'ufar': [('uf', False)],
           'ufarna': [('uf', False)],
           'ufarnas': [('uf', False)],
           'uitos': [('uito', False)],
           'ukos': [('ukos', False)],
           'ular': [('ul', False)],
           'ularna': [('ul', False)],
           'ularnas': [('ul', False)],
           'ulers': [('uler', False)],
           'ules': [('ules', False)],
           'ulias': [('ulia', False)],
           'ulinor': [('ulina', False)],
           'ulinors': [('ulina', False)],
           'ulins': [('ulin', False)],
           'ullas': [('ulla', False)],
           'ullers': [('ullers', False)],
           'ulles': [('ulle', False)],
           'ulor': [('ula', False)],
           'ulors': [('ula', False)],
           'uls': [('ul', False)],
           'ulus': [('ulus', False)],
           'uman': [('uman', False)],
           'umans': [('uman', False)],
           'ums': [('um', False)],
           'un': [('un', False)],
           'una': [('una', False)],
           'unar': [('un', False)],
           'unarna': [('un', False)],
           'unarnas': [('un', False)],
           'unars': [('une', False)],
           'undar': [('unde', False)],
           'undarna': [('unde', False)],
           'undarnas': [('unde', False)],
           'undars': [('unde', False)],
           'undes': [('unde', False)],
           'unes': [('unes', False)],
           'unesar': [('unes', False)],
           'ungs': [('ung', False)],
           'unis': [('unis', False)],
           'unnars': [('unnar', False)],
           'unnes': [('unne', False)],
           'uns': [('un', False)],
           'untes': [('unte', False)],
           'unus': [('unus', False)],
           'urars': [('ure', False)],
           'uras': [('uras', False)],
           'urits': [('urits', False)],
           'urnes': [('urne', False)],
           'urns': [('urns', False)],
           'uror': [('ura', False)],
           'urors': [('ura', False)],
           'uros': [('uros', False)],
           'urs': [('ur', False)],
           'urtes': [('urte', False)],
           'urts': [('urt', False)],
           'us': [('us', False)],
           'us-': [('us', False)],
           'usan': [('usan', False)],
           'usans': [('usan', False)],
           'usar': [('us', False)],
           'usarna': [('us', False)],
           'usarnas': [('us', False)],
           'usons': [('uson', False)],
           'ussis': [('ussi', False)],
           'ustos': [('usto', False)],
           'usts': [('ust', False)],
           'utan': [('utan', False)],
           'utans': [('utan', False)],
           'utar': [('ut', False)],
           'utarna': [('ut', False)],
           'utarnas': [('ut', False)],
           'utars': [('ut', False)],
           'utus': [('utus', False)],
           'uvan': [('uvan', False)],
           'uvans': [('uvan', False)],
           'uvor': [('uva', False)],
           'uvors': [('uva', False)],
           'van': [('va', False)],
           'vanars': [('van', False)],
           'vans': [('va', False)],
           'vantes': [('vantes', False)],
           'var': [('ve', False)],
           'varis': [('vari', False)],
           'varna': [('ve', False)],
           'varnas': [('ve', False)],
           'varos': [('varo', False)],
           'vars': [('var', False)],
           'vas': [('va', False)],
           'ven': [('ven', False)],
           'vens': [('ven', False)],
           'verna': [('verna', False)],
           'ves': [('ve', False)],
           'vidar': [('vid', False)],
           'vidars': [('vid', False)],
           'viers': [('vier', False)],
           'vies': [('vies', False)],
           'vinars': [('vin', False)],
           'vinnan': [('vinnan', False)],
           'vinnans': [('vinnan', False)],
           'vior': [('via', False)],
           'viors': [('via', False)],
           'viran': [('vira', False)],
           'virans': [('vira', False)],
           'vis': [('vi', False)],
           'vits': [('vit', False)],
           'vns': [('vn', False)],
           'vor': [('vor', False)],
           'vors': [('vor', False)],
           'vos': [('vo', False)],
           'vs': [('v', False)],
           'walds': [('wald', False)],
           'wames': [('wame', False)],
           'wan': [('wa', False)],
           'wanars': [('wan', False)],
           'wans': [('wa', False)],
           'war': [('we', False)],
           'warna': [('we', False)],
           'warnas': [('we', False)],
           'wars': [('w', False)],
           'was': [('wa', False)],
           'wells': [('well', False)],
           'wen': [('wen', False)],
           'wens': [('wens', False)],
           'wes': [('we', False)],
           'widar': [('wid', False)],
           'widars': [('wid', False)],
           'winars': [('win', False)],
           'wior': [('wia', False)],
           'wiors': [('wia', False)],
           'wiran': [('wira', False)],
           'wirans': [('wira', False)],
           'wis': [('wi', False)],
           'wns': [('wn', False)],
           'woods': [('wood', False)],
           'ws': [('w', False)],
           'ws-': [('ws', False)],
           'xars': [('x', False)],
           'xen': [('xen', False)],
           'xens': [('xen', False)],
           'xior': [('xia', False)],
           'xiors': [('xia', False)],
           'xos': [('xo', False)],
           'xs': [('x', False)],
           'xtus': [('xtus', False)],
           'yaman': [('yama', False)],
           'yamans': [('yama', False)],
           'yamas': [('yama', False)],
           'yams': [('yam', False)],
           'yan': [('ya', False)],
           'yanars': [('yan', False)],
           'yans': [('ya', False)],
           'yars': [('y', False)],
           'yas': [('ya', False)],
           'yasars': [('yas', False)],
           'ychos': [('ycho', False)],
           'yckan': [('ycka', False)],
           'yckans': [('ycka', False)],
           'yders': [('yder', False)],
           'ydian': [('ydia', False)],
           'ydians': [('ydia', False)],
           'ydias': [('ydia', False)],
           'yds': [('yd', False)],
           'yen': [('yen', False)],
           'yens': [('yen', False)],
           'yes': [('ye', False)],
           'ylan': [('ylan', False)],
           'ylans': [('ylan', False)],
           'ylins': [('ylin', False)],
           'ylor': [('yla', False)],
           'ylors': [('yla', False)],
           'ylos': [('ylos', False)],
           'yls': [('yl', False)],
           'yman': [('yman', False)],
           'ymans': [('yman', False)],
           'yna': [('yna', False)],
           'ynor': [('yna', False)],
           'ynors': [('yna', False)],
           'yns': [('yn', False)],
           'yos': [('yo', False)],
           'yran': [('yran', False)],
           'yrans': [('yran', False)],
           'yrar': [('yr', False)],
           'yrarna': [('yr', False)],
           'yrarnas': [('yr', False)],
           'yris': [('yris', False)],
           'yror': [('yra', False)],
           'yrors': [('yra', False)],
           'yrs': [('yr', False)],
           'yrus': [('yrus', False)],
           'ys': [('y', False)],
           'ys-': [('ys', False)],
           'ysans': [('ysans', False)],
           'ysias': [('ysia', False)],
           'ysons': [('yson', False)],
           'ysos': [('ysos', False)],
           'yssan': [('yssa', False)],
           'yssans': [('yssa', False)],
           'ytos': [('ytos', False)],
           'zades': [('zade', False)],
           'zan': [('za', False)],
           'zans': [('za', False)],
           'zas': [('za', False)],
           'zells': [('zell', False)],
           'zen': [('zen', False)],
           'zens': [('zen', False)],
           'zes': [('ze', False)],
           'zior': [('zia', False)],
           'ziors': [('zia', False)],
           'zjan': [('zjan', False)],
           'zjans': [('zjan', False)],
           'zonas': [('zona', False)],
           'zos': [('zo', False)],
           'zror': [('zra', False)],
           'zrors': [('zra', False)],
           'zs': [('z', False)],
           'zyar': [('zy', False)],
           'Äs': [('Ä', False)],
           'Åkars': [('Åke', True)],
           'Ömers': [('Ömer', True)],
           'Ös': [('Ö', False)],
           'Östros': [('Östros', True)],
           'Östs': [('Öst', True)],
           'ános': [('ános', False)],
           'áns': [('án', False)],
           'ás': [('á', False)],
           'ás-': [('ás', False)],
           'äggs': [('ägg', False)],
           'ängs': [('äng', False)],
           'äns': [('än', False)],
           'ärar': [('är', False)],
           'ärarna': [('är', False)],
           'ärarnas': [('är', False)],
           'ärnes': [('ärne', False)],
           'ärs': [('är', False)],
           'äs': [('ä', False)],
           'äs-': [('äs', False)],
           'åkan': [('åkan', False)],
           'åkans': [('åkan', False)],
           'ålles': [('ålle', False)],
           'åls': [('ål', False)],
           'åns': [('åns', False)],
           'ånsars': [('åns', False)],
           'ås': [('ås', False)],
           'ås-': [('ås', False)],
           'çois': [('çois', False)],
           'èges': [('èges', False)],
           'ènnes': [('ènne', False)],
           'éan': [('éa', False)],
           'éans': [('éa', False)],
           'éas': [('éa', False)],
           'éasars': [('éas', False)],
           'éen': [('éen', False)],
           'éens': [('éen', False)],
           'éerna': [('éerna', False)],
           'ées': [('ée', False)],
           'éns': [('én', False)],
           'érs': [('ér', False)],
           'és': [('é', False)],
           'és-': [('és', False)],
           'ésar': [('és', False)],
           'ésarna': [('és', False)],
           'ésarnas': [('és', False)],
           'ésars': [('ésar', False)],
           'ëns': [('ën', False)],
           'ís-': [('ís', False)],
           'òs': [('ò', False)],
           'óns': [('ón', False)],
           'órs': [('ór', False)],
           'ós': [('ó', False)],
           'öarna': [('öarna', False)],
           'öarnas': [('öarna', False)],
           'öders': [('öder', False)],
           'ömers': [('ömer', False)],
           'öms': [('öm', False)],
           'ön': [('ön', False)],
           'önan': [('önan', False)],
           'önans': [('önan', False)],
           'öner': [('on', False)],
           'önerna': [('on', False)],
           'önernas': [('on', False)],
           'öners': [('on', False)],
           'öns': [('ön', False)],
           'öqvists': [('öqvists', True)],
           'öran': [('öran', False)],
           'örans': [('öran', False)],
           'örnars': [('örn', False)],
           'örnes': [('örne', False)],
           'ös': [('ö', False)],
           'ösus': [('ösus', False)],
           'ötars': [('öte', False)],
           'öyers': [('öyer', False)],
           'øyers': [('øyer', False)],
           'ürks': [('ürk', False)]},
 'PROPN_NOUN': {'a': [('um', False)]},
 'PROPN_VERB': {'as': [('as', False)],
                'eg': [('iga', False)],
                'er': [('a', False)],
                'ns': [('nas', False)],
                'r': [('', False)],
                's': [('a', False)],
                't': [('da', False)],
                'är': [('vara', True)]},
 'PUNCT_ADJ': {'t': [('d', False)], 'ättre': [('ra', False)]},
 'PUNCT_ADV': {'minst': [('lite', True)], 're': [('e', False)]},
 'PUNCT_DET': {'t': [('', False)]},
 'PUNCT_NOUN': {'-': [('a', False)],
                'ar': [('', False)],
                'arna': [('', False)],
                'der': [('r', False)],
                'erna': [('um', False)],
                'far': [('far', True)],
                'par': [('pa', False)],
                't': [('', False)]},
 'PUNCT_NUM': {'1)': [('1)', True), ('1', True)]},
 'PUNCT_PROPN': {'handen': [('hand', True), ('handen', True)]},
 'PUNCT_VERB': {'as': [('a', False)], 'gs': [('gas', False)], 'ns': [('nas', False)], 's': [('a', False)]},
 'SCONJ_ADV': {'er': [('ycket', False)], 'minst': [('lite', True)]},
 'SCONJ_DET': {'t': [('', False)]},
 'SCONJ_NOUN': {'arna': [('are', False)],
                'dern': [('r', False)],
                'en': [('', False)],
                'modern': [('mor', True), ('modern', True)],
                'rna': [('', False)],
                'äder': [('ar', False)],
                'ödrar': [('or', False)]},
 'VERB': {'-a': [('-a', False)],
          '-ad': [('-a', False)],
          '-ade': [('-a', False)],
          '-ades': [('-a', False)],
          '-ads': [('-a', False)],
          '-ande': [('-a', False)],
          '-andes': [('-a', False)],
          '-ar': [('-a', False)],
          '-as': [('-a', False)],
          '-at': [('-a', False)],
          '-vår': [('-våra', False)],
          '-vårades': [('-våra', False)],
          '-våras': [('-våra', False)],
          '-vårats': [('-våra', False)],
          ':a': [(':a', False)],
          ':ad': [(':a', False)],
          ':ade': [(':a', False)],
          ':ades': [(':a', False)],
          ':ads': [(':a', False)],
          ':ande': [(':a', False)],
          ':andes': [(':a', False)],
          ':ar': [(':a', False)],
          ':as': [(':a', False)],
          ':at': [(':a', False)],
          'Sa': [('Sa', False)],
          'Sad': [('Sa', False)],
          'Sade': [('Sa', False)],
          'Sades': [('Sa', False)],
          'Sads': [('Sa', False)],
          'Sande': [('Sa', False)],
          'Sandes': [('Sa', False)],
          'Sar': [('Sa', False)],
          'Sas': [('Sa', False)],
          'Sat': [('Sa', False)],
          'a-': [('a', False)],
          'abbades': [('abba', False)],
          'abbas': [('abba', False)],
          'abildades': [('abildas', False)],
          'abildas': [('abildas', False)],
          'abildats': [('abildas', False)],
          'ablad': [('abla', False)],
          'ack': [('icka', False)],
          'ackades': [('acka', False)],
          'ackas': [('acka', False)],
          'acker': [('ackra', False)],
          'acklades': [('ackla', False)],
          'acklas': [('ackla', False)],
          'acklats': [('ackla', False)],
          'acks': [('icka', False)],
          'ada': [('ada', False)],
          'adande': [('ada', False)],
          'adas': [('ada', False)],
          'adats': [('ada', False)],
          'add': [('adda', False)],
          'adda': [('adda', False)],
          'addas': [('ädja', False)],
          'adde': [('ädja', False)],
          'addes': [('ädja', False)],
          'adds': [('ädja', False)],
          'adel': [('adla', False)],
          'adel-': [('adla', False)],
          'adgades': [('adga', False)],
          'adgas': [('adga', False)],
          'adla': [('adla', False)],
          'adlas': [('adla', False)],
          'afades': [('afa', False)],
          'afar': [('afa', False)],
          'afas': [('afa', False)],
          'afats': [('afa', False)],
          'affas': [('affa', False)],
          'aft': [('a', False)],
          'ag': [('aga', True)],
          'ag-': [('aga', True)],
          'aga': [('aga', False)],
          'agades': [('aga', True)],
          'agala': [('agalägga', False)],
          'agalas': [('agalägga', False)],
          'agande': [('aga', False)],
          'agandes': [('aga', True)],
          'agar': [('aga', False)],
          'agas': [('aga', True)],
          'agats': [('aga', False)],
          'agd': [('ägga', False)],
          'agda': [('ägga', False)],
          'agdas': [('ägga', False)],
          'agde': [('ägga', False)],
          'agdes': [('ägga', False)],
          'agds': [('ägga', False)],
          'age': [('a', False)],
          'agen': [('å', False)],
          'agens': [('å', False)],
          'aget': [('å', False)],
          'agets': [('å', False)],
          'aggades': [('agga', False)],
          'aggar': [('agga', False)],
          'aggas': [('agga', False)],
          'agit': [('å', False)],
          'agits': [('å', False)],
          'agla': [('agla', False)],
          'aglade': [('aglägga', False)],
          'aglades': [('aglägga', False)],
          'aglas': [('agla', False)],
          'agna': [('agna', True)],
          'agnades': [('agna', True)],
          'agnas': [('agna', False)],
          'agnat': [('agna', True)],
          'agne': [('å', False)],
          'agnerades': [('agnera', False)],
          'agneras': [('agnera', False)],
          'agnes': [('å', False)],
          'agrades': [('agra', False)],
          'agras': [('agra', False)],
          'ags': [('aga', False)],
          'agt': [('inga', False)],
          'agte': [('inga', False)],
          'agtes': [('inga', False)],
          'agts': [('ägga', False)],
          'ahållas': [('ahålla', False)],
          'ahållits': [('ahålla', False)],
          'ahålls': [('ahålla', False)],
          'ahölls': [('ahålla', False)],
          'aila': [('aila', False)],
          'aiserad': [('aisera', False)],
          'ajande': [('aja', False)],
          'ajats': [('aja', False)],
          'ajs': [('ajsa', False)],
          'ajtas': [('ajtas', False)],
          'ajtats': [('ajtas', False)],
          'akar': [('aka', False)],
          'akas': [('aka', False)],
          'akats': [('aka', False)],
          'aker': [('aka', False)],
          'akes': [('aka', False)],
          'akla': [('akla', False)],
          'aklar': [('akla', False)],
          'aknade': [('akna', False)],
          'aknades': [('akna', False)],
          'aknas': [('akna', False)],
          'aknat': [('akna', False)],
          'akomna': [('akomma', False)],
          'aks': [('aka', False)],
          'akt': [('akta', False)],
          'akta': [('akta', True)],
          'aktades': [('akta', False)],
          'aktas': [('akta', True)],
          'aktes': [('aka', False)],
          'alade': [('alägga', False)],
          'alades': [('ala', False)],
          'alats': [('ala', False)],
          'ald': [('älja', False)],
          'alda': [('älja', False)],
          'aldades': [('alda', False)],
          'aldas': [('ala', False)],
          'alde': [('älja', False)],
          'alds': [('älja', False)],
          'ale': [('ala', False)],
          'alen': [('ala', False)],
          'aler': [('ala', False)],
          'ales': [('ala', False)],
          'alet': [('ala', False)],
          'alets': [('ala', False)],
          'alit': [('ala', False)],
          'alits': [('ala', False)],
          'alkades': [('alka', False)],
          'alkas': [('alkas', False)],
          'alkats': [('alkas', False)],
          'allas': [('alla', False)],
          'alldes': [('alla', False)],
          'aller': [('allra', False)],
          'allna': [('allna', False)],
          'allnas': [('alla', False)],
          'allts': [('alla', False)],
          'alnades': [('alna', False)],
          'alnas': [('alna', False)],
          'alnats': [('alnas', False)],
          'als': [('ala', False)],
          'alskas': [('alska', False)],
          'alskats': [('alska', False)],
          'alte': [('ala', False)],
          'altes': [('ala', False)],
          'alv': [('älva', False)],
          'alät': [('aläta', False)],
          'aläte': [('aläta', False)],
          'alätes': [('aläta', False)],
          'aläts': [('aläta', False)],
          'alåt': [('aläta', False)],
          'alåte': [('aläta', False)],
          'alåtes': [('aläta', False)],
          'alåts': [('aläta', False)],
          'amas': [('ama', False)],
          'amats': [('ama', False)],
          'amgåtts': [('amgå', False)],
          'amlas': [('amla', False)],
          'ammades': [('amma', False)],
          'ammas': [('amma', False)],
          'amme': [('imma', False)],
          'ammer': [('amra', False)],
          'ammes': [('imma', False)],
          'amnades': [('amna', False)],
          'amnas': [('amna', False)],
          'ampades': [('ampa', False)],
          'ampas': [('ampa', False)],
          'amps': [('impa', False)],
          'amrades': [('amra', False)],
          'amras': [('amra', False)],
          'ams': [('imma', False)],
          'amsade': [('amsa', False)],
          'amsades': [('amsa', False)],
          'ana': [('ana', False)],
          'anar': [('ana', False)],
          'anats': [('ana', False)],
          'and': [('anda', False)],
          'anda': [('anda', False)],
          'andades': [('andas', True)],
          'andas': [('andas', True)],
          'andats': [('andas', False)],
          'ander': [('andra', False)],
          'andlade': [('andla', False)],
          'andlades': [('andla', False)],
          'ands': [('inda', False)],
          'anerats': [('anera', False)],
          'ang': [('inga', False)],
          'angades': [('anga', False)],
          'angas': [('anga', False)],
          'ange': [('ange', True)],
          'anger': [('ange', True)],
          'angs': [('inga', False)],
          'ankades': [('anka', False)],
          'ankna': [('ankna', False)],
          'anks': [('inka', False)],
          'anletts': [('anleda', False)],
          'ann': [('inna', False)],
          'annas': [('anna', False)],
          'anns': [('inna', False)],
          'anser': [('anse', True)],
          'anses': [('anse', True)],
          'anskas': [('anska', False)],
          'anskats': [('anska', False)],
          'ansköt': [('ansköta', False)],
          'anskötes': [('ansköta', False)],
          'ansköts': [('ansköta', False)],
          'ant': [('anta', False)],
          'ante': [('ante', True)],
          'antierades': [('antieras', False)],
          'antieras': [('antieras', False)],
          'antrats': [('antra', False)],
          'ants': [('inta', False)],
          'anvisades': [('anvisa', True)],
          'anvisats': [('anvisa', True)],
          'apar': [('apa', False)],
          'apats': [('apa', False)],
          'apel': [('apla', False)],
          'apel-': [('apla', False)],
          'apla': [('apla', False)],
          'aplas': [('apla', False)],
          'appades': [('appa', False)],
          'appas': [('appa', False)],
          'appats': [('appa', True)],
          'apper': [('appra', False)],
          'applade': [('appla', False)],
          'applades': [('appla', False)],
          'apps': [('ippa', False)],
          'aprad': [('apra', False)],
          'aprat': [('apra', False)],
          'apta': [('apa', False)],
          'aptas': [('apa', False)],
          'aptes': [('apa', False)],
          'arat': [('ara', False)],
          'arats': [('ara', False)],
          'ardades': [('arda', False)],
          'arde': [('arda', False)],
          'are': [('ara', False)],
          'aren': [('ara', False)],
          'arens': [('ara', False)],
          'ares': [('ara', False)],
          'aret': [('ara', False)],
          'arets': [('ara', False)],
          'argades': [('arga', False)],
          'argas': [('arga', False)],
          'argat': [('arga', False)],
          'argats': [('arga', False)],
          'arhållits': [('arhålla', False)],
          'arit': [('ara', False)],
          'arkades': [('arka', False)],
          'arkat': [('arka', False)],
          'arker': [('arkera', False)],
          'arklade': [('arkla', False)],
          'arklades': [('arkla', False)],
          'arklas': [('arkla', False)],
          'arlade': [('arlägga', False)],
          'arlades': [('arlägga', False)],
          'armades': [('arma', False)],
          'arna': [('ara', False)],
          'arnades': [('arna', False)],
          'arnas': [('arna', False)],
          'aro': [('ara', False)],
          'aro-': [('ara', False)],
          'arrades': [('arra', False)],
          'arras': [('arra', False)],
          'arrats': [('arra', True)],
          'ars': [('ära', False)],
          'arsa': [('arsa', False)],
          'arsade': [('arsa', False)],
          'arsades': [('arsa', False)],
          'arsas': [('arsa', False)],
          'arslade': [('arsla', False)],
          'arslades': [('arsla', False)],
          'arslas': [('arsla', False)],
          'art': [('arta', False)],
          'artades': [('artas', True)],
          'artas': [('artas', False)],
          'artats': [('artas', False)],
          'artla': [('artlägga', False)],
          'arts': [('artsa', False)],
          'arvar': [('arva', False)],
          'asa': [('asa', False)],
          'asade': [('asa', False)],
          'asades': [('asa', False)],
          'asas': [('asa', False)],
          'asats': [('asa', False)],
          'asatt': [('asätta', False)],
          'asatts': [('asätta', False)],
          'aschas': [('ascha', False)],
          'aska': [('aska', False)],
          'askad': [('aska', False)],
          'askade': [('aska', True)],
          'askades': [('aska', False)],
          'askar': [('aska', False)],
          'aspar': [('aspa', False)],
          'assades': [('assa', False)],
          'asslade': [('assla', False)],
          'ast': [('asta', False)],
          'ast-': [('asta', False)],
          'astades': [('asta', False)],
          'astande': [('asta', False)],
          'astandes': [('asta', False)],
          'aster': [('astra', False)],
          'asts': [('ista', False)],
          'ata': [('ata', False)],
          'atag-': [('ata', False)],
          'atagits': [('ata', False)],
          'atas': [('ata', False)],
          'atats': [('ata', False)],
          'ate': [('äta', False)],
          'ates': [('äta', False)],
          'atogs': [('ata', False)],
          'atrades': [('atra', False)],
          'atras': [('atra', False)],
          'ats': [('a', False)],
          'atsade': [('atsa', False)],
          'atsades': [('atsa', False)],
          'att': [('ätta', False)],
          'atta': [('ätta', False)],
          'attades': [('atta', False)],
          'attas': [('ätta', False)],
          'atte': [('ätta', False)],
          'atter': [('attra', False)],
          'attes': [('ätta', False)],
          'attla': [('attlägga', False)],
          'attlade': [('attla', False)],
          'attlades': [('attla', False)],
          'attlas': [('attla', False)],
          'attlats': [('attla', False)],
          'atts': [('ädja', False)],
          'aussas': [('aussa', False)],
          'aussats': [('aussa', False)],
          'av': [('e', False)],
          'ava': [('ava', True)],
          'avad': [('ava', False)],
          'avande': [('ava', False)],
          'avandes': [('ava', True)],
          'avann': [('avinna', False)],
          'avar': [('ava', True)],
          'avas': [('ava', True)],
          'avats': [('ava', False)],
          'avda': [('ava', False)],
          'avdas': [('ava', False)],
          'avel': [('avla', False)],
          'avel-': [('avla', False)],
          'aven': [('ava', False)],
          'avens': [('ava', False)],
          'aver': [('ava', False)],
          'aves': [('ava', False)],
          'avet': [('ava', False)],
          'avets': [('ava', False)],
          'avisats': [('avisa', False)],
          'avit': [('ava', False)],
          'avits': [('ava', False)],
          'avla': [('avla', True), ('avlägga', True)],
          'avlade': [('avlägga', True), ('avla', True)],
          'avlades': [('avla', True), ('avlägga', True)],
          'avlas': [('avlägga', True), ('avla', True)],
          'avled': [('avleda', True), ('avlida', True)],
          'avleds': [('avlida', True), ('avleda', True)],
          'avmattades': [('avmattas', True), ('avmatta', True)],
          'avmattas': [('avmatta', True), ('avmattas', True)],
          'avmattats': [('avmatta', True), ('avmattas', True)],
          'avna': [('ava', False)],
          'avred': [('avreda', True)],
          'avreds': [('avreda', True)],
          'avs': [('e', False)],
          'avsåg': [('avsåga', True), ('avse', True)],
          'axats': [('axa', False)],
          'ay-': [('aya', False)],
          'b': [('ba', False)],
          'b-': [('ba', False)],
          'ba': [('ba', False)],
          'back': [('backa', True)],
          'bad': [('bada', True), ('be', True)],
          'badad': [('bada', False)],
          'baddas': [('badda', True)],
          'bade': [('be', True)],
          'bades': [('be', True)],
          'bads': [('be', True)],
          'bakades': [('baka', False)],
          'bakt': [('baka', False)],
          'bakta': [('baka', False)],
          'baktas': [('baka', False)],
          'bal': [('bala', True)],
          'bala': [('bala', True)],
          'balade': [('bala', True)],
          'balas': [('bala', True)],
          'balkas': [('balka', False)],
          'balkats': [('balka', False)],
          'band': [('banda', True), ('binda', True)],
          'bandades': [('banda', True)],
          'bandas': [('banda', True)],
          'bandats': [('banda', True)],
          'bande': [('ba', False)],
          'bandes': [('ba', False)],
          'bank': [('banka', True)],
          'bankas': [('banka', True)],
          'bankats': [('banka', True)],
          'bann': [('banna', False)],
          'bar': [('bära', True)],
          'barades': [('bara', False)],
          'baras': [('bara', False)],
          'barkas': [('barka', False)],
          'barkats': [('barka', True)],
          'bas': [('basa', True)],
          'bat': [('ba', False)],
          'bbad': [('bba', False)],
          'bbade': [('bba', False)],
          'bbads': [('bba', False)],
          'bbar': [('bba', False)],
          'bbats': [('bba', False)],
          'bber': [('bbra', False)],
          'bber-': [('bbra', False)],
          'bblad': [('bbla', False)],
          'be': [('be', False)],
          'bed': [('be', False)],
          'beda': [('be', True)],
          'bedande': [('be', True)],
          'bedas': [('be', False)],
          'bedda': [('be', False)],
          'bedds': [('be', False)],
          'bede': [('be', False)],
          'bedes': [('be', True)],
          'bedj': [('be', False)],
          'bedja': [('be', True)],
          'bedjandes': [('be', False)],
          'bedjas': [('be', False)],
          'beds': [('be', False)],
          'befanns': [('befinnas', True), ('befinna', True)],
          'befinnas': [('befinnas', True), ('befinna', True)],
          'befinnes': [('befinnas', True), ('befinna', True)],
          'befinns': [('befinna', True), ('befinnas', True)],
          'befunnits': [('befinnas', True), ('befinna', True)],
          'behövas': [('behövas', True), ('behöva', True)],
          'behövdes': [('behövas', True), ('behöva', True)],
          'behöves': [('behövas', True), ('behöva', True)],
          'behövs': [('behövas', True), ('behöva', True)],
          'behövts': [('behöva', True), ('behövas', True)],
          'belade': [('belägga', False)],
          'belades': [('belägga', False)],
          'bele': [('bele', True)],
          'bele-': [('bele', True)],
          'belett': [('bele', True)],
          'ben': [('bena', True)],
          'benades': [('bena', True)],
          'benas': [('bena', True)],
          'benats': [('bena', True)],
          'ber': [('be', True)],
          'ber-': [('bera', False)],
          'berad': [('bera', False)],
          'berades': [('bera', False)],
          'beras': [('bera', False)],
          'bes': [('be', True)],
          'besatt': [('besitta', True), ('besätta', True)],
          'besatts': [('besitta', True), ('besätta', True)],
          'beser': [('bese', True)],
          'beses': [('bese', True)],
          'besvär': [('besvära', True), ('besvärja', True)],
          'besvär-': [('besvära', True), ('besvärja', True)],
          'besvära': [('besvärja', True), ('besvära', True)],
          'besvärande': [('besvärja', True), ('besvära', True)],
          'besvärandes': [('besvära', True), ('besvärja', True)],
          'besväras': [('besvärja', True), ('besvära', True)],
          'bet': [('bita', True), ('beta', True)],
          'betades': [('beta', False)],
          'bets': [('bitas', True), ('betsa', True), ('bita', True)],
          'bett': [('be', True)],
          'bevar': [('bevara', True)],
          'bidas': [('bida', True)],
          'bidats': [('bida', False)],
          'bikta': [('bikta', True)],
          'biktas': [('bikta', True)],
          'bila': [('bila', True), ('bilägga', True)],
          'bilade': [('bilägga', True), ('bila', True)],
          'bilades': [('bilägga', True), ('bila', True)],
          'bilas': [('bilägga', True), ('bila', True)],
          'bilda': [('bilda', False)],
          'bildades': [('bilda', True)],
          'bildas': [('bilda', True)],
          'bildats': [('bilda', False)],
          'billa': [('billa', False)],
          'billade': [('billa', False)],
          'billades': [('billa', False)],
          'billats': [('billa', False)],
          'binder': [('binda', False)],
          'binds': [('binda', False)],
          'bise': [('bise', False)],
          'biser': [('bise', False)],
          'bises': [('bise', False)],
          'bit': [('bita', True)],
          'bitas': [('bitas', True), ('bita', True)],
          'bitits': [('bitas', True), ('bita', True)],
          'bitnas': [('bita', True)],
          'bits': [('bitas', True), ('bita', True)],
          'bjudas': [('bjuda', False)],
          'bjudits': [('bjuda', False)],
          'bjuds': [('bjuda', False)],
          'bla': [('bla', False)],
          'blad': [('blada', True)],
          'blade': [('bla', False)],
          'blades': [('bla', False)],
          'blas': [('bla', False)],
          'blats': [('bla', False)],
          'blev': [('bli', False)],
          'bliv': [('bli', False)],
          'bliv-': [('bli', False)],
          'bliva': [('bli', False)],
          'blivande': [('bli', True)],
          'blivandes': [('bli', False)],
          'blive': [('bli', False)],
          'blockas': [('blocka', True)],
          'blog': [('bloga', True)],
          'bly': [('blya', True)],
          'blygas': [('blygas', True)],
          'bläd': [('bläda', True)],
          'bläda': [('bläda', True)],
          'blädande': [('bläda', True)],
          'blädas': [('bläda', True)],
          'bläst': [('blästa', True)],
          'blästa': [('blästa', True)],
          'blästas': [('blästa', True)],
          'blöd': [('blöda', True)],
          'blödes': [('blöda', True)],
          'blöds': [('blöda', False)],
          'blöt': [('blöta', True)],
          'blötes': [('blöta', True)],
          'blöts': [('blöta', True)],
          'blött': [('blöda', True), ('blöta', True)],
          'blötts': [('blöta', True), ('blöda', True)],
          'bo': [('bo', False)],
          'bo-': [('bo', False)],
          'bockats': [('bocka', False)],
          'bodda': [('bo', False)],
          'bol': [('bola', True)],
          'bola': [('bola', True)],
          'bollats': [('bolla', True)],
          'bombad': [('bomba', False)],
          'bombade': [('bomba', False)],
          'bombades': [('bomba', False)],
          'bombads': [('bomba', False)],
          'bonades': [('bona', False)],
          'bonas': [('bona', False)],
          'boniserad': [('bonisera', False)],
          'bor': [('bo', True)],
          'bord': [('borda', True)],
          'borda': [('borda', True)],
          'bordas': [('borda', False)],
          'borde': [('böra', True)],
          'bort': [('böra', True)],
          'bos': [('bo', False)],
          'bott': [('bo', False)],
          'boxades': [('boxas', True), ('boxa', True)],
          'boxas': [('boxa', True), ('boxas', True)],
          'boxats': [('boxas', True), ('boxa', True)],
          'brast': [('brista', True)],
          'brat': [('bra', False)],
          'brats': [('bra', False)],
          'bred': [('bre', False)],
          'bred-': [('bre', False)],
          'breda': [('bre', True)],
          'bredande': [('bre', False)],
          'bredandes': [('bre', True)],
          'bredas': [('bre', True)],
          'bredd': [('bre', True), ('bredda', True)],
          'bredda': [('bredda', True), ('bre', True)],
          'breddas': [('bre', True), ('bredda', True)],
          'bredde': [('bre', True)],
          'breddes': [('bre', True)],
          'bredds': [('bre', True)],
          'breder': [('bre', True)],
          'breds': [('bre', False)],
          'bres': [('bre', True)],
          'brett': [('bre', True)],
          'bretts': [('bre', True)],
          'bro': [('broa', True)],
          'bro-': [('broa', True)],
          'brodd': [('brodda', True)],
          'brodda': [('brodda', True)],
          'broddas': [('brodda', True)],
          'brottas': [('brottas', True)],
          'brottats': [('brottas', True)],
          'brunna': [('brinna', False)],
          'brunnas': [('brinna', True)],
          'brydd': [('bry', True)],
          'brydde': [('bry', True)],
          'bryddes': [('bry', True)],
          'brys': [('bry', True)],
          'brytts': [('bry', True)],
          'bräckas': [('bräcka', True)],
          'bräda': [('bräda', True)],
          'brädande': [('bräda', True)],
          'brädas': [('bräda', True)],
          'bräddas': [('brädda', True)],
          'bräkas': [('bräka', True)],
          'bräkes': [('bräka', True)],
          'bräks': [('bräka', True)],
          'bräktes': [('bräka', True)],
          'brändes': [('brännas', True), ('bränna', True)],
          'brännas': [('brännas', True), ('bränna', True)],
          'brännes': [('bränna', True)],
          'bränns': [('bränna', True), ('brännas', True)],
          'bränts': [('brännas', True), ('bränna', True)],
          'brådd': [('brå', False)],
          'brådda': [('brå', False)],
          'bråddas': [('brå', False)],
          'brådde': [('brå', False)],
          'bråddes': [('brås', True)],
          'brådds': [('brå', False)],
          'bråkades': [('bråka', False)],
          'bråkas': [('bråka', False)],
          'bråkats': [('bråka', False)],
          'brås': [('brås', True)],
          'brått': [('brå', False)],
          'bråtts': [('brås', True)],
          'brö': [('bröa', True)],
          'brö-': [('bröa', True)],
          'bröt': [('bryta', False)],
          'bs': [('bs', False)],
          'bubbats': [('bubba', True)],
          'buffades': [('buffa', True)],
          'buffats': [('buffa', True)],
          'buggats': [('bugga', True)],
          'bulna': [('bulna', True)],
          'bunt': [('bunta', True)],
          'bunta': [('bunta', True)],
          'buntas': [('bunta', True)],
          'bussas': [('bussa', True)],
          'bussats': [('bussa', True)],
          'bykt': [('byka', True)],
          'bytt': [('byta', False)],
          'bytts': [('byta', False)],
          'bädd': [('bädda', True)],
          'bädda': [('bädda', True)],
          'bäddas': [('bädda', True)],
          'bändas': [('bända', True)],
          'bänds': [('bända', True)],
          'bänslades': [('bänsla', True)],
          'bänslas': [('bänsla', True)],
          'bänt': [('bända', True)],
          'bänts': [('bända', True)],
          'bär': [('bära', False)],
          'bär-': [('bära', False)],
          'bära': [('bära', False)],
          'bärande': [('bära', False)],
          'bärandes': [('bära', False)],
          'bäras': [('bära', False)],
          'bärgades': [('bärga', True)],
          'bärgas': [('bärga', True)],
          'bärgats': [('bärga', True)],
          'båd-': [('båda', False)],
          'bådandes': [('båda', True)],
          'böjas': [('böja', True)],
          'böjd': [('böja', False)],
          'böjdes': [('böja', False)],
          'böjs': [('böja', True)],
          'böjt': [('böja', False)],
          'böjts': [('böja', False)],
          'böras': [('böra', False)],
          'börd': [('börda', False)],
          'börda': [('börda', False)],
          'bördas': [('börda', False)],
          'böst': [('bösta', True)],
          'bösta': [('bösta', True)],
          'böstas': [('bösta', True)],
          'böstats': [('bösta', True)],
          'ca': [('ca', False)],
          'cad': [('ca', False)],
          'cade': [('ca', False)],
          'cades': [('ca', False)],
          'cads': [('ca', False)],
          'campats': [('campa', True)],
          'cande': [('ca', False)],
          'candes': [('ca', False)],
          'car': [('ca', False)],
          'cas': [('ca', False)],
          'cat': [('ca', False)],
          'centa': [('centa', False)],
          'centas': [('centa', False)],
          'cerad': [('cera', False)],
          'cerades': [('cera', False)],
          'ceras': [('cera', False)],
          'charmades': [('charma', True)],
          'charmas': [('charma', True)],
          'charmats': [('charma', True)],
          'chat': [('cha', False)],
          'cierats': [('ciera', False)],
          'ciserad': [('cisera', False)],
          'cit': [('cit', False)],
          'ckar': [('cka', False)],
          'ckats': [('cka', False)],
          'cke': [('cka', False)],
          'cke-': [('cka', False)],
          'ckel': [('ckla', False)],
          'ckel-': [('ckla', False)],
          'cker': [('cka', False)],
          'cker-': [('ckra', False)],
          'ckes': [('cka', False)],
          'ckla': [('ckla', False)],
          'cklar': [('ckla', False)],
          'ckläs': [('ckläsa', False)],
          'cknade': [('ckna', False)],
          'cknades': [('ckna', False)],
          'cknas': [('ckna', False)],
          'cknat': [('ckna', False)],
          'ckrats': [('ckra', False)],
          'cksades': [('cksa', False)],
          'cksats': [('cksa', False)],
          'ckta': [('cka', False)],
          'cktas': [('cka', False)],
          'cktes': [('cka', False)],
          'crat': [('cra', False)],
          'crats': [('cra', False)],
          'd-': [('da', False)],
          'da': [('a', False)],
          'dad': [('da', False)],
          'daddas': [('dadda', True)],
          'dade': [('da', False)],
          'dades': [('da', False)],
          'dads': [('da', False)],
          'dag': [('daga', False)],
          'dagades': [('dagas', True)],
          'dagas': [('dagas', True)],
          'dagats': [('dagas', True)],
          'dala': [('dala', True)],
          'dalade': [('dala', True)],
          'dalas': [('dala', True)],
          'dalt': [('dalta', True)],
          'damp': [('dampa', True), ('dimpa', True)],
          'dampats': [('dampa', True)],
          'dan': [('dana', False)],
          'dandes': [('da', False)],
          'dar': [('da', False)],
          'das': [('a', False)],
          'dat': [('da', False)],
          'datt': [('datta', True)],
          'datta': [('datta', True)],
          'dattas': [('datta', True)],
          'dattats': [('datta', True)],
          'dbrändes': [('dbränna', False)],
          'dbrännas': [('dbränna', False)],
          'dbrännes': [('dbränna', False)],
          'dbränns': [('dbränna', False)],
          'dbränts': [('dbränna', False)],
          'dd': [('da', False)],
          'ddande': [('dda', False)],
          'ddas': [('dda', False)],
          'ddats': [('dda', False)],
          'dde': [('da', False)],
          'ddel': [('ddla', False)],
          'ddel-': [('ddla', False)],
          'ddelades': [('ddela', False)],
          'dder-': [('ddra', False)],
          'ddla': [('ddla', False)],
          'ddlas': [('ddla', False)],
          'ddrades': [('ddra', False)],
          'ddragits': [('ddra', False)],
          'ddras': [('ddra', False)],
          'ddrog': [('ddra', False)],
          'ddrogs': [('ddra', False)],
          'dds': [('', False)],
          'degat': [('dega', True)],
          'degats': [('dega', True)],
          'del': [('dela', False)],
          'del-': [('dela', False)],
          'dela': [('dela', False)],
          'delade': [('dela', True)],
          'delades': [('dela', True)],
          'delas': [('dela', False)],
          'delat': [('dela', False)],
          'dens': [('densa', False)],
          'der': [('dra', False)],
          'derad': [('dera', False)],
          'derades': [('dera', False)],
          'deras': [('dera', False)],
          'derfaras': [('derfaras', False)],
          'derfarits': [('derfaras', False)],
          'derfars': [('derfaras', False)],
          'derfors': [('derfaras', False)],
          'derfå': [('derfås', False)],
          'derfå-': [('derfås', False)],
          'derfåtts': [('derfås', False)],
          'dets': [('da', False)],
          'dflytt': [('dfly', False)],
          'dfägnades': [('dfägna', False)],
          'dfägnas': [('dfägna', False)],
          'dfägnats': [('dfägna', False)],
          'dfår': [('dfå', False)],
          'dfås': [('dfå', False)],
          'dga': [('dga', False)],
          'dgades': [('dgas', False)],
          'dgande': [('dga', False)],
          'dgar': [('dga', False)],
          'dgas': [('dgas', False)],
          'dgats': [('dga', False)],
          'dgicks': [('dgå', False)],
          'dgjord': [('dgöra', False)],
          'dgjorda': [('dgöra', False)],
          'dgjordas': [('dgöra', False)],
          'dhas': [('dha', False)],
          'dhållas': [('dhålla', False)],
          'dhållits': [('dhålla', False)],
          'dhålls': [('dhålla', False)],
          'dhölls': [('dhålla', False)],
          'dierats': [('diera', False)],
          'digades': [('diga', False)],
          'digas': [('diga', False)],
          'digna': [('digna', True)],
          'dignas': [('digna', True)],
          'dignerades': [('digneras', False)],
          'digneras': [('digneras', False)],
          'dikta': [('dikta', True)],
          'diktas': [('dikta', True)],
          'dila': [('dila', True)],
          'dilla': [('dilla', True)],
          'dillade': [('dilla', True)],
          'dillades': [('dilla', True)],
          'dillats': [('dilla', True)],
          'diserad': [('disera', False)],
          'djande': [('dja', False)],
          'djats': [('dja', False)],
          'dje': [('', False)],
          'djer': [('', False)],
          'djes': [('', False)],
          'djo': [('dja', False)],
          'dkar': [('dka', False)],
          'dkas': [('dka', False)],
          'dkats': [('dka', False)],
          'dkomna': [('dkomma', False)],
          'dkändes': [('dkänna', False)],
          'dkännas': [('dkänna', False)],
          'dkänns': [('dkännas', False)],
          'dkänts': [('dkänna', False)],
          'dkörd': [('dköra', False)],
          'dkörda': [('dköra', False)],
          'dla': [('dlägga', False)],
          'dlade': [('dla', False)],
          'dlades': [('dla', False)],
          'dlas': [('dlägga', False)],
          'dlats': [('dla', False)],
          'dled': [('dleda', False)],
          'dledas': [('dleda', False)],
          'dleddes': [('dleda', False)],
          'dledes': [('dleda', False)],
          'dleds': [('dleda', False)],
          'dlett': [('dleda', False)],
          'dletts': [('dleda', False)],
          'dlurades': [('dlura', False)],
          'dluras': [('dlura', False)],
          'dlurats': [('dlura', False)],
          'dlådda': [('dlåda', False)],
          'dlåddas': [('dlåda', False)],
          'dlådds': [('dlåda', False)],
          'dlått': [('dlåda', False)],
          'dlöd': [('dlöda', False)],
          'dlödes': [('dlöda', False)],
          'dlöds': [('dlöda', False)],
          'dna': [('dna', False)],
          'dnappades': [('dnappa', False)],
          'dnappas': [('dnappa', False)],
          'dnappats': [('dnappa', False)],
          'dnar': [('dna', False)],
          'dnas': [('da', False)],
          'dnats': [('dna', False)],
          'dockats': [('docka', True)],
          'dog': [('dö', False)],
          'doge': [('dö', False)],
          'doges': [('dö', True)],
          'dogs': [('dö', True)],
          'dold': [('dölja', False)],
          'doldas': [('dölja', True)],
          'dolt': [('dölja', True)],
          'domna': [('domna', False)],
          'donades': [('dona', True)],
          'donas': [('dona', True)],
          'dopp': [('doppa', True)],
          'doppats': [('doppa', True)],
          'dpussades': [('dpussa', False)],
          'dpussas': [('dpussa', False)],
          'dpussats': [('dpussa', False)],
          'dragits': [('dras', True), ('dra', True)],
          'dras': [('dra', True), ('dras', True)],
          'drat': [('dra', False)],
          'drats': [('dra', False)],
          'dravlade': [('dravla', True)],
          'drev': [('dreva', True), ('driva', True)],
          'drevar': [('dreva', True)],
          'drevs': [('driva', False)],
          'drivas': [('driva', False)],
          'drivits': [('driva', False)],
          'drivs': [('driva', True)],
          'drog': [('droga', True), ('dra', True)],
          'drogs': [('dras', True), ('dra', True)],
          'drottades': [('drotta', False)],
          'dräm': [('drämma', True)],
          'dräm-': [('drämma', True)],
          'drämt': [('drämma', True)],
          'drås': [('dråsa', True)],
          'dröjda': [('dröja', False)],
          'dröjdas': [('dröja', False)],
          'dröp': [('drypa', True)],
          'drör': [('dröra', False)],
          'drös': [('drösa', True)],
          'dröses': [('drösa', True)],
          'dröst': [('drösa', True)],
          'dsa': [('dsa', False)],
          'dsade': [('dsa', False)],
          'dsades': [('dsa', False)],
          'dsas': [('dsa', False)],
          'dsats': [('dsa', False)],
          'dsatt': [('dsätta', False)],
          'dsatts': [('dsätta', False)],
          'dsel': [('dsla', False)],
          'dsel-': [('dsla', False)],
          'dska': [('dska', False)],
          'dskade': [('dska', False)],
          'dskades': [('dska', False)],
          'dskar': [('dska', False)],
          'dskas': [('dskas', False)],
          'dskats': [('dskas', False)],
          'dskjuts': [('dskjuta', False)],
          'dskrev': [('dskriva', False)],
          'dsköt': [('dskjuta', False)],
          'dskötes': [('dskjuta', False)],
          'dsköts': [('dskjuta', False)],
          'dsla': [('dsla', False)],
          'dslades': [('dsla', False)],
          'dslagits': [('dslå', False)],
          'dslapp': [('dslippa', False)],
          'dslas': [('dsla', False)],
          'dslogs': [('dslå', False)],
          'dsnades': [('dsna', False)],
          'dsnar': [('dsna', False)],
          'dsnas': [('dsna', False)],
          'dsteg': [('dstiga', False)],
          'dstött': [('dstöta', False)],
          'dstötta': [('dstöta', False)],
          'dstöttas': [('dstöta', False)],
          'dstötte': [('dstöta', False)],
          'dstötts': [('dstöta', False)],
          'dsår': [('dså', False)],
          'dsås': [('dså', False)],
          'dta': [('dta', False)],
          'dtag-': [('dta', False)],
          'dtagits': [('dta', False)],
          'dtalades': [('dtala', False)],
          'dtas': [('dta', False)],
          'dtogs': [('dta', False)],
          'dubbats': [('dubba', True)],
          'duggats': [('dugga', True)],
          'dugit': [('duga', True)],
          'dummats': [('dumma', False)],
          'dumpats': [('dumpa', True)],
          'dunkas': [('dunka', True)],
          'dunkats': [('dunka', True)],
          'duvna': [('duvna', True)],
          'duvnas': [('duvna', True)],
          'dvaldes': [('dväljas', True)],
          'dvalts': [('dväljas', True)],
          'dvarades': [('dvara', False)],
          'dvaras': [('dvara', False)],
          'dvarats': [('dvara', False)],
          'dvek': [('dvika', False)],
          'dverkat': [('dverka', False)],
          'dväljas': [('dväljas', True)],
          'dväljes': [('dväljas', True)],
          'dväljs': [('dväljas', True)],
          'dvälts': [('dväljas', True)],
          'dvänt': [('dvända', False)],
          'dykt': [('dyka', True)],
          'däckats': [('däcka', True)],
          'dämde': [('dämma', True)],
          'dämts': [('dämma', False)],
          'dängs': [('dänga', True)],
          'därvas': [('därva', False)],
          'därvs': [('därva', False)],
          'dårades': [('dåra', False)],
          'dåras': [('dåra', False)],
          'dås': [('dåsa', True)],
          'dö': [('dö', False)],
          'dö-': [('dö', False)],
          'död': [('döda', True)],
          'död-': [('döda', True)],
          'dödandes': [('döda', True)],
          'dök': [('dyka', True)],
          'dökes': [('dyka', True)],
          'döks': [('dyka', True)],
          'döm': [('döma', False)],
          'döm-': [('döma', False)],
          'dömdes': [('döma', False)],
          'dömds': [('döma', False)],
          'döms': [('döma', False)],
          'döp': [('döpa', True)],
          'döpes': [('döpa', True)],
          'dör': [('dö', False)],
          'dös': [('dö', True)],
          'dött': [('dö', False)],
          'dötts': [('dö', True)],
          'dövades': [('döva', False)],
          'e': [('a', False)],
          'e-': [('a', False)],
          'ea': [('ea', False)],
          'ead': [('ea', False)],
          'eade': [('ea', False)],
          'eades': [('ea', False)],
          'eads': [('ea', False)],
          'eakades': [('eaka', False)],
          'eakta': [('eakta', False)],
          'eande': [('ea', False)],
          'eandes': [('ea', False)],
          'ear': [('ea', False)],
          'earades': [('eara', False)],
          'earas': [('eara', False)],
          'eas': [('ea', False)],
          'eat': [('ea', False)],
          'ebar': [('ebära', False)],
          'ebbades': [('ebba', True)],
          'ebbas': [('ebba', True)],
          'ebrännas': [('ebrännas', False)],
          'ebrännes': [('ebrännas', False)],
          'ebränns': [('ebrännas', False)],
          'ebråddes': [('ebrå', False)],
          'ebrås': [('ebrå', False)],
          'ebråtts': [('ebrå', False)],
          'eckades': [('ecka', False)],
          'eckas': [('ecka', False)],
          'ecklades': [('eckla', False)],
          'ecklas': [('eckla', False)],
          'ecklats': [('eckla', False)],
          'ed': [('ida', False)],
          'eda': [('eda', False)],
          'edande': [('eda', False)],
          'edandes': [('e', False)],
          'edas': [('eda', False)],
          'edats': [('eda', False)],
          'edd': [('e', False)],
          'edda': [('eda', False)],
          'eddas': [('e', False)],
          'edde': [('e', False)],
          'eddes': [('e', False)],
          'edds': [('eda', False)],
          'ede': [('ida', False)],
          'eder': [('e', False)],
          'edgats': [('edgas', False)],
          'edigats': [('ediga', False)],
          'edj': [('edja', False)],
          'edja': [('edja', False)],
          'edjande': [('e', False)],
          'edjandes': [('edja', False)],
          'edjas': [('edja', False)],
          'edla': [('edla', False)],
          'edlade': [('edlägga', False)],
          'edlades': [('edlägga', False)],
          'edlas': [('edla', False)],
          'edrades': [('edra', False)],
          'edragits': [('edra', False)],
          'edras': [('edra', False)],
          'edrev': [('edriva', False)],
          'edrog': [('edra', False)],
          'edrogs': [('edra', False)],
          'eds': [('ida', False)],
          'edskades': [('edskas', False)],
          'edskar': [('edskära', False)],
          'eed': [('eeda', False)],
          'eed-': [('eeda', False)],
          'eedandes': [('eeda', False)],
          'eerad': [('eera', False)],
          'eerades': [('eera', False)],
          'eeras': [('eera', False)],
          'eetades': [('eeta', False)],
          'efades': [('efa', False)],
          'efar': [('efara', False)],
          'efas': [('efa', False)],
          'efats': [('efa', False)],
          'efattades': [('efatta', False)],
          'efattas': [('efatta', False)],
          'efattats': [('efatta', False)],
          'efinns': [('efinnas', False)],
          'efordrades': [('efordra', False)],
          'efordras': [('efordra', False)],
          'efordrats': [('efordra', False)],
          'efors': [('efara', False)],
          'eg': [('iga', False)],
          'ega': [('ega', False)],
          'egande': [('ega', False)],
          'egar': [('ega', False)],
          'egat': [('igga', False)],
          'egats': [('igga', False)],
          'eggades': [('egga', False)],
          'eggar': [('egga', True)],
          'eggas': [('egga', True)],
          'egjord': [('egöra', False)],
          'egjorda': [('egöra', False)],
          'egjordas': [('egöra', False)],
          'egla': [('egla', False)],
          'eglas': [('egla', False)],
          'egna': [('egna', False)],
          'egnades': [('egna', False)],
          'egnas': [('egna', False)],
          'egnat': [('egna', False)],
          'egnerades': [('egnera', False)],
          'egneras': [('egnera', False)],
          'egrades': [('egra', False)],
          'egras': [('egra', False)],
          'egs': [('iga', False)],
          'egärd': [('egära', False)],
          'egärda': [('egära', False)],
          'egärdas': [('egära', False)],
          'egås': [('egå', False)],
          'egåtts': [('egå', False)],
          'ehandla': [('ehandla', False)],
          'ehandlade': [('ehandla', False)],
          'ehandlades': [('ehandla', False)],
          'ehandlas': [('ehandla', False)],
          'ehas': [('eha', False)],
          'ehållas': [('ehålla', False)],
          'ehållits': [('ehålla', False)],
          'ehålls': [('ehålla', False)],
          'ehölls': [('ehålla', False)],
          'eiserad': [('eisera', False)],
          'ejande': [('eja', False)],
          'ejats': [('eja', False)],
          'ejd': [('ejda', False)],
          'ejdades': [('ejda', False)],
          'ejer': [('eja', False)],
          'ejs': [('ejsa', False)],
          'ejt': [('ejta', False)],
          'ejtades': [('ejta', False)],
          'ekar': [('eka', False)],
          'ekas': [('eka', False)],
          'ekats': [('eka', False)],
          'eke': [('ika', False)],
          'eker': [('eka', False)],
          'ekes': [('eka', False)],
          'eknade': [('ekna', False)],
          'eknades': [('ekna', False)],
          'eknas': [('ekna', False)],
          'eknat': [('ekna', False)],
          'eknips': [('eknipa', False)],
          'ekomna': [('ekomma', False)],
          'eks': [('ika', False)],
          'ekta': [('eka', False)],
          'ektas': [('eka', False)],
          'ektes': [('eka', False)],
          'ekändes': [('ekänna', False)],
          'ekännas': [('ekänna', False)],
          'ekänns': [('ekänna', False)],
          'ekänts': [('ekänna', False)],
          'el': [('la', False)],
          'el-': [('la', False)],
          'ela': [('elägga', False)],
          'elade': [('ela', False)],
          'elades': [('ela', False)],
          'elas': [('elägga', False)],
          'elats': [('ela', False)],
          'eld': [('elda', True)],
          'elda': [('elda', True)],
          'eldades': [('elda', True)],
          'eldas': [('elda', True)],
          'ele': [('elea', False)],
          'ele-': [('elea', False)],
          'elear': [('elea', False)],
          'eleas': [('elea', False)],
          'eled': [('eleda', False)],
          'eledas': [('eleda', False)],
          'eleddes': [('eleda', False)],
          'eledes': [('eleda', False)],
          'eleds': [('eleda', False)],
          'elett': [('eleda', False)],
          'eletts': [('ele', False)],
          'elfaras': [('elfara', False)],
          'elfarits': [('elfara', False)],
          'elfars': [('elfara', False)],
          'elfors': [('elfara', False)],
          'elnades': [('elna', False)],
          'elnas': [('elna', False)],
          'eloges': [('ele', False)],
          'elte': [('ela', False)],
          'eltes': [('ela', False)],
          'elurades': [('elura', False)],
          'eluras': [('elura', False)],
          'elurats': [('elura', False)],
          'elä': [('eläa', False)],
          'emala': [('emalägga', False)],
          'emalas': [('emalägga', False)],
          'emas': [('ema', False)],
          'emats': [('ema', False)],
          'ement': [('ementa', False)],
          'emmades': [('emma', False)],
          'emmas': [('emma', False)],
          'empades': [('empa', False)],
          'empas': [('empa', False)],
          'emsade': [('emsa', False)],
          'emsades': [('emsa', False)],
          'emätt': [('emäta', False)],
          'emätta': [('emäta', False)],
          'emättas': [('emäta', False)],
          'emötas': [('emöta', False)],
          'emötes': [('emöta', False)],
          'emöts': [('emöta', False)],
          'emöttes': [('emöta', False)],
          'emötts': [('emöta', False)],
          'en': [('a', False)],
          'ena': [('ena', True)],
          'enades': [('ena', True), ('enas', True)],
          'enar': [('ena', False)],
          'enas': [('ena', True), ('enas', True)],
          'enats': [('enas', True), ('ena', True)],
          'end': [('ena', False)],
          'enda': [('ena', False)],
          'endas': [('ena', False)],
          'ende': [('', False)],
          'ender': [('endera', False)],
          'ender-': [('endera', False)],
          'endes': [('', False)],
          'endlade': [('endla', False)],
          'endlades': [('endla', False)],
          'ends': [('ena', False)],
          'enerats': [('enera', False)],
          'ennas': [('enna', False)],
          'ens': [('ensa', True)],
          'enskades': [('enskas', False)],
          'enskas': [('enska', False)],
          'enskats': [('enska', False)],
          'enslats': [('ensla', False)],
          'ent': [('enta', False)],
          'enta': [('ena', False)],
          'entas': [('ena', False)],
          'ente': [('ena', False)],
          'entes': [('ena', False)],
          'entierats': [('entiera', False)],
          'entrats': [('entra', False)],
          'ents': [('ena', False)],
          'envisas': [('envisas', True)],
          'eordrades': [('eordra', False)],
          'eordras': [('eordra', False)],
          'ep': [('ipa', False)],
          'epar': [('epa', False)],
          'epats': [('epa', False)],
          'eper': [('epa', False)],
          'epes': [('epa', False)],
          'eppades': [('eppa', False)],
          'eppas': [('eppa', False)],
          'eps': [('epa', False)],
          'epta': [('epa', False)],
          'eptas': [('epa', False)],
          'eptes': [('epa', False)],
          'er': [('a', False)],
          'er-': [('ra', False)],
          'erat': [('era', False)],
          'erats': [('era', False)],
          'erdel': [('erdela', False)],
          'erdel-': [('erdela', False)],
          'ered': [('ereda', False)],
          'ereda': [('ereda', False)],
          'eredande': [('ereda', False)],
          'eredds': [('ereda', False)],
          'ereds': [('ereda', False)],
          'erfaras': [('erfara', True)],
          'erfarits': [('erfara', True)],
          'erfars': [('erfara', True)],
          'erfors': [('erfara', True)],
          'erfå': [('erfå', False)],
          'erfå-': [('erfå', False)],
          'erfås': [('erfås', False)],
          'erfåtts': [('erfå', False)],
          'erhållits': [('erhålla', False)],
          'erkades': [('erka', False)],
          'erlade': [('erlägga', False)],
          'erlades': [('erlägga', False)],
          'erlista': [('erlista', False)],
          'erlistas': [('erlista', False)],
          'erodd': [('ero', False)],
          'eroddas': [('ero', False)],
          'eros': [('ero', False)],
          'ers': [('ersa', False)],
          'ersa': [('ersa', False)],
          'ersade': [('ersa', False)],
          'ersades': [('ersa', False)],
          'ersamlades': [('ersamla', False)],
          'ersamlats': [('ersamla', False)],
          'ersas': [('ersa', False)],
          'ersatts': [('ersätta', False)],
          'ervar': [('erva', False)],
          'eräknade': [('eräkna', False)],
          'eräknades': [('eräkna', False)],
          'eräknas': [('eräkna', False)],
          'eräknats': [('eräkna', False)],
          'erätt': [('erätta', False)],
          'erök': [('eröka', False)],
          'erör': [('eröra', False)],
          'erös': [('erösa', False)],
          'eröses': [('erösa', False)],
          'eröst': [('erösa', False)],
          'erösta': [('erösa', False)],
          'eröstas': [('erösa', False)],
          'es': [('a', False)],
          'esa': [('esa', False)],
          'esade': [('esa', False)],
          'esades': [('esa', False)],
          'esas': [('esa', False)],
          'esats': [('esa', False)],
          'esatt': [('esätta', False)],
          'esatts': [('esätta', False)],
          'eser': [('esa', False)],
          'eses': [('esa', False)],
          'eskjuts': [('eskjuta', False)],
          'eskrev': [('eskriva', False)],
          'eskydd': [('eskydda', False)],
          'eskydda': [('eskydda', False)],
          'eskyddas': [('eskydda', False)],
          'esköt': [('eskjuta', False)],
          'eskötes': [('eskjuta', False)],
          'esköts': [('eskjuta', False)],
          'eslagits': [('eslå', False)],
          'eslogs': [('eslå', False)],
          'esmitt': [('esmitta', False)],
          'esnades': [('esna', False)],
          'esnar': [('esna', False)],
          'esnas': [('esna', False)],
          'espråkades': [('espråka', False)],
          'espråkas': [('espråka', False)],
          'espråkats': [('espråka', False)],
          'espår': [('espå', False)],
          'essades': [('essa', False)],
          'essla': [('esslägga', False)],
          'esslades': [('esslägga', False)],
          'esslas': [('esslägga', False)],
          'est': [('esta', False)],
          'est-': [('esta', False)],
          'estack': [('esticka', False)],
          'estades': [('esta', False)],
          'estande': [('esta', False)],
          'estandes': [('esta', False)],
          'este': [('esa', False)],
          'esteg': [('estiga', False)],
          'estes': [('esa', False)],
          'esvor': [('esvärja', False)],
          'esvors': [('esvärja', False)],
          'esvure': [('esvärja', False)],
          'esvuren': [('esvärja', False)],
          'esvurens': [('esvärja', False)],
          'esvures': [('esvärja', False)],
          'esvuret': [('esvärja', False)],
          'esvurets': [('esvärja', False)],
          'esvurit': [('esvärja', False)],
          'esvurits': [('esvärja', False)],
          'esvurna': [('esvärja', False)],
          'esvurnas': [('esvärja', False)],
          'esvurne': [('esvärja', False)],
          'esvurnes': [('esvärja', False)],
          'esvärja': [('esvärja', False)],
          'esvärjande': [('esvärja', False)],
          'esvärjandes': [('esvärja', False)],
          'esvärjas': [('esvärja', False)],
          'esvärje': [('esvärja', False)],
          'esvärjer': [('esvärja', False)],
          'esvärjes': [('esvärja', False)],
          'esåg': [('ese', False)],
          'esår': [('eså', False)],
          'esås': [('eså', False)],
          'et': [('a', False)],
          'eta': [('eta', False)],
          'etades': [('etas', False)],
          'etag-': [('eta', False)],
          'etagits': [('eta', False)],
          'etalades': [('etala', False)],
          'etalde': [('etala', False)],
          'etaldes': [('etala', False)],
          'etalt': [('etala', False)],
          'etalts': [('etala', False)],
          'etas': [('eta', False)],
          'etats': [('eta', False)],
          'ete': [('ete', False)],
          'eter': [('ete', False)],
          'etes': [('ete', False)],
          'etnas': [('etna', False)],
          'etogs': [('eta', False)],
          'etroniserad': [('etronisera', False)],
          'eträd': [('eträda', False)],
          'eträd-': [('eträda', False)],
          'eträda': [('eträda', False)],
          'eträdande': [('eträda', False)],
          'eträdandes': [('eträda', False)],
          'eträdas': [('eträda', False)],
          'eträdd': [('eträda', False)],
          'eträdda': [('eträda', False)],
          'eträddas': [('eträda', False)],
          'eträdde': [('eträda', False)],
          'eträddes': [('eträda', False)],
          'eträdds': [('eträda', False)],
          'eträder': [('eträda', False)],
          'eträds': [('eträda', False)],
          'eträffades': [('eträffa', False)],
          'eträffas': [('eträffa', False)],
          'eträffats': [('eträffa', False)],
          'eträtt': [('eträda', False)],
          'eträtts': [('eträda', False)],
          'ets': [('etsa', True)],
          'etsade': [('etsa', False)],
          'etsades': [('etsa', False)],
          'ettades': [('etta', False)],
          'ette': [('eta', False)],
          'etter': [('ettra', False)],
          'ettlade': [('ettla', False)],
          'ettlades': [('ettla', False)],
          'ettlas': [('ettla', False)],
          'ettlats': [('ettla', False)],
          'etts': [('e', False)],
          'etäckas': [('etäcka', False)],
          'etäckes': [('etäcka', False)],
          'etäcks': [('etäcka', False)],
          'etäcktes': [('etäcka', False)],
          'etäckts': [('etäcka', False)],
          'eutvecklades': [('eutveckla', False)],
          'eutvecklas': [('eutveckla', False)],
          'eutvecklats': [('eutveckla', False)],
          'evad': [('eva', False)],
          'evande': [('eva', False)],
          'evandes': [('eva', False)],
          'evar': [('eva', False)],
          'evarades': [('evara', False)],
          'evaras': [('evara', False)],
          'evarats': [('evara', False)],
          'evare': [('evare', False)],
          'evas': [('eva', False)],
          'evats': [('eva', False)],
          'evda': [('eva', False)],
          'evdas': [('eva', False)],
          'eve': [('i', False)],
          'evek': [('eveka', False)],
          'evekes': [('eveka', False)],
          'eveks': [('eveka', False)],
          'ever': [('eva', False)],
          'eves': [('eva', False)],
          'evisas': [('evisa', False)],
          'evisats': [('evisa', False)],
          'evistades': [('evista', False)],
          'evistas': [('evista', False)],
          'evistats': [('evista', False)],
          'evlas': [('evla', False)],
          'evrades': [('evra', False)],
          'evras': [('evra', False)],
          'evrats': [('evras', False)],
          'evärandes': [('evära', False)],
          'evärdigades': [('evärdiga', False)],
          'evärdigas': [('evärdiga', False)],
          'evärdigats': [('evärdiga', False)],
          'exats': [('exa', False)],
          'ext': [('exta', False)],
          'exta': [('exta', False)],
          'f': [('fa', False)],
          'f-': [('fa', False)],
          'fa': [('fa', False)],
          'fad': [('fa', False)],
          'fade': [('fa', False)],
          'fads': [('fa', False)],
          'falkas': [('falka', True)],
          'falkats': [('falka', True)],
          'fall': [('falla', False)],
          'faller': [('falla', False)],
          'fallna': [('falla', False)],
          'falna': [('falna', True)],
          'falnats': [('falna', True)],
          'fals': [('falsa', True)],
          'famla': [('famla', True)],
          'famlade': [('famla', True)],
          'famlades': [('famla', True)],
          'famlats': [('famla', True)],
          'fande': [('fa', False)],
          'fandes': [('fa', False)],
          'fanns': [('finnas', True), ('finna', True)],
          'far': [('fara', True)],
          'farades': [('fara', False)],
          'faras': [('fara', False)],
          'farits': [('fara', False)],
          'farnas': [('fara', False)],
          'fars': [('fara', True)],
          'fas': [('fasa', True)],
          'fasades': [('fasa', True)],
          'fasas': [('fasa', True)],
          'fasats': [('fasa', True)],
          'fat': [('fa', False)],
          'fatt': [('fatta', False)],
          'fatta': [('fatta', False)],
          'fattades': [('fattas', True), ('fatta', True)],
          'fattas': [('fattas', True), ('fatta', True)],
          'fattats': [('fattas', True), ('fatta', True)],
          'fegat': [('fega', True)],
          'fegats': [('fega', True)],
          'fel': [('fela', False)],
          'fel-': [('fela', False)],
          'fela': [('fela', True)],
          'felades': [('felas', True), ('fela', True)],
          'felas': [('felas', True), ('fela', True)],
          'felat': [('fela', False)],
          'felats': [('felas', True), ('fela', True)],
          'fer': [('fra', False)],
          'ferad': [('fera', False)],
          'ferades': [('fera', False)],
          'feras': [('fera', False)],
          'fes': [('fisa', True)],
          'festa': [('festa', False)],
          'festas': [('festa', True)],
          'fett': [('fetta', False)],
          'fettas': [('fetta', False)],
          'fettats': [('fetta', False)],
          'ffades': [('ffa', False)],
          'ffar': [('ffa', False)],
          'ffats': [('ffa', False)],
          'ffel': [('ffla', False)],
          'ffel-': [('ffla', False)],
          'fierats': [('fiera', False)],
          'fila': [('fila', False)],
          'filt': [('filta', True)],
          'finge': [('få', False)],
          'finges': [('få', False)],
          'fingrades': [('fingra', True)],
          'fingras': [('fingra', True)],
          'finnas': [('finna', True), ('finnas', True)],
          'finnes': [('finnas', True), ('finna', True)],
          'finns': [('finnas', True), ('finna', True)],
          'fla': [('fla', False)],
          'flade': [('fla', False)],
          'flades': [('fla', False)],
          'flagnas': [('flagna', True)],
          'flam': [('flamma', True)],
          'flam-': [('flamma', True)],
          'flas': [('fla', False)],
          'flats': [('fla', False)],
          'flockades': [('flockas', True)],
          'flockas': [('flockas', True)],
          'flockats': [('flockas', True)],
          'flugna': [('flyga', False)],
          'flugnas': [('flyga', False)],
          'flummades': [('flumma', True)],
          'flummas': [('flumma', True)],
          'flutens': [('flyta', True)],
          'flutet': [('flyta', False)],
          'flutets': [('flyta', False)],
          'flutit': [('flyta', True)],
          'flutits': [('flyta', False)],
          'flutnas': [('flyta', False)],
          'flutne': [('flyta', True)],
          'flutnes': [('flyta', False)],
          'fly-': [('fly', True)],
          'flydd': [('fly', False)],
          'flydda': [('fly', True)],
          'flyddas': [('fly', False)],
          'flydde': [('fly', False)],
          'flyddes': [('fly', False)],
          'flydds': [('fly', False)],
          'flyges': [('flyga', False)],
          'flygs': [('flyga', True)],
          'flyr': [('fly', True)],
          'flys': [('fly', True)],
          'flytt': [('flytta', True), ('fly', True)],
          'flytts': [('fly', False)],
          'fläckas': [('fläcka', True)],
          'fläkt': [('fläkta', True), ('fläka', True)],
          'fläkta': [('fläkta', True), ('fläka', True)],
          'fläktades': [('fläkta', True)],
          'fläktas': [('fläka', True), ('fläkta', True)],
          'flängas': [('flänga', False)],
          'flängdes': [('flänga', True)],
          'flänges': [('flänga', False)],
          'flängs': [('flänga', True)],
          'flängts': [('flänga', True)],
          'flät': [('fläta', False)],
          'flådd': [('flå', True)],
          'flådde': [('flå', True)],
          'flåddes': [('flå', True)],
          'flås': [('flå', True), ('flåsa', True)],
          'flåtts': [('flå', True)],
          'flöd': [('flöda', True)],
          'flög': [('flyga', False)],
          'flöjt': [('flöjta', True)],
          'flöt': [('flyta', False)],
          'flöts': [('flyta', False)],
          'fnattades': [('fnatta', True)],
          'fnattas': [('fnatta', True)],
          'fnattats': [('fnatta', True)],
          'fnyst': [('fnysa', True)],
          'fockats': [('focka', True)],
          'fog': [('foga', False)],
          'foge': [('foga', True)],
          'for': [('fara', False)],
          'fordrades': [('fordras', True), ('fordra', True)],
          'fordras': [('fordras', True), ('fordra', True)],
          'fordrats': [('fordras', True), ('fordra', True)],
          'fors': [('fara', True), ('forsa', True)],
          'forsla': [('forsla', True)],
          'fr': [('fr', False)],
          'framla': [('framlägga', True)],
          'framlade': [('framlägga', True)],
          'framlades': [('framlägga', True)],
          'framlas': [('framlägga', True)],
          'framsade': [('framsäga', True)],
          'framsades': [('framsäga', True)],
          'frat': [('fra', False)],
          'frats': [('fra', False)],
          'fred': [('freda', True)],
          'fredas': [('freda', True)],
          'fresta': [('fresta', True)],
          'frestas': [('fresta', True)],
          'frila': [('frilägga', True)],
          'frisade': [('frisäga', True)],
          'frisades': [('frisäga', True)],
          'frysta': [('frysa', False)],
          'frystas': [('frysa', False)],
          'frät': [('fräta', True)],
          'frätes': [('fräta', True)],
          'fräts': [('fräta', False)],
          'frätt': [('fräta', False)],
          'frätta': [('fräta', False)],
          'frättas': [('fräta', True)],
          'frätte': [('fräta', True)],
          'frättes': [('fräta', False)],
          'frätts': [('fräta', False)],
          'fröjd': [('fröjda', True)],
          'fröjda': [('fröjda', True)],
          'fröjdades': [('fröjda', True), ('fröjdas', True)],
          'fröjdas': [('fröjda', True), ('fröjdas', True)],
          'fröjdats': [('fröjdas', True), ('fröjda', True)],
          'frös': [('frysa', False)],
          'fs': [('fsa', False)],
          'fsa': [('fsa', False)],
          'fsade': [('fsa', False)],
          'fsades': [('fsa', False)],
          'fsas': [('fsa', False)],
          'fsats': [('fsa', False)],
          'fser': [('fsa', False)],
          'fses': [('fsa', False)],
          'fste': [('fsa', False)],
          'fstes': [('fsa', False)],
          'ft': [('fta', False)],
          'fta': [('fta', False)],
          'ftas': [('fta', False)],
          'ftats': [('fta', False)],
          'fte': [('fta', False)],
          'fter': [('fta', False)],
          'ftes': [('fta', False)],
          'fts': [('', False)],
          'funkas': [('funka', True)],
          'funkats': [('funka', True)],
          'funna': [('finna', False)],
          'funnas': [('finna', False)],
          'funnits': [('finnas', True), ('finna', True)],
          'fylkades': [('fylkas', True), ('fylka', True)],
          'fylkas': [('fylka', True), ('fylkas', True)],
          'fylkats': [('fylka', True), ('fylkas', True)],
          'fyller': [('fylla', False)],
          'fä-': [('fäa', False)],
          'fägnades': [('fägnas', True), ('fägna', True)],
          'fägnas': [('fägnas', True), ('fägna', True)],
          'fägnats': [('fägnas', True), ('fägna', True)],
          'fäkta': [('fäkta', False)],
          'fäktades': [('fäktas', True), ('fäkta', True)],
          'fäktas': [('fäktas', True), ('fäkta', True)],
          'fäktats': [('fäktas', True), ('fäkta', True)],
          'fänats': [('fänas', False)],
          'fängslades': [('fängsla', True)],
          'fängslas': [('fängsla', True)],
          'fängslats': [('fängsla', True)],
          'fär': [('fära', False)],
          'färd': [('färda', False)],
          'färda': [('färda', False)],
          'färdades': [('färdas', True)],
          'färdas': [('färdas', True)],
          'färdats': [('färdas', True)],
          'färdigats': [('färdiga', False)],
          'färgades': [('färga', False)],
          'färgas': [('färga', True)],
          'färgats': [('färga', False)],
          'färglade': [('färglägga', True)],
          'färglades': [('färglägga', True)],
          'fästa': [('fästa', False)],
          'fästas': [('fästa', False)],
          'fäste': [('fästa', False)],
          'fäster': [('fästa', False)],
          'fästes': [('fästa', False)],
          'få': [('få', False)],
          'få-': [('få', True)],
          'fångats': [('fånga', False)],
          'får': [('få', True), ('fåra', True)],
          'fårades': [('fåra', True)],
          'fåras': [('fåra', True)],
          'fås': [('få', True)],
          'fått': [('få', True)],
          'fåtts': [('få', True)],
          'föd': [('föda', False)],
          'föd-': [('föda', False)],
          'födas': [('föda', True)],
          'födats': [('födas', False)],
          'födde': [('föda', False)],
          'föddes': [('föda', False)],
          'föder': [('föda', False)],
          'födes': [('föda', False)],
          'föds': [('föda', True)],
          'föll': [('falla', False)],
          'fölle': [('falla', False)],
          'förargades': [('förargas', True), ('förarga', True)],
          'förargas': [('förargas', True), ('förarga', True)],
          'förargats': [('förargas', True), ('förarga', True)],
          'föras': [('föra', False)],
          'fördes': [('föra', False)],
          'förfaras': [('förfaras', True), ('förfara', True)],
          'förfarits': [('förfaras', True), ('förfara', True)],
          'förfars': [('förfaras', True), ('förfara', True)],
          'förfors': [('förfaras', True), ('förfara', True)],
          'förfärades': [('förfära', True), ('förfäras', True)],
          'förfäras': [('förfära', True), ('förfäras', True)],
          'förfärats': [('förfära', True), ('förfäras', True)],
          'förgicks': [('förgå', True), ('förgås', True)],
          'förgås': [('förgå', True), ('förgås', True)],
          'förgåtts': [('förgå', True), ('förgås', True)],
          'förhållas': [('förhålla', True), ('förhållas', True)],
          'förhållits': [('förhållas', True), ('förhålla', True)],
          'förhålls': [('förhålla', True), ('förhållas', True)],
          'förhölls': [('förhålla', True), ('förhållas', True)],
          'förkrympas': [('förkrympas', True), ('förkrympa', True)],
          'förkrympes': [('förkrympa', True), ('förkrympas', True)],
          'förkrymps': [('förkrympa', True), ('förkrympas', True)],
          'förkrymptes': [('förkrympas', True), ('förkrympa', True)],
          'förkrympts': [('förkrympas', True), ('förkrympa', True)],
          'förla': [('förlägga', True)],
          'förlade': [('förlägga', True)],
          'förlades': [('förlägga', True)],
          'förlas': [('förlägga', True)],
          'förled': [('förlida', True), ('förleda', True)],
          'förleds': [('förlida', True), ('förleda', True)],
          'förlikas': [('förlika', True), ('förlikas', True)],
          'förlikes': [('förlika', True), ('förlikas', True)],
          'förliks': [('förlika', True), ('förlikas', True)],
          'förliktes': [('förlika', True), ('förlikas', True)],
          'förlikts': [('förlikas', True), ('förlika', True)],
          'församlades': [('församlas', True), ('församla', True)],
          'församlas': [('församla', True), ('församlas', True)],
          'församlats': [('församlas', True), ('församla', True)],
          'försatt': [('försätta', True), ('försitta', True)],
          'försatts': [('försitta', True), ('försätta', True)],
          'förskräckas': [('förskräcka', True), ('förskräckas', True)],
          'förskräckes': [('förskräckas', True), ('förskräcka', True)],
          'förskräcks': [('förskräckas', True), ('förskräcka', True)],
          'förskräcktes': [('förskräckas', True), ('förskräcka', True)],
          'förskräckts': [('förskräckas', True), ('förskräcka', True)],
          'försonades': [('försonas', True), ('försona', True)],
          'försonas': [('försonas', True), ('försona', True)],
          'försonats': [('försonas', True), ('försona', True)],
          'förstöras': [('förstöras', True), ('förstöra', True)],
          'förstördes': [('förstöra', True), ('förstöras', True)],
          'förstöres': [('förstöras', True), ('förstöra', True)],
          'förstörs': [('förstöras', True), ('förstöra', True)],
          'förstörts': [('förstöras', True), ('förstöra', True)],
          'försurades': [('försuras', True), ('försura', True)],
          'försuras': [('försuras', True), ('försura', True)],
          'försurats': [('försuras', True), ('försura', True)],
          'fört': [('föra', False)],
          'förts': [('föra', False)],
          'förvänt': [('förvända', True), ('förvänta', True)],
          'fösas': [('fösa', True)],
          'fötts': [('föda', True)],
          'g': [('ga', False)],
          'g-': [('ga', False)],
          'gabbats': [('gabba', False)],
          'gad': [('ga', False)],
          'gaddas': [('gadda', True)],
          'gade': [('ga', False)],
          'gades': [('ga', False)],
          'gads': [('ga', False)],
          'gakta': [('gakta', False)],
          'gal': [('gala', True)],
          'gala': [('gala', True)],
          'galades': [('galägga', False)],
          'galas': [('gala', True)],
          'galnades': [('galnas', True)],
          'galnas': [('galnas', True)],
          'galt': [('gala', True)],
          'galts': [('gala', True)],
          'galv': [('galva', True)],
          'gan': [('gana', True)],
          'gandes': [('ga', False)],
          'gar': [('gara', True)],
          'garades': [('gara', True)],
          'garas': [('gara', True)],
          'gas': [('ga', False)],
          'gat': [('ga', False)],
          'gboxades': [('gboxa', False)],
          'gboxas': [('gboxa', False)],
          'gboxats': [('gboxa', False)],
          'gd': [('ga', False)],
          'gde': [('ga', False)],
          'gdes': [('ga', False)],
          'gdragits': [('gdra', False)],
          'gdras': [('gdra', False)],
          'gdrog': [('gdra', False)],
          'gdrogs': [('gdra', False)],
          'gds': [('ga', False)],
          'ge': [('ge', True)],
          'gen': [('gena', True)],
          'genades': [('gena', True)],
          'genas': [('gena', True)],
          'genats': [('gena', True)],
          'gens': [('ga', False)],
          'genta': [('genta', True)],
          'gentas': [('genta', True)],
          'ger': [('ge', True)],
          'gerad': [('gera', False)],
          'gerades': [('gera', False)],
          'geras': [('gera', False)],
          'ges': [('ge', True)],
          'gett': [('ge', False)],
          'gfar': [('gfara', False)],
          'gfors': [('gfara', False)],
          'gga': [('gga', False)],
          'ggala': [('ggalägga', False)],
          'ggalas': [('ggalägga', False)],
          'ggande': [('gga', False)],
          'ggats': [('gga', False)],
          'gge': [('gga', False)],
          'ggen': [('gga', False)],
          'gger': [('gga', False)],
          'gges': [('gga', False)],
          'gget': [('gga', False)],
          'ggets': [('gga', False)],
          'ggicks': [('ggå', False)],
          'ggit': [('gga', False)],
          'ggjord': [('ggöra', False)],
          'ggjorda': [('ggöra', False)],
          'ggjordas': [('ggöra', False)],
          'ggla': [('ggla', False)],
          'gglas': [('ggla', False)],
          'ggna': [('gga', False)],
          'ggnas': [('gga', False)],
          'ggne': [('gga', False)],
          'ggs': [('gga', False)],
          'ghållas': [('ghålla', False)],
          'ghållits': [('ghålla', False)],
          'ghålls': [('ghålla', False)],
          'ghölls': [('ghålla', False)],
          'gicks': [('gå', True)],
          'gierats': [('giera', False)],
          'giftas': [('giftas', True)],
          'gigades': [('giga', True)],
          'gigas': [('giga', True)],
          'gilla': [('gilla', True)],
          'gillade': [('gilla', False)],
          'gillades': [('gillas', True), ('gilla', True)],
          'gillas': [('gillas', True), ('gilla', True)],
          'gillats': [('gillas', True), ('gilla', True)],
          'gilldes': [('gillas', True)],
          'gillts': [('gillas', True)],
          'ginge': [('gå', False)],
          'ginges': [('gå', False)],
          'gips': [('gipsa', True)],
          'giserad': [('gisera', False)],
          'gista': [('gista', True)],
          'gistas': [('gista', True)],
          'gistats': [('gista', True)],
          'gitter': [('gitta', True)],
          'gitts': [('gitta', True)],
          'given': [('ge', False)],
          'gives': [('ge', False)],
          'gjord': [('gjorda', True), ('göra', True)],
          'gjorda': [('gjorda', True), ('göra', True)],
          'gjordas': [('gjorda', True), ('göra', True)],
          'gjuts': [('gjuta', False)],
          'gkomna': [('gkomma', False)],
          'gladdes': [('glädja', True), ('glädjas', True)],
          'glade': [('gla', False)],
          'glades': [('gla', False)],
          'glas': [('glasa', True)],
          'glats': [('gla', False)],
          'glatt': [('glädja', True), ('glatta', True)],
          'glatts': [('glädja', True), ('glädjas', True)],
          'gled': [('glida', True)],
          'gledas': [('gledas', False)],
          'gledats': [('gledas', False)],
          'gleddes': [('gledas', False)],
          'gledes': [('gleda', False)],
          'gleds': [('glida', True)],
          'gler': [('glera', False)],
          'gles': [('glesa', False)],
          'glett': [('gleda', False)],
          'gletts': [('gledas', False)],
          'glist': [('glisa', True)],
          'glott': [('glo', True)],
          'glunkades': [('glunkas', True), ('glunka', True)],
          'glunkas': [('glunkas', True), ('glunka', True)],
          'glunkats': [('glunkas', True), ('glunka', True)],
          'gläd': [('glädja', True)],
          'glädes': [('glädja', True), ('glädjas', True)],
          'glädjas': [('glädja', True), ('glädjas', True)],
          'gläds': [('glädja', True), ('glädjas', True)],
          'glänt': [('glänta', True)],
          'glätt': [('glätta', True)],
          'glöd': [('glöda', True)],
          'glödes': [('glöda', True)],
          'glöds': [('glöda', True)],
          'glöt': [('glöta', True)],
          'gnabbats': [('gnabbas', True)],
          'gnager': [('gnaga', True)],
          'gnar': [('gna', False)],
          'gnat': [('gnata', True)],
          'gnats': [('gna', False)],
          'gnerats': [('gnera', False)],
          'gnos': [('gno', True)],
          'gny-': [('gny', True)],
          'gnys': [('gny', True)],
          'go-': [('ga', False)],
          'gol': [('gola', True), ('gala', True)],
          'gola': [('gola', True)],
          'gordnas': [('gordna', False)],
          'grat': [('gra', False)],
          'grats': [('gra', False)],
          'gravla': [('gravlägga', True)],
          'gravlades': [('gravlägga', True)],
          'gravlas': [('gravlägga', True)],
          'grenades': [('grenas', False)],
          'grenas': [('grenas', False)],
          'grenats': [('grenas', False)],
          'grep': [('gripa', False)],
          'grodd': [('gro', True), ('grodda', True)],
          'grodda': [('grodda', True), ('gro', True)],
          'groddas': [('grodda', True), ('gro', True)],
          'gros': [('gro', True)],
          'grov': [('grava', False)],
          'grunna': [('grunna', True)],
          'grunnas': [('grunna', True)],
          'grydd': [('gry', True)],
          'grydde': [('gry', True)],
          'gryddes': [('gry', True)],
          'grymmas': [('grymma', False)],
          'grys': [('gry', True)],
          'grytts': [('gry', True)],
          'gräddas': [('grädda', False)],
          'gräknade': [('gräknad', False)],
          'grämde': [('gräma', True)],
          'grämt': [('gräma', True)],
          'grännas': [('gränna', False)],
          'grät': [('gråta', True)],
          'grävas': [('gräva', True)],
          'gräves': [('gräva', False)],
          'grävs': [('gräva', False)],
          'grök': [('gröka', False)],
          'gsatt': [('gsätta', False)],
          'gsatts': [('gsätta', False)],
          'gsel': [('gsla', False)],
          'gsel-': [('gsla', False)],
          'gskjuts': [('gskjuta', False)],
          'gskörd': [('gsköra', False)],
          'gskörda': [('gsköra', False)],
          'gskördas': [('gsköra', False)],
          'gsköt': [('gskjuta', False)],
          'gskötes': [('gskjuta', False)],
          'gsköts': [('gskjuta', False)],
          'gsla': [('gsla', False)],
          'gslagits': [('gslå', False)],
          'gslogs': [('gslå', False)],
          'gsnades': [('gsna', False)],
          'gsnar': [('gsna', False)],
          'gsnas': [('gsna', False)],
          'gt': [('ga', False)],
          'gta': [('gta', False)],
          'gtag-': [('gta', False)],
          'gtagits': [('gta', False)],
          'gtas': [('gta', False)],
          'gtats': [('gta', False)],
          'gtogs': [('gta', False)],
          'gts': [('ga', False)],
          'gubbades': [('gubbas', False)],
          'gubbas': [('gubbas', False)],
          'gullades': [('gulla', True)],
          'gullas': [('gulla', True)],
          'gullats': [('gulla', True)],
          'gulna': [('gulna', True)],
          'gumpats': [('gumpa', True)],
          'guppats': [('guppa', True)],
          'gvänt': [('gvända', False)],
          'gyller': [('gylla', False)],
          'gynte': [('gynna', False)],
          'gyntes': [('gynna', False)],
          'gynts': [('gynna', False)],
          'gäckades': [('gäckas', True), ('gäcka', True)],
          'gäckas': [('gäckas', True), ('gäcka', True)],
          'gäckats': [('gäcka', True), ('gäckas', True)],
          'gäld': [('gälda', False)],
          'gälda': [('gälda', False)],
          'gäldas': [('gälda', False)],
          'gällades': [('gälla', True)],
          'gällats': [('gälla', True)],
          'gär': [('gära', False)],
          'gärande': [('gära', False)],
          'gäras': [('gära', False)],
          'gärd': [('gärda', True)],
          'gärda': [('gärda', False)],
          'gärdas': [('gärda', False)],
          'gärdats': [('gärda', False)],
          'gärdes': [('gära', False)],
          'gärt': [('gära', False)],
          'gästa': [('gästa', True)],
          'gästas': [('gästa', True)],
          'gätnas': [('gäta', False)],
          'gå': [('gå', False)],
          'gångats': [('gånga', True)],
          'går': [('gå', False)],
          'gås': [('gå', True)],
          'gått': [('gå', False)],
          'gåtts': [('gå', True)],
          'göd': [('göda', False)],
          'göd-': [('göda', True)],
          'gödandes': [('göda', False)],
          'gödd': [('göda', False)],
          'göddes': [('göda', True)],
          'gömd': [('gömma', True)],
          'gömda': [('gömma', True)],
          'gömdas': [('gömma', True)],
          'gömde': [('gömma', False)],
          'göms': [('gömma', False)],
          'gömt': [('gömma', False)],
          'gömts': [('gömma', True)],
          'göras': [('göra', False)],
          'gördel': [('gördla', True)],
          'gördel-': [('gördla', True)],
          'göt': [('gjuta', False)],
          'götes': [('gjuta', True)],
          'göts': [('gjuta', False)],
          'h': [('ha', False)],
          'h-': [('ha', False)],
          'ha': [('ha', False)],
          'hack': [('hacka', False)],
          'had': [('ha', False)],
          'hade': [('ha', False)],
          'hades': [('ha', False)],
          'hads': [('ha', False)],
          'hagades': [('haga', False)],
          'hagandes': [('haga', False)],
          'hagas': [('haga', False)],
          'haglade': [('hagla', True)],
          'haglades': [('hagla', True)],
          'hakades': [('haka', True)],
          'hal': [('hala', True)],
          'hala': [('hala', False)],
          'halade': [('hala', False)],
          'halas': [('hala', True)],
          'halkas': [('halka', True)],
          'halkats': [('halka', True)],
          'hals': [('halsa', True)],
          'hamla': [('hamla', True)],
          'hamlade': [('hamla', True)],
          'hamlades': [('hamla', True)],
          'hamlats': [('hamla', True)],
          'hande': [('ha', False)],
          'handes': [('ha', False)],
          'handla': [('handlägga', True), ('handla', True)],
          'handlade': [('handlägga', True), ('handla', True)],
          'handlades': [('handlägga', True), ('handla', True)],
          'handlas': [('handlägga', True), ('handla', True)],
          'hank': [('hanka', True)],
          'hankas': [('hanka', True)],
          'hankats': [('hanka', True)],
          'happ': [('happa', False)],
          'happats': [('happa', False)],
          'har': [('ha', False)],
          'harmades': [('harmas', True), ('harma', True)],
          'harmas': [('harmas', True), ('harma', True)],
          'harmats': [('harmas', True), ('harma', True)],
          'has': [('hasa', True), ('ha', True)],
          'hat': [('hata', True)],
          'hatt': [('hatta', True)],
          'hatta': [('hatta', False)],
          'hattas': [('hatta', False)],
          'hattats': [('hatta', False)],
          'hava': [('ha', True)],
          'havande': [('ha', False)],
          'havandes': [('ha', False)],
          'havas': [('ha', False)],
          'haver': [('ha', False)],
          'hefar': [('hefa', False)],
          'hel': [('hela', True)],
          'hel-': [('hela', True)],
          'hela': [('hela', True)],
          'helas': [('hela', True)],
          'helat': [('hela', True)],
          'henades': [('hena', True)],
          'henas': [('hena', True)],
          'henats': [('hena', True)],
          'her': [('hera', False)],
          'her-': [('hera', False)],
          'herad': [('hera', False)],
          'herades': [('hera', False)],
          'heras': [('hera', False)],
          'het': [('heta', True)],
          'heter': [('heta', True)],
          'hets': [('hetsa', False)],
          'hett': [('hetta', False)],
          'hettas': [('hetta', True)],
          'hettats': [('hetta', True)],
          'hick': [('hicka', True)],
          'hilla': [('hilla', False)],
          'hillade': [('hilla', False)],
          'hillades': [('hilla', False)],
          'hillats': [('hilla', False)],
          'hinnes': [('hinna', True)],
          'hinns': [('hinna', True)],
          'hiv': [('hiva', True)],
          'hiv-': [('hiva', True)],
          'hiva': [('hiva', True)],
          'hivades': [('hiva', True)],
          'hivande': [('hiva', True)],
          'hivandes': [('hiva', True)],
          'hivas': [('hiva', True)],
          'hockats': [('hocka', False)],
          'hopp': [('hoppa', True)],
          'hoppades': [('hoppas', True), ('hoppa', True)],
          'hoppas': [('hoppas', True), ('hoppa', True)],
          'hoppats': [('hoppas', True), ('hoppa', True)],
          'hor': [('hora', True)],
          'hottas': [('hotta', False)],
          'hottats': [('hotta', True)],
          'hov': [('häva', False)],
          'hovs': [('häva', False)],
          'htades': [('htas', False)],
          'htas': [('htas', False)],
          'huggas': [('hugga', True)],
          'hugges': [('hugga', False)],
          'huggits': [('hugga', False)],
          'huggs': [('hugga', True)],
          'hugna': [('hugna', True)],
          'hugnas': [('hugna', True)],
          'hummats': [('humma', True)],
          'hunna': [('hinna', True)],
          'hunnas': [('hinna', True)],
          'hunnits': [('hinna', True)],
          'hunt': [('hunta', False)],
          'hunta': [('hunta', False)],
          'huntas': [('hunta', False)],
          'hvår': [('hvåra', False)],
          'hvårades': [('hvåra', False)],
          'hvåras': [('hvåra', False)],
          'hvårats': [('hvåra', False)],
          'hydd': [('hyda', False)],
          'hydde': [('hyda', False)],
          'hyddes': [('hyda', False)],
          'hys': [('hysa', False)],
          'hyst': [('hysa', True), ('hysta', True)],
          'hysta': [('hysta', True), ('hysa', True)],
          'hystas': [('hysta', True), ('hysa', True)],
          'hytt': [('hytta', True)],
          'hytta': [('hytta', True)],
          'hyttas': [('hytta', True)],
          'hytte': [('hytta', True)],
          'hytter': [('hytta', True)],
          'hyttes': [('hytta', True)],
          'hytts': [('hytta', True)],
          'hyvas': [('hyva', True)],
          'häckats': [('häcka', True)],
          'häd-': [('häda', True)],
          'hädandes': [('häda', True)],
          'hädd': [('häda', True)],
          'häddas': [('häda', True)],
          'hädde': [('häda', True)],
          'häddes': [('häda', True)],
          'hägnats': [('hägna', False)],
          'häktats': [('häkta', True)],
          'hämnades': [('hämnas', True), ('hämna', True)],
          'hämnas': [('hämnas', True), ('hämna', True)],
          'hämnats': [('hämnas', True), ('hämna', True)],
          'hämt': [('hämta', True)],
          'händas': [('hända', True)],
          'händs': [('hända', True)],
          'hängs': [('hänga', False)],
          'hänt': [('hända', True)],
          'hänts': [('hända', False)],
          'härd': [('härda', False)],
          'härda': [('härda', False)],
          'härdas': [('härda', False)],
          'härdats': [('härda', False)],
          'härjande': [('härja', False)],
          'hätt': [('häda', True)],
          'hätts': [('häda', True)],
          'hävd': [('hävda', True), ('häva', True)],
          'hävda': [('hävda', True), ('häva', True)],
          'hävdas': [('hävda', True), ('häva', True)],
          'hävdes': [('häva', True)],
          'hävts': [('häva', False)],
          'håla': [('håla', True)],
          'hålade': [('håla', True)],
          'hålades': [('håla', True)],
          'hålas': [('håla', True)],
          'hållas': [('hållas', True), ('hålla', True)],
          'hållits': [('hållas', True), ('hålla', True)],
          'hålls': [('hållas', True), ('hålla', True)],
          'höggs': [('hugga', True)],
          'höjas': [('höja', False)],
          'höjd': [('höja', False)],
          'höjdes': [('höja', True)],
          'höjs': [('höja', True)],
          'höjt': [('höja', False)],
          'höjts': [('höja', True)],
          'hölles': [('hålla', False)],
          'hölls': [('hållas', True), ('hålla', True)],
          'höras': [('höra', False)],
          'hördes': [('höra', False)],
          'hört': [('höra', False)],
          'hörts': [('höra', False)],
          'höst': [('hösta', True)],
          'hösta': [('hösta', True)],
          'höstades': [('höstas', True), ('hösta', True)],
          'höstas': [('hösta', True), ('höstas', True)],
          'höstats': [('hösta', True), ('höstas', True)],
          'hötes': [('höta', True)],
          'hött': [('hötta', True), ('höta', True)],
          'hötta': [('hötta', True)],
          'höttas': [('hötta', True)],
          'höttats': [('hötta', True)],
          'hötte': [('hötta', True), ('höta', True)],
          'hötter': [('hötta', True), ('höta', True)],
          'höttes': [('hötta', True), ('höta', True)],
          'hötts': [('hötta', True), ('höta', True)],
          'höv': [('höva', False)],
          'hövas': [('hövas', False)],
          'hövdes': [('hövas', True)],
          'höves': [('hövas', False)],
          'hövts': [('hövas', True)],
          'i': [('ia', False)],
          'i-': [('ia', False)],
          'ia': [('ia', False)],
          'iad': [('ia', False)],
          'iade': [('ia', False)],
          'iades': [('ia', False)],
          'iads': [('ia', False)],
          'iande': [('ia', False)],
          'iandes': [('ia', False)],
          'iar': [('ia', False)],
          'ias': [('ia', False)],
          'iat': [('ia', False)],
          'ibbades': [('ibba', False)],
          'ibbas': [('ibba', False)],
          'ick': [('å', False)],
          'ickades': [('icka', False)],
          'ickas': [('icka', False)],
          'icker': [('ickra', False)],
          'icklades': [('ickla', False)],
          'icklas': [('ickla', False)],
          'icklats': [('ickla', False)],
          'icks': [('å', False)],
          'ickts': [('icka', False)],
          'id': [('ida', False)],
          'ida': [('ida', False)],
          'idande': [('ida', False)],
          'idas': [('idas', True)],
          'idats': [('idas', True)],
          'idda': [('ida', False)],
          'iddas': [('ida', False)],
          'iddes': [('idas', True)],
          'idds': [('ida', False)],
          'ide': [('ida', False)],
          'idens': [('ida', False)],
          'ider': [('ida', False)],
          'ides': [('idas', True)],
          'idgades': [('idga', False)],
          'idgas': [('idga', False)],
          'idits': [('ida', False)],
          'idkännas': [('idkännas', False)],
          'idna': [('ida', False)],
          'idrades': [('idra', False)],
          'idragits': [('idra', False)],
          'idras': [('idra', False)],
          'idrog': [('idra', False)],
          'idrogs': [('idra', False)],
          'ids': [('idas', True)],
          'iefar': [('iefa', False)],
          'ierad': [('iera', False)],
          'ierades': [('iera', False)],
          'ieras': [('iera', False)],
          'ifades': [('ifa', False)],
          'ifar': [('ifa', False)],
          'ifas': [('ifa', False)],
          'ifats': [('ifa', False)],
          'iffas': [('iffa', False)],
          'iftes': [('iftas', False)],
          'ifts': [('iftas', False)],
          'ifylld': [('fylla_i', True)],
          'iga': [('iga', False)],
          'igande': [('iga', False)],
          'igar': [('iga', False)],
          'igats': [('iga', False)],
          'ige': [('iga', False)],
          'igen': [('iga', False)],
          'iger': [('iga', False)],
          'iges': [('iga', False)],
          'iget': [('iga', False)],
          'igets': [('iga', False)],
          'iggades': [('igga', False)],
          'iggar': [('igga', False)],
          'iggas': [('igga', False)],
          'igit': [('iga', False)],
          'igits': [('iga', False)],
          'igjord': [('igöra', False)],
          'igjorda': [('igöra', False)],
          'igjordas': [('igöra', False)],
          'igla': [('igla', False)],
          'iglas': [('igla', False)],
          'igna': [('iga', False)],
          'ignades': [('igna', False)],
          'ignas': [('iga', False)],
          'ignat': [('igna', False)],
          'igne': [('iga', False)],
          'ignerades': [('ignera', False)],
          'igneras': [('ignera', False)],
          'ignerats': [('igneras', False)],
          'igs': [('iga', False)],
          'ikappades': [('ikappa', False)],
          'ikappas': [('ikappa', False)],
          'ikappats': [('ikappa', False)],
          'ikar': [('ika', False)],
          'ikas': [('ika', False)],
          'ikats': [('ika', False)],
          'ike': [('ika', False)],
          'iken': [('ika', False)],
          'ikens': [('ika', False)],
          'iker': [('ika', False)],
          'ikes': [('ika', False)],
          'iket': [('ika', False)],
          'ikets': [('ika', False)],
          'ikit': [('ika', False)],
          'ikits': [('ika', False)],
          'ikna': [('ika', False)],
          'iknade': [('ikna', False)],
          'iknades': [('ikna', False)],
          'iknas': [('ikna', False)],
          'iknat': [('ikna', False)],
          'ikne': [('ika', False)],
          'iko': [('ika', False)],
          'iko-': [('ika', False)],
          'ikrats': [('ikra', False)],
          'iks': [('ika', False)],
          'ikt': [('ikta', False)],
          'iktades': [('ikta', False)],
          'iktes': [('ika', False)],
          'iktigades': [('iktiga', False)],
          'iktigas': [('iktiga', False)],
          'ikändes': [('ikänna', False)],
          'ikännas': [('ikänna', False)],
          'ikänns': [('ikänna', False)],
          'ikänts': [('ikänna', False)],
          'ila': [('ila', True)],
          'ilade': [('ila', False)],
          'ilades': [('ila', False)],
          'ilas': [('ila', False)],
          'ilats': [('ila', False)],
          'ild': [('ilda', False)],
          'ilda': [('ilja', False)],
          'ildats': [('ildas', False)],
          'ilde': [('ilja', False)],
          'ildrats': [('ildra', False)],
          'ilds': [('ilja', False)],
          'ile': [('ilea', False)],
          'ile-': [('ilea', False)],
          'ilear': [('ilea', False)],
          'ileas': [('ilea', False)],
          'iljas': [('ilja', False)],
          'ilkades': [('ilka', False)],
          'ill': [('illa', False)],
          'illas': [('illa', False)],
          'illdes': [('illa', False)],
          'ille': [('ilja', False)],
          'iller': [('illra', False)],
          'illkomna': [('illkomma', False)],
          'illna': [('illna', False)],
          'ills': [('illas', False)],
          'illts': [('illa', False)],
          'ils': [('iljas', False)],
          'ilskades': [('ilskas', False)],
          'ilt': [('ilja', False)],
          'ilurades': [('ilura', False)],
          'iluras': [('ilura', False)],
          'ilurats': [('ilura', False)],
          'im': [('imma', False)],
          'im-': [('imma', False)],
          'imas': [('ima', False)],
          'imats': [('ima', False)],
          'imlas': [('imla', False)],
          'immades': [('imma', False)],
          'immas': [('imma', False)],
          'immer': [('imra', False)],
          'impades': [('impa', True)],
          'impas': [('impa', False)],
          'imrades': [('imra', False)],
          'imras': [('imra', False)],
          'ims': [('imma', False)],
          'imsade': [('imsa', False)],
          'imsades': [('imsa', False)],
          'ina': [('ina', False)],
          'inar': [('ina', False)],
          'inats': [('ina', False)],
          'ind': [('inda', False)],
          'inda': [('inda', False)],
          'indades': [('inda', False)],
          'indas': [('inda', False)],
          'inde': [('inda', False)],
          'indel': [('indela', True)],
          'indel-': [('indela', True)],
          'inder': [('indra', False)],
          'indes': [('inda', False)],
          'indlade': [('indla', False)],
          'indlades': [('indla', False)],
          'inds': [('inna', False)],
          'ine': [('ina', False)],
          'inerats': [('inera', False)],
          'ines': [('ina', False)],
          'ingades': [('inga', False)],
          'ingas': [('inga', False)],
          'ingdes': [('inga', False)],
          'inge': [('inge', True)],
          'inger': [('inge', True)],
          'inges': [('inge', True)],
          'ingrats': [('ingra', False)],
          'ingt': [('inga', False)],
          'ingts': [('inga', False)],
          'init': [('ina', False)],
          'inits': [('ina', False)],
          'inkades': [('inka', False)],
          'inletts': [('inleda', True)],
          'innas': [('inna', False)],
          'ins': [('ina', False)],
          'inser': [('inse', True)],
          'inses': [('inse', True)],
          'inskas': [('inska', False)],
          'inskats': [('inska', False)],
          'int': [('inta', False)],
          'inte': [('inta', False)],
          'inter': [('inta', False)],
          'intes': [('inta', False)],
          'intrats': [('intra', False)],
          'ipar': [('ipa', False)],
          'ipats': [('ipa', False)],
          'ipe': [('ipa', False)],
          'iper': [('ipa', False)],
          'ipes': [('ipa', False)],
          'ipet': [('ipa', False)],
          'ipets': [('ipa', False)],
          'ipna': [('ipa', False)],
          'ippades': [('ippa', False)],
          'ippas': [('ippa', False)],
          'ipplade': [('ippla', False)],
          'ipplades': [('ippla', False)],
          'ips': [('ipa', False)],
          'ir': [('ira', False)],
          'irat': [('ira', False)],
          'irats': [('ira', False)],
          'irkades': [('irka', False)],
          'irkat': [('irka', False)],
          'irklade': [('irkla', False)],
          'irklades': [('irkla', False)],
          'irklas': [('irkla', False)],
          'irmades': [('irma', False)],
          'irrades': [('irra', False)],
          'irras': [('irra', False)],
          'irt': [('irta', False)],
          'irtades': [('irta', False)],
          'is': [('isa', False)],
          'isa': [('isa', False)],
          'isade': [('isa', True)],
          'isades': [('isa', True)],
          'isas': [('isa', False)],
          'isats': [('isa', False)],
          'isatt': [('isätta', False)],
          'isatts': [('isätta', False)],
          'ischas': [('ischa', False)],
          'ise': [('isa', False)],
          'iser': [('isa', False)],
          'ises': [('isa', False)],
          'iska': [('iska', False)],
          'iskad': [('iska', False)],
          'iskade': [('iska', False)],
          'iskades': [('iska', False)],
          'iskar': [('iska', False)],
          'iske': [('iska', False)],
          'iske-': [('iska', False)],
          'islade': [('islägga', True)],
          'islades': [('islägga', True)],
          'islas': [('islägga', True)],
          'isnades': [('isna', False)],
          'isnar': [('isna', False)],
          'isnas': [('isna', False)],
          'ispar': [('ispa', False)],
          'issades': [('issa', False)],
          'issköt': [('issköta', False)],
          'isskötes': [('issköta', False)],
          'issköts': [('issköta', False)],
          'isslade': [('issla', False)],
          'issta': [('issta', False)],
          'isstas': [('issta', False)],
          'isste': [('eta', False)],
          'ist': [('ista', False)],
          'ist-': [('ista', False)],
          'istades': [('ista', False)],
          'istande': [('ista', False)],
          'istandes': [('ista', False)],
          'iste': [('isa', False)],
          'ister': [('istra', False)],
          'istes': [('isa', False)],
          'ists': [('ista', False)],
          'isåg': [('ise', False)],
          'it': [('a', False)],
          'ita': [('ita', False)],
          'itagits': [('ita', False)],
          'itas': [('ita', False)],
          'itats': [('ita', False)],
          'ite': [('ita', False)],
          'iten': [('ita', False)],
          'iter': [('ita', False)],
          'ites': [('ita', False)],
          'itierades': [('itiera', False)],
          'itieras': [('itiera', False)],
          'itits': [('ita', False)],
          'itla': [('itla', False)],
          'itlas': [('itla', False)],
          'itna': [('ita', False)],
          'itnas': [('itna', False)],
          'itogs': [('ita', False)],
          'itrades': [('itra', False)],
          'itras': [('itra', False)],
          'iträd': [('iträda', False)],
          'iträd-': [('iträda', False)],
          'iträda': [('iträda', False)],
          'iträdande': [('iträda', False)],
          'iträdandes': [('iträda', False)],
          'iträdas': [('iträda', False)],
          'iträdd': [('iträda', False)],
          'iträdda': [('iträda', False)],
          'iträddas': [('iträda', False)],
          'iträdde': [('iträda', False)],
          'iträddes': [('iträda', False)],
          'iträdds': [('iträda', False)],
          'iträder': [('iträda', False)],
          'iträds': [('iträda', False)],
          'iträtt': [('iträda', False)],
          'iträtts': [('iträda', False)],
          'its': [('a', False)],
          'itsade': [('itsa', False)],
          'itsades': [('itsa', False)],
          'itt': [('itta', False)],
          'ittades': [('itta', False)],
          'itter': [('ittra', False)],
          'ittlade': [('ittla', False)],
          'itts': [('idas', True)],
          'iv': [('e', False)],
          'iv-': [('e', False)],
          'iva': [('e', False)],
          'ivad': [('iva', False)],
          'ivande': [('e', False)],
          'ivandes': [('e', False)],
          'ivar': [('iva', False)],
          'ivas': [('e', False)],
          'ivats': [('iva', False)],
          'ivdes': [('ivas', False)],
          'ive': [('e', False)],
          'iven': [('iva', False)],
          'ivens': [('e', False)],
          'iver': [('e', False)],
          'ives': [('iva', False)],
          'ivet': [('e', False)],
          'ivets': [('e', False)],
          'ivit': [('e', False)],
          'ivits': [('e', False)],
          'ivlas': [('ivla', False)],
          'ivna': [('e', False)],
          'ivnas': [('e', False)],
          'ivne': [('e', False)],
          'ivnes': [('e', False)],
          'ivrades': [('ivra', False)],
          'ivras': [('ivra', False)],
          'ivs': [('e', False)],
          'ivts': [('ivas', False)],
          'ixats': [('ixa', False)],
          'j': [('ja', False)],
          'j-': [('ja', False)],
          'ja': [('ja', False)],
          'jabbats': [('jabba', True)],
          'jack': [('jacka', False)],
          'jad': [('ja', False)],
          'jade': [('ja', False)],
          'jades': [('ja', False)],
          'jads': [('ja', False)],
          'jag': [('jaga', False)],
          'jagades': [('jaga', False)],
          'jagandes': [('jaga', False)],
          'jagas': [('jaga', True)],
          'jakades': [('jaka', False)],
          'jall': [('jalla', False)],
          'jam': [('jama', True)],
          'jam-': [('jama', True)],
          'jams': [('jamsa', True)],
          'jamsas': [('jamsa', True)],
          'jamsats': [('jamsa', True)],
          'jandes': [('ja', False)],
          'japp': [('jappa', False)],
          'jar': [('ja', False)],
          'jas': [('ja', False)],
          'jat': [('ja', False)],
          'jav': [('java', False)],
          'jd': [('ja', False)],
          'jda': [('jda', False)],
          'jdande': [('jda', False)],
          'jdas': [('jda', False)],
          'jdats': [('jda', False)],
          'jde': [('ja', False)],
          'jdes': [('ja', False)],
          'jdrades': [('jdra', False)],
          'jdras': [('jdra', False)],
          'jds': [('ja', False)],
          'jerad': [('jera', False)],
          'jerades': [('jera', False)],
          'jeras': [('jera', False)],
          'jilla': [('jilla', False)],
          'jillade': [('jilla', False)],
          'jillades': [('jilla', False)],
          'jillats': [('jilla', False)],
          'jjande': [('jja', False)],
          'jjats': [('jja', False)],
          'jkar': [('jka', False)],
          'jkas': [('jka', False)],
          'jkats': [('jka', False)],
          'jkott': [('jkotta', False)],
          'jla': [('jla', False)],
          'jlade': [('jla', False)],
          'jlades': [('jla', False)],
          'jlas': [('jla', False)],
          'jlats': [('jla', False)],
          'jmas': [('jma', False)],
          'jmats': [('jma', False)],
          'jna': [('jna', False)],
          'jnar': [('jna', False)],
          'jnats': [('jna', False)],
          'jo': [('joa', False)],
          'jo-': [('ja', False)],
          'jockats': [('jocka', False)],
          'jollades': [('jollas', False)],
          'jollas': [('jollas', False)],
          'jollats': [('jollas', False)],
          'joniserad': [('jonisera', True)],
          'jord': [('jorda', True)],
          'jorda': [('jorda', True)],
          'jordas': [('jorda', True)],
          'jorde': [('öra', False)],
          'jordes': [('öra', False)],
          'jords': [('öra', False)],
          'jort': [('öra', False)],
          'jorts': [('öra', False)],
          'joskas': [('joska', False)],
          'joskats': [('joska', False)],
          'joxades': [('joxa', True)],
          'joxas': [('joxa', True)],
          'jpar': [('jpa', False)],
          'jpats': [('jpa', False)],
          'jsa': [('jsa', False)],
          'jsade': [('jsa', False)],
          'jsades': [('jsa', False)],
          'jsas': [('jsa', False)],
          'jsats': [('jsa', False)],
          'jsla': [('jsla', False)],
          'jslades': [('jsla', False)],
          'jslas': [('jsla', False)],
          'jt': [('ja', False)],
          'jta': [('jta', False)],
          'jtades': [('jtas', False)],
          'jtas': [('jta', False)],
          'jtats': [('jta', False)],
          'jts': [('ja', False)],
          'judes': [('juda', False)],
          'jugens': [('juga', False)],
          'juget': [('juga', False)],
          'jugit': [('juga', False)],
          'jugits': [('juga', False)],
          'jugne': [('juga', False)],
          'jugnes': [('juga', False)],
          'jukna': [('jukna', False)],
          'juknas': [('jukna', False)],
          'jummats': [('jumma', False)],
          'jumpats': [('jumpa', True)],
          'junge': [('junga', False)],
          'jungen': [('junga', False)],
          'jungens': [('junga', False)],
          'junges': [('junga', False)],
          'junget': [('junga', False)],
          'jungets': [('junga', False)],
          'jungit': [('junga', False)],
          'jungits': [('junga', False)],
          'jungna': [('junga', False)],
          'jungnas': [('junga', False)],
          'junkas': [('junka', False)],
          'junkats': [('junka', False)],
          'junke': [('junka', False)],
          'junker': [('junka', False)],
          'junkes': [('junka', False)],
          'junkit': [('junka', False)],
          'junkits': [('junka', False)],
          'junkna': [('junka', False)],
          'junknas': [('junka', False)],
          'jupna': [('jupna', False)],
          'jupnas': [('jupna', False)],
          'jurades': [('jura', False)],
          'juras': [('jura', False)],
          'jusna': [('jusna', False)],
          'jusnas': [('jusna', False)],
          'jussas': [('jussa', False)],
          'jussats': [('jussa', False)],
          'just': [('jusa', False)],
          'juste': [('jusa', False)],
          'justes': [('jusa', False)],
          'jutens': [('juta', False)],
          'jutes': [('juta', False)],
          'jutet': [('juta', False)],
          'jutets': [('juta', False)],
          'jutit': [('juta', False)],
          'jutits': [('juta', False)],
          'jutnas': [('juta', False)],
          'jutne': [('juta', False)],
          'jutnes': [('juta', False)],
          'jutsade': [('jutsa', False)],
          'jutsades': [('jutsa', False)],
          'jvänt': [('jvända', False)],
          'jyvas': [('jyva', False)],
          'jäbbats': [('jäbba', False)],
          'jäktats': [('jäkta', True)],
          'jällades': [('jälla', False)],
          'jällats': [('jälla', False)],
          'jänades': [('jäna', False)],
          'jänas': [('jäna', False)],
          'jär': [('jära', False)],
          'järande': [('jära', False)],
          'järas': [('jära', False)],
          'järvdes': [('järvas', False)],
          'järvs': [('järvas', False)],
          'järvts': [('järvas', False)],
          'jäs': [('jäsa', False)],
          'jäst': [('jäsa', True)],
          'jästs': [('jäsa', True)],
          'jöd': [('juda', False)],
          'jödes': [('juda', False)],
          'jöds': [('juda', False)],
          'jöges': [('juga', False)],
          'jörnats': [('jörna', False)],
          'jöt': [('juta', False)],
          'jöte': [('juta', False)],
          'jöts': [('juta', False)],
          'k': [('ka', False)],
          'k-': [('ka', False)],
          'ka': [('ka', False)],
          'kack': [('kacka', True)],
          'kad': [('ka', False)],
          'kade': [('ka', False)],
          'kades': [('ka', False)],
          'kads': [('ka', False)],
          'kaft': [('kafta', False)],
          'kakades': [('kaka', False)],
          'kal': [('kala', False)],
          'kala': [('kala', False)],
          'kalade': [('kala', False)],
          'kalas': [('kala', False)],
          'kald': [('kalda', False)],
          'kalda': [('kalda', False)],
          'kaldas': [('kalda', False)],
          'kalkades': [('kalka', True)],
          'kalkas': [('kalka', False)],
          'kalkats': [('kalka', False)],
          'kall': [('kalla', False)],
          'kallnas': [('kallna', True)],
          'kalna': [('kalna', True)],
          'kalnats': [('kalna', True)],
          'kampats': [('kampa', True)],
          'kan': [('kana', True), ('kunna', True)],
          'kande': [('ka', False)],
          'kandes': [('ka', False)],
          'kapp': [('kappa', False)],
          'kappades': [('kappas', True)],
          'kappas': [('kappas', True)],
          'kappats': [('kappas', True)],
          'kar': [('kara', True)],
          'karades': [('kara', True)],
          'karas': [('kara', True)],
          'kas': [('kasa', True)],
          'kat': [('ka', False)],
          'katt': [('katta', False)],
          'katta': [('katta', True)],
          'kattas': [('katta', False)],
          'kattats': [('katta', False)],
          'kattlade': [('kattlägga', False)],
          'kattlades': [('kattlägga', False)],
          'kattlas': [('kattlägga', False)],
          'kav': [('kava', False)],
          'kava': [('kava', False)],
          'kavandes': [('kava', False)],
          'kavla': [('kavla', True)],
          'kavlade': [('kavla', True)],
          'kavlades': [('kavla', True)],
          'kavlas': [('kavla', True)],
          'kavs': [('kava', False)],
          'kband': [('kbinda', False)],
          'kedandes': [('keda', False)],
          'kedda': [('ke', False)],
          'kedds': [('ke', False)],
          'kedjande': [('kedja', False)],
          'kel': [('kela', False)],
          'kel-': [('kela', False)],
          'kela': [('kela', False)],
          'kelas': [('kela', True)],
          'kelat': [('kela', False)],
          'kenades': [('kena', False)],
          'kenas': [('kena', False)],
          'kenats': [('kena', False)],
          'kens': [('kina', False)],
          'ker-': [('kera', False)],
          'kerad': [('kera', False)],
          'kerades': [('kera', False)],
          'keras': [('kera', False)],
          'kes': [('kesa', True)],
          'ket': [('kita', False)],
          'kets': [('kita', False)],
          'kett': [('ke', False)],
          'kevrats': [('kevra', False)],
          'kgjord': [('kgöra', False)],
          'kgjorda': [('kgöra', False)],
          'kgjordas': [('kgöra', False)],
          'kick': [('kicka', False)],
          'kidas': [('kida', False)],
          'kidats': [('kida', False)],
          'kiftas': [('kifta', False)],
          'kikna': [('kikna', True)],
          'kikta': [('kikta', False)],
          'kiktas': [('kikta', False)],
          'kild': [('kilja', False)],
          'kildas': [('kilja', False)],
          'killa': [('killa', True)],
          'killade': [('killa', True)],
          'killades': [('killa', True)],
          'killats': [('killa', True)],
          'kisade': [('kisa', True)],
          'kisades': [('kisa', True)],
          'kiserad': [('kisera', False)],
          'kit': [('kita', False)],
          'kits': [('kita', False)],
          'kittlades': [('kittla', True), ('kittlas', True)],
          'kittlas': [('kittlas', True), ('kittla', True)],
          'kittlats': [('kittlas', True), ('kittla', True)],
          'kiv': [('kiva', False)],
          'kiv-': [('kiva', False)],
          'kiva': [('kiva', False)],
          'kivades': [('kivas', True)],
          'kivande': [('kiva', False)],
          'kivandes': [('kiva', False)],
          'kivas': [('kivas', True)],
          'kivats': [('kivas', True)],
          'klade': [('kla', False)],
          'klades': [('kla', False)],
          'klang': [('klinga', True)],
          'klar': [('klara', False)],
          'klas': [('kla', False)],
          'klats': [('kla', False)],
          'kled': [('kleda', False)],
          'kledas': [('kleda', False)],
          'kleddes': [('kleda', False)],
          'kledes': [('kleda', False)],
          'kleds': [('kleda', False)],
          'klet': [('kleta', True)],
          'klett': [('kleda', False)],
          'kletts': [('kleda', False)],
          'klev': [('kliva', True)],
          'klevs': [('kliva', True)],
          'kli': [('klia', True)],
          'klir': [('klira', True)],
          'kliva': [('kliva', True)],
          'kliver': [('kliva', True)],
          'klivit': [('kliva', True)],
          'klockas': [('klocka', True)],
          'klä-': [('klä', True)],
          'kläckas': [('kläcka', True), ('kläckas', True)],
          'kläckes': [('kläckas', True), ('kläcka', True)],
          'kläcks': [('kläckas', True), ('kläcka', True)],
          'kläcktes': [('kläckas', True), ('kläcka', True)],
          'kläckts': [('kläcka', True), ('kläckas', True)],
          'kläd-': [('klä', False)],
          'klädandes': [('klä', False)],
          'klämt': [('klämma', True), ('klämta', True)],
          'klängas': [('klänga', True)],
          'klängdes': [('klänga', True)],
          'klänges': [('klänga', True)],
          'klängs': [('klänga', True)],
          'klängts': [('klänga', True)],
          'klär': [('klä', False)],
          'kläs': [('klä', False)],
          'klästas': [('kläsa', False)],
          'klådd': [('klå', True)],
          'klådde': [('klå', True)],
          'klåddes': [('klå', True)],
          'klås': [('klå', True)],
          'klåtts': [('klå', True)],
          'klösas': [('klösas', True), ('klösa', True)],
          'klöses': [('klösas', True), ('klösa', True)],
          'klöstes': [('klösas', True), ('klösa', True)],
          'klösts': [('klösas', True), ('klösa', True)],
          'klöv': [('klyva', True)],
          'kna': [('kna', False)],
          'knar': [('kna', False)],
          'knarrades': [('knarra', True)],
          'knarras': [('knarra', True)],
          'knarrats': [('knarra', True)],
          'knat': [('knata', True)],
          'knats': [('kna', False)],
          'kne': [('kna', False)],
          'knips': [('knipa', True), ('knipsa', True)],
          'knoppades': [('knoppas', True)],
          'knoppas': [('knoppas', True)],
          'knoppats': [('knoppas', True)],
          'knuffades': [('knuffas', True), ('knuffa', True)],
          'knuffas': [('knuffa', True), ('knuffas', True)],
          'knuffats': [('knuffas', True), ('knuffa', True)],
          'knöt': [('knyta', False)],
          'knötes': [('knyta', False)],
          'knöts': [('knyta', False)],
          'ko': [('ko', False)],
          'ko-': [('ko', False)],
          'kockades': [('kocka', True)],
          'kockas': [('kocka', True)],
          'kockats': [('kocka', True)],
          'kodades': [('koda', False)],
          'kodda': [('ko', False)],
          'koksades': [('koksa', True)],
          'koksas': [('koksa', True)],
          'koksats': [('koksa', True)],
          'kol': [('kola', False)],
          'kola': [('kola', False)],
          'kollats': [('kolla', True)],
          'komna': [('komma', True)],
          'komnas': [('komma', False)],
          'konades': [('kona', False)],
          'konas': [('kona', False)],
          'kopp': [('koppa', True)],
          'koppats': [('koppa', True)],
          'koppla': [('koppla', False)],
          'kopplade': [('koppla', False)],
          'kopplades': [('koppla', False)],
          'kopplas': [('koppla', False)],
          'kopprad': [('koppra', False)],
          'kor': [('kora', True)],
          'kors': [('korsa', True)],
          'korslade': [('korslägga', True)],
          'korslades': [('korslägga', True)],
          'korslas': [('korslägga', True)],
          'kort': [('korta', False)],
          'kos': [('ko', False)],
          'kottas': [('kotta', False)],
          'kottats': [('kotta', False)],
          'kottla': [('kottla', True)],
          'koxades': [('koxa', True)],
          'koxas': [('koxa', True)],
          'koxats': [('koxa', True)],
          'kramlas': [('kramla', False)],
          'krat': [('kra', False)],
          'krats': [('kratsa', True)],
          'kravlade': [('kravla', True)],
          'kred': [('krida', False)],
          'kreds': [('krida', False)],
          'krek': [('krika', False)],
          'kretades': [('kreta', True)],
          'kretas': [('kreta', True)],
          'kretats': [('kreta', True)],
          'krevar': [('kreva', False)],
          'krevs': [('kriva', False)],
          'krivas': [('kriva', False)],
          'krivits': [('kriva', False)],
          'krivs': [('kriva', False)],
          'krydda': [('krydda', True)],
          'kryddas': [('krydda', True)],
          'krymdes': [('krymma', False)],
          'krymmas': [('krymma', False)],
          'krympas': [('krympa', False)],
          'krympes': [('krympa', True)],
          'krymps': [('krympa', True)],
          'krymptes': [('krympa', True)],
          'krympts': [('krympa', True)],
          'kryms': [('krymma', False)],
          'krymts': [('krymma', False)],
          'kryst': [('krysta', True)],
          'kräd': [('kräda', False)],
          'kräda': [('kräda', False)],
          'krädande': [('kräda', False)],
          'krädas': [('kräda', False)],
          'kräddes': [('kräda', False)],
          'krädds': [('kräda', False)],
          'kräder': [('kräda', False)],
          'kräds': [('kräda', False)],
          'kräktas': [('kräkta', False)],
          'kräkts': [('kräkas', False)],
          'kräm': [('krämma', False)],
          'kräm-': [('krämma', False)],
          'krämt': [('krämta', True)],
          'krängas': [('kränga', True)],
          'krängdes': [('kränga', True)],
          'krängt': [('kränga', True)],
          'krängts': [('kränga', True)],
          'krävas': [('krävas', True), ('kräva', True)],
          'krävdes': [('krävas', True), ('kräva', True)],
          'kräves': [('krävas', True), ('kräva', True)],
          'krävs': [('krävas', True), ('kräva', True)],
          'krävts': [('krävas', True), ('kräva', True)],
          'krök': [('kröka', True)],
          'kröks': [('kröka', True)],
          'kröp': [('krypa', True)],
          'kröt': [('kryta', False)],
          'ksa': [('ksa', False)],
          'ksade': [('ksa', False)],
          'ksas': [('ksa', False)],
          'ksatt': [('ksätta', False)],
          'ksatts': [('ksätta', False)],
          'kskjuts': [('kskjuta', False)],
          'kskrev': [('kskriva', False)],
          'ksköt': [('kskjuta', False)],
          'kskötes': [('kskjuta', False)],
          'ksköts': [('kskjuta', False)],
          'kslagits': [('kslå', False)],
          'kslogs': [('kslå', False)],
          'kt': [('ka', False)],
          'kta': [('kta', False)],
          'ktalades': [('ktala', False)],
          'ktas': [('kta', False)],
          'ktats': [('kta', False)],
          'ktigades': [('ktigas', False)],
          'ktigas': [('ktigas', False)],
          'ktigats': [('ktiga', False)],
          'ktrades': [('ktra', False)],
          'ktras': [('ktra', False)],
          'kts': [('ka', False)],
          'kubbades': [('kubbas', True)],
          'kubbas': [('kubbas', True)],
          'kubbats': [('kubbas', True)],
          'kuffades': [('kuffa', False)],
          'kuffats': [('kuffa', False)],
          'kuggats': [('kugga', False)],
          'kullades': [('kulla', True)],
          'kullas': [('kulla', True)],
          'kullats': [('kulla', True)],
          'kulle': [('kola', False)],
          'kulna': [('kulna', True)],
          'kummats': [('kumma', False)],
          'kumpats': [('kumpa', False)],
          'kunde': [('kunna', True)],
          'kunna': [('kunna', False)],
          'kuppats': [('kuppa', False)],
          'kurades': [('kura', False)],
          'kuras': [('kura', False)],
          'kvad': [('kväda', True)],
          'kvade': [('kväda', True)],
          'kvades': [('kväda', True)],
          'kvads': [('kväda', True)],
          'kvalt': [('kvälja', True)],
          'kvarvar': [('kvarvara', True)],
          'kved': [('kvida', True)],
          'kvedes': [('kvida', True)],
          'kveds': [('kvida', True)],
          'kvisas': [('kvisa', False)],
          'kvisats': [('kvisa', False)],
          'kvistades': [('kvista', False)],
          'kvistas': [('kvista', True)],
          'kvistats': [('kvista', False)],
          'kväljas': [('kvälja', True)],
          'kvällas': [('kvällas', True)],
          'kvätt': [('kvätta', False)],
          'kvätta': [('kvätta', False)],
          'kvättas': [('kvätta', False)],
          'kvätte': [('kvätta', False)],
          'kvättes': [('kvätta', False)],
          'kvätts': [('kvätta', False)],
          'kydds': [('ky', False)],
          'kyller': [('kylla', False)],
          'kylt': [('kyla', False)],
          'kymts': [('kymma', False)],
          'kyr': [('ky', False)],
          'kyss': [('kyssa', True)],
          'kyssas': [('kyssa', True), ('kyssas', True)],
          'kysses': [('kyssas', True), ('kyssa', True)],
          'kysstes': [('kyssas', True), ('kyssa', True)],
          'kyssts': [('kyssas', True), ('kyssa', True)],
          'kytt': [('ky', False)],
          'käkta': [('käkta', False)],
          'käktats': [('käkta', False)],
          'kämde': [('kämma', False)],
          'kämts': [('kämma', False)],
          'känd': [('känna', False)],
          'kända': [('känna', False)],
          'kändades': [('kända', False)],
          'kändas': [('känna', False)],
          'kändats': [('kända', False)],
          'kände': [('känna', False)],
          'kändes': [('kännas', True), ('känna', True)],
          'kännas': [('känna', True), ('kännas', True)],
          'kännes': [('känna', True)],
          'känns': [('kännas', True), ('känna', True)],
          'känt': [('känna', False)],
          'känts': [('kännas', True), ('känna', True)],
          'kär': [('kära', False)],
          'kär-': [('kära', False)],
          'kära': [('kära', False)],
          'kärande': [('kära', False)],
          'käras': [('kära', False)],
          'kärdes': [('kära', False)],
          'kärrades': [('kärra', False)],
          'kärras': [('kärra', False)],
          'kärrats': [('kärra', False)],
          'kärt': [('kära', False)],
          'kärvas': [('kärva', False)],
          'kåd-': [('kåda', False)],
          'kådandes': [('kåda', False)],
          'kåla': [('kåla', False)],
          'kålade': [('kåla', False)],
          'kålades': [('kåla', False)],
          'kålas': [('kåla', False)],
          'kårades': [('kåra', True), ('kåras', True)],
          'kåras': [('kåra', True), ('kåras', True)],
          'kårats': [('kåras', True), ('kåra', True)],
          'köp': [('köpa', False)],
          'köpes': [('köpa', False)],
          'köras': [('köra', False)],
          'körd': [('köra', True)],
          'körda': [('köra', True)],
          'kördas': [('köra', True)],
          'kördes': [('köra', True)],
          'körnats': [('körna', True)],
          'kört': [('köra', False)],
          'körts': [('köra', False)],
          'kött': [('köta', False)],
          'kötts': [('köta', False)],
          'kövdes': [('köva', True)],
          'kövs': [('köva', True)],
          'kövts': [('köva', True)],
          'l': [('la', False)],
          'l-': [('la', False)],
          'la': [('lägga', True)],
          'labbats': [('labba', False)],
          'lack': [('lacka', False)],
          'lad': [('la', False)],
          'ladad': [('lada', False)],
          'laddas': [('ladda', False)],
          'lade': [('lägga', True)],
          'lades': [('lägga', True)],
          'lads': [('la', False)],
          'lag': [('laga', False)],
          'lagades': [('laga', False)],
          'lagas': [('laga', False)],
          'lagla': [('laglägga', False)],
          'laglas': [('laglägga', False)],
          'lagna': [('lagna', False)],
          'lagnas': [('lå', False)],
          'lagt': [('lägga', False)],
          'lakades': [('laka', False)],
          'laknats': [('lakna', False)],
          'lall': [('lalla', True)],
          'lam': [('lama', False)],
          'lam-': [('lama', False)],
          'lamp': [('lampa', False)],
          'lampats': [('lampa', False)],
          'lams': [('lamsa', False)],
          'lamsas': [('lamsa', False)],
          'lamsats': [('lamsa', False)],
          'lan': [('lana', False)],
          'landades': [('landa', False)],
          'landas': [('landa', False)],
          'landats': [('landa', False)],
          'lande': [('la', False)],
          'landes': [('la', False)],
          'lang': [('langa', True)],
          'lange': [('linga', False)],
          'lankas': [('lanka', False)],
          'lankats': [('lanka', False)],
          'lapp': [('lappa', False)],
          'lappats': [('lappa', False)],
          'lar': [('la', False)],
          'larades': [('lara', False)],
          'laras': [('lara', False)],
          'larmas': [('larma', True)],
          'larmats': [('larma', True)],
          'larna': [('larna', False)],
          'las': [('lägga', True)],
          'lat': [('la', False)],
          'latt': [('latta', False)],
          'latta': [('latta', False)],
          'lattas': [('latta', False)],
          'lattats': [('latta', False)],
          'lav': [('lava', False)],
          'lava': [('lava', False)],
          'lavandes': [('lava', False)],
          'lbad': [('lbada', False)],
          'lbade': [('lbe', False)],
          'lbades': [('lbe', False)],
          'lbads': [('lbe', False)],
          'lband': [('lbinda', False)],
          'lber': [('lbe', False)],
          'lbesatt': [('lbesätta', False)],
          'lbesatts': [('lbesätta', False)],
          'lda': [('lda', False)],
          'ldande': [('lda', False)],
          'ldats': [('lda', False)],
          'lde': [('la', False)],
          'ldelade': [('ldela', False)],
          'ldelades': [('ldela', False)],
          'lder-': [('ldra', False)],
          'ldes': [('la', False)],
          'ldigats': [('ldiga', False)],
          'ldrades': [('ldra', False)],
          'ldragits': [('ldra', False)],
          'ldras': [('ldra', False)],
          'ldrats': [('ldras', False)],
          'ldrog': [('ldra', False)],
          'ldrogs': [('ldra', False)],
          'lds': [('la', False)],
          'le': [('le', False)],
          'le-': [('le', True)],
          'lear': [('leara', False)],
          'leas': [('leasa', True)],
          'led': [('lida', True), ('leda', True)],
          'led-': [('leda', False)],
          'ledandes': [('leda', False)],
          'ledas': [('leda', True), ('ledas', True)],
          'ledats': [('leda', True), ('ledas', True)],
          'ledd': [('leda', False)],
          'leddas': [('leda', False)],
          'ledde': [('leda', False)],
          'leddes': [('leda', True), ('ledas', True)],
          'leder': [('leda', False)],
          'ledes': [('leda', True), ('ledas', True)],
          'leds': [('lida', True), ('leda', True), ('ledas', True)],
          'lejt': [('leja', True)],
          'lek': [('leka', True)],
          'leks': [('leka', False)],
          'lekts': [('leka', True)],
          'len': [('lena', False)],
          'lenades': [('lena', True)],
          'lenas': [('lena', False)],
          'lenats': [('lena', True)],
          'lens': [('la', False)],
          'ler': [('le', True)],
          'ler-': [('lera', False)],
          'lerad': [('lera', False)],
          'lerades': [('lera', False)],
          'leras': [('lera', False)],
          'les': [('le', True)],
          'let': [('leta', True)],
          'letades': [('leta', False)],
          'lets': [('lita', False)],
          'lett': [('leda', True), ('le', True)],
          'letts': [('ledas', True), ('leda', True), ('le', True)],
          'lev': [('leva', True)],
          'levrades': [('levras', True)],
          'levras': [('levras', True)],
          'levs': [('leva', False)],
          'lfades': [('lfa', False)],
          'lfar': [('lfara', False)],
          'lfas': [('lfa', False)],
          'lfats': [('lfa', False)],
          'lfägnades': [('lfägna', False)],
          'lfägnas': [('lfägna', False)],
          'lfägnats': [('lfägna', False)],
          'lfärdades': [('lfärda', False)],
          'lfärdas': [('lfärda', False)],
          'lfärdats': [('lfärda', False)],
          'lförstöras': [('lförstöra', False)],
          'lförstördes': [('lförstöra', False)],
          'lförstöres': [('lförstöra', False)],
          'lförstörs': [('lförstöra', False)],
          'lförstörts': [('lförstöra', False)],
          'lga': [('lga', False)],
          'lgande': [('lga', False)],
          'lgar': [('lga', False)],
          'lgats': [('lga', False)],
          'lgicks': [('lgå', False)],
          'lgjord': [('lgöra', False)],
          'lgjorda': [('lgöra', False)],
          'lgjordas': [('lgöra', False)],
          'lgåtts': [('lgå', False)],
          'lhandla': [('lhandla', False)],
          'lhandlade': [('lhandla', False)],
          'lhandlades': [('lhandla', False)],
          'lhandlas': [('lhandla', False)],
          'lhållas': [('lhålla', False)],
          'lhållits': [('lhålla', False)],
          'lhålls': [('lhålla', False)],
          'lhöggs': [('lhugga', False)],
          'lhölls': [('lhålla', False)],
          'li': [('li', False)],
          'lick': [('licka', False)],
          'lidas': [('lida', True)],
          'lides': [('lida', False)],
          'lids': [('lida', False)],
          'lierats': [('liera', False)],
          'liftas': [('lifta', True)],
          'ligades': [('liga', False)],
          'ligas': [('liga', False)],
          'likas': [('lika', True)],
          'likna': [('likna', True)],
          'likt': [('lika', False)],
          'likta': [('likta', False)],
          'liktas': [('likta', False)],
          'linge': [('linga', False)],
          'linger': [('lingra', False)],
          'lingrades': [('lingra', False)],
          'lingras': [('lingra', False)],
          'lints': [('linta', False)],
          'lir': [('li', False)],
          'liserad': [('lisera', False)],
          'list': [('lista', True)],
          'lista': [('lista', True)],
          'listas': [('lista', True)],
          'listats': [('lista', False)],
          'lists': [('lisa', False)],
          'lit': [('lita', False)],
          'litnas': [('lita', False)],
          'lits': [('litsa', False)],
          'liv': [('liva', True)],
          'liv-': [('liva', False)],
          'liva': [('liva', True)],
          'livades': [('liva', True)],
          'livande': [('liva', False)],
          'livandes': [('liva', False)],
          'livas': [('liva', False)],
          'live': [('liva', False)],
          'liven': [('li', False)],
          'livens': [('li', False)],
          'liver': [('li', False)],
          'livet': [('li', False)],
          'livets': [('li', False)],
          'livit': [('li', False)],
          'livits': [('liva', False)],
          'livna': [('li', False)],
          'livnas': [('li', False)],
          'livne': [('li', False)],
          'livnes': [('li', False)],
          'livs': [('liva', False)],
          'ljande': [('lja', False)],
          'ljats': [('lja', False)],
          'ljda': [('lja', False)],
          'ljdas': [('lja', False)],
          'ljer': [('lja', False)],
          'ljes': [('lja', False)],
          'ljs': [('lja', False)],
          'ljudas': [('ljuda', False)],
          'ljudes': [('ljuda', True)],
          'ljudits': [('ljuda', True)],
          'ljuds': [('ljuda', False)],
          'ljöds': [('ljuda', True)],
          'lkar': [('lka', False)],
          'lkas': [('lka', False)],
          'lkats': [('lka', False)],
          'lkomnas': [('lkomna', False)],
          'lla': [('lla', False)],
          'llade': [('lla', False)],
          'llades': [('lla', False)],
          'llats': [('lla', False)],
          'llbad': [('llbe', False)],
          'lld': [('lla', False)],
          'llda': [('lla', False)],
          'lldas': [('lla', False)],
          'lle': [('lla', False)],
          'llen': [('lla', False)],
          'ller': [('lla', False)],
          'ller-': [('llra', False)],
          'lles': [('lla', False)],
          'llet': [('lla', False)],
          'llets': [('lla', False)],
          'llit': [('lla', False)],
          'llits': [('lla', False)],
          'llkomna': [('llkomna', False)],
          'llkomnas': [('llkomma', False)],
          'llna': [('lla', False)],
          'llnades': [('llna', False)],
          'llnas': [('llna', False)],
          'lloge': [('lloge', False)],
          'lloges': [('lloge', False)],
          'lls': [('lla', False)],
          'llsade': [('llsäga', False)],
          'llsades': [('llsäga', False)],
          'llser': [('llse', False)],
          'llses': [('llse', False)],
          'llskar': [('llskära', False)],
          'llvande': [('llvänja', False)],
          'llvandes': [('llvänja', False)],
          'llästas': [('lläsa', False)],
          'llåts': [('llåta', False)],
          'lmas': [('lma', False)],
          'lmats': [('lma', False)],
          'lmätt': [('lmäta', False)],
          'lmätta': [('lmäta', False)],
          'lmättas': [('lmäta', False)],
          'lna': [('lna', False)],
          'lnar': [('lna', False)],
          'lnats': [('lna', False)],
          'lo': [('lo', False)],
          'lo-': [('lo', False)],
          'lockades': [('locka', True)],
          'lockas': [('locka', True)],
          'lockats': [('locka', False)],
          'lodades': [('loda', False)],
          'lodda': [('lo', False)],
          'log': [('le', True)],
          'loge': [('le', True)],
          'loges': [('le', True)],
          'logs': [('le', True)],
          'lonades': [('lona', False)],
          'lonas': [('lona', False)],
          'loniserad': [('lonisera', False)],
          'loppats': [('loppa', False)],
          'lor': [('lo', False)],
          'los': [('lo', False)],
          'loskas': [('loska', True)],
          'loskats': [('loska', True)],
          'lott': [('lotta', True)],
          'lottas': [('lotta', True)],
          'lottats': [('lotta', False)],
          'lottlade': [('lottlägga', False)],
          'lottlades': [('lottlägga', False)],
          'lottlas': [('lottlägga', False)],
          'lov': [('lova', False)],
          'lpar': [('lpa', False)],
          'lpats': [('lpa', False)],
          'lper': [('lpa', False)],
          'lpes': [('lpa', False)],
          'lprat': [('lprata', False)],
          'lps': [('lpa', False)],
          'lpta': [('lpa', False)],
          'lptas': [('lpa', False)],
          'lptes': [('lpa', False)],
          'lrat': [('lra', False)],
          'lrats': [('lra', False)],
          'lred': [('lreda', False)],
          'lreda': [('lreda', False)],
          'lredda': [('lreda', False)],
          'lreds': [('lreda', False)],
          'lrett': [('lreda', False)],
          'lräknade': [('lräkna', False)],
          'lräknades': [('lräkna', False)],
          'lräknas': [('lräkna', False)],
          'lräknats': [('lräkna', False)],
          'lråd': [('lråda', False)],
          'lråd-': [('lråda', False)],
          'lråda': [('lråda', False)],
          'lrådande': [('lråda', False)],
          'lrådandes': [('lråda', False)],
          'lrådas': [('lråda', False)],
          'lrådd': [('lråda', False)],
          'lrådda': [('lråda', False)],
          'lråddas': [('lråda', False)],
          'lrådde': [('lråda', False)],
          'lråddes': [('lråda', False)],
          'lrådds': [('lråda', False)],
          'lråder': [('lråda', False)],
          'lråds': [('lråda', False)],
          'lrått': [('lråda', False)],
          'lråtts': [('lråda', False)],
          'lrök': [('lröka', False)],
          'lrör': [('lröra', False)],
          'lsa': [('lsa', False)],
          'lsade': [('lsa', False)],
          'lsades': [('lsa', False)],
          'lsas': [('lsa', False)],
          'lsats': [('lsa', False)],
          'lsatt': [('lsätta', False)],
          'lsatts': [('lsätta', False)],
          'lser': [('lsa', False)],
          'lses': [('lsa', False)],
          'lska': [('lska', False)],
          'lskad': [('lska', False)],
          'lskadad': [('lskadad', False)],
          'lskade': [('lska', False)],
          'lskades': [('lska', False)],
          'lskar': [('lska', False)],
          'lskas': [('lskas', False)],
          'lskats': [('lskas', False)],
          'lskjuts': [('lskjuta', False)],
          'lskrev': [('lskriva', False)],
          'lsköt': [('lskjuta', False)],
          'lskötes': [('lskjuta', False)],
          'lsköts': [('lskjuta', False)],
          'lslagits': [('lslå', False)],
          'lslogs': [('lslå', False)],
          'lsmitt': [('lsmida', False)],
          'lsta': [('lsa', False)],
          'lstas': [('lsa', False)],
          'lste': [('lsa', False)],
          'lster': [('lstra', False)],
          'lstes': [('lsa', False)],
          'lstäd': [('lstädja', False)],
          'lstött': [('lstöta', False)],
          'lstötta': [('lstöta', False)],
          'lstöttas': [('lstöta', False)],
          'lstötte': [('lstöta', False)],
          'lstötts': [('lstöta', False)],
          'lsvettades': [('lsvettas', False)],
          'lsvettas': [('lsvettas', False)],
          'lsvettats': [('lsvettas', False)],
          'lsåg': [('lse', False)],
          'lt': [('la', False)],
          'lta': [('lta', False)],
          'ltag-': [('lta', False)],
          'ltagits': [('lta', False)],
          'ltalades': [('ltala', False)],
          'ltas': [('lta', False)],
          'ltats': [('lta', False)],
          'lteg': [('ltiga', False)],
          'lter': [('lta', False)],
          'ltogs': [('lta', False)],
          'ltrades': [('ltra', False)],
          'ltras': [('ltra', False)],
          'lträd': [('lträda', False)],
          'lträd-': [('lträda', False)],
          'lträda': [('lträda', False)],
          'lträdande': [('lträda', False)],
          'lträdandes': [('lträda', False)],
          'lträdas': [('lträda', False)],
          'lträdd': [('lträda', False)],
          'lträdda': [('lträda', False)],
          'lträddas': [('lträda', False)],
          'lträdde': [('lträda', False)],
          'lträddes': [('lträda', False)],
          'lträdds': [('lträda', False)],
          'lträder': [('lträda', False)],
          'lträds': [('lträda', False)],
          'lträtt': [('lträda', False)],
          'lträtts': [('lträda', False)],
          'lts': [('la', False)],
          'lubbats': [('lubba', False)],
          'luffades': [('luffa', False)],
          'luffats': [('luffa', False)],
          'luge': [('lyga', False)],
          'lugen': [('lyga', False)],
          'luges': [('lyga', False)],
          'lugets': [('lyga', False)],
          'luggades': [('luggas', True), ('lugga', True)],
          'luggas': [('luggas', True), ('lugga', True)],
          'luggats': [('luggas', True), ('lugga', True)],
          'lugna': [('lugna', True)],
          'lugnas': [('lugna', True)],
          'luke': [('luka', False)],
          'lukes': [('luka', False)],
          'lullades': [('lulla', True)],
          'lullas': [('lulla', True)],
          'lullats': [('lulla', True)],
          'lummades': [('lummas', False)],
          'lummas': [('lummas', False)],
          'lummats': [('lumma', False)],
          'lumpats': [('lumpa', False)],
          'lundats': [('lunda', False)],
          'lunkades': [('lunka', True)],
          'lunkas': [('lunka', True)],
          'lunkats': [('lunka', False)],
          'lunna': [('lunna', True)],
          'lunta': [('lunta', True)],
          'luntas': [('lunta', True)],
          'lunte': [('linta', False)],
          'luntes': [('linta', False)],
          'lupe': [('löpa', False)],
          'lupens': [('löpa', False)],
          'lupes': [('löpa', True)],
          'lupit': [('löpa', True)],
          'lurades': [('luras', True), ('lura', True)],
          'luras': [('lura', True), ('luras', True)],
          'lurats': [('luras', True), ('lura', True)],
          'lussas': [('lussa', False)],
          'lussats': [('lussa', False)],
          'lusta': [('lusta', False)],
          'lustas': [('lusta', False)],
          'luten': [('lyta', False)],
          'lutens': [('luta', False)],
          'lutes': [('luta', False)],
          'lutet': [('luta', False)],
          'lutets': [('luta', False)],
          'lutit': [('luta', False)],
          'lutits': [('luta', False)],
          'lutna': [('lyta', False)],
          'lutnas': [('luta', False)],
          'lutne': [('luta', False)],
          'lutnes': [('luta', False)],
          'lvad': [('lva', False)],
          'lvande': [('lva', False)],
          'lvandes': [('lva', False)],
          'lvar': [('lva', False)],
          'lvas': [('lva', False)],
          'lvats': [('lva', False)],
          'lvda': [('lva', False)],
          'lvdas': [('lva', False)],
          'lver': [('lva', False)],
          'lverkat': [('lverka', False)],
          'lves': [('lva', False)],
          'lvrades': [('lvra', False)],
          'lvras': [('lvra', False)],
          'lvs': [('lva', False)],
          'ly': [('ly', False)],
          'ly-': [('lya', False)],
          'lyckades': [('lyckas', False)],
          'lyckas': [('lyckas', False)],
          'lydd': [('lyda', True)],
          'lydda': [('lyda', True)],
          'lyddas': [('lyda', True)],
          'lydde': [('lyda', True)],
          'lyddes': [('lyda', False)],
          'lydds': [('lyda', True)],
          'lygas': [('lyga', False)],
          'lyges': [('lygas', False)],
          'lygs': [('lygas', False)],
          'lyktas': [('lykta', True)],
          'lyktats': [('lykta', True)],
          'lyr': [('lyra', True)],
          'lys': [('lysa', False)],
          'lyst': [('lysa', False)],
          'lysta': [('lysa', False)],
          'lystas': [('lysa', False)],
          'lytt': [('lyda', True)],
          'lytta': [('lytta', False)],
          'lyttas': [('lytta', False)],
          'lytts': [('lyda', False)],
          'lyvas': [('lyva', False)],
          'lyves': [('lyva', False)],
          'lyvs': [('lyva', False)],
          'lyvts': [('lyva', False)],
          'lä': [('lä', False)],
          'lä-': [('läa', False)],
          'läckas': [('läcka', True)],
          'läckats': [('läcka', False)],
          'läckes': [('läcka', True)],
          'läcks': [('läcka', False)],
          'läcktes': [('läcka', False)],
          'läckts': [('läcka', True)],
          'läd': [('lä', False)],
          'läd-': [('läda', False)],
          'läda': [('lä', False)],
          'lädande': [('lä', False)],
          'lädandes': [('läda', False)],
          'lädas': [('lä', False)],
          'lädda': [('lä', False)],
          'lädds': [('lä', False)],
          'läder': [('lä', False)],
          'läds': [('lä', False)],
          'lägnats': [('lägna', False)],
          'läkt': [('läka', True)],
          'läkta': [('läka', False)],
          'läktades': [('läktas', False)],
          'läktas': [('läka', True)],
          'läktats': [('läkta', False)],
          'läkts': [('läka', False)],
          'lämde': [('lämma', False)],
          'lämnats': [('lämna', False)],
          'lämt': [('lämta', False)],
          'lämts': [('lämma', False)],
          'länades': [('läna', False)],
          'länas': [('läna', False)],
          'ländades': [('lända', False)],
          'ländas': [('lända', False)],
          'ländats': [('lända', False)],
          'länds': [('lända', False)],
          'längas': [('längas', True), ('länga', True)],
          'längdes': [('längas', True), ('länga', True)],
          'länges': [('längas', True), ('länga', True)],
          'längs': [('längas', True), ('länga', True)],
          'längts': [('längas', True), ('länga', True)],
          'länsta': [('länsa', False)],
          'länstas': [('länsa', False)],
          'länt': [('lända', True)],
          'länts': [('lända', False)],
          'lär': [('lär', True), ('lära', True)],
          'lär-': [('lära', True)],
          'lära': [('lära', False)],
          'lärande': [('lära', False)],
          'lärandes': [('lära', False)],
          'läras': [('lära', True)],
          'lärdes': [('lära', False)],
          'lärt': [('lära', True)],
          'läs': [('läsa', False)],
          'läst': [('läsa', False)],
          'lästa': [('läsa', True)],
          'lästas': [('läsa', True)],
          'lästs': [('läsa', False)],
          'lät': [('låta', False)],
          'läte': [('låta', True)],
          'lätes': [('låta', True)],
          'läts': [('låta', False)],
          'lätt': [('lä', False)],
          'lätta': [('lätta', True)],
          'lättas': [('lätta', False)],
          'lätts': [('lä', False)],
          'lå': [('lå', False)],
          'låd-': [('låda', False)],
          'lådandes': [('låda', False)],
          'lådd': [('låda', False)],
          'lådda': [('lå', False)],
          'låddas': [('lå', False)],
          'lådde': [('låda', False)],
          'låddes': [('låda', False)],
          'lådds': [('lå', False)],
          'låg': [('ligga', False)],
          'låge': [('lå', False)],
          'låges': [('lå', False)],
          'lågs': [('ligga', False)],
          'lår': [('lå', False)],
          'lås': [('låsa', False)],
          'låser': [('låsa', False)],
          'låses': [('låsa', False)],
          'låss': [('låssa', True)],
          'låssades': [('låssas', True), ('låssa', True)],
          'låssas': [('låssa', True), ('låssas', True)],
          'låssats': [('låssa', True), ('låssas', True)],
          'låst': [('låsa', False)],
          'låt': [('låta', False)],
          'låte': [('låta', False)],
          'låtes': [('låta', False)],
          'låts': [('låtsa', True), ('låta', True)],
          'låtsades': [('låtsas', True), ('låtsa', True)],
          'låtsas': [('låtsa', True), ('låtsas', True)],
          'låtsats': [('låtsa', True), ('låtsas', True)],
          'lått': [('lå', False)],
          'låtts': [('låda', False)],
          'löd': [('lyda', True), ('löda', True)],
          'löd-': [('löda', False)],
          'lödandes': [('löda', False)],
          'lödd': [('löda', False)],
          'löddes': [('löda', False)],
          'löde': [('lyda', False)],
          'löder': [('löda', False)],
          'lödes': [('löda', True), ('lyda', True)],
          'lödgats': [('lödga', False)],
          'löds': [('lyda', True), ('löda', True)],
          'lög': [('löga', True)],
          'löge': [('lyga', False)],
          'lögg': [('lögga', False)],
          'lögs': [('lyga', False)],
          'löjas': [('löja', False)],
          'löjd': [('löja', False)],
          'löjda': [('löjda', False)],
          'löjdas': [('löjda', False)],
          'löjdats': [('löjda', False)],
          'löjdes': [('löja', False)],
          'löjs': [('löja', False)],
          'löjt': [('löja', False)],
          'löjts': [('löja', False)],
          'lök': [('luka', False)],
          'löke': [('luka', False)],
          'lömde': [('lömma', False)],
          'lömt': [('lömma', False)],
          'löp': [('löpa', False)],
          'löpe': [('löpa', False)],
          'löpes': [('löpa', False)],
          'löras': [('löra', False)],
          'lösas': [('lösa', False)],
          'löses': [('lösa', True)],
          'löst': [('lösa', False)],
          'löstes': [('lösa', True)],
          'lösts': [('lösa', False)],
          'löt': [('luta', False)],
          'löte': [('lyta', False)],
          'lötes': [('lyta', False)],
          'löts': [('luta', False)],
          'lött': [('löda', True)],
          'lötts': [('löda', False)],
          'löv': [('löva', True)],
          'lövades': [('lövas', True), ('löva', True)],
          'lövas': [('lövas', True), ('löva', True)],
          'lövats': [('lövas', True), ('löva', True)],
          'löves': [('lyva', False)],
          'm': [('ma', False)],
          'm-': [('ma', False)],
          'ma': [('ma', False)],
          'mack': [('macka', False)],
          'mad': [('ma', False)],
          'made': [('ma', False)],
          'mades': [('ma', False)],
          'mads': [('ma', False)],
          'makades': [('maka', True)],
          'mal': [('mala', False)],
          'mala': [('mala', False)],
          'malades': [('malägga', False)],
          'malas': [('mala', False)],
          'mald': [('mala', False)],
          'malda': [('mala', True)],
          'malde': [('mala', False)],
          'maldes': [('mala', True)],
          'malds': [('mala', True)],
          'mall': [('mälla', False)],
          'malna': [('mala', True)],
          'malnas': [('mala', False)],
          'malnats': [('malna', False)],
          'malt': [('mala', False)],
          'malts': [('mala', False)],
          'man': [('mana', False)],
          'mande': [('ma', False)],
          'mandes': [('ma', False)],
          'mann': [('manna', False)],
          'mansköt': [('manskjuta', False)],
          'manskötes': [('manskjuta', False)],
          'mansköts': [('manskjuta', False)],
          'mar': [('ma', False)],
          'mas': [('masa', True)],
          'mat': [('ma', False)],
          'matt': [('matta', True)],
          'matta': [('matta', False)],
          'mattades': [('mattas', True), ('matta', True)],
          'mattas': [('matta', True), ('mattas', True)],
          'mattats': [('matta', True), ('mattas', True)],
          'mavla': [('mavla', False)],
          'mavlade': [('mavla', False)],
          'mavlades': [('mavla', False)],
          'mavlas': [('mavla', False)],
          'mbar': [('mbära', False)],
          'mbas': [('mba', False)],
          'mbats': [('mba', False)],
          'mbesvär': [('mbesvärja', False)],
          'mbesvär-': [('mbesvärja', False)],
          'mbesvära': [('mbesvärja', False)],
          'mbesvärande': [('mbesvärja', False)],
          'mbesvärandes': [('mbesvärja', False)],
          'mbesväras': [('mbesvärja', False)],
          'mbildades': [('mbilda', False)],
          'mbildas': [('mbilda', False)],
          'md': [('mma', False)],
          'mda': [('mma', False)],
          'mdas': [('mma', False)],
          'mde': [('mma', False)],
          'mdes': [('ma', False)],
          'mdrev': [('mdriva', False)],
          'mds': [('ma', False)],
          'medlade': [('medla', True)],
          'medlades': [('medla', False)],
          'mek': [('meka', False)],
          'mekas': [('meka', True)],
          'mel': [('la', False)],
          'mel-': [('la', False)],
          'men': [('mena', False)],
          'menades': [('mena', False)],
          'menas': [('mena', False)],
          'menats': [('mena', True)],
          'mende': [('mena', True)],
          'mendes': [('mena', True)],
          'mens': [('ma', False)],
          'ment': [('mena', False)],
          'menta': [('menta', False)],
          'mentas': [('menta', False)],
          'mer-': [('ra', False)],
          'merad': [('mera', False)],
          'merades': [('mera', False)],
          'meras': [('mera', False)],
          'met': [('meta', False)],
          'metades': [('meta', False)],
          'mets': [('mita', False)],
          'mfades': [('mfa', False)],
          'mfar': [('mfara', False)],
          'mfas': [('mfa', False)],
          'mfats': [('mfa', False)],
          'mfattades': [('mfatta', False)],
          'mfattas': [('mfatta', False)],
          'mfattats': [('mfatta', False)],
          'mflytt': [('mflytta', False)],
          'mfors': [('mfara', False)],
          'mfödas': [('mföda', False)],
          'mföds': [('mföda', False)],
          'mger': [('mge', False)],
          'mges': [('mge', False)],
          'mgicks': [('mgå', False)],
          'mgås': [('mgå', False)],
          'mgåtts': [('mgås', False)],
          'mhävd': [('mhäva', False)],
          'mhävda': [('mhäva', False)],
          'mhävdas': [('mhäva', False)],
          'mhållas': [('mhålla', False)],
          'mhållits': [('mhålla', False)],
          'mhålls': [('mhålla', False)],
          'mhölls': [('mhålla', False)],
          'midas': [('mida', False)],
          'middes': [('mida', False)],
          'mides': [('mida', False)],
          'mids': [('mida', False)],
          'mierats': [('miera', False)],
          'mim': [('mima', True)],
          'mim-': [('mima', True)],
          'mind': [('minna', True)],
          'minda': [('minna', False)],
          'mindas': [('minna', True)],
          'minde': [('minna', True)],
          'mindes': [('minnas', True), ('minna', True)],
          'minnas': [('minnas', True), ('minna', True)],
          'minnes': [('minna', True)],
          'minns': [('minna', True), ('minnas', True)],
          'mint': [('minna', True)],
          'mints': [('minnas', True), ('minna', True)],
          'miserad': [('misera', False)],
          'mista': [('mista', True)],
          'mistas': [('mista', True)],
          'mistats': [('mista', True)],
          'miste': [('mista', True)],
          'mister': [('mista', True)],
          'mistes': [('mista', True)],
          'mit': [('mita', False)],
          'mits': [('mita', False)],
          'mitts': [('mida', False)],
          'mjande': [('mja', False)],
          'mjda': [('mja', False)],
          'mjdas': [('mja', False)],
          'mjer': [('mja', False)],
          'mkar': [('mka', False)],
          'mkas': [('mka', False)],
          'mkats': [('mka', False)],
          'mkomna': [('mkomma', False)],
          'mkörd': [('mköra', False)],
          'mla': [('mla', False)],
          'mlade': [('mla', False)],
          'mlades': [('mla', False)],
          'mlats': [('mla', False)],
          'mled': [('mlida', False)],
          'mleds': [('mlida', False)],
          'mlev': [('mleva', False)],
          'mläst': [('mlästa', False)],
          'mlästa': [('mlästa', False)],
          'mlästas': [('mlästa', False)],
          'mmats': [('mma', False)],
          'mmdes': [('mmas', False)],
          'mmen': [('mma', False)],
          'mmer': [('mma', False)],
          'mmet': [('mma', False)],
          'mmets': [('mma', False)],
          'mmit': [('mma', False)],
          'mmits': [('mma', False)],
          'mmts': [('mmas', False)],
          'mna': [('mna', False)],
          'mnar': [('mna', False)],
          'mnats': [('mna', False)],
          'mnd': [('mna', False)],
          'mnda': [('mna', False)],
          'mndas': [('mna', False)],
          'mnde': [('mna', False)],
          'mndes': [('mna', False)],
          'mnds': [('mna', False)],
          'mne': [('mma', False)],
          'mnerats': [('mnera', False)],
          'mnes': [('mna', False)],
          'mnge': [('mnge', False)],
          'mnger': [('mnge', False)],
          'mns': [('mna', False)],
          'mnt': [('mna', False)],
          'mnts': [('mna', False)],
          'mockats': [('mocka', False)],
          'modades': [('moda', False)],
          'moniserad': [('monisera', False)],
          'mopp': [('moppa', True)],
          'moppats': [('moppa', True)],
          'morda': [('mörja', False)],
          'mordas': [('mörja', False)],
          'mordna': [('mordna', False)],
          'mordnas': [('mordna', False)],
          'motsade': [('motsäga', True)],
          'motsades': [('motsäga', True)],
          'mottas': [('motta', False)],
          'mpar': [('mpa', False)],
          'mpats': [('mpa', False)],
          'mpe': [('mpa', False)],
          'mpel': [('mpla', False)],
          'mpel-': [('mpla', False)],
          'mper': [('mpa', False)],
          'mpes': [('mpa', False)],
          'mpla': [('mpla', False)],
          'mplas': [('mpla', False)],
          'mpnas': [('mpna', False)],
          'mps': [('mpa', False)],
          'mpta': [('mpa', False)],
          'mptas': [('mpa', False)],
          'mrades': [('mras', False)],
          'mras': [('mras', False)],
          'mrat': [('mra', False)],
          'mrats': [('mra', False)],
          'mräknade': [('mräkna', False)],
          'mräknades': [('mräkna', False)],
          'mräknas': [('mräkna', False)],
          'mräknats': [('mräkna', False)],
          'mråd': [('mråda', False)],
          'mråd-': [('mråda', False)],
          'mråda': [('mråda', False)],
          'mrådande': [('mråda', False)],
          'mrådandes': [('mråda', False)],
          'mrådas': [('mråda', False)],
          'mrådd': [('mråda', False)],
          'mrådda': [('mråda', False)],
          'mråddas': [('mråda', False)],
          'mrådde': [('mråda', False)],
          'mråddes': [('mråda', False)],
          'mrådds': [('mråda', False)],
          'mråder': [('mråda', False)],
          'mråds': [('mråda', False)],
          'mrått': [('mråda', False)],
          'mråtts': [('mråda', False)],
          'mrök': [('mröka', False)],
          'mröks': [('mröka', False)],
          'ms': [('msa', False)],
          'msa': [('msa', False)],
          'msas': [('msa', False)],
          'msats': [('msa', False)],
          'msatt': [('msätta', False)],
          'msatts': [('msätta', False)],
          'mska': [('mska', False)],
          'mskad': [('mska', False)],
          'mskade': [('mska', False)],
          'mskades': [('mska', False)],
          'mskar': [('mska', False)],
          'msken': [('mskina', False)],
          'mskjuts': [('mskjuta', False)],
          'mskrev': [('mskriva', False)],
          'mskymt': [('mskymta', False)],
          'msköt': [('mskjuta', False)],
          'mskötes': [('mskjuta', False)],
          'msköts': [('mskjuta', False)],
          'mslagits': [('mslå', False)],
          'mslogs': [('mslå', False)],
          'mspelas': [('mspela', False)],
          'mspråkades': [('mspråka', False)],
          'mspråkas': [('mspråka', False)],
          'mspråkats': [('mspråka', False)],
          'mspänt': [('mspänna', False)],
          'mster': [('mstra', False)],
          'mstöp': [('mstöpa', False)],
          'mstöpes': [('mstöpa', False)],
          'mstöps': [('mstöpa', False)],
          'mstört': [('mstörta', False)],
          'msyr': [('msyra', False)],
          'msåg': [('mse', False)],
          'mt': [('mta', False)],
          'mta': [('mta', False)],
          'mtagits': [('mta', False)],
          'mtalades': [('mtala', False)],
          'mtas': [('mta', False)],
          'mtats': [('mta', False)],
          'mtogs': [('mta', False)],
          'mträd': [('mträda', False)],
          'mträd-': [('mträda', False)],
          'mträda': [('mträda', False)],
          'mträdande': [('mträda', False)],
          'mträdandes': [('mträda', False)],
          'mträdas': [('mträda', False)],
          'mträdd': [('mträda', False)],
          'mträdda': [('mträda', False)],
          'mträddas': [('mträda', False)],
          'mträdde': [('mträda', False)],
          'mträddes': [('mträda', False)],
          'mträdds': [('mträda', False)],
          'mträder': [('mträda', False)],
          'mträds': [('mträda', False)],
          'mträngas': [('mtränga', False)],
          'mträngdes': [('mtränga', False)],
          'mträngs': [('mtränga', False)],
          'mträngt': [('mtränga', False)],
          'mträngts': [('mtränga', False)],
          'mträtt': [('mträda', False)],
          'mträtts': [('mträda', False)],
          'mtyckas': [('mtycka', False)],
          'mtyckes': [('mtycka', False)],
          'mtycks': [('mtycka', False)],
          'mtycktes': [('mtycka', False)],
          'mtyckts': [('mtycka', False)],
          'mugen': [('myga', False)],
          'mugets': [('myga', False)],
          'mugna': [('myga', False)],
          'mugnas': [('myga', False)],
          'mulna': [('mulna', True)],
          'multna': [('multna', True)],
          'multnas': [('multna', False)],
          'murades': [('mura', True)],
          'muras': [('mura', True)],
          'muts': [('mutsa', False)],
          'mutsade': [('mutsa', False)],
          'mutsades': [('mutsa', False)],
          'mvalt': [('mvälja', False)],
          'mvar': [('mvara', False)],
          'mvarades': [('mvara', False)],
          'mvaras': [('mvara', False)],
          'mverkat': [('mverka', False)],
          'mvisats': [('mvisa', False)],
          'mväljas': [('mvälja', False)],
          'mvänt': [('mvända', False)],
          'myckats': [('mycka', False)],
          'mygas': [('myga', False)],
          'mynt': [('mynta', True)],
          'mynta': [('mynta', True)],
          'myntas': [('mynta', False)],
          'mys': [('mysa', False)],
          'myst': [('mysa', False)],
          'mäckes': [('mäcka', False)],
          'mäcks': [('mäcka', False)],
          'mäcktes': [('mäcka', False)],
          'mädandes': [('mäda', False)],
          'mäklades': [('mäkla', True)],
          'mäklas': [('mäkla', True)],
          'mäklats': [('mäkla', True)],
          'mäkta': [('mäkta', True)],
          'mäktats': [('mäkta', False)],
          'mälde': [('mäla', False)],
          'mäldes': [('mäla', False)],
          'mält': [('mälta', True), ('mäla', True)],
          'mälte': [('mäla', True)],
          'mältes': [('mäla', True)],
          'mälts': [('mäla', True)],
          'mängs': [('mänga', False)],
          'märgla': [('märgla', False)],
          'märglas': [('märgla', False)],
          'mätt': [('mätta', True), ('mäta', True)],
          'mätta': [('mätta', True), ('mäta', True)],
          'mättas': [('mäta', True), ('mätta', True)],
          'mätte': [('mäta', True)],
          'mätter': [('mätta', False)],
          'mättes': [('mäta', True)],
          'mätts': [('mäta', False)],
          'må': [('må', False)],
          'mådda': [('må', False)],
          'måddas': [('må', False)],
          'mådds': [('må', False)],
          'måla': [('måla', False)],
          'målade': [('måla', False)],
          'målades': [('måla', False)],
          'målas': [('måla', False)],
          'måles': [('måle', False)],
          'mår': [('må', True)],
          'måsta': [('måste', True)],
          'måste': [('måste', True)],
          'mått': [('må', True), ('måtta', True)],
          'mög': [('myga', False)],
          'möge': [('myga', False)],
          'mögs': [('myga', False)],
          'möras': [('möra', False)],
          'mörd': [('mörda', False)],
          'mörda': [('mörda', True)],
          'mördas': [('mörda', False)],
          'mötas': [('mötas', True), ('möta', True)],
          'mötes': [('möta', True), ('mötas', True)],
          'möts': [('mötas', True), ('möta', True)],
          'mött': [('möta', True)],
          'möttes': [('mötas', True), ('möta', True)],
          'mötts': [('mötas', True), ('möta', True)],
          'n': [('na', False)],
          'n-': [('na', False)],
          'nabbades': [('nabbas', False)],
          'nabbas': [('nabbas', False)],
          'nabbats': [('nabba', False)],
          'nack': [('nacka', True)],
          'nad': [('na', False)],
          'nade': [('na', False)],
          'nades': [('na', False)],
          'nads': [('na', False)],
          'nag': [('naga', False)],
          'nagandes': [('naga', False)],
          'nagd': [('naga', False)],
          'nagda': [('naga', False)],
          'nagdas': [('naga', False)],
          'nagde': [('naga', False)],
          'nagdes': [('naga', False)],
          'nagds': [('naga', False)],
          'nage': [('nage', False)],
          'nager': [('nage', False)],
          'nages': [('naga', False)],
          'naglade': [('nagla', True)],
          'naglades': [('nagla', True)],
          'nagt': [('naga', False)],
          'nagts': [('naga', False)],
          'nakades': [('naka', False)],
          'nala': [('nala', False)],
          'nalade': [('nala', False)],
          'nalas': [('nala', False)],
          'nalkades': [('nalkas', True)],
          'nall': [('nalla', True)],
          'nam': [('nimma', False)],
          'nande': [('na', False)],
          'nandes': [('na', False)],
          'napp': [('nappa', False)],
          'nappades': [('nappas', True), ('nappa', True)],
          'nappas': [('nappas', True), ('nappa', True)],
          'nappats': [('nappas', True), ('nappa', True)],
          'nar': [('nara', True)],
          'narades': [('nara', False)],
          'naras': [('nara', False)],
          'narkas': [('narka', False)],
          'narkats': [('narka', False)],
          'narrades': [('narras', True), ('narra', True)],
          'narras': [('narras', True), ('narra', True)],
          'narrats': [('narras', True), ('narra', True)],
          'nartades': [('nartas', False)],
          'nas': [('na', False)],
          'nat': [('na', False)],
          'natt': [('natta', False)],
          'natta': [('natta', False)],
          'nattades': [('nattas', True), ('natta', True)],
          'nattas': [('natta', True), ('nattas', True)],
          'nattats': [('nattas', True), ('natta', True)],
          'nav': [('nava', False)],
          'nava': [('nava', False)],
          'navandes': [('nava', False)],
          'navla': [('navla', True)],
          'navlade': [('navla', False)],
          'navlades': [('navla', False)],
          'navlas': [('navla', False)],
          'navs': [('nava', False)],
          'nband': [('nbinda', False)],
          'nbar': [('nbara', False)],
          'nbildades': [('nbilda', False)],
          'nbrändes': [('nbränna', False)],
          'nbrännas': [('nbränna', False)],
          'nbränns': [('nbränna', False)],
          'nbränts': [('nbränna', False)],
          'nchas': [('ncha', False)],
          'ndande': [('nda', False)],
          'ndats': [('nda', False)],
          'ndel': [('ndla', False)],
          'ndel-': [('ndla', False)],
          'ndelade': [('ndela', False)],
          'ndelades': [('ndela', False)],
          'nden': [('', False)],
          'ndens': [('', False)],
          'nder': [('nda', False)],
          'nder-': [('ndra', False)],
          'ndet': [('', False)],
          'ndets': [('', False)],
          'ndigats': [('ndiga', False)],
          'ndla': [('ndla', False)],
          'ndlade': [('ndlägga', False)],
          'ndlades': [('ndlägga', False)],
          'ndlas': [('ndla', False)],
          'ndna': [('', False)],
          'ndnas': [('', False)],
          'ndne': [('', False)],
          'ndnes': [('', False)],
          'ndrades': [('ndra', False)],
          'ndragits': [('ndra', False)],
          'ndras': [('ndra', False)],
          'ndrev': [('ndriva', False)],
          'ndrog': [('ndra', False)],
          'ndrogs': [('ndra', False)],
          'ndskades': [('ndskas', False)],
          'ne': [('a', False)],
          'nedd': [('nedda', False)],
          'nedda': [('nedda', False)],
          'neddas': [('nedda', False)],
          'nedla': [('nedlägga', True)],
          'nedlas': [('nedlägga', True)],
          'negat': [('nega', False)],
          'negats': [('nega', False)],
          'nek': [('neka', False)],
          'nekes': [('nika', False)],
          'nel': [('nela', False)],
          'nel-': [('nela', False)],
          'nela': [('nela', False)],
          'nelas': [('nela', False)],
          'nelat': [('nela', False)],
          'nenta': [('nenta', False)],
          'nentas': [('nenta', False)],
          'neps': [('nipa', False)],
          'nerad': [('nera', False)],
          'nerades': [('nera', False)],
          'neras': [('nera', False)],
          'nes': [('a', False)],
          'net': [('neta', False)],
          'netades': [('neta', False)],
          'nfattades': [('nfatta', False)],
          'nfattas': [('nfatta', False)],
          'nfattats': [('nfatta', False)],
          'nflytt': [('nflytta', False)],
          'nfordrades': [('nfordra', False)],
          'nfordras': [('nfordra', False)],
          'nfordrats': [('nfordra', False)],
          'nfäktades': [('nfäkta', False)],
          'nfäktas': [('nfäkta', False)],
          'nfäktats': [('nfäkta', False)],
          'nga': [('nga', False)],
          'ngande': [('nga', False)],
          'ngar': [('nga', False)],
          'ngats': [('nga', False)],
          'nge': [('', False)],
          'ngen': [('', False)],
          'ngens': [('', False)],
          'nger': [('nga', False)],
          'nges': [('nge', False)],
          'nget': [('', False)],
          'ngets': [('', False)],
          'ngicks': [('ngå', False)],
          'ngjord': [('ngöra', False)],
          'ngjorda': [('ngöra', False)],
          'ngjordas': [('ngöra', False)],
          'ngla': [('ngla', False)],
          'nglas': [('ngla', False)],
          'ngledes': [('ngledas', False)],
          'ngleds': [('ngledas', False)],
          'ngna': [('', False)],
          'ngnas': [('', False)],
          'ngne': [('', False)],
          'ngnes': [('', False)],
          'ngrades': [('ngra', False)],
          'ngras': [('ngra', False)],
          'ngs': [('nga', False)],
          'ngås': [('ngå', False)],
          'nhandla': [('nhandla', False)],
          'nhandlade': [('nhandla', False)],
          'nhandlades': [('nhandla', False)],
          'nhandlas': [('nhandla', False)],
          'nhuggas': [('nhuggas', False)],
          'nhugges': [('nhuggas', False)],
          'nhuggits': [('nhuggas', False)],
          'nhuggs': [('nhuggas', False)],
          'nhyst': [('nhysa', False)],
          'nhysta': [('nhysa', False)],
          'nhystas': [('nhysa', False)],
          'nhållas': [('nhålla', False)],
          'nhållits': [('nhålla', False)],
          'nhålls': [('nhålla', False)],
          'nhöggs': [('nhuggas', False)],
          'nhölls': [('nhålla', False)],
          'nhöstades': [('nhösta', False)],
          'nhöstas': [('nhösta', False)],
          'nhöstats': [('nhösta', False)],
          'nidas': [('nida', False)],
          'nidats': [('nida', False)],
          'nides': [('nida', False)],
          'nids': [('nida', False)],
          'nierats': [('niera', False)],
          'nigas': [('niga', True)],
          'nilla': [('nilla', False)],
          'nillade': [('nilla', False)],
          'nillades': [('nilla', False)],
          'nillats': [('nilla', False)],
          'nimmer': [('nimma', False)],
          'niserad': [('nisera', False)],
          'nista': [('nista', False)],
          'nistas': [('nista', False)],
          'nistats': [('nista', False)],
          'nit': [('nita', False)],
          'nits': [('nitsa', False)],
          'niva': [('niva', False)],
          'nivades': [('niva', False)],
          'nivande': [('niva', False)],
          'nivandes': [('niva', False)],
          'nivas': [('niva', False)],
          'njande': [('nja', False)],
          'njats': [('nja', False)],
          'njda': [('nja', False)],
          'njdas': [('nja', False)],
          'njer': [('nja', False)],
          'njes': [('nja', False)],
          'njs': [('nja', False)],
          'njuts': [('njuta', True)],
          'nkar': [('nka', False)],
          'nkas': [('nka', False)],
          'nkats': [('nka', False)],
          'nke': [('nka', False)],
          'nkel': [('nkla', False)],
          'nkel-': [('nkla', False)],
          'nken': [('nka', False)],
          'nkens': [('nka', False)],
          'nker': [('nka', False)],
          'nker-': [('nkra', False)],
          'nkes': [('nka', False)],
          'nket': [('nka', False)],
          'nkets': [('nka', False)],
          'nkla': [('nkla', False)],
          'nklar': [('nkla', False)],
          'nknade': [('nkna', False)],
          'nknades': [('nkna', False)],
          'nknas': [('nkna', False)],
          'nknat': [('nkna', False)],
          'nkne': [('nka', False)],
          'nkomna': [('nkomma', False)],
          'nkrats': [('nkra', False)],
          'nkrävas': [('nkräva', False)],
          'nkrävdes': [('nkräva', False)],
          'nkräves': [('nkräva', False)],
          'nkrävs': [('nkräva', False)],
          'nkrävts': [('nkräva', False)],
          'nks': [('nka', False)],
          'nkta': [('nka', False)],
          'nktades': [('nkta', False)],
          'nktas': [('nka', False)],
          'nktes': [('nka', False)],
          'nkändes': [('nkänna', False)],
          'nkännas': [('nkänna', False)],
          'nkänns': [('nkänna', False)],
          'nkänts': [('nkänna', False)],
          'nla': [('nlägga', False)],
          'nlas': [('nlägga', False)],
          'nled': [('nleda', False)],
          'nledas': [('nleda', False)],
          'nleddes': [('nleda', False)],
          'nledes': [('nleda', False)],
          'nleds': [('nleda', False)],
          'nlett': [('nleda', False)],
          'nletts': [('nle', False)],
          'nlev': [('nleva', False)],
          'nljudes': [('nljuda', False)],
          'nljöds': [('nljuda', False)],
          'nlär': [('nlära', False)],
          'nlåts': [('nlåta', False)],
          'nmat': [('nmata', False)],
          'nmält': [('nmäla', False)],
          'nmälte': [('nmäla', False)],
          'nna': [('nna', False)],
          'nnages': [('nnage', False)],
          'nnar': [('nna', False)],
          'nnats': [('nna', False)],
          'nndes': [('nnas', False)],
          'nne': [('nna', False)],
          'nnerats': [('nnera', False)],
          'nnes': [('nna', False)],
          'nns': [('nna', False)],
          'nnskad': [('nnskada', False)],
          'nnts': [('nnas', False)],
          'no': [('no', False)],
          'no-': [('no', False)],
          'nockats': [('nocka', True)],
          'nodda': [('no', False)],
          'nol': [('nola', False)],
          'noniserad': [('nonisera', False)],
          'nopp': [('noppa', False)],
          'noppades': [('noppa', True)],
          'noppas': [('noppa', True)],
          'noppats': [('noppa', False)],
          'nopprad': [('noppra', True)],
          'nor': [('no', False)],
          'nordna': [('nordna', False)],
          'nordnas': [('nordna', False)],
          'nos': [('nosa', True)],
          'nott': [('no', False)],
          'nrat': [('nra', False)],
          'nrats': [('nra', False)],
          'nred': [('nreda', False)],
          'nreda': [('nreda', False)],
          'nredds': [('nreda', False)],
          'nreds': [('nreda', False)],
          'nrestas': [('nresa', False)],
          'nrev': [('nreva', False)],
          'nrymdes': [('nrymma', False)],
          'nrymmas': [('nrymma', False)],
          'nryms': [('nrymma', False)],
          'nrymt': [('nrymma', False)],
          'nrymts': [('nrymma', False)],
          'nräknade': [('nräkna', False)],
          'nräknades': [('nräkna', False)],
          'nräknas': [('nräkna', False)],
          'nräknats': [('nräkna', False)],
          'nrätt': [('nrätta', False)],
          'nröjda': [('nröja', False)],
          'ns': [('nsa', False)],
          'nsa': [('nsa', False)],
          'nsade': [('nsa', False)],
          'nsades': [('nsa', False)],
          'nsamlades': [('nsamla', False)],
          'nsamlas': [('nsamla', False)],
          'nsamlats': [('nsamla', False)],
          'nsas': [('nsa', False)],
          'nsats': [('nsa', False)],
          'nsatt': [('nsätta', False)],
          'nsatts': [('nsätta', False)],
          'nschas': [('nscha', False)],
          'nsel': [('nsla', False)],
          'nsel-': [('nsla', False)],
          'nser': [('nsa', False)],
          'nses': [('nsa', False)],
          'nska': [('nska', False)],
          'nskad': [('nska', False)],
          'nskadad': [('nskada', False)],
          'nskade': [('nska', False)],
          'nskades': [('nska', False)],
          'nskar': [('nska', False)],
          'nske': [('nska', False)],
          'nske-': [('nska', False)],
          'nskildes': [('nskilja', False)],
          'nskiljas': [('nskilja', False)],
          'nskiljes': [('nskilja', False)],
          'nskiljs': [('nskilja', False)],
          'nskilts': [('nskilja', False)],
          'nskjuts': [('nskjuta', False)],
          'nskott': [('nsko', False)],
          'nskrev': [('nskriva', False)],
          'nskymt': [('nskymma', False)],
          'nsköt': [('nskjuta', False)],
          'nskötes': [('nskjuta', False)],
          'nsköts': [('nskjuta', False)],
          'nsla': [('nsla', False)],
          'nslades': [('nsla', False)],
          'nslagits': [('nslå', False)],
          'nslas': [('nsla', False)],
          'nslogs': [('nslå', False)],
          'nst': [('nsta', False)],
          'nst-': [('nsta', False)],
          'nstack': [('nsticka', False)],
          'nstades': [('nsta', False)],
          'nstande': [('nsta', False)],
          'nstandes': [('nsta', False)],
          'nste': [('nsa', False)],
          'nstes': [('nsa', False)],
          'nstött': [('nstöta', False)],
          'nstötta': [('nstöta', False)],
          'nstöttas': [('nstöta', False)],
          'nstötte': [('nstöta', False)],
          'nstötts': [('nstöta', False)],
          'nsåg': [('nse', False)],
          'nta': [('nta', False)],
          'ntag': [('nta', False)],
          'ntag-': [('nta', False)],
          'ntagits': [('nta', False)],
          'ntalades': [('ntala', False)],
          'ntas': [('nta', False)],
          'ntats': [('nta', False)],
          'nte-': [('nta', False)],
          'nter': [('ntra', False)],
          'ntierades': [('ntiera', False)],
          'ntieras': [('ntiera', False)],
          'ntierats': [('ntieras', False)],
          'ntla': [('ntla', False)],
          'ntlas': [('ntla', False)],
          'ntogs': [('nta', False)],
          'ntrades': [('ntra', False)],
          'ntras': [('ntra', False)],
          'nträd': [('nträda', False)],
          'nträd-': [('nträda', False)],
          'nträda': [('nträda', False)],
          'nträdande': [('nträda', False)],
          'nträdandes': [('nträda', False)],
          'nträdas': [('nträda', False)],
          'nträdd': [('nträda', False)],
          'nträdda': [('nträda', False)],
          'nträddas': [('nträda', False)],
          'nträdde': [('nträda', False)],
          'nträddes': [('nträda', False)],
          'nträdds': [('nträda', False)],
          'nträder': [('nträda', False)],
          'nträds': [('nträda', False)],
          'nträffades': [('nträffa', False)],
          'nträffas': [('nträffa', False)],
          'nträffats': [('nträffa', False)],
          'nträngas': [('ntränga', False)],
          'nträngdes': [('ntränga', False)],
          'nträngs': [('ntränga', False)],
          'nträngt': [('ntränga', False)],
          'nträngts': [('ntränga', False)],
          'nträtt': [('nträda', False)],
          'nträtts': [('nträda', False)],
          'nubbats': [('nubba', True)],
          'nuggats': [('nugga', False)],
          'nullades': [('nulla', False)],
          'nullas': [('nulla', False)],
          'nullats': [('nulla', False)],
          'nupen': [('nypa', True)],
          'nupet': [('nypa', True)],
          'nupets': [('nypa', True)],
          'nupits': [('nypa', True)],
          'nupna': [('nypa', True)],
          'nupnas': [('nypa', True)],
          'nupne': [('nypa', True)],
          'nupnes': [('nypa', True)],
          'nuppats': [('nuppa', True)],
          'nussas': [('nussa', False)],
          'nussats': [('nussa', False)],
          'nuten': [('nyta', False)],
          'nutna': [('nyta', False)],
          'nvalt': [('nvälja', False)],
          'nverkat': [('nverka', False)],
          'nvintrades': [('nvintra', False)],
          'nvintras': [('nvintra', False)],
          'nvintrats': [('nvintra', False)],
          'nvisades': [('nvisas', False)],
          'nvisas': [('nvisa', False)],
          'nvisats': [('nvisas', False)],
          'nväljas': [('nvälja', False)],
          'nvänt': [('nvända', False)],
          'ny': [('ny', False)],
          'ny-': [('nya', False)],
          'nyckes': [('nycka', False)],
          'nycks': [('nycka', False)],
          'nycktes': [('nycka', False)],
          'nydda': [('ny', False)],
          'nyddas': [('ny', False)],
          'nydds': [('ny', False)],
          'nyr': [('ny', False)],
          'nys': [('nysa', True)],
          'nyst': [('nysa', True), ('nysta', True)],
          'nysta': [('nysta', True)],
          'nytt': [('ny', False)],
          'nytta': [('nytta', True)],
          'nyttas': [('nytta', True)],
          'näbbades': [('näbbas', True)],
          'näbbas': [('näbbas', True)],
          'näckats': [('näcka', True)],
          'näckes': [('näcka', False)],
          'näcks': [('näcka', False)],
          'näcktes': [('näcka', False)],
          'nändes': [('nännas', True)],
          'nännas': [('nännas', True)],
          'nänts': [('nännas', True)],
          'näps': [('näpsa', True)],
          'när': [('nära', True)],
          'när-': [('nära', True)],
          'närande': [('nära', True)],
          'närandes': [('nära', True)],
          'näras': [('nära', False)],
          'närdes': [('nära', False)],
          'närjande': [('närja', False)],
          'närjer': [('närja', False)],
          'närjes': [('närja', False)],
          'närt': [('nära', False)],
          'närvar': [('närvara', True)],
          'näs': [('näsa', False)],
          'näst': [('nästa', True)],
          'nästa': [('nästa', True)],
          'nästas': [('nästa', True)],
          'näste': [('nästa', True)],
          'nästes': [('nästa', True)],
          'nästs': [('näsa', False)],
          'nå': [('nå', False)],
          'nåd-': [('nåda', False)],
          'nådandes': [('nåda', True)],
          'nådda': [('nå', True)],
          'nåddas': [('nå', True)],
          'nådds': [('nå', True)],
          'nåde': [('nåde', True)],
          'nådes': [('nåde', True)],
          'nåla': [('nåla', True)],
          'nålade': [('nåla', False)],
          'nålades': [('nåla', True)],
          'nålas': [('nåla', False)],
          'når': [('nå', False)],
          'nått': [('nå', False)],
          'nödgades': [('nödgas', True), ('nödga', True)],
          'nödgas': [('nödgas', True), ('nödga', True)],
          'nödgats': [('nödga', True), ('nödgas', True)],
          'nödsakades': [('nödsakas', True), ('nödsaka', True)],
          'nödsakas': [('nödsakas', True), ('nödsaka', True)],
          'nödsakats': [('nödsakas', True), ('nödsaka', True)],
          'nöjas': [('nöjas', True)],
          'nöjd': [('nöja', False)],
          'nöjdes': [('nöjas', True)],
          'nöjs': [('nöjas', True)],
          'nöjt': [('nöja', False)],
          'nöjts': [('nöjas', True)],
          'nöp': [('nypa', True)],
          'nöpe': [('nypa', True)],
          'nöpes': [('nypa', True)],
          'nöps': [('nypa', True)],
          'nöras': [('nöra', False)],
          'nördes': [('nöra', False)],
          'nört': [('nöra', False)],
          'nörts': [('nöra', False)],
          'nös': [('nysa', True)],
          'nöses': [('nysa', False)],
          'nöt': [('nöta', True)],
          'nöte': [('nyta', False)],
          'nötes': [('nöta', True)],
          'nöts': [('nöta', True)],
          'nött': [('nöta', True)],
          'nötts': [('nöta', True)],
          'növades': [('növa', False)],
          'o': [('a', False)],
          'oa': [('oa', False)],
          'oad': [('oa', False)],
          'oade': [('oa', False)],
          'oades': [('oa', False)],
          'oads': [('oa', False)],
          'oande': [('oa', False)],
          'oandes': [('oa', False)],
          'oar': [('oa', False)],
          'oas': [('oa', False)],
          'oat': [('oa', False)],
          'obbades': [('obba', False)],
          'obbas': [('obba', False)],
          'ockades': [('ocka', False)],
          'ockas': [('ocka', False)],
          'ocker': [('ockra', True)],
          'od': [('oda', False)],
          'oda': [('oda', False)],
          'odades': [('odas', False)],
          'odande': [('oda', False)],
          'odas': [('oda', False)],
          'odats': [('oda', False)],
          'odd': [('o', False)],
          'oddas': [('o', False)],
          'odde': [('o', False)],
          'oddes': [('o', False)],
          'ode': [('å', False)],
          'oder-': [('odra', False)],
          'odes': [('å', False)],
          'odkänns': [('odkänna', False)],
          'odla': [('odla', True)],
          'odlas': [('odla', True)],
          'odnas': [('odna', False)],
          'odrades': [('odra', False)],
          'odras': [('odra', False)],
          'ods': [('å', False)],
          'oe': [('å', False)],
          'oes': [('å', False)],
          'offas': [('offa', False)],
          'oga': [('oga', False)],
          'ogande': [('oga', False)],
          'ogar': [('oga', False)],
          'ogats': [('oga', False)],
          'oges': [('a', False)],
          'oggades': [('ogga', False)],
          'oggar': [('ogga', False)],
          'oggas': [('ogga', False)],
          'ogillades': [('ogilla', True)],
          'ogillas': [('ogilla', True)],
          'ogillats': [('ogilla', True)],
          'ogjord': [('ogöra', False)],
          'ogjorda': [('ogöra', False)],
          'ogjordas': [('ogöra', False)],
          'ogla': [('ogla', False)],
          'oglas': [('ogla', False)],
          'ogna': [('ogna', False)],
          'ognades': [('ogna', False)],
          'ognas': [('ogna', False)],
          'ognat': [('ogna', False)],
          'ohandla': [('ohandla', False)],
          'ohandlade': [('ohandla', False)],
          'ohandlades': [('ohandla', False)],
          'ohandlas': [('ohandla', False)],
          'oiserad': [('oisera', False)],
          'ojande': [('oja', False)],
          'ojats': [('oja', False)],
          'ojt': [('ojta', False)],
          'ojtades': [('ojta', False)],
          'okar': [('oka', False)],
          'okas': [('oka', False)],
          'okats': [('oka', False)],
          'oker': [('oka', False)],
          'okes': [('oka', False)],
          'oknade': [('okna', False)],
          'oknades': [('okna', False)],
          'oknas': [('okna', False)],
          'oknat': [('okna', False)],
          'oks': [('oka', False)],
          'okta': [('oka', False)],
          'oktas': [('oka', False)],
          'oktes': [('oka', False)],
          'ol': [('ola', True)],
          'ola': [('ola', True)],
          'olade': [('ola', False)],
          'olades': [('ola', False)],
          'olas': [('ola', False)],
          'olats': [('ola', False)],
          'old': [('olda', False)],
          'olda': [('ölja', False)],
          'oldades': [('olda', False)],
          'oldas': [('olda', False)],
          'olde': [('ölja', False)],
          'oldes': [('ölja', False)],
          'olds': [('ölja', False)],
          'ole': [('ala', False)],
          'oler': [('olera', False)],
          'oles': [('ala', False)],
          'olfar': [('olfa', False)],
          'oljas': [('olja', True)],
          'olkades': [('olka', False)],
          'oll': [('olla', False)],
          'ollades': [('olla', True)],
          'ollas': [('olla', True)],
          'ollats': [('olla', True)],
          'oller': [('ollra', False)],
          'olnades': [('olna', False)],
          'olnas': [('olna', False)],
          'ols': [('ala', False)],
          'olt': [('olta', False)],
          'olts': [('ölja', False)],
          'om': [('omma', False)],
          'om-': [('omma', False)],
          'omas': [('oma', False)],
          'omats': [('oma', False)],
          'ombad': [('ombe', True)],
          'ombade': [('ombe', True)],
          'ombades': [('ombe', True)],
          'ombads': [('ombe', True)],
          'ombar': [('omba', False)],
          'omgåtts': [('omgå', False)],
          'omlas': [('omla', False)],
          'ommades': [('omma', False)],
          'ommas': [('omma', False)],
          'omnades': [('omna', False)],
          'omnas': [('omna', False)],
          'omnes': [('omma', False)],
          'ompades': [('ompa', False)],
          'ompas': [('ompa', False)],
          'omrats': [('omras', False)],
          'oms': [('omma', False)],
          'omsade': [('omsa', False)],
          'omsades': [('omsa', False)],
          'omskar': [('omskära', True)],
          'omsköt': [('omsköta', True)],
          'omskötes': [('omsköta', True)],
          'omsköts': [('omsköta', True)],
          'ona': [('ona', False)],
          'onar': [('ona', False)],
          'onats': [('ona', False)],
          'onerats': [('onera', False)],
          'ongades': [('onga', False)],
          'ongas': [('onga', False)],
          'onkades': [('onka', False)],
          'ont': [('onta', False)],
          'ontrats': [('ontra', False)],
          'oom': [('ooma', False)],
          'oom-': [('ooma', False)],
          'opar': [('opa', False)],
          'opats': [('opa', False)],
          'opp': [('öpa', False)],
          'oppades': [('oppa', False)],
          'oppas': [('oppa', False)],
          'oppla': [('opplägga', True)],
          'opplade': [('opplägga', True)],
          'opplades': [('opplägga', True)],
          'opplas': [('opplägga', True)],
          'opprad': [('opprada', True)],
          'opps': [('öpa', False)],
          'oppta': [('oppta', True)],
          'opptas': [('oppta', True)],
          'opåverkat': [('opåverkad', True)],
          'orat': [('ora', False)],
          'orats': [('ora', False)],
          'ord': [('örja', False)],
          'orda': [('orda', True)],
          'ordades': [('orda', False)],
          'ordas': [('orda', True)],
          'orde': [('örja', False)],
          'orden': [('arda', False)],
          'ordens': [('arda', False)],
          'ordes': [('örja', False)],
          'ordet': [('arda', False)],
          'ordets': [('arda', False)],
          'ordla': [('ordlägga', False)],
          'ordlas': [('ordlägga', False)],
          'ordna': [('ordna', True)],
          'ordnas': [('ordna', True)],
          'ordne': [('arda', False)],
          'ordnes': [('arda', False)],
          'ordrats': [('ordra', False)],
          'ords': [('örja', False)],
          'ore': [('ara', False)],
          'ored': [('oreda', True)],
          'oreda': [('oreda', True)],
          'oredande': [('oreda', True)],
          'ores': [('ara', False)],
          'orgades': [('orga', False)],
          'orgas': [('orga', False)],
          'orgat': [('orga', False)],
          'orgats': [('orga', False)],
          'orkades': [('orka', False)],
          'orkat': [('orka', False)],
          'orklade': [('orkla', False)],
          'orklades': [('orkla', False)],
          'orklas': [('orkla', False)],
          'orla': [('orla', False)],
          'orlas': [('orla', False)],
          'ormades': [('orma', False)],
          'ornades': [('orna', False)],
          'ornas': [('orna', False)],
          'oro': [('oroa', True)],
          'oro-': [('oroa', True)],
          'orrades': [('orra', False)],
          'orras': [('orra', False)],
          'orsa': [('orsa', False)],
          'orsade': [('orsa', False)],
          'orsades': [('orsa', False)],
          'orsas': [('orsa', False)],
          'orskas': [('orska', False)],
          'orskats': [('orska', False)],
          'orsla': [('orslägga', False)],
          'orslade': [('orsla', False)],
          'orslades': [('orsla', False)],
          'orslas': [('orsla', False)],
          'ort': [('örja', False)],
          'ortades': [('orta', False)],
          'ortlade': [('ortla', False)],
          'ortlades': [('ortla', False)],
          'ortlas': [('ortla', False)],
          'orts': [('örja', False)],
          'orvar': [('orva', False)],
          'oräknade': [('oräkna', False)],
          'oräknades': [('oräkna', False)],
          'oräknas': [('oräkna', False)],
          'oräknats': [('oräkna', False)],
          'orätt': [('orätta', False)],
          'os': [('osa', True)],
          'osa': [('osa', False)],
          'osade': [('osa', False)],
          'osades': [('osa', False)],
          'osas': [('osa', False)],
          'osats': [('osa', False)],
          'osatt': [('osätta', False)],
          'osatts': [('osätta', False)],
          'oska': [('oska', False)],
          'oskade': [('oska', False)],
          'oskades': [('oska', False)],
          'oskar': [('oska', False)],
          'oskas': [('oskas', False)],
          'oskats': [('oskas', False)],
          'oskrev': [('oskriva', False)],
          'ossades': [('ossa', False)],
          'osslade': [('ossla', False)],
          'ost': [('osta', False)],
          'ost-': [('osta', False)],
          'ostades': [('osta', False)],
          'ostande': [('osta', False)],
          'ostandes': [('osta', False)],
          'oster': [('ostra', False)],
          'osåg': [('ose', False)],
          'ot': [('ota', False)],
          'ota': [('ota', False)],
          'otas': [('ota', False)],
          'otats': [('ota', False)],
          'ote': [('ota', False)],
          'ote-': [('ota', False)],
          'otierades': [('otiera', False)],
          'otieras': [('otiera', False)],
          'ots': [('otsa', False)],
          'otsade': [('otsa', False)],
          'otsades': [('otsa', False)],
          'ott': [('otta', False)],
          'ottades': [('otta', False)],
          'otter': [('ottra', False)],
          'ottla': [('ottlägga', False)],
          'ottlade': [('ottla', False)],
          'ottlades': [('ottla', False)],
          'ottlas': [('ottla', False)],
          'ottlats': [('ottla', False)],
          'otts': [('o', False)],
          'oturades': [('oturas', True)],
          'oturas': [('oturas', True)],
          'ovad': [('ova', False)],
          'ovande': [('ova', False)],
          'ovandes': [('ova', False)],
          'ovar': [('ova', False)],
          'ovas': [('ova', False)],
          'ovats': [('ova', False)],
          'ove': [('äva', False)],
          'ovel': [('ovla', False)],
          'ovel-': [('ovla', False)],
          'over': [('ova', False)],
          'oves': [('äva', False)],
          'ovisas': [('ovisa', False)],
          'ovisats': [('ovisa', False)],
          'ovit': [('ova', False)],
          'ovits': [('ova', False)],
          'ovlas': [('ovla', False)],
          'ovnas': [('ovna', False)],
          'ovrades': [('ovra', False)],
          'ovras': [('ovra', False)],
          'ovs': [('ava', False)],
          'ovänt': [('ovända', False)],
          'oxats': [('oxa', False)],
          'p': [('pa', False)],
          'p-': [('pa', False)],
          'pa': [('pa', False)],
          'pack': [('packa', False)],
          'pad': [('pa', False)],
          'pade': [('pa', False)],
          'pades': [('pa', False)],
          'pads': [('pa', False)],
          'pakades': [('paka', False)],
          'paknats': [('pakna', False)],
          'pakta': [('pakta', False)],
          'palt': [('palta', False)],
          'pan': [('pana', False)],
          'pande': [('pa', False)],
          'pandes': [('pa', False)],
          'par': [('para', True)],
          'parades': [('para', False)],
          'paras': [('para', False)],
          'pars': [('parsa', True)],
          'partades': [('parta', True)],
          'partas': [('parta', True)],
          'partats': [('parta', True)],
          'pas': [('pa', False)],
          'pat': [('pa', False)],
          'pband': [('pbinda', False)],
          'pbar': [('pbära', False)],
          'pdagades': [('pdaga', False)],
          'pdagas': [('pdaga', False)],
          'pdagats': [('pdaga', False)],
          'pdelade': [('pdela', False)],
          'pdelades': [('pdela', False)],
          'pdragits': [('pdra', False)],
          'pdras': [('pdra', False)],
          'pdrev': [('pdriva', False)],
          'pdrog': [('pdra', False)],
          'pdrogs': [('pdra', False)],
          'pe': [('pe', False)],
          'pedandes': [('peda', False)],
          'pek': [('peka', False)],
          'pel': [('pela', False)],
          'pel-': [('pela', False)],
          'pela': [('pela', False)],
          'pelat': [('pela', False)],
          'peld': [('pela', False)],
          'pelda': [('pela', False)],
          'peldas': [('pela', False)],
          'pens': [('pa', False)],
          'peps': [('pipa', True)],
          'per': [('pra', False)],
          'perad': [('pera', False)],
          'perades': [('pera', False)],
          'peras': [('pera', False)],
          'pesta': [('pesta', False)],
          'pestas': [('pesta', False)],
          'pet': [('peta', False)],
          'petades': [('peta', False)],
          'pets': [('petsa', False)],
          'pett': [('petta', False)],
          'pettas': [('petta', False)],
          'pettats': [('petta', False)],
          'pfanns': [('pfinna', False)],
          'pfattades': [('pfatta', False)],
          'pfattas': [('pfatta', False)],
          'pfattats': [('pfatta', False)],
          'pfinnas': [('pfinna', False)],
          'pfinnes': [('pfinna', False)],
          'pfinns': [('pfinna', False)],
          'pfordrades': [('pfordra', False)],
          'pfordras': [('pfordra', False)],
          'pfordrats': [('pfordra', False)],
          'pfunnits': [('pfinna', False)],
          'pfödas': [('pföda', False)],
          'pföds': [('pföda', False)],
          'pge': [('pge', False)],
          'pges': [('pge', False)],
          'pgicks': [('pgå', False)],
          'phandla': [('phandla', False)],
          'phandlade': [('phandla', False)],
          'phandlades': [('phandla', False)],
          'phandlas': [('phandla', False)],
          'phuggas': [('phugga', False)],
          'phävd': [('phäva', False)],
          'phävda': [('phäva', False)],
          'phävdas': [('phäva', False)],
          'phöggs': [('phugga', False)],
          'pick': [('picka', True)],
          'pierats': [('piera', False)],
          'piggar': [('pigg', True)],
          'pilla': [('pilla', True)],
          'pillade': [('pilla', True)],
          'pillades': [('pilla', True)],
          'pillats': [('pilla', True)],
          'piller': [('pillra', True)],
          'pills': [('pilla', False)],
          'pinnes': [('pinna', False)],
          'pinns': [('pinna', False)],
          'pisade': [('pisa', False)],
          'piserad': [('pisera', False)],
          'pjande': [('pja', False)],
          'pjats': [('pja', False)],
          'pkomna': [('pkomma', False)],
          'pkörda': [('pköra', False)],
          'plade': [('pla', False)],
          'plades': [('pla', False)],
          'plant': [('planta', False)],
          'plats': [('pla', False)],
          'plir': [('plira', True)],
          'plockas': [('plocka', False)],
          'plog': [('ploga', False)],
          'plott': [('plotta', True)],
          'pluggades': [('plugga', True)],
          'pluggas': [('plugga', False)],
          'pluggats': [('plugga', True)],
          'plästas': [('pläsa', False)],
          'plåg': [('plåga', True)],
          'plåts': [('plåta', False)],
          'plöjda': [('plöja', False)],
          'plöjdas': [('plöja', False)],
          'pmätt': [('pmäta', False)],
          'pmätta': [('pmäta', False)],
          'pmättas': [('pmäta', False)],
          'pna': [('pna', False)],
          'pnar': [('pna', False)],
          'pnas': [('pa', False)],
          'pnats': [('pna', False)],
          'pockats': [('pocka', True)],
          'pol': [('pola', False)],
          'pola': [('pola', False)],
          'poppats': [('poppa', True)],
          'porda': [('pörja', False)],
          'pordas': [('pörja', False)],
          'pottas': [('potta', False)],
          'pottats': [('potta', False)],
          'ppar': [('ppa', False)],
          'ppats': [('ppa', False)],
          'ppe': [('ppa', False)],
          'ppel': [('ppla', False)],
          'ppel-': [('ppla', False)],
          'pper': [('ppa', False)],
          'ppes': [('ppa', False)],
          'ppla': [('ppla', False)],
          'pplade': [('pplägga', False)],
          'pplades': [('pplägga', False)],
          'pplas': [('ppla', False)],
          'ppnas': [('ppna', False)],
          'pprad': [('ppra', False)],
          'pprat': [('ppra', False)],
          'ppränt': [('ppränna', False)],
          'pps': [('ppa', False)],
          'ppta': [('ppa', False)],
          'pptas': [('ppa', False)],
          'pptes': [('ppa', False)],
          'prat': [('prata', True)],
          'prats': [('pra', False)],
          'pratt': [('pritta', False)],
          'pred': [('prida', False)],
          'predes': [('prida', False)],
          'preds': [('prida', False)],
          'pretades': [('preta', False)],
          'pretas': [('preta', False)],
          'pretats': [('preta', False)],
          'prevs': [('priva', False)],
          'privas': [('priva', False)],
          'privits': [('priva', False)],
          'privs': [('priva', False)],
          'prydd': [('pryda', False)],
          'prydda': [('pryda', False)],
          'pryddas': [('pryda', True)],
          'prydds': [('pryda', True)],
          'prymdes': [('prymma', False)],
          'prymmas': [('prymma', False)],
          'pryms': [('prymma', False)],
          'prymt': [('prymma', False)],
          'prymts': [('prymma', False)],
          'prytt': [('pryda', False)],
          'präckas': [('präcka', False)],
          'präknade': [('präkna', False)],
          'präknades': [('präkna', False)],
          'präknas': [('präkna', False)],
          'präknats': [('präkna', False)],
          'prängas': [('pränga', False)],
          'prängdes': [('pränga', False)],
          'prängt': [('pränga', False)],
          'prängts': [('pränga', False)],
          'prännas': [('pränna', False)],
          'pränt': [('pränta', True)],
          'pränts': [('pränna', False)],
          'prätt': [('prätta', False)],
          'prätts': [('prätta', False)],
          'pröjs': [('pröjsa', True)],
          'pröt': [('pröta', False)],
          'ps': [('psa', False)],
          'psa': [('psa', False)],
          'psade': [('psa', False)],
          'psades': [('psa', False)],
          'psamlades': [('psamla', False)],
          'psamlas': [('psamla', False)],
          'psamlats': [('psamla', False)],
          'psas': [('psa', False)],
          'psats': [('psa', False)],
          'psatt': [('psätta', False)],
          'psatts': [('psätta', False)],
          'psel': [('psla', False)],
          'psel-': [('psla', False)],
          'pser': [('psa', False)],
          'pses': [('psa', False)],
          'pskjuts': [('pskjuta', False)],
          'psköt': [('pskjuta', False)],
          'pskötes': [('pskjuta', False)],
          'psköts': [('pskjuta', False)],
          'psla': [('psla', False)],
          'pslades': [('psla', False)],
          'pslagits': [('pslå', False)],
          'pslas': [('psla', False)],
          'pslogs': [('pslå', False)],
          'psta': [('psa', False)],
          'pstas': [('psa', False)],
          'pste': [('psa', False)],
          'psteg': [('pstiga', False)],
          'pstes': [('psa', False)],
          'psår': [('pså', False)],
          'psås': [('pså', False)],
          'psåt': [('psäta', False)],
          'pt': [('pa', False)],
          'ptag-': [('pta', False)],
          'ptagits': [('pta', False)],
          'ptogs': [('pta', False)],
          'pträd': [('pträda', False)],
          'pträd-': [('pträda', False)],
          'pträda': [('pträda', False)],
          'pträdande': [('pträda', False)],
          'pträdandes': [('pträda', False)],
          'pträdas': [('pträda', False)],
          'pträdd': [('pträda', False)],
          'pträdda': [('pträda', False)],
          'pträddas': [('pträda', False)],
          'pträdde': [('pträda', False)],
          'pträddes': [('pträda', False)],
          'pträdds': [('pträda', False)],
          'pträder': [('pträda', False)],
          'pträds': [('pträda', False)],
          'pträtt': [('pträda', False)],
          'pträtts': [('pträda', False)],
          'pts': [('pa', False)],
          'ptäckas': [('ptäcka', False)],
          'ptäckes': [('ptäcka', False)],
          'ptäcks': [('ptäcka', False)],
          'ptäcktes': [('ptäcka', False)],
          'ptäckts': [('ptäcka', False)],
          'puffades': [('puffa', True)],
          'puffats': [('puffa', True)],
          'pullades': [('pulla', True)],
          'pullas': [('pulla', True)],
          'pullats': [('pulla', True)],
          'pumpats': [('pumpa', False)],
          'punna': [('pinna', False)],
          'punnas': [('pinna', False)],
          'punnits': [('pinna', False)],
          'puppades': [('puppas', False)],
          'puppas': [('puppas', False)],
          'pussades': [('pussas', True), ('pussa', True)],
          'pussas': [('pussa', True), ('pussas', True)],
          'pussats': [('pussas', True), ('pussa', True)],
          'pusta': [('pusta', True)],
          'pustas': [('pusta', True)],
          'puts': [('putsa', False)],
          'putsade': [('putsa', True)],
          'putsades': [('putsa', True)],
          'pveks': [('pvika', False)],
          'pvisas': [('pvisa', False)],
          'py': [('py', False)],
          'pydda': [('py', False)],
          'pyddas': [('py', False)],
          'pydds': [('py', False)],
          'pynt': [('pynta', True)],
          'pynta': [('pynta', False)],
          'pyntas': [('pynta', True)],
          'pyr': [('pyra', True)],
          'pys': [('pysa', True)],
          'pyst': [('pysa', True)],
          'pyts': [('pytsa', True)],
          'pytt': [('py', False)],
          'pä': [('pä', False)],
          'päckats': [('päcka', False)],
          'päd': [('pä', False)],
          'päda': [('pä', False)],
          'pädande': [('pä', False)],
          'pädas': [('pä', False)],
          'pädda': [('pä', False)],
          'pädds': [('pä', False)],
          'päder': [('pä', False)],
          'päds': [('pä', False)],
          'päkt': [('päka', False)],
          'päkta': [('päka', False)],
          'päktas': [('päka', False)],
          'päkts': [('päka', False)],
          'pänd': [('pänna', False)],
          'pända': [('pänna', False)],
          'pändas': [('pänna', False)],
          'pände': [('pänna', False)],
          'pändes': [('pänna', False)],
          'pännes': [('pänna', False)],
          'pänns': [('pänna', False)],
          'pänst': [('pänsta', False)],
          'pär': [('pä', False)],
          'pärrades': [('pärra', False)],
          'pärras': [('pärra', False)],
          'pärrats': [('pärra', False)],
          'pätnas': [('päta', False)],
          'pätt': [('pä', False)],
          'pätts': [('pä', False)],
          'på': [('på', False)],
          'pådda': [('på', False)],
          'påddas': [('på', False)],
          'pådds': [('på', False)],
          'påla': [('pålägga', True), ('påla', True)],
          'pålade': [('pålägga', True), ('påla', True)],
          'pålades': [('pålägga', True), ('påla', True)],
          'pålas': [('pålägga', True), ('påla', True)],
          'pångats': [('pånga', False)],
          'pårades': [('påra', False)],
          'påras': [('påra', False)],
          'påtes': [('päta', False)],
          'pått': [('på', False)],
          'påverkat': [('påverka', True)],
          'pöv': [('pöva', False)],
          'pövades': [('pöva', False)],
          'r-': [('ra', False)],
          'ra': [('ra', False)],
          'rabbats': [('rabba', False)],
          'rad': [('ra', False)],
          'radad': [('rada', False)],
          'rade': [('ra', False)],
          'rades': [('ra', False)],
          'rads': [('ra', False)],
          'rag': [('ra', False)],
          'rag-': [('ra', False)],
          'raga': [('ra', False)],
          'ragande': [('ra', False)],
          'ragandes': [('ra', False)],
          'ragas': [('ra', False)],
          'ragen': [('ra', False)],
          'ragens': [('ra', False)],
          'rager': [('ra', False)],
          'rages': [('ra', False)],
          'raget': [('ra', False)],
          'ragets': [('ra', False)],
          'ragit': [('ra', False)],
          'raglade': [('ragla', True)],
          'raglades': [('ragla', True)],
          'ragna': [('ra', False)],
          'ragnas': [('ra', False)],
          'ragne': [('ra', False)],
          'ragnes': [('ra', False)],
          'rags': [('ra', False)],
          'ragts': [('ringa', False)],
          'rakades': [('raka', False)],
          'raknats': [('rakna', True)],
          'rakta': [('rakta', False)],
          'rall': [('ralla', False)],
          'ralna': [('ralna', False)],
          'ralnats': [('ralna', False)],
          'ralt': [('ralta', False)],
          'ram': [('rama', False)],
          'ram-': [('rama', False)],
          'ramla': [('ramla', True)],
          'ramlade': [('ramla', True)],
          'ramlades': [('ramla', True)],
          'ramlas': [('ramla', True)],
          'ramlats': [('ramla', True)],
          'ramp': [('rampa', False)],
          'rampats': [('rampa', False)],
          'rams': [('ramsa', False)],
          'ramsade': [('ramsa', True)],
          'ramsades': [('ramsa', True)],
          'ramsas': [('ramsa', False)],
          'ramsats': [('ramsa', False)],
          'randades': [('randa', True), ('randas', True)],
          'randas': [('randas', True), ('randa', True)],
          'randats': [('randas', True), ('randa', True)],
          'rande': [('ra', False)],
          'randes': [('ra', False)],
          'rank': [('ranka', True)],
          'rankas': [('ranka', True)],
          'rankats': [('ranka', True)],
          'rapp': [('rappa', False)],
          'rappats': [('rappa', False)],
          'rar': [('ra', False)],
          'rartades': [('rarta', False)],
          'rartas': [('rarta', False)],
          'rartats': [('rarta', False)],
          'ras': [('ra', False)],
          'rast': [('rasta', True)],
          'rat': [('rata', True)],
          'ratt': [('ratta', True)],
          'ratta': [('ratta', False)],
          'rattas': [('ratta', False)],
          'rattats': [('ratta', False)],
          'rattla': [('rattla', False)],
          'ratts': [('ritta', False)],
          'rav': [('rava', False)],
          'rava': [('rava', False)],
          'ravandes': [('rava', False)],
          'ravla': [('ravla', False)],
          'ravlade': [('ravlägga', False)],
          'ravlades': [('ravla', False)],
          'ravlas': [('ravla', False)],
          'ravs': [('rava', False)],
          'rband': [('rbinda', False)],
          'rber': [('rbera', False)],
          'rbesatt': [('rbesätta', False)],
          'rbesatts': [('rbesätta', False)],
          'rbet': [('rbeta', False)],
          'rbildades': [('rbilda', False)],
          'rblött': [('rblöda', False)],
          'rblötts': [('rblöda', False)],
          'rbrändes': [('rbränna', False)],
          'rbrännas': [('rbränna', False)],
          'rbränns': [('rbränna', False)],
          'rbränts': [('rbränna', False)],
          'rd': [('rda', False)],
          'rda': [('rda', False)],
          'rdande': [('rda', False)],
          'rdas': [('rda', False)],
          'rdats': [('rda', False)],
          'rde': [('ra', False)],
          'rdelade': [('rdela', False)],
          'rdelades': [('rdela', False)],
          'rder': [('rda', False)],
          'rdes': [('ra', False)],
          'rdla': [('rdla', False)],
          'rdlade': [('rdlägga', False)],
          'rdlades': [('rdlägga', False)],
          'rdlas': [('rdla', False)],
          'rdnas': [('rdna', False)],
          'rdragits': [('rdra', False)],
          'rdras': [('rdra', False)],
          'rdrev': [('rdriva', False)],
          'rdrog': [('rdra', False)],
          'rdrogs': [('rdra', False)],
          'rds': [('ra', False)],
          're': [('re', False)],
          're-': [('re', False)],
          'red': [('reda', True), ('rida', True)],
          'red-': [('reda', False)],
          'reda': [('reda', True)],
          'redande': [('reda', True)],
          'redandes': [('reda', False)],
          'redas': [('reda', True)],
          'redd': [('reda', False)],
          'redda': [('reda', True)],
          'reddas': [('reda', False)],
          'redde': [('reda', False)],
          'reddes': [('reda', False)],
          'redds': [('reda', True)],
          'reder': [('reda', False)],
          'redes': [('reda', False)],
          'reds': [('reda', True), ('rida', True)],
          'refanns': [('refinnas', False)],
          'refinnas': [('refinnas', False)],
          'refinnes': [('refinnas', False)],
          'refunnits': [('refinnas', False)],
          'rek': [('reka', True)],
          'relade': [('relägga', False)],
          'relades': [('relägga', False)],
          'ren': [('rena', False)],
          'renades': [('rena', False)],
          'renas': [('rena', False)],
          'renats': [('rena', False)],
          'rens': [('rensa', False)],
          'renskas': [('renskas', False)],
          'renskats': [('renskas', False)],
          'rent': [('rena', False)],
          'rep': [('repa', False)],
          'reps': [('ripa', False)],
          'rer': [('re', False)],
          'rerad': [('rera', False)],
          'rerades': [('rera', False)],
          'reras': [('rera', False)],
          'res': [('resa', False)],
          'rest': [('resa', False)],
          'resta': [('resa', True)],
          'restas': [('resa', True)],
          'ret': [('reta', True)],
          'retades': [('retas', True), ('reta', True)],
          'retas': [('retas', True), ('reta', True)],
          'retats': [('retas', True), ('reta', True)],
          'rets': [('retsa', False)],
          'rett': [('reda', True)],
          'retts': [('reda', False)],
          'rev': [('riva', True)],
          'revar': [('reva', True)],
          'revs': [('rivas', True), ('riva', True)],
          'rfades': [('rfa', False)],
          'rfanns': [('rfinna', False)],
          'rfar': [('rfara', False)],
          'rfas': [('rfa', False)],
          'rfasades': [('rfasas', False)],
          'rfasas': [('rfasas', False)],
          'rfasats': [('rfasas', False)],
          'rfats': [('rfa', False)],
          'rfattades': [('rfatta', False)],
          'rfattas': [('rfatta', False)],
          'rfattats': [('rfatta', False)],
          'rfelades': [('rfela', False)],
          'rfelas': [('rfela', False)],
          'rfelats': [('rfela', False)],
          'rfinnas': [('rfinna', False)],
          'rfinnes': [('rfinna', False)],
          'rfinns': [('rfinna', False)],
          'rflytt': [('rflytta', False)],
          'rfordrades': [('rfordra', False)],
          'rfordras': [('rfordra', False)],
          'rfordrats': [('rfordra', False)],
          'rfunnits': [('rfinna', False)],
          'rfäktades': [('rfäkta', False)],
          'rfäktas': [('rfäkta', False)],
          'rfäktats': [('rfäkta', False)],
          'rfår': [('rfå', False)],
          'rfödas': [('rfödas', False)],
          'rföddes': [('rfödas', False)],
          'rfödes': [('rfödas', False)],
          'rföds': [('rfödas', False)],
          'rfötts': [('rfödas', False)],
          'rga': [('rga', False)],
          'rgande': [('rga', False)],
          'rgar': [('rga', False)],
          'rgat': [('rgäta', False)],
          'rgats': [('rgäta', False)],
          'rge': [('rge', False)],
          'rger': [('rge', False)],
          'rgicks': [('rgå', False)],
          'rgiftas': [('rgifta', False)],
          'rgjord': [('rgöra', False)],
          'rgjorda': [('rgöra', False)],
          'rgjordas': [('rgöra', False)],
          'rgla': [('rgla', False)],
          'rglas': [('rgla', False)],
          'rgrov': [('rgrova', False)],
          'rgås': [('rgå', False)],
          'rgåtts': [('rgå', False)],
          'rhandla': [('rhandla', False)],
          'rhandlade': [('rhandla', False)],
          'rhandlades': [('rhandla', False)],
          'rhandlas': [('rhandla', False)],
          'rhas': [('rha', False)],
          'rhoppades': [('rhoppa', False)],
          'rhoppas': [('rhoppa', False)],
          'rhoppats': [('rhoppa', False)],
          'rhytt': [('rhyda', False)],
          'rhytts': [('rhyda', False)],
          'rhållas': [('rhålla', False)],
          'rhålls': [('rhålla', False)],
          'rhölls': [('rhålla', False)],
          'rick': [('ricka', False)],
          'ricker': [('ricka', False)],
          'ricks': [('ricka', False)],
          'ridas': [('rida', False)],
          'riddes': [('rida', False)],
          'rides': [('rida', False)],
          'rids': [('rida', False)],
          'rierats': [('riera', False)],
          'riftas': [('rifta', False)],
          'rigades': [('riga', False)],
          'rigas': [('riga', False)],
          'rige': [('rige', False)],
          'riger': [('rige', False)],
          'riges': [('rige', False)],
          'rikta': [('rikta', False)],
          'riktas': [('rikta', False)],
          'rila': [('rila', False)],
          'rilade': [('rilägga', False)],
          'rilades': [('rilägga', False)],
          'rilas': [('rilägga', False)],
          'rilla': [('rilla', False)],
          'rillade': [('rilla', False)],
          'rillades': [('rilla', False)],
          'rillats': [('rilla', False)],
          'ringe': [('ringa', False)],
          'ringer': [('ringa', False)],
          'ringes': [('ringa', False)],
          'rinnes': [('rinna', False)],
          'rinns': [('rinna', False)],
          'risade': [('risa', True)],
          'risades': [('risa', False)],
          'riser': [('risera', False)],
          'riserad': [('risera', False)],
          'rista': [('rista', True)],
          'ristas': [('rista', True)],
          'ristats': [('rista', False)],
          'riste': [('rista', True)],
          'rister': [('rista', False)],
          'ristes': [('rista', True)],
          'rit': [('rita', False)],
          'rits': [('ritsa', True)],
          'ritt': [('rida', False)],
          'ritter': [('ritta', False)],
          'riv': [('riva', False)],
          'riv-': [('riva', False)],
          'riva': [('riva', False)],
          'rivande': [('riva', False)],
          'rivandes': [('riva', False)],
          'rivas': [('rivas', True), ('riva', True)],
          'rive': [('riva', False)],
          'rivens': [('riva', False)],
          'river': [('riva', False)],
          'rivet': [('riva', False)],
          'rivets': [('riva', False)],
          'rivit': [('riva', False)],
          'rivits': [('rivas', True), ('riva', True)],
          'rivna': [('riva', False)],
          'rivnas': [('riva', False)],
          'rivne': [('riva', False)],
          'rivnes': [('riva', False)],
          'rivs': [('rivas', True), ('riva', True)],
          'rjande': [('rja', False)],
          'rjats': [('rja', False)],
          'rjda': [('rja', False)],
          'rjdas': [('rja', False)],
          'rjer': [('rja', False)],
          'rjes': [('rja', False)],
          'rjs': [('rja', False)],
          'rkalkades': [('rkalka', False)],
          'rkalkas': [('rkalkas', False)],
          'rkalkats': [('rkalkas', False)],
          'rkar': [('rka', False)],
          'rkas': [('rka', False)],
          'rkats': [('rka', False)],
          'rkel': [('rkla', False)],
          'rkel-': [('rkla', False)],
          'rker': [('rka', False)],
          'rkes': [('rka', False)],
          'rkla': [('rkla', False)],
          'rklade': [('rklägga', False)],
          'rklades': [('rklägga', False)],
          'rklar': [('rkla', False)],
          'rklas': [('rklägga', False)],
          'rknade': [('rkna', False)],
          'rknades': [('rkna', False)],
          'rknas': [('rkna', False)],
          'rknat': [('rkna', False)],
          'rkoksades': [('rkoksas', False)],
          'rkoksas': [('rkoksas', False)],
          'rkoksats': [('rkoksas', False)],
          'rkomna': [('rkomma', False)],
          'rkoxades': [('rkoxas', False)],
          'rkoxas': [('rkoxas', False)],
          'rkoxats': [('rkoxas', False)],
          'rkrävas': [('rkräva', False)],
          'rkrävdes': [('rkräva', False)],
          'rkräves': [('rkräva', False)],
          'rkrävs': [('rkräva', False)],
          'rkrävts': [('rkräva', False)],
          'rks': [('rka', False)],
          'rkta': [('rka', False)],
          'rktas': [('rka', False)],
          'rktes': [('rka', False)],
          'rkändes': [('rkänna', False)],
          'rkännas': [('rkänna', False)],
          'rkänns': [('rkänna', False)],
          'rkänts': [('rkänna', False)],
          'rkörd': [('rköra', False)],
          'rla': [('rlägga', False)],
          'rlade': [('rla', False)],
          'rlades': [('rla', False)],
          'rlas': [('rlägga', False)],
          'rlats': [('rla', False)],
          'rledas': [('rleda', False)],
          'rleddes': [('rleda', False)],
          'rledes': [('rleda', False)],
          'rlett': [('rleda', False)],
          'rletts': [('rleda', False)],
          'rlikta': [('rlika', False)],
          'rliktas': [('rlika', False)],
          'rlist': [('rlista', False)],
          'rlista': [('rlisa', False)],
          'rlistas': [('rlisa', False)],
          'rljudas': [('rljudas', False)],
          'rljudes': [('rljudas', False)],
          'rljudits': [('rljudas', False)],
          'rljuds': [('rljudas', False)],
          'rljöds': [('rljudas', False)],
          'rlängas': [('rlänga', False)],
          'rlängdes': [('rlänga', False)],
          'rlänges': [('rlänga', False)],
          'rlängs': [('rlänga', False)],
          'rlängts': [('rlänga', False)],
          'rlästas': [('rläsa', False)],
          'rlåts': [('rlåta', False)],
          'rlöses': [('rlösa', False)],
          'rlöstes': [('rlösa', False)],
          'rmas': [('rma', False)],
          'rmats': [('rma', False)],
          'rmd': [('rma', False)],
          'rmda': [('rma', False)],
          'rmdas': [('rma', False)],
          'rmde': [('rma', False)],
          'rmer': [('rma', False)],
          'rms': [('rma', False)],
          'rmt': [('rma', False)],
          'rmts': [('rma', False)],
          'rmält': [('rmäla', False)],
          'rmälte': [('rmäla', False)],
          'rmätta': [('rmätta', False)],
          'rmättas': [('rmätta', False)],
          'rmått': [('rmå', False)],
          'rna': [('rna', False)],
          'rnar': [('rna', False)],
          'rnats': [('rna', False)],
          'rnattades': [('rnatta', False)],
          'rnattas': [('rnatta', False)],
          'rnattats': [('rnatta', False)],
          'rnerats': [('rnera', False)],
          'rny': [('rnya', False)],
          'rnöjas': [('rnöja', False)],
          'rnöjdes': [('rnöja', False)],
          'rnöjs': [('rnöja', False)],
          'rnöjts': [('rnöja', False)],
          'rnöts': [('rnöta', False)],
          'ro': [('ro', True)],
          'ro-': [('ro', False)],
          'rockats': [('rocka', False)],
          'rodas': [('rodas', False)],
          'rodats': [('rodas', False)],
          'rodd': [('ro', True)],
          'rodda': [('ro', False)],
          'roddas': [('ro', True)],
          'roge': [('ra', False)],
          'rola': [('rolägga', False)],
          'rolade': [('rolägga', False)],
          'rolades': [('rolägga', False)],
          'rolas': [('rolägga', False)],
          'rollats': [('rolla', False)],
          'roms': [('romsa', False)],
          'ronades': [('rona', False)],
          'ronas': [('rona', False)],
          'roniserad': [('ronisera', False)],
          'ropp': [('roppa', False)],
          'roppats': [('roppa', False)],
          'ror': [('ro', False)],
          'rordna': [('rordna', False)],
          'rordnas': [('rordna', False)],
          'ros': [('rosa', True), ('ro', True)],
          'roskades': [('roskas', False)],
          'rott': [('ro', False)],
          'rottades': [('rottas', False)],
          'rottas': [('rotta', False)],
          'rottats': [('rotta', False)],
          'rov': [('rova', False)],
          'rove': [('rava', False)],
          'roves': [('rava', False)],
          'rpar': [('rpa', False)],
          'rpats': [('rpa', False)],
          'rpel': [('rpla', False)],
          'rpel-': [('rpla', False)],
          'rper': [('rpa', False)],
          'rpes': [('rpa', False)],
          'rpla': [('rpla', False)],
          'rplas': [('rpla', False)],
          'rprad': [('rpra', False)],
          'rprat': [('rpra', False)],
          'rps': [('rpa', False)],
          'rpta': [('rpa', False)],
          'rptas': [('rpa', False)],
          'rptes': [('rpa', False)],
          'rr': [('rra', False)],
          'rrat': [('rra', False)],
          'rrats': [('rra', False)],
          'rrev': [('rriva', False)],
          'rrevs': [('rriva', False)],
          'rrivas': [('rriva', False)],
          'rrivits': [('rriva', False)],
          'rrivs': [('rriva', False)],
          'rrlade': [('rrlägga', False)],
          'rrlades': [('rrlägga', False)],
          'rräckas': [('rräcka', False)],
          'rränt': [('rränta', False)],
          'rrätt': [('rrätta', False)],
          'rrå': [('rråa', False)],
          'rrå-': [('rråa', False)],
          'rråd': [('rråda', False)],
          'rråd-': [('rråda', False)],
          'rråda': [('rråda', False)],
          'rrådande': [('rråda', False)],
          'rrådandes': [('rråda', False)],
          'rrådas': [('rråda', False)],
          'rrådd': [('rråda', False)],
          'rrådda': [('rråda', False)],
          'rråddas': [('rråda', False)],
          'rrådde': [('rråda', False)],
          'rråddes': [('rråda', False)],
          'rrådds': [('rråda', False)],
          'rråder': [('rråda', False)],
          'rråds': [('rråda', False)],
          'rrått': [('rråda', False)],
          'rråtts': [('rråda', False)],
          'rrök': [('rröka', False)],
          'rrör': [('rröra', False)],
          'rsakats': [('rsaka', False)],
          'rsamlas': [('rsamla', False)],
          'rsats': [('rsa', False)],
          'rsatt': [('rsätta', False)],
          'rsel': [('rsla', False)],
          'rsel-': [('rsla', False)],
          'rska': [('rska', False)],
          'rskad': [('rska', False)],
          'rskade': [('rska', False)],
          'rskades': [('rska', False)],
          'rskar': [('rska', False)],
          'rskas': [('rskas', False)],
          'rskats': [('rskas', False)],
          'rskel': [('rskla', False)],
          'rskel-': [('rskla', False)],
          'rskildes': [('rskilja', False)],
          'rskiljas': [('rskilja', False)],
          'rskiljes': [('rskilja', False)],
          'rskiljs': [('rskilja', False)],
          'rskilts': [('rskilja', False)],
          'rskingrades': [('rskingra', False)],
          'rskingras': [('rskingra', False)],
          'rskingrats': [('rskingra', False)],
          'rskjuts': [('rskjuta', False)],
          'rskott': [('rsko', False)],
          'rskrev': [('rskriva', False)],
          'rskylt': [('rskyla', False)],
          'rsköt': [('rskjuta', False)],
          'rskötes': [('rskjuta', False)],
          'rsköts': [('rskjuta', False)],
          'rsla': [('rsla', False)],
          'rslagits': [('rslå', False)],
          'rslapp': [('rslappa', False)],
          'rslits': [('rslita', False)],
          'rslogs': [('rslå', False)],
          'rsnades': [('rsna', False)],
          'rsnar': [('rsna', False)],
          'rsnas': [('rsna', False)],
          'rsport': [('rspörja', False)],
          'rst': [('rsta', False)],
          'rst-': [('rsta', False)],
          'rstack': [('rsticka', False)],
          'rstades': [('rsta', False)],
          'rstande': [('rsta', False)],
          'rstandes': [('rsta', False)],
          'rsteg': [('rstiga', False)],
          'rstört': [('rstöra', False)],
          'rstött': [('rstödja', False)],
          'rstötts': [('rstödja', False)],
          'rsumpades': [('rsumpas', False)],
          'rsumpas': [('rsumpas', False)],
          'rsumpats': [('rsumpas', False)],
          'rsvor': [('rsvärja', False)],
          'rsvors': [('rsvärja', False)],
          'rsvure': [('rsvärja', False)],
          'rsvuren': [('rsvärja', False)],
          'rsvurens': [('rsvärja', False)],
          'rsvures': [('rsvärja', False)],
          'rsvuret': [('rsvärja', False)],
          'rsvurets': [('rsvärja', False)],
          'rsvurit': [('rsvärja', False)],
          'rsvurits': [('rsvärja', False)],
          'rsvurna': [('rsvärja', False)],
          'rsvurnas': [('rsvärja', False)],
          'rsvurne': [('rsvärja', False)],
          'rsvurnes': [('rsvärja', False)],
          'rsvär': [('rsvärja', False)],
          'rsvär-': [('rsvärja', False)],
          'rsvära': [('rsvärja', False)],
          'rsvärande': [('rsvärja', False)],
          'rsvärandes': [('rsvärja', False)],
          'rsväras': [('rsvärja', False)],
          'rsvärja': [('rsvärja', False)],
          'rsvärjande': [('rsvärja', False)],
          'rsvärjandes': [('rsvärja', False)],
          'rsvärjas': [('rsvärja', False)],
          'rsvärje': [('rsvärja', False)],
          'rsvärjer': [('rsvärja', False)],
          'rsvärjes': [('rsvärja', False)],
          'rsyr': [('rsy', False)],
          'rsåg': [('rse', False)],
          'rt': [('ra', False)],
          'rta': [('rta', False)],
          'rtag-': [('rta', False)],
          'rtagits': [('rta', False)],
          'rtalades': [('rtala', False)],
          'rtalde': [('rtälja', False)],
          'rtaldes': [('rtälja', False)],
          'rtalt': [('rtälja', False)],
          'rtalts': [('rtälja', False)],
          'rtas': [('rta', False)],
          'rtats': [('rta', False)],
          'rteg': [('rtiga', False)],
          'rtla': [('rtla', False)],
          'rtlade': [('rtlägga', False)],
          'rtlades': [('rtlägga', False)],
          'rtlas': [('rtlägga', False)],
          'rtnas': [('rtna', False)],
          'rtogs': [('rta', False)],
          'rtrades': [('rtra', False)],
          'rtras': [('rtra', False)],
          'rträd': [('rträda', False)],
          'rträd-': [('rträda', False)],
          'rträda': [('rträda', False)],
          'rträdande': [('rträda', False)],
          'rträdandes': [('rträda', False)],
          'rträdas': [('rträda', False)],
          'rträdd': [('rträda', False)],
          'rträdda': [('rträda', False)],
          'rträddas': [('rträda', False)],
          'rträdde': [('rträda', False)],
          'rträddes': [('rträda', False)],
          'rträdds': [('rträda', False)],
          'rträder': [('rträda', False)],
          'rträds': [('rträda', False)],
          'rträffades': [('rträffa', False)],
          'rträffas': [('rträffa', False)],
          'rträffats': [('rträffa', False)],
          'rträngt': [('rtränga', False)],
          'rträtt': [('rträda', False)],
          'rträtts': [('rträda', False)],
          'rtröttades': [('rtröttas', False)],
          'rtröttas': [('rtröttas', False)],
          'rtröttats': [('rtröttas', False)],
          'rts': [('ra', False)],
          'rtsade': [('rtsa', False)],
          'rtsades': [('rtsa', False)],
          'rtyckas': [('rtycka', False)],
          'rtyckes': [('rtycka', False)],
          'rtycks': [('rtycka', False)],
          'rtycktes': [('rtycka', False)],
          'rtyckts': [('rtycka', False)],
          'rtäckas': [('rtäcka', False)],
          'rtäckes': [('rtäcka', False)],
          'rtäcks': [('rtäcka', False)],
          'rtäcktes': [('rtäcka', False)],
          'rtäckts': [('rtäcka', False)],
          'rtörnades': [('rtörnas', False)],
          'rtörnas': [('rtörnas', False)],
          'rtörnats': [('rtörnas', False)],
          'rubbats': [('rubba', False)],
          'ruffades': [('ruffa', False)],
          'ruffats': [('ruffa', False)],
          'ruggats': [('rugga', True)],
          'rullades': [('rulla', False)],
          'rullas': [('rulla', True)],
          'rullats': [('rulla', True)],
          'rummats': [('rumma', False)],
          'rundats': [('runda', False)],
          'rungne': [('ringa', False)],
          'rungnes': [('ringa', False)],
          'runkas': [('runka', False)],
          'runkats': [('runka', True)],
          'runknas': [('runkna', False)],
          'runna': [('rinna', True)],
          'runnas': [('rinna', True)],
          'runnits': [('rinna', False)],
          'runt': [('runta', False)],
          'runta': [('runta', False)],
          'runtas': [('runta', False)],
          'rupe': [('rypa', False)],
          'rupits': [('rypa', False)],
          'ruses': [('rysa', False)],
          'rusta': [('rusta', False)],
          'rustas': [('rusta', False)],
          'rute': [('ryta', False)],
          'ruten': [('ryta', False)],
          'rutna': [('ryta', False)],
          'rutsades': [('rutsäga', False)],
          'ruttna': [('ruttna', True)],
          'ruttnas': [('ruttna', False)],
          'rvad': [('rva', False)],
          'rvalt': [('rvälja', False)],
          'rvande': [('rva', False)],
          'rvandes': [('rva', False)],
          'rvann': [('rvinna', False)],
          'rvar': [('rvara', False)],
          'rvarades': [('rvara', False)],
          'rvaras': [('rvara', False)],
          'rvarats': [('rvara', False)],
          'rvas': [('rva', False)],
          'rvats': [('rva', False)],
          'rvda': [('rva', False)],
          'rvdas': [('rva', False)],
          'rvel': [('rvla', False)],
          'rvel-': [('rvla', False)],
          'rver': [('rva', False)],
          'rverkat': [('rverka', False)],
          'rvill': [('rvilla', False)],
          'rvintrades': [('rvintra', False)],
          'rvintras': [('rvintra', False)],
          'rvintrats': [('rvintra', False)],
          'rvisats': [('rvisa', False)],
          'rvlas': [('rvla', False)],
          'rväljas': [('rvälja', False)],
          'rvänt': [('rvända', False)],
          'ry': [('ry', False)],
          'ryckes': [('rycka', True)],
          'rycks': [('rycka', False)],
          'rycktes': [('rycka', False)],
          'rydd': [('rydda', False)],
          'rydda': [('ry', False)],
          'ryddas': [('ry', False)],
          'rydde': [('ryda', False)],
          'ryddes': [('ryda', False)],
          'rydds': [('ry', False)],
          'rykt': [('ryka', True), ('rykta', True)],
          'ryktades': [('ryktas', True), ('rykta', True)],
          'ryktas': [('rykta', True), ('ryktas', True)],
          'ryktats': [('rykta', True), ('ryktas', True)],
          'rymdes': [('rymmas', True), ('rymma', True)],
          'rymmas': [('rymmas', True), ('rymma', True)],
          'ryms': [('rymmas', True), ('rymma', True)],
          'rymt': [('rymma', True)],
          'rymts': [('rymmas', True), ('rymma', True)],
          'rynas': [('ryna', False)],
          'ryns': [('ryna', False)],
          'rynt': [('ryna', False)],
          'ryr': [('ry', False)],
          'rys': [('rysa', False)],
          'ryss': [('ryssa', False)],
          'ryssas': [('ryssa', False)],
          'ryst': [('rysa', False)],
          'rysta': [('rysta', False)],
          'rystas': [('rysta', False)],
          'rytt': [('ry', False)],
          'rytts': [('ryda', False)],
          'rä': [('rä', False)],
          'räckas': [('räcka', True)],
          'räckes': [('räcka', False)],
          'räcks': [('räcka', False)],
          'räcktes': [('räcka', False)],
          'räckts': [('räcka', True)],
          'räd-': [('räda', False)],
          'rädandes': [('räda', False)],
          'rädas': [('rädas', True)],
          'rädd': [('rädda', False)],
          'rädda': [('rädda', False)],
          'räddas': [('rädda', True)],
          'rädde': [('räda', False)],
          'räddes': [('rädas', True)],
          'räds': [('rädas', True)],
          'räkas': [('räkas', False)],
          'räkes': [('räkas', False)],
          'räknade': [('räkna', True)],
          'räknades': [('räknas', True), ('räkna', True)],
          'räknas': [('räknas', True), ('räkna', True)],
          'räknats': [('räknas', True), ('räkna', True)],
          'räks': [('räkas', False)],
          'räkt': [('räka', False)],
          'räkta': [('räkta', False)],
          'räktas': [('räka', False)],
          'räktats': [('räkta', False)],
          'räktes': [('räkas', False)],
          'räkts': [('räka', False)],
          'räls': [('rälsa', False)],
          'räm': [('räma', False)],
          'räm-': [('räma', False)],
          'rämde': [('rämma', False)],
          'rämjats': [('rämja', False)],
          'rämnats': [('rämna', True)],
          'rämts': [('rämma', False)],
          'ränades': [('räna', False)],
          'ränas': [('räna', False)],
          'ränd': [('ränna', True)],
          'rända': [('ränna', False)],
          'rändas': [('ränna', False)],
          'rände': [('ränna', True)],
          'rändes': [('ränna', False)],
          'rängs': [('ränga', False)],
          'rännas': [('ränna', True)],
          'rännes': [('ränna', False)],
          'ränns': [('ränna', False)],
          'ränslades': [('ränsla', False)],
          'ränslas': [('ränsla', False)],
          'ränt': [('ränna', False)],
          'ränts': [('ränna', True)],
          'rär': [('rä', False)],
          'räras': [('rära', False)],
          'räs': [('räsa', False)],
          'räst': [('räsa', False)],
          'rästs': [('räsa', False)],
          'rät': [('räta', True)],
          'räte': [('råta', False)],
          'rätes': [('råta', False)],
          'räts': [('råta', False)],
          'rätt': [('räda', False)],
          'rätta': [('rätta', False)],
          'rättas': [('rätta', False)],
          'rätte': [('rätta', False)],
          'rätter': [('rätta', False)],
          'rättes': [('rätta', False)],
          'rätts': [('räda', False)],
          'rävd': [('räva', False)],
          'rävdes': [('räva', False)],
          'rävlades': [('rävla', False)],
          'rävlas': [('rävla', False)],
          'rävlats': [('rävla', False)],
          'rävts': [('räva', False)],
          'rå': [('rå', False)],
          'rå-': [('rå', True)],
          'råd': [('rå', True), ('råda', True)],
          'råd-': [('rå', True), ('råda', True)],
          'råda': [('rå', True), ('råda', True)],
          'rådande': [('rå', True), ('råda', True)],
          'rådandes': [('rå', True), ('råda', True)],
          'rådas': [('rå', True), ('råda', True)],
          'rådd': [('rå', True), ('råda', True)],
          'rådda': [('rå', True), ('råda', True)],
          'råddas': [('råda', True), ('rå', True)],
          'rådde': [('rå', True), ('råda', True)],
          'råddes': [('rå', True), ('råda', True)],
          'rådds': [('råda', True), ('rå', True)],
          'råder': [('rå', True), ('råda', True)],
          'råds': [('rå', True), ('råda', True)],
          'råg': [('råga', False)],
          'råge': [('råga', False)],
          'råkades': [('råkas', True), ('råka', True)],
          'råkas': [('råka', True), ('råkas', True)],
          'råkats': [('råka', True), ('råkas', True)],
          'råla': [('råla', False)],
          'rålade': [('råla', False)],
          'rålades': [('råla', False)],
          'rålas': [('råla', False)],
          'rångats': [('rånga', False)],
          'rår': [('rå', True)],
          'rås': [('rå', True)],
          'råt': [('råta', False)],
          'råte': [('råta', False)],
          'råtes': [('råta', False)],
          'råts': [('råta', False)],
          'rått': [('råda', True), ('rå', True)],
          'råtts': [('rå', True), ('råda', True)],
          'rö': [('rö', False)],
          'rö-': [('rö', False)],
          'röd': [('röda', False)],
          'röd-': [('röda', False)],
          'rödandes': [('röda', False)],
          'rödd': [('rö', False)],
          'rödda': [('rö', False)],
          'röddas': [('rö', False)],
          'rödde': [('rö', False)],
          'röddes': [('röda', False)],
          'rödds': [('rö', False)],
          'röder': [('röda', False)],
          'rödes': [('röda', False)],
          'röjas': [('röja', False)],
          'röjd': [('röja', False)],
          'röjda': [('röja', True)],
          'röjdas': [('röja', True)],
          'röjdes': [('röja', False)],
          'röjs': [('röja', False)],
          'röjt': [('röja', False)],
          'röjts': [('röja', False)],
          'rök': [('ryka', True), ('röka', True)],
          'rökes': [('röka', False)],
          'röks': [('röka', True)],
          'römd': [('römma', False)],
          'römda': [('römma', False)],
          'römdas': [('römma', False)],
          'römde': [('römma', False)],
          'röms': [('römma', False)],
          'römt': [('römma', False)],
          'römts': [('römma', False)],
          'röp': [('röpa', False)],
          'röpe': [('rypa', False)],
          'röpes': [('rypa', False)],
          'röps': [('rypa', False)],
          'rör': [('röra', True)],
          'röras': [('röra', False)],
          'rördes': [('röra', False)],
          'rört': [('röra', False)],
          'rörts': [('röra', False)],
          'rös': [('rösa', True), ('rysa', True)],
          'rösas': [('rösa', False)],
          'röses': [('rysa', True)],
          'röst': [('rösta', False)],
          'rösta': [('rösta', True)],
          'röstas': [('rösta', True)],
          'röstats': [('rösta', False)],
          'röt': [('röta', True), ('ryta', True)],
          'röte': [('ryta', False)],
          'rötes': [('ryta', False)],
          'röts': [('ryta', False)],
          'rötta': [('rötta', False)],
          'rötts': [('rö', False)],
          'röv': [('röva', False)],
          'rövades': [('röva', False)],
          's': [('a', False)],
          's-': [('sa', False)],
          'sa': [('säga', True)],
          'sabbats': [('sabba', False)],
          'sack': [('sacka', True)],
          'sad': [('sa', False)],
          'sade': [('säga', True)],
          'sades': [('säga', True)],
          'sads': [('sa', False)],
          'saft': [('safta', True)],
          'sag': [('saga', False)],
          'sagades': [('saga', False)],
          'sagas': [('saga', False)],
          'sagd': [('säga', False)],
          'sagda': [('säga', False)],
          'sagdas': [('säga', False)],
          'sagde': [('säga', True)],
          'sagdes': [('säga', True)],
          'sagds': [('säga', True)],
          'saglade': [('sagla', True)],
          'saglades': [('sagla', True)],
          'sagt': [('säga', False)],
          'sagts': [('säga', True)],
          'sakades': [('saka', False)],
          'sakas': [('saka', True)],
          'sakats': [('saka', True)],
          'saknades': [('saknas', True), ('sakna', True)],
          'saknas': [('saknas', True), ('sakna', True)],
          'saknats': [('sakna', True), ('saknas', True)],
          'sakta': [('sakta', True)],
          'sal': [('sala', True)],
          'sala': [('sala', True)],
          'salade': [('sala', True)],
          'salas': [('sala', True)],
          'salt': [('salta', False)],
          'sam': [('simma', True)],
          'samla': [('samla', False)],
          'samlade': [('samla', False)],
          'samlades': [('samlas', True), ('samla', True)],
          'samlas': [('samla', True), ('samlas', True)],
          'samlats': [('samla', True), ('samlas', True)],
          'sams': [('samsa', True), ('simma', True)],
          'samsades': [('samsas', True), ('samsa', True)],
          'samsas': [('samsa', True), ('samsas', True)],
          'samsats': [('samsa', True), ('samsas', True)],
          'sandades': [('sanda', True)],
          'sandas': [('sanda', True)],
          'sandats': [('sanda', True)],
          'sande': [('sa', False)],
          'sandes': [('sa', False)],
          'sann': [('sanna', False)],
          'sar': [('sa', False)],
          'sas': [('säga', True)],
          'sat': [('sa', False)],
          'sats': [('satsa', True)],
          'satt': [('sitta', True), ('sätta', True)],
          'satts': [('sitta', True), ('sätta', True)],
          'sava': [('sava', True)],
          'schas': [('schasa', True)],
          'sd': [('sa', False)],
          'sde': [('sa', False)],
          'sdes': [('sa', False)],
          'sds': [('sa', False)],
          'se': [('se', True)],
          'se-': [('se', False)],
          'sedda': [('se', False)],
          'sedds': [('se', True)],
          'seg': [('sega', True)],
          'segat': [('sega', True)],
          'segats': [('sega', True)],
          'sel': [('sela', True)],
          'sel-': [('sela', True)],
          'sela': [('sela', True)],
          'selas': [('sela', True)],
          'selat': [('sela', True)],
          'seletts': [('seleda', False)],
          'sen': [('sena', False)],
          'senades': [('sena', False)],
          'senas': [('sena', False)],
          'senats': [('sena', False)],
          'senta': [('senta', False)],
          'sentas': [('senta', False)],
          'ser': [('se', False)],
          'ser-': [('sera', False)],
          'serad': [('sera', False)],
          'serades': [('sera', False)],
          'seras': [('sera', False)],
          'ses': [('se', False)],
          'sett': [('se', False)],
          'sger': [('sge', False)],
          'sges': [('sge', False)],
          'sgicks': [('sgå', False)],
          'sgjord': [('sgöra', False)],
          'sgjorda': [('sgöra', False)],
          'sgjordas': [('sgöra', False)],
          'sgås': [('sgå', False)],
          'sgåtts': [('sgå', False)],
          'shandla': [('shandla', False)],
          'shandlade': [('shandla', False)],
          'shandlades': [('shandla', False)],
          'shandlas': [('shandla', False)],
          'shas': [('sha', False)],
          'shat': [('sha', False)],
          'shoppades': [('shoppa', False)],
          'shoppas': [('shoppa', False)],
          'shoppats': [('shoppa', True)],
          'shuggas': [('shugga', False)],
          'shållas': [('shålla', False)],
          'shöggs': [('shugga', False)],
          'sierats': [('siera', False)],
          'signa': [('signa', False)],
          'signas': [('signa', False)],
          'signe': [('signe', False)],
          'signerats': [('signera', False)],
          'sikta': [('sikta', False)],
          'siktas': [('sikta', False)],
          'sims': [('simsa', True)],
          'sinter': [('sintra', True)],
          'sintrades': [('sintra', True)],
          'sintras': [('sintra', True)],
          'sisade': [('sisa', True)],
          'sitter': [('sitta', False)],
          'sitts': [('sitta', True)],
          'sjande': [('sja', False)],
          'sjas': [('sjasa', True)],
          'sjats': [('sja', False)],
          'sjudas': [('sjuda', True)],
          'sjudits': [('sjuda', True)],
          'sjuds': [('sjuda', True)],
          'ska': [('skola', True)],
          'skadad': [('skada', True)],
          'skade': [('skada', True)],
          'skalkades': [('skalka', True), ('skalkas', True)],
          'skalkas': [('skalkas', True), ('skalka', True)],
          'skalkats': [('skalkas', True), ('skalka', True)],
          'skall': [('skola', True)],
          'skar': [('skära', True)],
          'skas': [('ska', False)],
          'skats': [('ska', False)],
          'ske': [('ske', True)],
          'ske-': [('ske', True)],
          'skel': [('skela', True)],
          'skel-': [('skela', True)],
          'sken': [('skena', True), ('skina', True)],
          'sker': [('ske', True)],
          'skes': [('ske', True)],
          'skildes': [('skiljas', True), ('skilja', True)],
          'skiljas': [('skilja', True), ('skiljas', True)],
          'skiljes': [('skiljas', True), ('skilja', True)],
          'skiljs': [('skiljas', True), ('skilja', True)],
          'skilts': [('skilja', True), ('skiljas', True)],
          'skingrades': [('skingras', True), ('skingra', True)],
          'skingras': [('skingras', True), ('skingra', True)],
          'skingrats': [('skingra', True), ('skingras', True)],
          'skivades': [('skiva', True)],
          'skivas': [('skiva', True)],
          'skivats': [('skiva', True)],
          'skjuts': [('skjutsa', True), ('skjuta', True)],
          'skla': [('skla', False)],
          'sklar': [('skla', False)],
          'sknade': [('skna', False)],
          'sknades': [('skna', False)],
          'sknas': [('skna', False)],
          'sknat': [('skna', False)],
          'skockades': [('skockas', True)],
          'skockas': [('skockas', True)],
          'skockats': [('skockas', True)],
          'skomna': [('skomma', False)],
          'skor': [('sko', False)],
          'skott': [('skotta', True), ('sko', True)],
          'skrev': [('skreva', True), ('skriva', True)],
          'skrymt': [('skrymta', True), ('skrymma', True)],
          'skräckes': [('skräcka', False)],
          'skräcks': [('skräcka', False)],
          'skräcktes': [('skräcka', False)],
          'skräckts': [('skräcka', False)],
          'skrädd': [('skrädda', True), ('skräda', True)],
          'skrädda': [('skrädda', True), ('skräda', True)],
          'skräddas': [('skrädda', True), ('skräda', True)],
          'skrämt': [('skrämma', True)],
          'skubbades': [('skubba', True)],
          'skubbas': [('skubba', True)],
          'skubbats': [('skubba', True)],
          'skvalt': [('skvalta', True)],
          'sky': [('skya', True), ('sky', True)],
          'sky-': [('sky', True), ('skya', True)],
          'skydd': [('skydda', True), ('sky', True)],
          'skydda': [('skydda', True), ('sky', True)],
          'skyddas': [('sky', True), ('skydda', True)],
          'skylt': [('skylta', True), ('skyla', True)],
          'skymt': [('skymta', True), ('skymma', True)],
          'skämmas': [('skämma', True), ('skämmas', True)],
          'skäms': [('skämma', True), ('skämmas', True)],
          'skämt': [('skämma', True), ('skämta', True)],
          'skänd': [('skända', True)],
          'skända': [('skända', True)],
          'skändas': [('skända', True)],
          'skändes': [('skänna', False)],
          'skännas': [('skänna', False)],
          'skänns': [('skänna', False)],
          'skänts': [('skänna', False)],
          'skårades': [('skåra', True)],
          'skåras': [('skåra', True)],
          'skårats': [('skåra', True)],
          'skörd': [('skörda', True)],
          'skörda': [('skörda', True)],
          'skördas': [('skörda', True)],
          'sköt': [('sköta', True), ('skjuta', True)],
          'skötes': [('sköta', True), ('skjuta', True)],
          'sköts': [('sköta', True), ('skjuta', True)],
          'sla': [('slägga', False)],
          'slade': [('sla', False)],
          'slagits': [('slåss', True), ('slå', True)],
          'slagna': [('slå', False)],
          'slank': [('slinka', True), ('slanka', True)],
          'slant': [('slanta', True), ('slinta', True)],
          'slapp': [('slippa', True), ('slappa', True)],
          'slas': [('slasa', True)],
          'slats': [('sla', False)],
          'sled': [('sleda', False)],
          'sledas': [('sleda', False)],
          'sleddes': [('sleda', False)],
          'sledes': [('sleda', False)],
          'sleds': [('sleda', False)],
          'slet': [('slita', False)],
          'slett': [('sleda', False)],
          'sletts': [('sleda', False)],
          'slikt': [('slikta', True)],
          'slir': [('slira', True)],
          'slits': [('slitsa', True), ('slita', True)],
          'slog': [('slå', False)],
          'sloge': [('slå', False)],
          'sloges': [('slå', False)],
          'slogs': [('slåss', True), ('slå', True)],
          'sluggades': [('slugga', True)],
          'sluggas': [('slugga', True)],
          'sluggats': [('slugga', True)],
          'slummats': [('slummas', False)],
          'sluten': [('sluta', False)],
          'slutna': [('sluta', True)],
          'släckas': [('släcka', False)],
          'släktas': [('släktas', True)],
          'släktats': [('släktas', True)],
          'slängas': [('slänga', True)],
          'slängdes': [('slänga', True)],
          'slänges': [('slänga', True)],
          'slängs': [('slänga', True)],
          'slängts': [('slänga', True)],
          'slästas': [('släsa', False)],
          'slät': [('släta', False)],
          'slås': [('slå', False)],
          'slåss': [('slåss', True)],
          'slått': [('slåtta', True)],
          'slöjd': [('slöjda', True)],
          'slöte': [('sluta', False)],
          'slötes': [('sluta', False)],
          'smalna': [('smalna', False)],
          'smalnas': [('smalna', False)],
          'smalt': [('smälta', True)],
          'smalts': [('smälta', True)],
          'smas': [('sma', False)],
          'smats': [('sma', False)],
          'smekas': [('smekas', True), ('smeka', True)],
          'smekes': [('smeka', True), ('smekas', True)],
          'smeks': [('smekas', True), ('smeka', True)],
          'smektes': [('smeka', True), ('smekas', True)],
          'smekts': [('smekas', True), ('smeka', True)],
          'smet': [('smita', True), ('smeta', True)],
          'smitt': [('smitta', True), ('smida', True)],
          'smultna': [('smälta', True)],
          'smultnas': [('smälta', True)],
          'smält': [('smälta', True)],
          'smälte': [('smälta', False)],
          'smältes': [('smälta', True)],
          'smälts': [('smälta', False)],
          'smätt': [('smätta', True)],
          'smätta': [('smätta', True)],
          'smättas': [('smätta', True)],
          'smätte': [('smätta', True)],
          'smättes': [('smätta', True)],
          'smätts': [('smätta', True)],
          'smått': [('små', False)],
          'sna': [('sna', False)],
          'snabbades': [('snabba', False)],
          'snabbas': [('snabba', False)],
          'snades': [('snas', False)],
          'snappades': [('snappa', False)],
          'snappas': [('snappa', False)],
          'snappats': [('snappa', False)],
          'snar': [('snara', True)],
          'snarrades': [('snarra', True)],
          'snarras': [('snarra', True)],
          'snarrats': [('snarra', True)],
          'snas': [('snas', False)],
          'snats': [('sna', False)],
          'snattades': [('snatta', True)],
          'snattas': [('snatta', True)],
          'snattats': [('snatta', True)],
          'snek': [('snika', True)],
          'snoppades': [('snoppa', False)],
          'snoppas': [('snoppa', True)],
          'snor': [('snora', True), ('sno', True)],
          'snos': [('sno', True)],
          'snärt': [('snärta', True)],
          'snäst': [('snäsa', True)],
          'snästa': [('snäsa', True)],
          'snästas': [('snäsa', True)],
          'snäste': [('snäsa', True)],
          'snästes': [('snäsa', True)],
          'snöp': [('snöpa', True)],
          'snöpes': [('snöpa', True)],
          'snöps': [('snöpa', True)],
          'snöt': [('snyta', True)],
          'snötes': [('snyta', True)],
          'snöts': [('snyta', True)],
          'sol': [('sola', True)],
          'sola': [('sola', True)],
          'solda': [('solda', False)],
          'somna': [('somna', False)],
          'sonades': [('sona', True)],
          'sonas': [('sona', False)],
          'sonats': [('sona', True)],
          'sord': [('sorda', False)],
          'sordas': [('sorda', False)],
          'sordna': [('sordna', False)],
          'sordnas': [('sordna', False)],
          'sov': [('sova', False)],
          'sove': [('sova', False)],
          'soves': [('sova', False)],
          'sovs': [('sova', True)],
          'spar': [('spara', True)],
          'sparkades': [('sparka', True), ('sparkas', True)],
          'sparkas': [('sparkas', True), ('sparka', True)],
          'sparkats': [('sparkas', True), ('sparka', True)],
          'spars': [('spara', True)],
          'spats': [('spa', False)],
          'spelades': [('spela', False)],
          'spelas': [('spela', True)],
          'spelats': [('spela', False)],
          'spiller': [('spilla', True)],
          'spla': [('spla', False)],
          'splas': [('spla', False)],
          'sport': [('sporta', True), ('spörja', True)],
          'spritt': [('spritta', True), ('sprida', True)],
          'spritts': [('spritta', True), ('sprida', True)],
          'språkades': [('språkas', True), ('språka', True)],
          'språkas': [('språkas', True), ('språka', True)],
          'språkats': [('språkas', True), ('språka', True)],
          'spyr': [('spy', True)],
          'spys': [('spy', False)],
          'spänt': [('spänta', True), ('spänna', True)],
          'spår': [('spåra', True), ('spå', True)],
          'srat': [('sra', False)],
          'srats': [('sra', False)],
          'ss': [('ssa', False)],
          'ssa': [('ssa', False)],
          'ssade': [('ssa', False)],
          'ssas': [('ssa', False)],
          'ssats': [('ssa', False)],
          'ssatt': [('ssätta', False)],
          'ssatts': [('ssätta', False)],
          'ssel': [('ssla', False)],
          'ssel-': [('ssla', False)],
          'sser': [('ssa', False)],
          'ssjas': [('ssja', False)],
          'sskjuts': [('sskjuta', False)],
          'sskrev': [('sskriva', False)],
          'sskänd': [('sskänna', False)],
          'sskända': [('sskänna', False)],
          'sskändas': [('sskänna', False)],
          'ssköt': [('sskjuta', False)],
          'sskötes': [('sskjuta', False)],
          'ssköts': [('sskjuta', False)],
          'ssla': [('ssla', False)],
          'sslade': [('sslägga', False)],
          'sslades': [('ssla', False)],
          'sslas': [('ssla', False)],
          'ssnades': [('ssna', False)],
          'ssnar': [('ssna', False)],
          'ssnas': [('ssna', False)],
          'ssta': [('ssa', False)],
          'sstag': [('ssta', False)],
          'sstag-': [('ssta', False)],
          'sstaga': [('ssta', False)],
          'sstagande': [('ssta', False)],
          'sstagandes': [('ssta', False)],
          'sstagas': [('ssta', False)],
          'sstas': [('ssa', False)],
          'sste': [('ssa', False)],
          'sstros': [('sstro', False)],
          'st': [('sa', False)],
          'st-': [('ste', False)],
          'sta': [('sta', False)],
          'stack': [('stacka', True), ('sticka', True)],
          'stag': [('staga', True)],
          'stag-': [('staga', True)],
          'staga': [('staga', True)],
          'stagande': [('staga', True)],
          'stagandes': [('staga', True)],
          'stagas': [('staga', True)],
          'stagits': [('sta', False)],
          'stal': [('stjäla', False)],
          'stalades': [('stala', False)],
          'stalt': [('stalta', False)],
          'stampades': [('stampa', True)],
          'stampas': [('stampa', True)],
          'stampats': [('stampa', True)],
          'stande': [('ste', False)],
          'standes': [('ste', False)],
          'stank': [('stinka', True)],
          'stas': [('sta', False)],
          'stats': [('sta', False)],
          'ste-': [('sta', False)],
          'steg': [('stega', True), ('stiga', True)],
          'stilla': [('stilla', True)],
          'stillade': [('stilla', True)],
          'stillades': [('stilla', True)],
          'stillas': [('stilla', True)],
          'stlade': [('stlägga', False)],
          'stlades': [('stlägga', False)],
          'stlas': [('stlägga', False)],
          'stnas': [('stna', False)],
          'stogs': [('sta', False)],
          'strades': [('stra', False)],
          'stras': [('stra', False)],
          'streds': [('strida', False)],
          'stros': [('strosa', True)],
          'strängas': [('stränga', True)],
          'strängdes': [('stränga', False)],
          'strängs': [('stränga', False)],
          'strängt': [('stränga', False)],
          'strängts': [('stränga', False)],
          'strött': [('strö', False)],
          'sts': [('sa', False)],
          'stspelades': [('stspela', False)],
          'stspelats': [('stspela', False)],
          'sturats': [('stura', True)],
          'styckas': [('stycka', False)],
          'styckes': [('stycka', False)],
          'stycks': [('stycka', False)],
          'stycktes': [('stycka', False)],
          'styckts': [('stycka', False)],
          'stäckas': [('stäcka', True)],
          'stäckes': [('stäcka', True)],
          'stäcks': [('stäcka', True)],
          'stäcktes': [('stäcka', True)],
          'stäckts': [('stäcka', True)],
          'städ': [('städa', True), ('städja', True)],
          'stämt': [('stämma', False)],
          'stämts': [('stämma', True)],
          'stätna': [('stäta', False)],
          'stätnas': [('stäta', False)],
          'stångades': [('stånga', True), ('stångas', True)],
          'stångas': [('stångas', True), ('stånga', True)],
          'stångats': [('stångas', True), ('stånga', True)],
          'ståt': [('ståta', True)],
          'stöp': [('stupa', True), ('stöpa', True)],
          'stöpes': [('stupa', True), ('stöpa', True)],
          'stöps': [('stupa', True), ('stöpa', True)],
          'stör': [('störa', False)],
          'störas': [('störa', True)],
          'stördes': [('störa', True)],
          'störes': [('störa', False)],
          'störs': [('störa', False)],
          'stört': [('störta', True), ('störa', True)],
          'störts': [('störa', True)],
          'stött': [('stödja', True), ('stöta', True)],
          'stötta': [('stötta', True), ('stöta', True)],
          'stöttas': [('stötta', True), ('stöta', True)],
          'stötte': [('stötta', True), ('stöta', True)],
          'stötts': [('stödja', True), ('stöta', True)],
          'sugens': [('suga', False)],
          'suget': [('suga', False)],
          'sugit': [('suga', False)],
          'sugits': [('suga', False)],
          'sugne': [('suga', False)],
          'sugnes': [('suga', False)],
          'summats': [('summa', True)],
          'sumpades': [('sumpa', True)],
          'sumpas': [('sumpa', True)],
          'sumpats': [('sumpa', True)],
          'sunna': [('sunna', False)],
          'supen': [('supa', False)],
          'supens': [('supa', False)],
          'supes': [('supa', False)],
          'supet': [('supa', False)],
          'supets': [('supa', False)],
          'supit': [('supa', False)],
          'supits': [('supa', True)],
          'supna': [('supa', False)],
          'supnas': [('supa', False)],
          'supne': [('supa', False)],
          'supnes': [('supa', False)],
          'surades': [('sura', True)],
          'suras': [('sura', False)],
          'surats': [('sura', True)],
          'surna': [('surna', True)],
          'surnas': [('surna', True)],
          'sussas': [('sussa', True)],
          'sussats': [('sussa', True)],
          'svalt': [('svälta', True), ('svälja', True)],
          'svalts': [('svälta', True), ('svälja', True)],
          'svankades': [('svanka', True)],
          'svankas': [('svanka', True)],
          'svankats': [('svanka', True)],
          'svann': [('svinna', False)],
          'svar': [('svara', False)],
          'svarades': [('svara', False)],
          'svaras': [('svara', False)],
          'svarats': [('svara', False)],
          'sved': [('svida', True), ('sveda', True)],
          'sveds': [('svida', True), ('sveda', True)],
          'sveks': [('svika', True)],
          'svett': [('sveda', True), ('svetta', True)],
          'svettades': [('svetta', True), ('svettas', True)],
          'svettas': [('svetta', True), ('svettas', True)],
          'svettats': [('svettas', True), ('svetta', True)],
          'svetts': [('sveda', True)],
          'svikt': [('svikta', True)],
          'svisats': [('svisa', False)],
          'svor': [('svära', True)],
          'svors': [('svära', True)],
          'svure': [('svära', True)],
          'svuren': [('svära', True)],
          'svurens': [('svära', True)],
          'svures': [('svära', False)],
          'svuret': [('svära', True)],
          'svurets': [('svära', True)],
          'svurit': [('svära', False)],
          'svurits': [('svära', False)],
          'svurna': [('svära', True)],
          'svurnas': [('svära', True)],
          'svurne': [('svära', True)],
          'svurnes': [('svära', True)],
          'sväljas': [('svälja', True)],
          'svär': [('svära', False)],
          'svär-': [('svära', True)],
          'svära': [('svära', True)],
          'svärande': [('svära', True)],
          'svärandes': [('svära', False)],
          'sväras': [('svära', True)],
          'svärj': [('svärja', False)],
          'svärj-': [('svärja', False)],
          'svärja': [('svära', True)],
          'svärjande': [('svära', True)],
          'svärjandes': [('svära', False)],
          'svärjas': [('svära', True)],
          'svärje': [('svära', True)],
          'svärjer': [('svära', False)],
          'svärjes': [('svära', True)],
          'svärs': [('svära', True)],
          'svårades': [('svåra', False)],
          'svåras': [('svåra', False)],
          'svårats': [('svåra', False)],
          'sy': [('sy', False)],
          'sydda': [('sy', False)],
          'syddas': [('sy', True)],
          'sydds': [('sy', False)],
          'synas': [('synas', True), ('syna', True)],
          'synes': [('synas', True)],
          'syntes': [('synas', True)],
          'synts': [('synas', True)],
          'syr': [('syra', True), ('sy', True)],
          'sytt': [('sy', True)],
          'säckats': [('säcka', True)],
          'säjande': [('säga', False)],
          'säjes': [('säga', False)],
          'säjs': [('säga', True)],
          'säkta': [('säkta', False)],
          'säktats': [('säkta', False)],
          'säljes': [('sälja', False)],
          'säljs': [('sälja', False)],
          'sämjades': [('sämjas', True)],
          'sämjas': [('sämjas', True)],
          'sändas': [('sända', False)],
          'sänds': [('sända', False)],
          'sänt': [('sända', True)],
          'sänts': [('sända', True)],
          'sär': [('sära', True)],
          'sär-': [('sära', True)],
          'särande': [('sära', True)],
          'säras': [('sära', True)],
          'sätnas': [('säta', False)],
          'sätta': [('sätta', False)],
          'sättas': [('sätta', False)],
          'sätter': [('sätta', False)],
          'sättes': [('sätta', False)],
          'så': [('så', False)],
          'sådda': [('så', False)],
          'såddas': [('så', False)],
          'sådds': [('så', True)],
          'såg': [('se', True), ('såga', True)],
          'sår': [('såra', True), ('så', True)],
          'sårades': [('såra', True)],
          'såras': [('såra', True)],
          'sås': [('såsa', True), ('så', True)],
          'såt': [('såta', True)],
          'sått': [('så', False)],
          'söges': [('suga', False)],
          'sök': [('söka', False)],
          'sökes': [('söka', False)],
          'söks': [('söka', False)],
          'söp': [('supa', False)],
          'söps': [('supa', False)],
          'sövdes': [('söva', True)],
          'sövs': [('söva', True)],
          'sövts': [('söva', True)],
          't-': [('ta', False)],
          'ta': [('ta', True)],
          'tack': [('tacka', False)],
          'tad': [('ta', False)],
          'tadd': [('tädja', False)],
          'tadda': [('tädja', False)],
          'tade': [('ta', False)],
          'tades': [('ta', False)],
          'tads': [('ta', False)],
          'tag': [('ta', True)],
          'tag-': [('ta', True)],
          'taga': [('ta', False)],
          'tagades': [('taga', False)],
          'tagande': [('ta', False)],
          'tagandes': [('ta', False)],
          'tagas': [('ta', False)],
          'tagen': [('ta', False)],
          'tagens': [('ta', False)],
          'tager': [('ta', False)],
          'tages': [('ta', False)],
          'taget': [('ta', False)],
          'tagets': [('ta', False)],
          'tagit': [('ta', False)],
          'tagits': [('tas', True), ('ta', True)],
          'taglade': [('tagla', True)],
          'taglades': [('tagla', True)],
          'tagna': [('ta', False)],
          'tagnas': [('ta', False)],
          'tagne': [('ta', False)],
          'tagnes': [('ta', False)],
          'tags': [('ta', False)],
          'takades': [('taka', False)],
          'takta': [('takta', False)],
          'tal': [('tala', False)],
          'tala': [('tala', False)],
          'talade': [('tala', False)],
          'talades': [('tala', True)],
          'talas': [('tala', False)],
          'tald': [('tala', False)],
          'talda': [('tala', False)],
          'talde': [('tälja', True), ('tala', True)],
          'taldes': [('tala', True), ('tälja', True)],
          'talds': [('tala', False)],
          'talkas': [('talka', True)],
          'talkats': [('talka', True)],
          'tall': [('talla', False)],
          'tals': [('tjäla', False)],
          'talt': [('tala', True), ('tälja', True)],
          'talts': [('tala', True), ('tälja', True)],
          'tamp': [('tampa', False)],
          'tampades': [('tampas', True)],
          'tampas': [('tampas', True)],
          'tampats': [('tampas', True)],
          'tandades': [('tanda', True)],
          'tandas': [('tanda', True)],
          'tandats': [('tanda', True)],
          'tande': [('ta', False)],
          'tandes': [('ta', False)],
          'tank': [('tanka', True)],
          'tankas': [('tanka', True)],
          'tankats': [('tanka', True)],
          'tann': [('tanna', False)],
          'tapp': [('tappa', False)],
          'tappats': [('tappa', False)],
          'tar': [('ta', False)],
          'tarmas': [('tarma', False)],
          'tarmats': [('tarma', False)],
          'tartades': [('tarta', False)],
          'tartas': [('tarta', False)],
          'tartats': [('tarta', False)],
          'tas': [('ta', True), ('tas', True)],
          'tat': [('ta', False)],
          'tats': [('tas', False)],
          'tatt': [('tädja', False)],
          'tav': [('tava', False)],
          'tava': [('tava', False)],
          'tavandes': [('tava', False)],
          'tbildades': [('tbilda', False)],
          'tbildas': [('tbilda', False)],
          'tblött': [('tblöda', False)],
          'tblötts': [('tblöda', False)],
          'tbredd': [('tbre', False)],
          'tbredda': [('tbre', False)],
          'tbreddas': [('tbre', False)],
          'tchas': [('tcha', False)],
          'tdelade': [('tdela', False)],
          'tdragits': [('tdra', False)],
          'tdras': [('tdra', False)],
          'tdrev': [('tdriva', False)],
          'tdrog': [('tdra', False)],
          'tdrogs': [('tdra', False)],
          'te': [('a', False)],
          'te-': [('te', False)],
          'tedda': [('te', False)],
          'tedds': [('te', False)],
          'teg': [('tiga', True)],
          'tegat': [('tega', False)],
          'tegats': [('tega', False)],
          'tek': [('teka', False)],
          'teks': [('teka', False)],
          'tekts': [('teka', False)],
          'ten': [('tena', False)],
          'tenades': [('tena', False)],
          'tenas': [('tena', False)],
          'tenats': [('tena', False)],
          'tens': [('ta', False)],
          'tenta': [('tenta', True)],
          'tentas': [('tenta', True)],
          'ter': [('te', True)],
          'terad': [('tera', False)],
          'terades': [('tera', False)],
          'teras': [('tera', False)],
          'terfås': [('terfå', False)],
          'tersa': [('tersäga', False)],
          'tersade': [('tersäga', False)],
          'tersades': [('tersäga', False)],
          'tersas': [('tersäga', False)],
          'tes': [('a', False)],
          'testa': [('testa', True)],
          'testas': [('testa', False)],
          'tetas': [('tetas', True)],
          'tetats': [('tetas', True)],
          'tets': [('ta', False)],
          'tett': [('te', False)],
          'tfar': [('tfara', False)],
          'tfordrades': [('tfordra', False)],
          'tfordras': [('tfordra', False)],
          'tfordrats': [('tfordra', False)],
          'tfors': [('tfara', False)],
          'tfärdades': [('tfärda', False)],
          'tfärdas': [('tfärda', False)],
          'tfärdats': [('tfärda', False)],
          'tfår': [('tfå', False)],
          'tfås': [('tfå', False)],
          'tga': [('tga', False)],
          'tgande': [('tga', False)],
          'tgar': [('tga', False)],
          'tgats': [('tga', False)],
          'tge': [('tge', False)],
          'tgicks': [('tgå', False)],
          'tgjord': [('tgöra', False)],
          'tgjorda': [('tgöra', False)],
          'tgjordas': [('tgöra', False)],
          'tgås': [('tgå', False)],
          'thandla': [('thandla', False)],
          'thandlade': [('thandla', False)],
          'thandlades': [('thandla', False)],
          'thandlas': [('thandla', False)],
          'thuggas': [('thugga', False)],
          'thållas': [('thålla', False)],
          'thållits': [('thålla', False)],
          'thålls': [('thålla', False)],
          'thöggs': [('thugga', False)],
          'thölls': [('thålla', False)],
          'tick': [('ticka', False)],
          'ticker': [('ticka', False)],
          'ticks': [('ticka', False)],
          'tierats': [('tiera', False)],
          'tiftas': [('tifta', False)],
          'tigades': [('tiga', False)],
          'tigas': [('tiga', False)],
          'tila': [('tila', False)],
          'tilla': [('tillägga', True)],
          'tillade': [('tillägga', True)],
          'tillades': [('tillägga', True)],
          'tillas': [('tillägga', True)],
          'tillats': [('tilla', False)],
          'tim': [('tima', True)],
          'tim-': [('tima', True)],
          'tinge': [('tinga', False)],
          'tinger': [('tinga', False)],
          'tinges': [('tinga', False)],
          'tips': [('tipsa', True)],
          'tiserad': [('tisera', False)],
          'tjande': [('tja', False)],
          'tjat': [('tjata', True)],
          'tjats': [('tja', False)],
          'tjo-': [('tjoa', True)],
          'tjuts': [('tjuta', False)],
          'tkomna': [('tkomma', False)],
          'tkrävas': [('tkräva', False)],
          'tkrävdes': [('tkräva', False)],
          'tkräves': [('tkräva', False)],
          'tkrävs': [('tkräva', False)],
          'tkrävts': [('tkräva', False)],
          'tla': [('tlägga', False)],
          'tlade': [('tla', False)],
          'tlades': [('tla', False)],
          'tlats': [('tla', False)],
          'tlist': [('tlista', False)],
          'tlott': [('tlotta', False)],
          'tlästas': [('tläsa', False)],
          'tlås': [('tlå', False)],
          'tlåts': [('tlåta', False)],
          'tlöd': [('tlyda', False)],
          'tlödes': [('tlyda', False)],
          'tlöds': [('tlyda', False)],
          'tmas': [('tma', False)],
          'tmats': [('tma', False)],
          'tmattades': [('tmatta', False)],
          'tmattas': [('tmatta', False)],
          'tmattats': [('tmatta', False)],
          'tmätt': [('tmäta', False)],
          'tmätta': [('tmäta', False)],
          'tmättas': [('tmäta', False)],
          'tna': [('tna', False)],
          'tnar': [('tna', False)],
          'tnas': [('ta', False)],
          'tnats': [('tna', False)],
          'tnöjts': [('tnöjas', False)],
          'tockats': [('tocka', False)],
          'tod': [('tå', False)],
          'tog': [('ta', False)],
          'toge': [('ta', False)],
          'togs': [('tas', True), ('ta', True)],
          'tonades': [('tona', False)],
          'tonas': [('tona', False)],
          'topp': [('toppa', False)],
          'toppats': [('toppa', False)],
          'tor': [('tora', False)],
          'tordas': [('töras', True)],
          'torde': [('torde', True)],
          'tordes': [('töras', True)],
          'torts': [('töras', True)],
          'tov': [('tova', True)],
          'tramsades': [('tramsa', True)],
          'trandades': [('tranda', False)],
          'trandas': [('tranda', False)],
          'trandats': [('tranda', False)],
          'tras': [('trasa', True)],
          'trat': [('tra', False)],
          'trats': [('tra', False)],
          'tred': [('trida', False)],
          'treda': [('treda', False)],
          'tredande': [('treda', False)],
          'tredds': [('treda', False)],
          'tredes': [('trida', False)],
          'treds': [('treda', False)],
          'tretades': [('treta', False)],
          'tretas': [('treta', False)],
          'tretats': [('treta', False)],
          'trett': [('treda', False)],
          'trev': [('treva', True)],
          'trilade': [('trila', False)],
          'trilades': [('trila', False)],
          'trilas': [('trila', False)],
          'tritts': [('trida', False)],
          'trivas': [('trivas', False)],
          'trivs': [('trivas', True)],
          'tro': [('tro', False)],
          'trodd': [('tro', False)],
          'troddas': [('tro', False)],
          'troniserad': [('troniserad', False)],
          'tros': [('tro', False)],
          'trymdes': [('trymma', False)],
          'trymmas': [('trymma', False)],
          'tryms': [('trymma', False)],
          'trymt': [('trymma', False)],
          'trymts': [('trymma', False)],
          'träckas': [('träcka', False)],
          'träd': [('trä', True), ('träda', True)],
          'träd-': [('trä', True), ('träda', True)],
          'träda': [('trä', True), ('träda', True)],
          'trädande': [('trä', True), ('träda', True)],
          'trädandes': [('trä', True), ('träda', True)],
          'trädas': [('trä', True), ('träda', True)],
          'trädd': [('trä', True), ('träda', True)],
          'trädda': [('trä', True), ('träda', True)],
          'träddas': [('trä', True), ('träda', True)],
          'trädde': [('trä', True), ('träda', True)],
          'träddes': [('trä', True), ('träda', True)],
          'trädds': [('trä', True), ('träda', True)],
          'träder': [('trä', True), ('träda', True)],
          'träds': [('trä', True), ('träda', True)],
          'träffades': [('träffas', True), ('träffa', True)],
          'träffas': [('träffas', True), ('träffa', True)],
          'träffats': [('träffas', True), ('träffa', True)],
          'träknade': [('träkna', False)],
          'träknades': [('träkna', False)],
          'träknas': [('träkna', False)],
          'träknats': [('träkna', False)],
          'trängas': [('trängas', True), ('tränga', True)],
          'trängdes': [('trängas', True), ('tränga', True)],
          'trängs': [('trängas', True), ('tränga', True)],
          'trängt': [('trängta', True), ('tränga', True)],
          'trängts': [('trängas', True), ('tränga', True)],
          'träs': [('trä', True)],
          'trät': [('träta', True)],
          'trätes': [('träta', True)],
          'träts': [('träta', True)],
          'trätt': [('trä', True), ('träta', True), ('träda', True)],
          'trätta': [('träta', False)],
          'trättas': [('träta', True)],
          'trätte': [('träta', False)],
          'trättes': [('träta', True)],
          'trätts': [('träta', True), ('trä', True), ('träda', True)],
          'trävas': [('träva', False)],
          'tråda': [('tråda', False)],
          'trådande': [('tråda', False)],
          'trådandes': [('tråda', False)],
          'trådas': [('tråda', False)],
          'trådd': [('trå', False)],
          'trådda': [('trå', False)],
          'tråddas': [('trå', True)],
          'trådde': [('trå', False)],
          'tråddes': [('trå', False)],
          'trådds': [('trå', True)],
          'tråkades': [('tråka', True)],
          'tråkas': [('tråka', True)],
          'tråkats': [('tråka', True)],
          'trått': [('trå', False)],
          'tråtts': [('trå', False)],
          'tröddes': [('trö', False)],
          'trök': [('tryka', False)],
          'trökes': [('tryka', False)],
          'tröks': [('tryka', False)],
          'tröp': [('trypa', False)],
          'trör': [('trö', False)],
          'trös': [('trö', False)],
          'tröt': [('tryta', True)],
          'trött': [('trötta', True)],
          'tröttades': [('tröttas', True), ('trötta', True)],
          'tröttas': [('tröttas', True), ('trötta', True)],
          'tröttats': [('trötta', True), ('tröttas', True)],
          'tsa': [('tsa', False)],
          'tsamlades': [('tsamla', False)],
          'tsamlas': [('tsamla', False)],
          'tsamlats': [('tsamla', False)],
          'tsas': [('tsa', False)],
          'tsats': [('tsa', False)],
          'tsatt': [('tsätta', False)],
          'tsatts': [('tsätta', False)],
          'tschas': [('tscha', False)],
          'tsel': [('tsla', False)],
          'tsel-': [('tsla', False)],
          'tska': [('tska', False)],
          'tskad': [('tska', False)],
          'tskadad': [('tskada', False)],
          'tskade': [('tska', False)],
          'tskar': [('tska', False)],
          'tskildes': [('tskilja', False)],
          'tskiljas': [('tskilja', False)],
          'tskiljes': [('tskilja', False)],
          'tskiljs': [('tskilja', False)],
          'tskilts': [('tskilja', False)],
          'tskrev': [('tskriva', False)],
          'tskydd': [('tskydda', False)],
          'tskydda': [('tskydda', False)],
          'tskyddas': [('tskydda', False)],
          'tsla': [('tsla', False)],
          'tslades': [('tsla', False)],
          'tslagits': [('tslå', False)],
          'tslas': [('tsla', False)],
          'tslogs': [('tslå', False)],
          'tspelades': [('tspelas', False)],
          'tspelas': [('tspela', False)],
          'tspelats': [('tspelas', False)],
          'tspritt': [('tsprida', False)],
          'tspritts': [('tsprida', False)],
          'tspår': [('tspå', False)],
          'tstött': [('tstöta', False)],
          'tstötta': [('tstöta', False)],
          'tstöttas': [('tstöta', False)],
          'tstötte': [('tstöta', False)],
          'tstötts': [('tstöta', False)],
          'tsynas': [('tsyna', False)],
          'tsåg': [('tse', False)],
          'tta': [('tta', False)],
          'ttag-': [('tta', False)],
          'ttagits': [('tta', False)],
          'ttala': [('ttalägga', False)],
          'ttalade': [('ttalägga', False)],
          'ttalades': [('ttalägga', False)],
          'ttalas': [('ttalägga', False)],
          'ttas': [('tta', False)],
          'ttats': [('tta', False)],
          'tte': [('tta', False)],
          'tte-': [('tta', False)],
          'ttes': [('tta', False)],
          'ttigats': [('ttiga', False)],
          'ttjat': [('ttja', False)],
          'ttla': [('ttla', False)],
          'ttnas': [('ttna', False)],
          'ttogs': [('tta', False)],
          'ttrades': [('ttra', False)],
          'ttras': [('ttra', False)],
          'tträd': [('tträda', False)],
          'tträd-': [('tträda', False)],
          'tträda': [('tträda', False)],
          'tträdande': [('tträda', False)],
          'tträdandes': [('tträda', False)],
          'tträdas': [('tträda', False)],
          'tträdd': [('tträda', False)],
          'tträdda': [('tträda', False)],
          'tträddas': [('tträda', False)],
          'tträdde': [('tträda', False)],
          'tträddes': [('tträda', False)],
          'tträdds': [('tträda', False)],
          'tträder': [('tträda', False)],
          'tträds': [('tträda', False)],
          'tträngas': [('ttränga', False)],
          'tträngdes': [('ttränga', False)],
          'tträngs': [('ttränga', False)],
          'tträngt': [('ttränga', False)],
          'tträngts': [('ttränga', False)],
          'tträtt': [('tträda', False)],
          'tträtts': [('tträda', False)],
          'ttröttades': [('ttrötta', False)],
          'ttröttas': [('ttrötta', False)],
          'ttröttats': [('ttrötta', False)],
          'ttspår': [('ttspåra', False)],
          'tubbats': [('tubba', False)],
          'tudel': [('tudela', True)],
          'tudel-': [('tudela', True)],
          'tuds': [('tudsa', False)],
          'tuffades': [('tuffa', True)],
          'tuffats': [('tuffa', True)],
          'tuggats': [('tugga', True)],
          'tullades': [('tulla', False)],
          'tullas': [('tulla', False)],
          'tullats': [('tulla', True)],
          'tulnas': [('tjäla', False)],
          'tummats': [('tumma', True)],
          'tundats': [('tunda', False)],
          'tungne': [('tinga', False)],
          'tungnes': [('tinga', False)],
          'tunna': [('tunna', True)],
          'tunnas': [('tunna', False)],
          'tupes': [('tupa', False)],
          'tuppats': [('tuppa', False)],
          'turades': [('tura', False)],
          'turas': [('tura', False)],
          'turats': [('turas', False)],
          'tussas': [('tussa', True)],
          'tussats': [('tussa', True)],
          'tvaldes': [('tvälja', False)],
          'tvalt': [('tvälja', False)],
          'tvann': [('tvinna', False)],
          'tvarades': [('tvara', False)],
          'tvaras': [('tvara', False)],
          'tvarats': [('tvara', False)],
          'tvek': [('tveka', True)],
          'tverkat': [('tverka', False)],
          'tvistades': [('tvista', True)],
          'tvistas': [('tvista', True)],
          'tvistats': [('tvista', True)],
          'tväljas': [('tvälja', False)],
          'tvärandes': [('tvära', True)],
          'tvätt': [('tvätta', False)],
          'tvätta': [('tvätta', False)],
          'tvättas': [('tvätta', False)],
          'tvår': [('två', True)],
          'ty-': [('tya', True)],
          'tyckas': [('tyckas', True), ('tycka', True)],
          'tyckats': [('tycka', False)],
          'tyckes': [('tyckas', True), ('tycka', True)],
          'tycks': [('tycka', True), ('tyckas', True)],
          'tycktes': [('tyckas', True), ('tycka', True)],
          'tyckts': [('tyckas', True), ('tycka', True)],
          'tydd': [('tyda', True)],
          'tydde': [('tyda', False)],
          'tyddes': [('tyda', False)],
          'tygas': [('tyga', False)],
          'tynas': [('tyna', True)],
          'tysta': [('tysta', True)],
          'tystas': [('tysta', True)],
          'tytts': [('tyda', True)],
          'tyvas': [('tyva', False)],
          'täckas': [('täckas', True), ('täcka', True)],
          'täckes': [('täckas', True), ('täcka', True)],
          'täcks': [('täckas', True), ('täcka', True)],
          'täcktes': [('täckas', True), ('täcka', True)],
          'täckts': [('täckas', True), ('täcka', True)],
          'täd-': [('täda', False)],
          'tädandes': [('täda', False)],
          'täder': [('tädja', False)],
          'tädes': [('tädja', False)],
          'täds': [('tädja', False)],
          'täljes': [('tälja', False)],
          'täljs': [('tälja', False)],
          'tämde': [('tämma', False)],
          'tämjs': [('tämja', True)],
          'tämt': [('tämja', True)],
          'tämts': [('tämja', True)],
          'tändas': [('tända', False)],
          'tänds': [('tända', True)],
          'tängs': [('tänga', False)],
          'tängslades': [('tängsla', False)],
          'tängslas': [('tängsla', False)],
          'tängslats': [('tängsla', False)],
          'tänt': [('tända', True)],
          'tänts': [('tända', True)],
          'tär': [('tära', False)],
          'tär-': [('tära', True)],
          'tära': [('tära', False)],
          'täras': [('tära', False)],
          'tärdes': [('tära', False)],
          'tärt': [('tära', True)],
          'tätna': [('tätna', True)],
          'tätnas': [('tätna', True)],
          'tävlades': [('tävla', True)],
          'tävlas': [('tävla', True)],
          'tävlats': [('tävla', True)],
          'tå': [('tå', False)],
          'tådda': [('tå', False)],
          'tåddas': [('tå', False)],
          'tådds': [('tå', False)],
          'tåg': [('tåga', False)],
          'tåla': [('tåla', True)],
          'tålas': [('tåla', True)],
          'tåld': [('tåla', True)],
          'tålda': [('tåla', True)],
          'tåldas': [('tåla', True)],
          'tålde': [('tåla', True)],
          'tåldes': [('tåla', True)],
          'tålds': [('tåla', True)],
          'tålt': [('tåla', True)],
          'tålts': [('tåla', True)],
          'tåndats': [('tånda', False)],
          'tångades': [('tånga', True)],
          'tångas': [('tånga', True)],
          'tångats': [('tånga', False)],
          'tår': [('tå', False)],
          'tårats': [('tåras', True)],
          'tått': [('tå', False)],
          'töd': [('tödja', False)],
          'töd-': [('tödja', False)],
          'töda': [('tödja', False)],
          'tödande': [('tödja', False)],
          'tödandes': [('tödja', False)],
          'tödas': [('tödja', False)],
          'tödd': [('tödja', False)],
          'tödda': [('tödja', False)],
          'töddas': [('tödja', False)],
          'tödde': [('tödja', False)],
          'töddes': [('tödja', False)],
          'tödds': [('tödja', False)],
          'töder': [('tödja', False)],
          'tödes': [('tödja', False)],
          'töds': [('tödja', False)],
          'töjas': [('töja', True)],
          'töjd': [('töja', False)],
          'töjdes': [('töja', False)],
          'töjs': [('töja', True)],
          'töjt': [('töja', True)],
          'töjts': [('töja', False)],
          'tömd': [('tömma', True)],
          'tömda': [('tömma', True)],
          'tömdas': [('tömma', True)],
          'tömde': [('tömma', False)],
          'töms': [('tömma', True)],
          'tömt': [('tömma', False)],
          'tömts': [('tömma', True)],
          'tönt': [('tönta', True)],
          'tönta': [('tönta', True)],
          'töntas': [('tönta', True)],
          'tör': [('torde', True)],
          'töras': [('töras', True)],
          'törnades': [('törna', True)],
          'törnas': [('törna', True)],
          'törnats': [('törna', True)],
          'törs': [('töras', False)],
          'tötes': [('töta', False)],
          'töttats': [('tötta', False)],
          'töv': [('töva', False)],
          'tövades': [('töva', False)],
          'u': [('ua', False)],
          'u-': [('ua', False)],
          'ua': [('ua', False)],
          'uad': [('ua', False)],
          'uade': [('ua', False)],
          'uades': [('ua', False)],
          'uads': [('ua', False)],
          'uande': [('ua', False)],
          'uandes': [('ua', False)],
          'uar': [('ua', False)],
          'uas': [('ua', False)],
          'uat': [('ua', False)],
          'ubbades': [('ubba', False)],
          'ubbas': [('ubba', False)],
          'ubbats': [('ubbas', False)],
          'ublad': [('ubla', False)],
          'uchas': [('ucha', False)],
          'uckades': [('ucka', False)],
          'uckas': [('ucka', False)],
          'ucke': [('icka', False)],
          'ucken': [('icka', False)],
          'uckens': [('icka', False)],
          'ucker': [('uckra', False)],
          'uckes': [('icka', False)],
          'ucket': [('icka', False)],
          'uckets': [('icka', False)],
          'uckit': [('icka', False)],
          'uckits': [('icka', False)],
          'ucklades': [('uckla', False)],
          'ucklas': [('uckla', False)],
          'ucklats': [('uckla', False)],
          'uckna': [('icka', False)],
          'ucknas': [('icka', False)],
          'uckne': [('icka', False)],
          'ucknes': [('icka', False)],
          'ud': [('uda', False)],
          'uda': [('uda', False)],
          'udande': [('uda', False)],
          'udas': [('uda', False)],
          'udats': [('uda', False)],
          'udd': [('udda', False)],
          'udda': [('udda', False)],
          'ude': [('uda', False)],
          'udel': [('udla', False)],
          'udel-': [('udla', False)],
          'udelade': [('udela', False)],
          'udens': [('uda', False)],
          'uder': [('uda', False)],
          'udla': [('udla', False)],
          'udlas': [('udla', False)],
          'udna': [('uda', False)],
          'udrades': [('udra', False)],
          'udras': [('udra', False)],
          'uerad': [('uera', False)],
          'uerades': [('uera', False)],
          'ueras': [('uera', False)],
          'uffas': [('uffa', False)],
          'uga': [('uga', False)],
          'ugande': [('uga', False)],
          'ugar': [('uga', False)],
          'ugats': [('uga', False)],
          'uge': [('uga', False)],
          'ugen': [('uga', False)],
          'ugens': [('yga', False)],
          'uger': [('uga', False)],
          'uges': [('uga', False)],
          'uget': [('yga', False)],
          'ugets': [('uga', False)],
          'uggades': [('ugga', False)],
          'uggar': [('ugga', False)],
          'uggas': [('ugga', False)],
          'ugit': [('yga', False)],
          'ugits': [('yga', False)],
          'ugna': [('uga', False)],
          'ugnades': [('ugna', False)],
          'ugnas': [('uga', False)],
          'ugnat': [('ugna', False)],
          'ugne': [('yga', False)],
          'ugnes': [('yga', False)],
          'ugs': [('uga', False)],
          'uidas': [('uida', False)],
          'uidats': [('uida', False)],
          'uilt': [('uilta', False)],
          'ukar': [('uka', False)],
          'ukas': [('uka', False)],
          'ukats': [('uka', False)],
          'uke': [('yka', False)],
          'uken': [('yka', False)],
          'ukens': [('yka', False)],
          'ukes': [('yka', False)],
          'uket': [('yka', False)],
          'ukets': [('yka', False)],
          'ukit': [('yka', False)],
          'ukits': [('yka', False)],
          'ukna': [('yka', False)],
          'uknade': [('ukna', False)],
          'uknades': [('ukna', False)],
          'uknas': [('yka', False)],
          'uknat': [('ukna', False)],
          'ukne': [('yka', False)],
          'uknes': [('yka', False)],
          'ukt': [('ukta', False)],
          'uktades': [('ukta', False)],
          'ula': [('ula', False)],
          'ulade': [('ula', False)],
          'ulades': [('ula', False)],
          'ulas': [('ula', False)],
          'ulats': [('ula', False)],
          'uld': [('ulda', False)],
          'uldades': [('ulda', False)],
          'uldas': [('ulda', False)],
          'ulde': [('älda', False)],
          'ulden': [('älda', False)],
          'uldens': [('älda', False)],
          'uldes': [('älda', False)],
          'uldet': [('älda', False)],
          'uldets': [('älda', False)],
          'uldna': [('älda', False)],
          'uldnas': [('älda', False)],
          'uldne': [('älda', False)],
          'uldnes': [('älda', False)],
          'ule': [('jäla', False)],
          'ulen': [('jäla', False)],
          'ulens': [('jäla', False)],
          'ules': [('jäla', False)],
          'ulet': [('jäla', False)],
          'ulets': [('jäla', False)],
          'ulit': [('jäla', False)],
          'ulits': [('jäla', False)],
          'ulkades': [('ulka', True)],
          'ull': [('ulla', False)],
          'ullades': [('ullas', True)],
          'ullas': [('ullas', True)],
          'ullats': [('ullas', True)],
          'ulle': [('älla', False)],
          'uller': [('ullra', False)],
          'ullkomnas': [('ullkomna', False)],
          'ullna': [('ullna', False)],
          'ulna': [('jäla', False)],
          'ulnades': [('ulna', False)],
          'ulnas': [('ulna', False)],
          'ulne': [('jäla', False)],
          'ulnes': [('jäla', False)],
          'ult': [('ulta', False)],
          'ulte': [('älta', False)],
          'ulten': [('älta', False)],
          'ultens': [('älta', False)],
          'ultes': [('älta', False)],
          'ultet': [('älta', False)],
          'ultets': [('älta', False)],
          'ultit': [('älta', False)],
          'ultits': [('älta', False)],
          'ultne': [('älta', False)],
          'ultnes': [('älta', False)],
          'ulve': [('älva', False)],
          'um': [('umma', False)],
          'um-': [('umma', False)],
          'umfar': [('umfa', False)],
          'umgicks': [('umgås', True)],
          'umgås': [('umgås', True)],
          'umlas': [('umla', False)],
          'ummades': [('umma', False)],
          'ummas': [('umma', False)],
          'umme': [('imma', False)],
          'ummen': [('imma', False)],
          'ummens': [('imma', False)],
          'ummes': [('imma', False)],
          'ummet': [('imma', False)],
          'ummets': [('imma', False)],
          'ummit': [('imma', False)],
          'ummits': [('imma', False)],
          'umna': [('imma', False)],
          'umnas': [('imma', False)],
          'umne': [('imma', False)],
          'umnes': [('imma', False)],
          'umpades': [('umpa', False)],
          'umpas': [('umpa', False)],
          'umpe': [('impa', False)],
          'umpes': [('impa', False)],
          'umpit': [('impa', False)],
          'umpits': [('impa', False)],
          'umrades': [('umra', False)],
          'umras': [('umra', False)],
          'umsade': [('umsa', False)],
          'umsades': [('umsa', False)],
          'una': [('una', False)],
          'unar': [('una', False)],
          'unats': [('una', False)],
          'und': [('unda', False)],
          'unda': [('unda', False)],
          'undades': [('unda', False)],
          'undas': [('unda', False)],
          'undats': [('undas', False)],
          'unde': [('inda', False)],
          'unden': [('inda', False)],
          'undens': [('inda', False)],
          'under': [('undra', False)],
          'undes': [('inda', False)],
          'undet': [('inda', False)],
          'undets': [('inda', False)],
          'undit': [('inda', False)],
          'undits': [('inda', False)],
          'undla': [('undlägga', False)],
          'undlas': [('undlägga', False)],
          'undna': [('inda', False)],
          'undnas': [('inda', False)],
          'undne': [('inda', False)],
          'undnes': [('inda', False)],
          'unerats': [('unera', False)],
          'ungades': [('unga', False)],
          'ungas': [('unga', False)],
          'unge': [('inga', False)],
          'ungen': [('inga', False)],
          'ungens': [('inga', False)],
          'unges': [('inga', False)],
          'unget': [('inga', False)],
          'ungets': [('inga', False)],
          'ungit': [('inga', False)],
          'ungits': [('inga', False)],
          'ungna': [('inga', False)],
          'ungnas': [('inga', False)],
          'ungne': [('unga', False)],
          'ungnes': [('unga', False)],
          'ungrats': [('ungra', False)],
          'unkades': [('unka', False)],
          'unke': [('inka', False)],
          'unker': [('unkra', False)],
          'unkes': [('inka', False)],
          'unkit': [('inka', False)],
          'unkits': [('inka', False)],
          'unkna': [('unkna', True)],
          'unknas': [('unkna', True)],
          'unkta': [('unkta', False)],
          'unktas': [('unkta', False)],
          'unna': [('unna', True)],
          'unnas': [('unna', True)],
          'unne': [('inna', False)],
          'unnen': [('inna', False)],
          'unnens': [('inna', False)],
          'unnes': [('inna', False)],
          'unnet': [('inna', False)],
          'unnets': [('inna', False)],
          'unnit': [('inna', False)],
          'unsta': [('unsta', False)],
          'unstas': [('unsta', False)],
          'unt': [('unna', True)],
          'unta': [('unna', True)],
          'untas': [('unna', True)],
          'unte': [('unna', True)],
          'untes': [('unna', True)],
          'untit': [('inta', False)],
          'untits': [('inta', False)],
          'untrats': [('untra', False)],
          'unts': [('unna', True)],
          'upar': [('upa', False)],
          'upats': [('upa', False)],
          'upe': [('upa', False)],
          'upen': [('öpa', False)],
          'upens': [('ypa', False)],
          'uper': [('upa', False)],
          'upes': [('ypa', False)],
          'upet': [('öpa', False)],
          'upets': [('öpa', False)],
          'upit': [('ypa', False)],
          'upits': [('öpa', False)],
          'upna': [('öpa', False)],
          'upnas': [('öpa', False)],
          'upne': [('öpa', False)],
          'upnes': [('öpa', False)],
          'uppades': [('uppa', False)],
          'uppas': [('uppa', False)],
          'uppats': [('uppas', False)],
          'uppe': [('ippa', False)],
          'uppes': [('ippa', False)],
          'uppit': [('ippa', False)],
          'uppits': [('ippa', False)],
          'uppla': [('upplägga', True)],
          'upplas': [('upplägga', True)],
          'upprad': [('upprada', True)],
          'uppropad': [('ropa_upp', True)],
          'uppta': [('uppta', True)],
          'upptas': [('uppta', True)],
          'ups': [('upa', False)],
          'ur': [('ura', False)],
          'urat': [('ura', False)],
          'urats': [('ura', False)],
          'ure': [('ära', False)],
          'uren': [('ära', False)],
          'urens': [('ära', False)],
          'ures': [('ära', False)],
          'uret': [('ära', False)],
          'urets': [('ära', False)],
          'urfar': [('urfa', False)],
          'urglade': [('urgla', False)],
          'urglades': [('urgla', False)],
          'urit': [('ära', False)],
          'urits': [('ära', False)],
          'urkades': [('urka', False)],
          'urkalkas': [('urkalka', True)],
          'urkalkats': [('urkalka', True)],
          'urkat': [('urka', False)],
          'urla': [('urla', False)],
          'urlas': [('urla', False)],
          'urmades': [('urma', False)],
          'urna': [('ära', False)],
          'urnades': [('urna', False)],
          'urnas': [('ära', False)],
          'urne': [('ära', False)],
          'urnes': [('ära', False)],
          'urrades': [('urra', False)],
          'urras': [('urra', False)],
          'ursa': [('ursa', False)],
          'ursade': [('ursa', False)],
          'ursades': [('ursa', False)],
          'ursas': [('ursa', False)],
          'urskades': [('urskas', False)],
          'urt': [('urta', False)],
          'urtades': [('urta', False)],
          'us': [('usa', False)],
          'usa': [('usa', False)],
          'usade': [('usa', False)],
          'usades': [('usa', False)],
          'usas': [('usa', False)],
          'usats': [('usa', False)],
          'uschas': [('uscha', False)],
          'use': [('ysa', False)],
          'usen': [('ysa', False)],
          'usens': [('ysa', False)],
          'user': [('usa', False)],
          'uses': [('usa', False)],
          'uset': [('ysa', False)],
          'usets': [('ysa', False)],
          'usit': [('ysa', False)],
          'usits': [('ysa', False)],
          'uska': [('uska', False)],
          'uskad': [('uska', False)],
          'uskade': [('uska', False)],
          'uskades': [('uska', False)],
          'uskar': [('uska', False)],
          'usmalna': [('usmala', False)],
          'usmalnas': [('usmala', False)],
          'usmalt': [('usmala', False)],
          'usmalts': [('usmala', False)],
          'usna': [('ysa', False)],
          'usnades': [('usna', False)],
          'usnar': [('usna', False)],
          'usnas': [('ysa', False)],
          'usne': [('ysa', False)],
          'usnes': [('ysa', False)],
          'ussades': [('ussa', False)],
          'usslade': [('ussla', False)],
          'ust': [('usta', False)],
          'ust-': [('usta', False)],
          'usta': [('usa', False)],
          'ustades': [('usta', False)],
          'ustande': [('usta', False)],
          'ustandes': [('usta', False)],
          'ustas': [('usa', False)],
          'uste': [('ista', False)],
          'usten': [('ista', False)],
          'ustens': [('ista', False)],
          'uster': [('ustra', False)],
          'ustes': [('ista', False)],
          'ustet': [('ista', False)],
          'ustets': [('ista', False)],
          'ustit': [('ista', False)],
          'ustits': [('ista', False)],
          'ustna': [('ista', False)],
          'ustnas': [('ista', False)],
          'ustne': [('ista', False)],
          'ustnes': [('ista', False)],
          'ut': [('uta', False)],
          'uta': [('uta', False)],
          'utandades': [('utandas', True)],
          'utandas': [('utandas', True)],
          'utandats': [('utandas', True)],
          'utas': [('uta', False)],
          'utats': [('uta', False)],
          'ute': [('uta', False)],
          'uten': [('uta', False)],
          'utens': [('yta', False)],
          'uter': [('uta', False)],
          'utes': [('yta', False)],
          'utet': [('yta', False)],
          'utets': [('yta', False)],
          'utit': [('yta', False)],
          'utits': [('yta', False)],
          'utlade': [('utlägga', True)],
          'utlades': [('utlägga', True)],
          'utlas': [('utlägga', True)],
          'utna': [('uta', False)],
          'utnas': [('yta', False)],
          'utne': [('yta', False)],
          'utnes': [('yta', False)],
          'utred': [('utreda', False)],
          'utredes': [('utreda', False)],
          'uträtta': [('uträtta', True)],
          'uträttas': [('uträtta', True)],
          'uts': [('uta', False)],
          'utsade': [('utsäga', True)],
          'utsades': [('utsäga', True)],
          'utspelas': [('utspelas', True)],
          'utt': [('utta', False)],
          'uttades': [('utta', False)],
          'uttagna': [('ta_ut', True)],
          'uttala': [('uttala', True)],
          'uttalade': [('uttala', True)],
          'uttalades': [('uttala', True)],
          'uttalas': [('uttala', True)],
          'utte': [('itta', False)],
          'utten': [('itta', False)],
          'uttens': [('itta', False)],
          'utter': [('uttra', False)],
          'uttes': [('itta', False)],
          'uttet': [('itta', False)],
          'uttets': [('itta', False)],
          'uttit': [('itta', False)],
          'uttits': [('itta', False)],
          'uttlade': [('uttla', False)],
          'uttlades': [('uttla', False)],
          'uttlas': [('uttla', False)],
          'uttlats': [('uttla', False)],
          'uttna': [('itta', False)],
          'uttnas': [('itta', False)],
          'uttne': [('itta', False)],
          'uttnes': [('itta', False)],
          'utvecklades': [('utvecklas', True), ('utveckla', True)],
          'utvecklas': [('utvecklas', True), ('utveckla', True)],
          'utvecklats': [('utvecklas', True), ('utveckla', True)],
          'uvad': [('uva', False)],
          'uvande': [('uva', False)],
          'uvandes': [('uva', False)],
          'uvar': [('uva', False)],
          'uvas': [('uva', False)],
          'uvats': [('uva', False)],
          'uven': [('yva', False)],
          'uvens': [('yva', False)],
          'uvet': [('yva', False)],
          'uvets': [('yva', False)],
          'uvit': [('yva', False)],
          'uvits': [('yva', False)],
          'uvna': [('yva', False)],
          'uvnas': [('yva', False)],
          'uvne': [('yva', False)],
          'uvnes': [('yva', False)],
          'uxe': [('äxa', False)],
          'uxen': [('äxa', False)],
          'uxens': [('äxa', False)],
          'uxet': [('äxa', False)],
          'uxets': [('äxa', False)],
          'uxit': [('äxa', False)],
          'uxna': [('äxa', False)],
          'uxnas': [('äxa', False)],
          'uxne': [('äxa', False)],
          'uxnes': [('äxa', False)],
          'v': [('va', False)],
          'v-': [('va', False)],
          'va': [('va', False)],
          'vabbats': [('vabba', True)],
          'vack': [('vacka', False)],
          'vad': [('vada', True)],
          'vadad': [('vada', True)],
          'vaddas': [('vadda', False)],
          'vade': [('va', False)],
          'vades': [('va', False)],
          'vads': [('va', False)],
          'vag': [('vaga', False)],
          'vag-': [('vaga', False)],
          'vagades': [('vaga', False)],
          'vagas': [('vaga', False)],
          'vakades': [('vaka', False)],
          'vaknats': [('vakna', True)],
          'vakta': [('vakta', True)],
          'vaktas': [('vakta', False)],
          'val': [('vala', False)],
          'vala': [('vala', False)],
          'valade': [('vala', False)],
          'valas': [('vala', False)],
          'valdas': [('välja', False)],
          'valdes': [('välja', True)],
          'valkas': [('valka', False)],
          'valkats': [('valka', False)],
          'vall': [('valla', False)],
          'valna': [('valna', True)],
          'valnats': [('valna', False)],
          'vals': [('valsa', False)],
          'valt': [('välja', True)],
          'valts': [('välja', False)],
          'vamla': [('vamla', False)],
          'vamlade': [('vamla', False)],
          'vamlades': [('vamla', False)],
          'vamlats': [('vamla', False)],
          'vamp': [('vampa', True)],
          'vampats': [('vampa', True)],
          'vand': [('vänja', False)],
          'vanda': [('vänja', False)],
          'vandas': [('vänja', False)],
          'vande': [('vänja', True)],
          'vandes': [('vänja', True)],
          'vandla': [('vandla', False)],
          'vandlas': [('vandla', False)],
          'vands': [('vänja', True)],
          'vank': [('vanka', True)],
          'vankades': [('vankas', True), ('vanka', True)],
          'vankas': [('vanka', True), ('vankas', True)],
          'vankats': [('vankas', True), ('vanka', True)],
          'vann': [('vanna', True), ('vinna', True)],
          'vant': [('vänja', False)],
          'vants': [('vänja', False)],
          'var': [('vara', True)],
          'varades': [('varas', True), ('vara', True)],
          'varas': [('varas', True), ('vara', True)],
          'varats': [('varas', True), ('vara', True)],
          'vare': [('vara', True)],
          'varits': [('vara', True)],
          'varna': [('varna', False)],
          'vars': [('vara', True)],
          'vart': [('varda', True)],
          'vartades': [('varta', False)],
          'vartas': [('varta', False)],
          'vartats': [('varta', False)],
          'varvar': [('varva', True)],
          'vat': [('va', False)],
          'vatts': [('vätta', False)],
          'vavla': [('vavla', False)],
          'vavlade': [('vavla', False)],
          'vavlades': [('vavla', False)],
          'vavlas': [('vavla', False)],
          'vband': [('vbinda', False)],
          'vbet': [('vbeta', False)],
          'vbildades': [('vbilda', False)],
          'vbildas': [('vbilda', False)],
          'vd': [('va', False)],
          'vdande': [('vda', False)],
          'vdats': [('vda', False)],
          'vde': [('va', False)],
          'vdelade': [('vdela', False)],
          'vdes': [('va', False)],
          'vdrev': [('vdriva', False)],
          'vds': [('va', False)],
          'vecklades': [('veckla', True)],
          'vecklas': [('veckla', True)],
          'vecklats': [('veckla', True)],
          'ved': [('veda', False)],
          'ved-': [('veda', False)],
          'vedandes': [('veda', False)],
          'vedd': [('veda', False)],
          'veddas': [('veda', False)],
          'vedde': [('veda', False)],
          'veddes': [('veda', False)],
          'veder': [('veda', False)],
          'vedes': [('veda', False)],
          'vedjande': [('vedja', False)],
          'vek': [('vika', True)],
          'vekes': [('vika', True)],
          'veks': [('vika', True)],
          'vekts': [('veka', False)],
          'vel': [('vela', True)],
          'vel-': [('vela', True)],
          'vela': [('vela', True)],
          'velas': [('vela', True)],
          'velat': [('vela', True), ('vilja', True)],
          'ven': [('vina', True)],
          'vens': [('vina', True)],
          'venskades': [('venska', False)],
          'vep': [('vepa', False)],
          'verad': [('vera', False)],
          'verades': [('vera', False)],
          'veras': [('vera', False)],
          'verkat': [('verka', True)],
          'vervar': [('vervara', False)],
          'vet': [('veta', True)],
          'vete': [('veta', True)],
          'vets': [('vetsa', False)],
          'vett': [('vetta', False)],
          'vettas': [('vetta', False)],
          'vettats': [('vetta', True)],
          'vette': [('vetta', True)],
          'vetter': [('vetta', True)],
          'vetts': [('vetta', True)],
          'vev': [('veva', True)],
          'vfattades': [('vfatta', False)],
          'vfattas': [('vfatta', False)],
          'vfattats': [('vfatta', False)],
          'vflytt': [('vflytta', False)],
          'vfordrades': [('vfordra', False)],
          'vfordras': [('vfordra', False)],
          'vfordrats': [('vfordra', False)],
          'vfärdades': [('vfärda', False)],
          'vfärdas': [('vfärda', False)],
          'vfärdats': [('vfärda', False)],
          'vgiftas': [('vgifta', False)],
          'vgjord': [('vgöra', False)],
          'vgjorda': [('vgöra', False)],
          'vgjordas': [('vgöra', False)],
          'vgrenades': [('vgrena', False)],
          'vgrenas': [('vgrena', False)],
          'vgrenats': [('vgrena', False)],
          'vgås': [('vgå', False)],
          'vhandla': [('vhandla', False)],
          'vhandlade': [('vhandla', False)],
          'vhandlades': [('vhandla', False)],
          'vhandlas': [('vhandla', False)],
          'vhyst': [('vhysa', False)],
          'vhysta': [('vhysa', False)],
          'vhystas': [('vhysa', False)],
          'vhållas': [('vhålla', False)],
          'vhållits': [('vhålla', False)],
          'vhålls': [('vhålla', False)],
          'vhöggs': [('vhugga', False)],
          'vhölls': [('vhålla', False)],
          'vhöstades': [('vhösta', False)],
          'vhöstas': [('vhösta', False)],
          'vhöstats': [('vhösta', False)],
          'vick': [('vicka', False)],
          'vicker': [('vicka', False)],
          'vicks': [('vicka', False)],
          'vidas': [('vida', False)],
          'vides': [('vida', False)],
          'vids': [('vida', False)],
          'vierats': [('viera', False)],
          'viftas': [('vifta', True)],
          'vigades': [('viga', False)],
          'vigas': [('viga', False)],
          'viknas': [('vika', False)],
          'vikt': [('vika', False)],
          'vikta': [('vikta', True)],
          'viktas': [('vikta', True)],
          'vikts': [('vika', False)],
          'vila': [('vila', True)],
          'vildades': [('vildas', False)],
          'vildas': [('vildas', False)],
          'vill': [('vilja', True)],
          'villa': [('villa', False)],
          'villade': [('villa', False)],
          'villades': [('villa', False)],
          'villats': [('villa', False)],
          'villfaras': [('villfara', True), ('villfaras', True)],
          'villfarits': [('villfara', True), ('villfaras', True)],
          'villfars': [('villfara', True), ('villfaras', True)],
          'villfors': [('villfara', True), ('villfaras', True)],
          'vilt': [('vilta', False)],
          'vims': [('vimsa', True)],
          'vindel': [('vindla', False)],
          'vindel-': [('vindla', False)],
          'vinge': [('vinga', False)],
          'vinges': [('vinga', False)],
          'vinnes': [('vinna', False)],
          'vinns': [('vinna', False)],
          'vintrades': [('vintras', True)],
          'vintras': [('vintras', True)],
          'vintrats': [('vintras', True)],
          'visade': [('visa', False)],
          'visades': [('visa', False)],
          'visas': [('visa', True)],
          'visats': [('visa', True)],
          'viserad': [('visera', False)],
          'vista': [('vista', False)],
          'vistades': [('vistas', True)],
          'vistas': [('vistas', True)],
          'vistats': [('vistas', True)],
          'viste': [('vista', False)],
          'vit': [('vita', False)],
          'vitna': [('vitna', True)],
          'vits': [('vitsa', True)],
          'vjande': [('vja', False)],
          'vjats': [('vja', False)],
          'vknoppades': [('vknoppa', False)],
          'vknoppas': [('vknoppa', False)],
          'vknoppats': [('vknoppa', False)],
          'vkrävas': [('vkräva', False)],
          'vkrävdes': [('vkräva', False)],
          'vkräves': [('vkräva', False)],
          'vkrävs': [('vkräva', False)],
          'vkrävts': [('vkräva', False)],
          'vkändes': [('vkänna', False)],
          'vkännas': [('vkänna', False)],
          'vkänns': [('vkänna', False)],
          'vkänts': [('vkänna', False)],
          'vkörd': [('vköra', False)],
          'vla': [('vla', False)],
          'vlade': [('vla', False)],
          'vlades': [('vla', False)],
          'vlats': [('vla', False)],
          'vledas': [('vleda', False)],
          'vleddes': [('vleda', False)],
          'vledes': [('vleda', False)],
          'vlett': [('vleda', False)],
          'vletts': [('vleda', False)],
          'vlockas': [('vlocka', False)],
          'vlästas': [('vläsa', False)],
          'vlåts': [('vlåta', False)],
          'vlövades': [('vlöva', False)],
          'vlövas': [('vlöva', False)],
          'vlövats': [('vlöva', False)],
          'vmätt': [('vmäta', False)],
          'vmätta': [('vmäta', False)],
          'vmättas': [('vmäta', False)],
          'vna': [('vna', False)],
          'vnar': [('vna', False)],
          'vnas': [('va', False)],
          'vnats': [('vna', False)],
          'vo-': [('va', False)],
          'vord': [('vorda', False)],
          'vordas': [('vorda', False)],
          'vordna': [('varda', True)],
          'vordnas': [('varda', True)],
          'vrat': [('vra', False)],
          'vrats': [('vra', False)],
          'vred': [('vrida', True)],
          'vreda': [('vreda', False)],
          'vredds': [('vreda', False)],
          'vreds': [('vrida', False)],
          'vresta': [('vresa', False)],
          'vrestas': [('vresa', False)],
          'vrett': [('vreda', False)],
          'vrunna': [('vrinna', False)],
          'vräkas': [('vräka', False)],
          'vräkes': [('vräka', True)],
          'vräknade': [('vräkna', False)],
          'vräknades': [('vräkna', False)],
          'vräknas': [('vräkna', False)],
          'vräknats': [('vräkna', False)],
          'vräks': [('vräka', False)],
          'vräkta': [('vräka', True)],
          'vräktes': [('vräka', True)],
          'vrängas': [('vränga', True)],
          'vrängdes': [('vränga', True)],
          'vrängt': [('vränga', True)],
          'vrängts': [('vränga', True)],
          'vråd': [('vråda', False)],
          'vråd-': [('vråda', False)],
          'vråda': [('vråda', False)],
          'vrådande': [('vråda', False)],
          'vrådandes': [('vråda', False)],
          'vrådas': [('vråda', False)],
          'vrådd': [('vråda', False)],
          'vrådda': [('vråda', False)],
          'vråddas': [('vråda', False)],
          'vrådde': [('vråda', False)],
          'vråddes': [('vråda', False)],
          'vrådds': [('vråda', False)],
          'vråder': [('vråda', False)],
          'vråds': [('vråda', False)],
          'vrått': [('vråda', False)],
          'vråtts': [('vråda', False)],
          'vrök': [('vröka', False)],
          'vröks': [('vröka', False)],
          'vsa': [('vsäga', False)],
          'vsade': [('vsäga', False)],
          'vsades': [('vsäga', False)],
          'vsas': [('vsäga', False)],
          'vsatt': [('vsätta', False)],
          'vsatts': [('vsätta', False)],
          'vskildes': [('vskilja', False)],
          'vskiljas': [('vskilja', False)],
          'vskiljes': [('vskilja', False)],
          'vskiljs': [('vskilja', False)],
          'vskilts': [('vskilja', False)],
          'vskjuts': [('vskjuta', False)],
          'vskrev': [('vskriva', False)],
          'vskräckas': [('vskräcka', False)],
          'vskrädd': [('vskräda', False)],
          'vskrädda': [('vskräda', False)],
          'vskräddas': [('vskräda', False)],
          'vsky': [('vsky', False)],
          'vsky-': [('vsky', False)],
          'vskydd': [('vsky', False)],
          'vskydda': [('vsky', False)],
          'vskyddas': [('vsky', False)],
          'vsköt': [('vskjuta', False)],
          'vskötes': [('vskjuta', False)],
          'vsköts': [('vskjuta', False)],
          'vslagits': [('vslå', False)],
          'vslits': [('vslita', False)],
          'vslogs': [('vslå', False)],
          'vspelas': [('vspela', False)],
          'vstördes': [('vstöra', False)],
          'vstört': [('vstöra', False)],
          'vstörts': [('vstöra', False)],
          'vstött': [('vstöta', False)],
          'vstötta': [('vstöta', False)],
          'vstöttas': [('vstöta', False)],
          'vstötte': [('vstöta', False)],
          'vstötts': [('vstöta', False)],
          'vsvor': [('vsvärja', False)],
          'vsvors': [('vsvärja', False)],
          'vsvure': [('vsvärja', False)],
          'vsvuren': [('vsvärja', False)],
          'vsvurens': [('vsvärja', False)],
          'vsvures': [('vsvärja', False)],
          'vsvuret': [('vsvärja', False)],
          'vsvurets': [('vsvärja', False)],
          'vsvurit': [('vsvärja', False)],
          'vsvurits': [('vsvärja', False)],
          'vsvurna': [('vsvärja', False)],
          'vsvurnas': [('vsvärja', False)],
          'vsvurne': [('vsvärja', False)],
          'vsvurnes': [('vsvärja', False)],
          'vsvär': [('vsvärja', False)],
          'vsvär-': [('vsvärja', False)],
          'vsvära': [('vsvärja', False)],
          'vsvärande': [('vsvärja', False)],
          'vsvärandes': [('vsvärja', False)],
          'vsväras': [('vsvärja', False)],
          'vsvärja': [('vsvärja', False)],
          'vsvärjande': [('vsvärja', False)],
          'vsvärjandes': [('vsvärja', False)],
          'vsvärjas': [('vsvärja', False)],
          'vsvärje': [('vsvärja', False)],
          'vsvärjer': [('vsvärja', False)],
          'vsvärjes': [('vsvärja', False)],
          'vsynas': [('vsyna', False)],
          'vt': [('va', False)],
          'vtag-': [('vta', False)],
          'vtagits': [('vta', False)],
          'vtas': [('vta', False)],
          'vtogs': [('vta', False)],
          'vträd': [('vträda', False)],
          'vträd-': [('vträda', False)],
          'vträda': [('vträda', False)],
          'vträdande': [('vträda', False)],
          'vträdandes': [('vträda', False)],
          'vträdas': [('vträda', False)],
          'vträdd': [('vträda', False)],
          'vträdda': [('vträda', False)],
          'vträddas': [('vträda', False)],
          'vträdde': [('vträda', False)],
          'vträddes': [('vträda', False)],
          'vträdds': [('vträda', False)],
          'vträder': [('vträda', False)],
          'vträds': [('vträda', False)],
          'vträtt': [('vträda', False)],
          'vträtts': [('vträda', False)],
          'vts': [('va', False)],
          'vtäckas': [('vtäcka', False)],
          'vtäckes': [('vtäcka', False)],
          'vtäcks': [('vtäcka', False)],
          'vtäcktes': [('vtäcka', False)],
          'vtäckts': [('vtäcka', False)],
          'vundades': [('vundas', False)],
          'vundas': [('vundas', False)],
          'vungne': [('vinga', False)],
          'vungnes': [('vinga', False)],
          'vunna': [('vinna', False)],
          'vunnas': [('vinna', False)],
          'vunnits': [('vinna', False)],
          'vvande': [('vvänja', False)],
          'vvandes': [('vvänja', False)],
          'vvann': [('vvinna', False)],
          'vvarades': [('vvara', False)],
          'vvaras': [('vvara', False)],
          'vvarats': [('vvara', False)],
          'vvecklades': [('vveckla', False)],
          'vvecklats': [('vveckla', False)],
          'vverkat': [('vverka', False)],
          'vvisats': [('vvisa', False)],
          'vvänt': [('vvända', False)],
          'vvärj-': [('vvärja', False)],
          'vvärja': [('vvärja', False)],
          'vvärjas': [('vvärja', False)],
          'vyss': [('vyssa', True)],
          'vyssas': [('vyssa', True)],
          'väckes': [('väcka', False)],
          'väcks': [('väcka', False)],
          'väcktes': [('väcka', False)],
          'väd-': [('väda', False)],
          'vädandes': [('väda', False)],
          'vädde': [('väda', False)],
          'väddes': [('väda', False)],
          'väj': [('väja', True)],
          'väj-': [('väja', True)],
          'väja': [('väja', True)],
          'väjandes': [('väja', True)],
          'väjas': [('väja', True)],
          'väjer': [('väja', True)],
          'väkt': [('väka', False)],
          'väkts': [('väka', False)],
          'väljas': [('välja', True)],
          'väljdes': [('väljas', False)],
          'väljes': [('välja', False)],
          'väljs': [('välja', False)],
          'vällas': [('välla', True)],
          'välte': [('välta', True)],
          'vältes': [('välta', True)],
          'välts': [('välta', True)],
          'vämdes': [('vämjas', True)],
          'vämjas': [('vämjas', True), ('vämja', True)],
          'vämjdes': [('vämjas', True), ('vämja', True)],
          'vämjes': [('vämjas', True), ('vämja', True)],
          'vämjs': [('vämja', True), ('vämjas', True)],
          'vämjts': [('vämjas', True), ('vämja', True)],
          'vändas': [('vända', False)],
          'vänds': [('vända', False)],
          'vängs': [('vänga', False)],
          'vänslats': [('vänslas', True)],
          'vänt': [('vänta', True), ('vända', True)],
          'vänts': [('vända', False)],
          'vära': [('vära', False)],
          'värande': [('vära', False)],
          'väras': [('vära', False)],
          'värdigades': [('värdigas', True)],
          'värdigas': [('värdigas', True)],
          'värdigats': [('värdigas', True)],
          'värj': [('värja', True)],
          'värj-': [('värja', True)],
          'värja': [('värja', True)],
          'värjande': [('värja', False)],
          'värjandes': [('värja', True)],
          'värjas': [('värja', True)],
          'värjer': [('värja', True)],
          'värjes': [('värja', False)],
          'värrades': [('värra', False)],
          'värras': [('värra', False)],
          'värrats': [('värra', False)],
          'värs': [('värsa', False)],
          'värvas': [('värva', False)],
          'värves': [('värva', False)],
          'värvs': [('värva', False)],
          'väs': [('väsa', False)],
          'väst': [('väsa', True)],
          'västs': [('väsa', False)],
          'vätnas': [('väta', False)],
          'vätskades': [('vätska', True), ('vätskas', True)],
          'vätskas': [('vätskas', True), ('vätska', True)],
          'vätskats': [('vätskas', True), ('vätska', True)],
          'vätt': [('väta', True)],
          'vätta': [('väta', True)],
          'vättas': [('väta', True)],
          'vätte': [('väta', True)],
          'vätter': [('vätta', False)],
          'vättes': [('väta', True)],
          'vätts': [('väta', True)],
          'vävd': [('väva', False)],
          'vävdes': [('väva', False)],
          'vävts': [('väva', False)],
          'vå': [('vå', False)],
          'vådda': [('vå', False)],
          'våddas': [('vå', False)],
          'vådds': [('vå', False)],
          'våg': [('våga', True)],
          'våla': [('våla', False)],
          'vålade': [('våla', False)],
          'vålades': [('våla', False)],
          'vålas': [('våla', False)],
          'våndades': [('våndas', True)],
          'våndas': [('våndas', True)],
          'vår': [('våra', True)],
          'vårades': [('våras', True), ('våra', True)],
          'våras': [('våras', True), ('våra', True)],
          'vårats': [('våras', True), ('våra', True)],
          'våtes': [('väta', False)],
          'vått': [('vå', False)],
          'vörd': [('vörda', True)],
          'vörda': [('vörda', True)],
          'vördas': [('vörda', True)],
          'wa': [('wa', False)],
          'wade': [('wa', False)],
          'wades': [('wa', False)],
          'walkas': [('walka', False)],
          'walkats': [('walka', False)],
          'wande': [('wa', False)],
          'wandes': [('wa', False)],
          'war': [('wa', False)],
          'was': [('wa', False)],
          'wat': [('wa', False)],
          'wista': [('wista', False)],
          'wistas': [('wista', False)],
          'wistats': [('wista', False)],
          'wla': [('wla', False)],
          'wlade': [('wla', False)],
          'wlades': [('wla', False)],
          'wlas': [('wla', False)],
          'wlats': [('wla', False)],
          'x': [('xa', False)],
          'x-': [('xa', False)],
          'xa': [('xa', False)],
          'xad': [('xa', False)],
          'xade': [('xa', False)],
          'xades': [('xa', False)],
          'xads': [('xa', False)],
          'xande': [('xa', False)],
          'xandes': [('xa', False)],
          'xar': [('xa', False)],
          'xas': [('xa', False)],
          'xat': [('xa', False)],
          'xer': [('xera', False)],
          'xer-': [('xera', False)],
          'xerad': [('xera', False)],
          'xerades': [('xera', False)],
          'xeras': [('xera', False)],
          'xla': [('xla', False)],
          'xlade': [('xla', False)],
          'xlades': [('xla', False)],
          'xlas': [('xla', False)],
          'xlats': [('xla', False)],
          'xna': [('xna', False)],
          'xnar': [('xna', False)],
          'xnats': [('xna', False)],
          'xt': [('xa', False)],
          'xta': [('xa', False)],
          'xtas': [('xta', False)],
          'xtats': [('xta', False)],
          'xtrades': [('xtra', False)],
          'xtras': [('xtra', False)],
          'xts': [('xa', False)],
          'y': [('ya', False)],
          'y-': [('y', False)],
          'ya': [('ya', False)],
          'yad': [('ya', False)],
          'yade': [('ya', False)],
          'yades': [('ya', False)],
          'yads': [('ya', False)],
          'yande': [('ya', False)],
          'yandes': [('ya', False)],
          'yar': [('ya', False)],
          'yas': [('ya', False)],
          'yat': [('ya', False)],
          'yckades': [('ycka', False)],
          'yckas': [('ycka', False)],
          'yckats': [('yckas', False)],
          'ycklades': [('yckla', False)],
          'ycklas': [('yckla', False)],
          'ycklats': [('yckla', False)],
          'yckts': [('ycka', False)],
          'yd': [('yda', False)],
          'yda': [('yda', False)],
          'ydande': [('yda', False)],
          'ydas': [('yda', False)],
          'ydd': [('y', False)],
          'ydda': [('yda', False)],
          'yddas': [('yda', False)],
          'ydde': [('y', False)],
          'yddes': [('y', False)],
          'ydds': [('yda', False)],
          'yde': [('yda', False)],
          'yder': [('yda', False)],
          'ydes': [('yda', False)],
          'yds': [('yda', False)],
          'yffas': [('yffa', False)],
          'yfts': [('yfta', False)],
          'yga': [('yga', False)],
          'ygande': [('yga', False)],
          'ygar': [('yga', False)],
          'ygats': [('yga', False)],
          'ygdes': [('ygas', False)],
          'yge': [('yga', False)],
          'yger': [('yga', False)],
          'yges': [('yga', False)],
          'yggades': [('ygga', False)],
          'yggar': [('ygga', False)],
          'yggas': [('ygga', False)],
          'ygla': [('ygla', False)],
          'yglas': [('ygla', False)],
          'ygs': [('yga', False)],
          'ygts': [('ygas', False)],
          'ykar': [('yka', False)],
          'ykas': [('yka', False)],
          'ykats': [('yka', False)],
          'yke': [('yka', False)],
          'yker': [('yka', False)],
          'ykes': [('yka', False)],
          'ykla': [('ykla', False)],
          'yklar': [('ykla', False)],
          'yks': [('yka', False)],
          'ykt': [('ykta', False)],
          'yktades': [('ykta', False)],
          'yktes': [('yka', False)],
          'yktigats': [('yktigas', False)],
          'ykännas': [('ykännas', False)],
          'ykänns': [('ykännas', False)],
          'yla': [('yla', False)],
          'ylade': [('yla', False)],
          'ylades': [('yla', True)],
          'ylas': [('yla', False)],
          'ylats': [('yla', True)],
          'yld': [('yla', False)],
          'ylda': [('yla', False)],
          'yldas': [('yla', False)],
          'yldrats': [('yldra', False)],
          'yler': [('yla', False)],
          'yles': [('yla', False)],
          'yll': [('ylla', False)],
          'yllas': [('ylla', False)],
          'ylldes': [('ylla', False)],
          'yller': [('yllra', False)],
          'yllna': [('yllna', False)],
          'yllts': [('ylla', False)],
          'ylnades': [('ylna', False)],
          'ylnas': [('ylna', False)],
          'yls': [('yla', False)],
          'ylt': [('ylta', False)],
          'ym': [('ymma', False)],
          'ym-': [('ymma', False)],
          'ymdes': [('ymma', False)],
          'ymds': [('ymma', False)],
          'ymfar': [('ymfa', False)],
          'ymlas': [('ymla', False)],
          'ymmades': [('ymma', False)],
          'ymmas': [('ymma', False)],
          'ympades': [('ympa', False)],
          'ympas': [('ympa', False)],
          'ymrades': [('ymra', False)],
          'ymras': [('ymra', False)],
          'yms': [('ymma', False)],
          'yna': [('yna', False)],
          'ynar': [('yna', False)],
          'ynats': [('yna', False)],
          'ynd': [('ynda', False)],
          'ynda': [('ynda', False)],
          'yndades': [('ynda', False)],
          'yndas': [('ynda', False)],
          'ynes': [('yna', False)],
          'yngas': [('ynga', False)],
          'yngdes': [('ynga', False)],
          'ynges': [('ynga', False)],
          'yngrats': [('yngra', False)],
          'yngt': [('ynga', False)],
          'yngts': [('ynga', False)],
          'ynkades': [('ynka', True)],
          'ynnas': [('ynna', False)],
          'yns': [('ynas', False)],
          'ynt': [('ynna', False)],
          'ynta': [('yna', False)],
          'yntas': [('yna', False)],
          'ynte': [('yna', False)],
          'yntes': [('yna', False)],
          'ynts': [('yna', False)],
          'ypar': [('ypa', False)],
          'ypats': [('ypa', False)],
          'ype': [('ypa', False)],
          'yper': [('ypa', False)],
          'ypes': [('ypa', False)],
          'yppades': [('yppa', True)],
          'yppas': [('yppa', True)],
          'ypplade': [('yppla', False)],
          'ypplades': [('yppla', False)],
          'yprad': [('ypra', False)],
          'yprat': [('ypra', False)],
          'yps': [('ypa', False)],
          'ypta': [('ypa', False)],
          'yptas': [('ypa', False)],
          'yptes': [('ypa', False)],
          'yr': [('yra', False)],
          'yrat': [('yra', False)],
          'yrats': [('yra', False)],
          'yrd': [('yra', False)],
          'yrda': [('yra', False)],
          'yrdas': [('yra', False)],
          'yres': [('yra', False)],
          'yrkades': [('yrka', True)],
          'yrkat': [('yrka', False)],
          'yrs': [('yra', False)],
          'yrsatts': [('yrsätta', False)],
          'ys': [('y', False)],
          'ysa': [('ysa', False)],
          'ysade': [('ysa', False)],
          'ysades': [('ysa', False)],
          'ysas': [('ysa', False)],
          'ysats': [('ysa', False)],
          'ysatt': [('ysätta', False)],
          'ysatts': [('ysätta', False)],
          'yse': [('ysa', False)],
          'yser': [('ysa', False)],
          'yses': [('ysa', False)],
          'yska': [('yska', False)],
          'yskad': [('yska', False)],
          'yskade': [('yska', False)],
          'yskades': [('yska', False)],
          'yskar': [('yska', False)],
          'yss': [('yss', False)],
          'yssades': [('yssa', False)],
          'ysslade': [('yssla', False)],
          'yst': [('ysta', False)],
          'yst-': [('ysta', False)],
          'ysta': [('ysta', True)],
          'ystades': [('ysta', False)],
          'ystande': [('ysta', True)],
          'ystandes': [('ysta', False)],
          'ystas': [('ysta', True)],
          'yste': [('ysa', False)],
          'yster': [('yster', False)],
          'ystes': [('ysa', False)],
          'yt': [('yta', False)],
          'yta': [('yta', False)],
          'ytas': [('yta', False)],
          'yte': [('yta', False)],
          'yter': [('yta', False)],
          'ytes': [('yta', False)],
          'yts': [('yta', False)],
          'ytsade': [('ytsa', False)],
          'ytsades': [('ytsa', False)],
          'ytt': [('yda', False)],
          'ytta': [('yta', False)],
          'yttades': [('ytta', False)],
          'yttas': [('yta', False)],
          'ytte': [('yta', False)],
          'ytter': [('yttra', False)],
          'yttes': [('yta', False)],
          'yttlade': [('yttla', False)],
          'yttlades': [('yttla', False)],
          'yttlas': [('yttla', False)],
          'yttlats': [('yttla', False)],
          'ytts': [('y', False)],
          'yvad': [('yva', False)],
          'yvalt': [('yvälja', False)],
          'yvande': [('yva', False)],
          'yvandes': [('yva', False)],
          'yvar': [('yva', False)],
          'yvas': [('yvas', True)],
          'yvats': [('yva', False)],
          'yvdes': [('yvas', True)],
          'yvel': [('yvla', False)],
          'yvel-': [('yvla', False)],
          'yver': [('yva', False)],
          'yves': [('yvas', True)],
          'yvit': [('yva', False)],
          'yvits': [('yva', False)],
          'yvlas': [('yvla', False)],
          'yvnas': [('yvna', False)],
          'yvs': [('yvas', True)],
          'yvts': [('yvas', True)],
          'yväljas': [('yvälja', False)],
          'yxats': [('yxa', False)],
          'z': [('za', False)],
          'z-': [('za', False)],
          'za': [('za', False)],
          'zad': [('za', False)],
          'zade': [('za', False)],
          'zades': [('za', False)],
          'zads': [('za', False)],
          'zande': [('za', False)],
          'zandes': [('za', False)],
          'zapp': [('zappa', True)],
          'zappats': [('zappa', True)],
          'zar': [('za', False)],
          'zas': [('za', False)],
          'zat': [('za', False)],
          'ä': [('äa', False)],
          'ä-': [('ä', False)],
          'äa': [('äa', False)],
          'äad': [('äa', False)],
          'äade': [('äa', False)],
          'äades': [('äa', False)],
          'äads': [('äa', False)],
          'äande': [('äa', False)],
          'äandes': [('äa', False)],
          'äar': [('äa', False)],
          'äas': [('äa', False)],
          'äat': [('äa', False)],
          'äbbades': [('äbba', False)],
          'äbbas': [('äbba', False)],
          'äbbats': [('äbbas', False)],
          'äckades': [('äcka', False)],
          'äckas': [('äcka', False)],
          'äcklades': [('äckla', False)],
          'äcklas': [('äckla', False)],
          'äcklats': [('äckla', False)],
          'äckts': [('äcka', False)],
          'äd': [('äda', False)],
          'äd-': [('ä', False)],
          'äda': [('äda', False)],
          'ädande': [('äda', False)],
          'ädandes': [('ä', False)],
          'ädas': [('äda', False)],
          'ädats': [('äda', False)],
          'ädd': [('ä', False)],
          'ädda': [('äda', False)],
          'äddas': [('ä', False)],
          'ädde': [('ä', False)],
          'äddes': [('ä', False)],
          'ädds': [('äda', False)],
          'äde': [('äda', False)],
          'ädens': [('äda', False)],
          'äder': [('äda', False)],
          'ädes': [('äda', False)],
          'ädits': [('äda', False)],
          'ädj': [('ädja', False)],
          'ädja': [('ädja', False)],
          'ädjandes': [('ädja', False)],
          'ädjas': [('ädja', False)],
          'ädjer': [('ädja', False)],
          'ädla': [('ädla', False)],
          'ädlas': [('ädla', False)],
          'ädna': [('äda', False)],
          'ädrades': [('ädra', False)],
          'ädras': [('ädra', False)],
          'äds': [('äda', False)],
          'äga': [('äga', False)],
          'ägande': [('äga', False)],
          'ägar': [('äga', False)],
          'ägats': [('äga', False)],
          'äger': [('äga', True)],
          'äges': [('äga', False)],
          'äggades': [('ägga', False)],
          'äggar': [('ägga', False)],
          'äggas': [('ägga', False)],
          'ägla': [('ägla', False)],
          'äglas': [('ägla', False)],
          'ägled': [('ägleda', False)],
          'ägledas': [('ägleda', False)],
          'ägleddes': [('ägleda', False)],
          'ägleds': [('ägleda', False)],
          'ägletts': [('ägleda', False)],
          'ägna': [('ägna', False)],
          'ägnades': [('ägna', False)],
          'ägnas': [('ägna', False)],
          'ägnat': [('ägna', False)],
          'ägnats': [('ägna', True)],
          'ägrades': [('ägra', False)],
          'ägras': [('ägra', False)],
          'ägs': [('äga', False)],
          'äj': [('äga', False)],
          'äj-': [('äga', False)],
          'äja': [('äga', False)],
          'äjande': [('äja', False)],
          'äjandes': [('äga', False)],
          'äjas': [('äga', False)],
          'äjda': [('äja', False)],
          'äjdas': [('äja', False)],
          'äjer': [('äga', False)],
          'äjes': [('äja', False)],
          'äjs': [('äja', False)],
          'äkar': [('äka', False)],
          'äkas': [('äka', False)],
          'äkats': [('äka', False)],
          'äker': [('äka', False)],
          'äkes': [('äka', False)],
          'äkla': [('äkla', False)],
          'äklades': [('äklas', False)],
          'äklar': [('äkla', False)],
          'äklas': [('äklas', False)],
          'äklats': [('äklas', False)],
          'äknat': [('äkna', False)],
          'äkrats': [('äkra', False)],
          'äks': [('äka', False)],
          'äkt': [('äkta', False)],
          'äkta': [('äkta', True)],
          'äktades': [('äkta', False)],
          'äktas': [('äkta', True)],
          'äktats': [('äkta', True)],
          'äktes': [('äka', False)],
          'äktigades': [('äktiga', False)],
          'äktigas': [('äktiga', False)],
          'äla': [('äla', False)],
          'älade': [('äla', False)],
          'älades': [('äla', False)],
          'älas': [('äla', False)],
          'älats': [('äla', False)],
          'äld': [('äla', False)],
          'älda': [('äla', False)],
          'äldades': [('älda', False)],
          'äldas': [('äla', False)],
          'älde': [('älda', False)],
          'äldes': [('älda', False)],
          'äle': [('äla', False)],
          'äler': [('äla', False)],
          'äles': [('äla', False)],
          'äljas': [('älja', False)],
          'äljdes': [('älja', False)],
          'älkades': [('älka', False)],
          'älkomna': [('älkomna', False)],
          'äll': [('älla', False)],
          'ällades': [('ällas', False)],
          'ällas': [('älla', False)],
          'ällats': [('ällas', False)],
          'älldes': [('älla', False)],
          'ällts': [('älla', False)],
          'äls': [('äla', False)],
          'älskas': [('älska', False)],
          'älskats': [('älska', True)],
          'ält': [('älta', False)],
          'äm': [('ämma', False)],
          'äm-': [('ämma', False)],
          'ämas': [('äma', False)],
          'ämats': [('äma', False)],
          'ämdes': [('ämma', False)],
          'ämds': [('ämma', False)],
          'ämer': [('äma', False)],
          'ämjades': [('ämja', False)],
          'ämjas': [('ämja', False)],
          'ämjats': [('ämjas', False)],
          'ämjdes': [('ämja', False)],
          'ämjes': [('ämja', False)],
          'ämjts': [('ämja', False)],
          'ämmades': [('ämma', False)],
          'ämmas': [('ämma', False)],
          'ämnades': [('ämna', False)],
          'ämnas': [('ämna', False)],
          'ämnats': [('ämna', True)],
          'ämpades': [('ämpa', False)],
          'ämpas': [('ämpa', False)],
          'ämrades': [('ämra', False)],
          'ämras': [('ämra', False)],
          'äms': [('ämma', False)],
          'ämt': [('ämma', False)],
          'ämts': [('ämjas', False)],
          'äna': [('äna', False)],
          'änades': [('änas', False)],
          'änar': [('äna', False)],
          'änas': [('änas', False)],
          'änats': [('äna', False)],
          'änd': [('ända', False)],
          'ända': [('ända', False)],
          'ändades': [('ändas', True), ('ända', True)],
          'ändas': [('ändas', True), ('ända', True)],
          'ändats': [('ändas', True), ('ända', True)],
          'ände': [('ända', False)],
          'ändes': [('ända', False)],
          'änds': [('änna', False)],
          'änerats': [('änera', False)],
          'ängades': [('änga', False)],
          'ängas': [('änga', False)],
          'ängdes': [('änga', False)],
          'änges': [('änga', False)],
          'ängslades': [('ängsla', True), ('ängslas', True)],
          'ängslas': [('ängslas', True), ('ängsla', True)],
          'ängslats': [('ängslas', True), ('ängsla', True)],
          'ängt': [('änga', False)],
          'ängts': [('änga', False)],
          'änkades': [('änka', False)],
          'ännas': [('änna', False)],
          'änns': [('ännas', False)],
          'änslades': [('änslas', False)],
          'änslas': [('änslas', False)],
          'änslats': [('änsla', False)],
          'änst': [('änsa', False)],
          'änsta': [('änsta', False)],
          'änstas': [('änsta', False)],
          'änte': [('änta', False)],
          'äntrats': [('äntra', False)],
          'änts': [('änna', False)],
          'änvisades': [('änvisa', False)],
          'änvisats': [('änvisa', False)],
          'äpar': [('äpa', False)],
          'äpats': [('äpa', False)],
          'äper': [('äpa', False)],
          'äpes': [('äpa', False)],
          'äpnas': [('äpna', False)],
          'äppades': [('äppa', False)],
          'äppas': [('äppa', False)],
          'äps': [('äpa', False)],
          'äpta': [('äpa', False)],
          'äptas': [('äpa', False)],
          'äptes': [('äpa', False)],
          'är': [('vara', True), ('ära', True)],
          'är-': [('ära', True)],
          'ära': [('ära', True)],
          'ärades': [('ära', True)],
          'ärande': [('ära', True)],
          'ärandes': [('ära', True)],
          'äras': [('ära', True)],
          'ärat': [('ära', False)],
          'ärats': [('ära', False)],
          'ärd': [('ära', False)],
          'ärda': [('ära', False)],
          'ärdades': [('ärda', False)],
          'ärdas': [('ära', False)],
          'ärdes': [('ärdes', False)],
          'ärdigades': [('ärdiga', False)],
          'ärdigas': [('ärdiga', False)],
          'äre': [('ära', False)],
          'äres': [('ära', False)],
          'ärgades': [('ärgas', True), ('ärga', True)],
          'ärgas': [('ärga', True), ('ärgas', True)],
          'ärgat': [('ärga', True)],
          'ärgats': [('ärgas', True), ('ärga', True)],
          'ärgla': [('ärglägga', False)],
          'ärglade': [('ärgla', False)],
          'ärglades': [('ärgla', False)],
          'ärglas': [('ärglägga', False)],
          'ärj': [('ärja', False)],
          'ärj-': [('ärja', False)],
          'ärja': [('ärja', False)],
          'ärjande': [('ärja', True)],
          'ärjandes': [('ärja', False)],
          'ärjas': [('ärja', False)],
          'ärla': [('ärla', False)],
          'ärlas': [('ärla', False)],
          'ärled': [('ärleda', False)],
          'ärleds': [('ärleda', False)],
          'ärmades': [('ärma', False)],
          'ärnades': [('ärna', False)],
          'ärnas': [('ärna', False)],
          'ärrades': [('ärras', True)],
          'ärras': [('ärras', True)],
          'ärrats': [('ärras', True)],
          'ärs': [('ära', False)],
          'ärsa': [('ärsa', False)],
          'ärsade': [('ärsa', False)],
          'ärsades': [('ärsa', False)],
          'ärsas': [('ärsa', False)],
          'ärskas': [('ärska', False)],
          'ärskats': [('ärska', False)],
          'ärt': [('ärta', False)],
          'ärtades': [('ärta', False)],
          'ärvar': [('ärva', False)],
          'ärvas': [('ärvas', False)],
          'ärvdes': [('ärva', False)],
          'ärves': [('ärvas', False)],
          'ärvs': [('ärva', True)],
          'ärvts': [('ärva', False)],
          'äs': [('ä', False)],
          'äsa': [('äsa', False)],
          'äsade': [('äsa', False)],
          'äsades': [('äsa', False)],
          'äsas': [('äsa', False)],
          'äsats': [('äsa', False)],
          'äsatt': [('äsätta', False)],
          'äsatts': [('äsätta', False)],
          'äser': [('äsa', False)],
          'äses': [('äsa', False)],
          'äska': [('äska', False)],
          'äskad': [('äska', True)],
          'äskade': [('äska', False)],
          'äskades': [('äska', True)],
          'äskar': [('äska', False)],
          'äsnats': [('äsnas', False)],
          'äspar': [('äspa', False)],
          'ässades': [('ässa', False)],
          'äst': [('ästa', False)],
          'äst-': [('ästa', False)],
          'ästa': [('äsa', False)],
          'ästades': [('ästa', False)],
          'ästande': [('ästa', False)],
          'ästandes': [('ästa', False)],
          'ästas': [('äsa', False)],
          'äste': [('äsa', False)],
          'äster': [('ästra', False)],
          'ästes': [('äsa', False)],
          'ästs': [('ästa', False)],
          'ät': [('äta', False)],
          'äta': [('äta', False)],
          'ätas': [('äta', False)],
          'ätats': [('äta', False)],
          'äte': [('äta', False)],
          'äten': [('äta', False)],
          'äter': [('äta', False)],
          'ätes': [('äta', False)],
          'ätits': [('äta', False)],
          'ätna': [('äta', False)],
          'ätnas': [('äta', True)],
          'äts': [('äta', False)],
          'ätt': [('ätta', False)],
          'ättades': [('ätta', False)],
          'ätter': [('ättra', False)],
          'ätts': [('ätta', False)],
          'ävad': [('äva', False)],
          'ävande': [('äva', False)],
          'ävandes': [('äva', False)],
          'ävar': [('äva', False)],
          'ävas': [('äva', False)],
          'ävats': [('äva', False)],
          'ävda': [('äva', False)],
          'ävdas': [('äva', False)],
          'ävel': [('ävla', False)],
          'ävel-': [('ävla', False)],
          'äver': [('äva', False)],
          'äves': [('äva', False)],
          'ävlades': [('ävlas', True)],
          'ävlas': [('ävlas', True)],
          'ävlats': [('ävlas', False)],
          'ävnas': [('ävna', False)],
          'ävs': [('äva', False)],
          'äxats': [('äxa', False)],
          'äxer': [('äxa', False)],
          'äxtas': [('äxa', False)],
          'å-': [('å', False)],
          'åa': [('åa', False)],
          'åad': [('åa', False)],
          'åade': [('åa', False)],
          'åades': [('åa', False)],
          'åads': [('åa', False)],
          'åande': [('åa', False)],
          'åandes': [('åa', False)],
          'åar': [('åa', False)],
          'åas': [('åa', False)],
          'åat': [('åa', False)],
          'åcklades': [('åckla', False)],
          'åcklas': [('åckla', False)],
          'åcklats': [('åckla', False)],
          'åd': [('åda', False)],
          'åda': [('åda', False)],
          'ådande': [('åda', False)],
          'ådas': [('åda', False)],
          'ådats': [('åda', False)],
          'ådd': [('å', False)],
          'ådde': [('å', False)],
          'åddes': [('å', False)],
          'åde': [('åda', False)],
          'åder': [('åda', False)],
          'ådes': [('åda', False)],
          'ådlade': [('ådlägga', False)],
          'ådlades': [('ådlägga', False)],
          'ådrades': [('ådra', True)],
          'ådragits': [('ådra', True)],
          'ådras': [('ådra', True)],
          'ådrog': [('ådra', True)],
          'ådrogs': [('ådra', True)],
          'åds': [('åda', False)],
          'ådskas': [('ådska', False)],
          'ådskats': [('ådska', False)],
          'åffas': [('åffa', False)],
          'åfordrades': [('åfordra', False)],
          'åfordras': [('åfordra', False)],
          'åfordrats': [('åfordra', False)],
          'åga': [('åga', False)],
          'ågande': [('åga', False)],
          'ågar': [('åga', False)],
          'ågats': [('åga', False)],
          'åge': [('e', False)],
          'åges': [('e', False)],
          'ågge': [('igga', False)],
          'ågges': [('igga', False)],
          'ågicks': [('ågå', False)],
          'ågna': [('ågna', False)],
          'ågnades': [('ågna', False)],
          'ågnas': [('ågna', False)],
          'ågnat': [('ågna', False)],
          'ågs': [('e', False)],
          'åkar': [('åka', False)],
          'åkas': [('åka', False)],
          'åker': [('åka', True)],
          'åkes': [('åka', True)],
          'åks': [('åka', True)],
          'åkta': [('åka', True)],
          'åktas': [('åka', True)],
          'åktes': [('åka', True)],
          'åkörd': [('åköra', False)],
          'åla': [('åla', True), ('ålägga', True)],
          'ålade': [('ålägga', True), ('åla', True)],
          'ålades': [('ålägga', True), ('åla', True)],
          'ålas': [('ålägga', True), ('åla', True)],
          'ålats': [('åla', False)],
          'åld': [('älja', False)],
          'ålda': [('älja', False)],
          'åldas': [('älja', False)],
          'ålde': [('älja', False)],
          'åldes': [('älja', False)],
          'åldrades': [('åldras', False)],
          'åldras': [('åldras', False)],
          'ålds': [('älja', False)],
          'åles': [('åla', False)],
          'ålett': [('åle', False)],
          'åletts': [('åle', False)],
          'åll': [('ålla', False)],
          'ållas': [('ålla', False)],
          'ållnas': [('ålla', False)],
          'åloges': [('åle', False)],
          'åls': [('åla', False)],
          'ålt': [('älja', False)],
          'ålts': [('älja', False)],
          'ålöd': [('ålöda', False)],
          'ålödes': [('ålöda', False)],
          'ålöds': [('ålöda', False)],
          'åmas': [('åma', False)],
          'åmats': [('åma', False)],
          'åmindes': [('åminna', False)],
          'åminnas': [('åminna', False)],
          'åminns': [('åminna', False)],
          'åmints': [('åminna', False)],
          'åna': [('åna', False)],
          'ånar': [('åna', False)],
          'ånats': [('åna', False)],
          'ånd': [('ånda', False)],
          'ånda': [('ånda', False)],
          'åndades': [('ånda', False)],
          'åndas': [('ånda', False)],
          'åndats': [('åndas', False)],
          'ånde': [('ånde', False)],
          'ångades': [('ånga', False)],
          'ångas': [('ånga', False)],
          'ångats': [('ånga', True)],
          'ånger': [('ångra', True)],
          'ånges': [('å', False)],
          'ångrats': [('ångra', False)],
          'ånkades': [('ånka', False)],
          'ånlett': [('ånle', False)],
          'ånnas': [('ånna', False)],
          'ånser': [('ånse', False)],
          'ånses': [('ånse', False)],
          'ånt': [('ånta', False)],
          'åpar': [('åpa', False)],
          'åpats': [('åpa', False)],
          'år': [('åra', False)],
          'årades': [('åras', False)],
          'åras': [('åras', False)],
          'årat': [('åra', False)],
          'årats': [('åra', False)],
          'årdades': [('årda', False)],
          'årevs': [('åriva', False)],
          'årivas': [('åriva', False)],
          'årivits': [('åriva', False)],
          'årivs': [('åriva', False)],
          'årt': [('årta', False)],
          'årtades': [('årta', False)],
          'åräknade': [('åräkna', False)],
          'åräknades': [('åräkna', False)],
          'åräknas': [('åräkna', False)],
          'åräknats': [('åräkna', False)],
          'ås': [('å', False)],
          'åsa': [('åsa', False)],
          'åsade': [('åsa', False)],
          'åsades': [('åsa', False)],
          'åsas': [('åsa', False)],
          'åsats': [('åsa', False)],
          'åsatt': [('åsätta', True)],
          'åsatts': [('åsätta', True)],
          'åser': [('åse', True)],
          'åses': [('åse', True)],
          'åska': [('åska', True)],
          'åskad': [('åska', True)],
          'åskade': [('åska', True)],
          'åskades': [('åska', True)],
          'åskar': [('åska', True)],
          'åsken': [('åskina', False)],
          'åst': [('åste', False)],
          'åsta': [('åsa', False)],
          'åstas': [('åsa', False)],
          'åste': [('åsa', False)],
          'åstes': [('åsa', False)],
          'åsvor': [('åsvära', False)],
          'åsvär-': [('åsvära', False)],
          'åsvära': [('åsvära', False)],
          'åsvärande': [('åsvära', False)],
          'åsvärj': [('åsvära', False)],
          'åsvärj-': [('åsvära', False)],
          'åsvärja': [('åsvära', False)],
          'åsåg': [('åse', True)],
          'åt': [('äta', False)],
          'åta': [('åta', False)],
          'åtag-': [('åta', False)],
          'åtagits': [('åta', False)],
          'åtalades': [('åtala', True)],
          'åtas': [('åta', False)],
          'åtats': [('åta', False)],
          'åte': [('äta', False)],
          'åten': [('åta', False)],
          'åter': [('åta', False)],
          'åtes': [('äta', True)],
          'åtits': [('åta', False)],
          'åtla': [('åtla', False)],
          'åtlas': [('åtla', False)],
          'åtna': [('åta', False)],
          'åtogs': [('åta', False)],
          'åtrades': [('åtra', True)],
          'åtras': [('åtra', True)],
          'åträffades': [('åträffa', False)],
          'åträffas': [('åträffa', False)],
          'åträffats': [('åträffa', False)],
          'åträtt': [('åträta', False)],
          'åträtts': [('åträta', False)],
          'åts': [('äta', False)],
          'åtsade': [('åtsa', False)],
          'åttades': [('åtta', False)],
          'åtte': [('å', False)],
          'åttes': [('å', False)],
          'åtts': [('å', False)],
          'åvad': [('åva', False)],
          'åvande': [('åva', False)],
          'åvandes': [('åva', False)],
          'åvar': [('åva', False)],
          'åvas': [('åva', False)],
          'åvats': [('åva', False)],
          'åve': [('e', False)],
          'åves': [('e', False)],
          'åvisats': [('åvisa', False)],
          'ö': [('öa', False)],
          'ö-': [('öa', False)],
          'öa': [('öa', False)],
          'öad': [('öa', False)],
          'öade': [('öa', False)],
          'öades': [('öa', False)],
          'öads': [('öa', False)],
          'öande': [('öa', False)],
          'öandes': [('öa', False)],
          'öar': [('öa', False)],
          'öas': [('öa', False)],
          'öat': [('öa', False)],
          'öd': [('öda', True)],
          'öd-': [('öda', True)],
          'öda': [('öda', False)],
          'ödande': [('öda', False)],
          'ödandes': [('öda', True)],
          'ödas': [('öda', False)],
          'ödats': [('öda', False)],
          'ödd': [('öda', True)],
          'ödda': [('öda', False)],
          'öddas': [('öda', False)],
          'ödde': [('öda', True)],
          'öddes': [('öda', True)],
          'ödds': [('öda', False)],
          'öde': [('uda', False)],
          'ödela': [('ödelägga', True)],
          'ödelade': [('ödelägga', True)],
          'ödelades': [('ödelägga', True)],
          'ödelas': [('ödelägga', True)],
          'öder': [('öda', True)],
          'ödes': [('öda', True)],
          'ödgades': [('ödga', False)],
          'ödgas': [('ödga', False)],
          'ödja': [('ödja', False)],
          'ödjandes': [('ödja', False)],
          'ödjas': [('ödja', False)],
          'ödje': [('ödja', False)],
          'ödjer': [('ödja', False)],
          'ödrades': [('ödra', False)],
          'ödras': [('ödra', False)],
          'öds': [('öda', False)],
          'öförstöras': [('öförstöra', False)],
          'ög': [('uga', False)],
          'öga': [('öga', False)],
          'ögande': [('öga', False)],
          'ögar': [('öga', False)],
          'ögats': [('öga', False)],
          'öge': [('uga', False)],
          'öges': [('yga', False)],
          'ögg': [('ugga', False)],
          'öggades': [('ögga', False)],
          'öggar': [('ögga', False)],
          'öggas': [('ögga', False)],
          'ögge': [('ugga', False)],
          'ögges': [('ugga', False)],
          'ögla': [('ögla', False)],
          'öglas': [('ögla', False)],
          'ögna': [('ögna', True)],
          'ögnades': [('ögna', True)],
          'ögnas': [('ögna', True)],
          'ögnat': [('ögna', True)],
          'ögs': [('uga', False)],
          'öjande': [('öja', False)],
          'öjats': [('öja', False)],
          'öjda': [('öja', False)],
          'öjdades': [('öjda', False)],
          'öjdas': [('öja', False)],
          'öjer': [('öja', False)],
          'öjes': [('öja', False)],
          'öjtades': [('öjta', False)],
          'ök': [('öka', True)],
          'ökar': [('öka', True)],
          'ökas': [('öka', False)],
          'ökats': [('öka', False)],
          'öke': [('yka', False)],
          'öken': [('öka', False)],
          'öker': [('öka', False)],
          'ökes': [('uka', False)],
          'öks': [('uka', False)],
          'ökta': [('öka', False)],
          'öktas': [('öka', False)],
          'öktes': [('öka', False)],
          'öla': [('öla', False)],
          'ölade': [('öla', False)],
          'ölades': [('öla', False)],
          'ölas': [('öla', False)],
          'ölats': [('öla', False)],
          'öljas': [('ölja', False)],
          'öljdes': [('ölja', False)],
          'ölkades': [('ölka', False)],
          'öll': [('ålla', False)],
          'ölle': [('ålla', False)],
          'ölles': [('alla', False)],
          'ölls': [('alla', False)],
          'ölt': [('ölta', False)],
          'öm': [('ömma', False)],
          'öm-': [('ömma', False)],
          'ömas': [('öma', False)],
          'ömd': [('öma', False)],
          'ömda': [('öma', False)],
          'ömdas': [('öma', False)],
          'ömde': [('öma', False)],
          'ömdes': [('ömma', False)],
          'ömds': [('ömma', False)],
          'ömer': [('öma', False)],
          'ömmades': [('ömma', False)],
          'ömmas': [('ömma', False)],
          'öms': [('ömsa', True)],
          'ömsade': [('ömsa', True)],
          'ömsades': [('ömsa', True)],
          'ömt': [('öma', False)],
          'ömts': [('öma', False)],
          'öna': [('öna', False)],
          'önar': [('öna', False)],
          'önats': [('öna', False)],
          'önes': [('öna', False)],
          'öng': [('unga', False)],
          'önge': [('unga', False)],
          'önges': [('unga', False)],
          'öngs': [('unga', False)],
          'önk': [('unka', False)],
          'önke': [('unka', False)],
          'önkes': [('unka', False)],
          'önks': [('unka', False)],
          'öns': [('öna', False)],
          'önskas': [('önska', False)],
          'önskats': [('önska', False)],
          'önt': [('öna', False)],
          'önta': [('öna', False)],
          'öntas': [('öna', False)],
          'önte': [('öna', False)],
          'öntes': [('öna', False)],
          'önts': [('öna', False)],
          'öpar': [('öpa', False)],
          'öpats': [('öpa', False)],
          'öpe': [('upa', False)],
          'öper': [('öpa', False)],
          'öpes': [('upa', False)],
          'öpnas': [('öpna', False)],
          'öpplade': [('öppla', False)],
          'öpplades': [('öppla', False)],
          'öps': [('öpa', False)],
          'öpta': [('öpa', False)],
          'öptas': [('öpa', False)],
          'öptes': [('öpa', False)],
          'ör': [('öra', False)],
          'örat': [('öra', False)],
          'örats': [('öra', False)],
          'örd': [('öra', False)],
          'örda': [('öra', False)],
          'ördades': [('örda', False)],
          'ördas': [('öra', False)],
          'ördel': [('ördela', False)],
          'ördel-': [('ördela', False)],
          'ördlade': [('ördla', False)],
          'ördlades': [('ördla', False)],
          'öres': [('öra', False)],
          'öretas': [('öreta', False)],
          'örevar': [('örevara', False)],
          'örgas': [('örgasa', False)],
          'örj': [('örja', False)],
          'örj-': [('örja', False)],
          'örja': [('örja', False)],
          'örjandes': [('örja', False)],
          'örjas': [('örja', False)],
          'örkades': [('örka', False)],
          'örkalkades': [('örkalkas', False)],
          'örkat': [('örka', False)],
          'örkla': [('örklägga', False)],
          'örklar': [('örklara', False)],
          'örla': [('örla', True)],
          'örlade': [('örla', True)],
          'örlades': [('örla', True)],
          'örlas': [('örla', True)],
          'örlist': [('örlisa', False)],
          'örnades': [('örna', False)],
          'örnas': [('örna', False)],
          'örs': [('öra', False)],
          'örskar': [('örskära', False)],
          'ört': [('örta', False)],
          'örtades': [('örta', False)],
          'örunna': [('örunna', False)],
          'örunnas': [('örunna', False)],
          'örvalt': [('örvalta', False)],
          'örär': [('örära', False)],
          'örödd': [('öröda', False)],
          'örödda': [('öröda', False)],
          'öröddas': [('öröda', False)],
          'örödde': [('öröda', False)],
          'örödds': [('öröda', False)],
          'örök': [('öröka', False)],
          'örött': [('öröda', False)],
          'örötts': [('öröda', False)],
          'ös': [('ösa', False)],
          'ösa': [('ösa', False)],
          'ösade': [('ösa', False)],
          'ösades': [('ösa', False)],
          'ösas': [('ösa', True)],
          'ösats': [('ösa', False)],
          'ösatt': [('ösätta', False)],
          'ösatts': [('ösätta', False)],
          'öse': [('ysa', False)],
          'öser': [('ösa', False)],
          'öses': [('ösa', True)],
          'öska': [('öska', False)],
          'öskad': [('öska', False)],
          'öskade': [('öska', False)],
          'öskades': [('öska', False)],
          'öskar': [('öska', False)],
          'öst': [('ösa', True)],
          'öst-': [('östa', False)],
          'östa': [('ösa', False)],
          'östades': [('östa', False)],
          'östande': [('östa', False)],
          'östandes': [('östa', False)],
          'östas': [('ösa', False)],
          'öste': [('ösa', False)],
          'östes': [('ösa', False)],
          'östs': [('ösa', True)],
          'öståt': [('östäta', False)],
          'öt': [('öta', False)],
          'öta': [('öta', False)],
          'ötas': [('öta', False)],
          'ötats': [('öta', False)],
          'öte': [('juta', False)],
          'öter': [('öta', False)],
          'ötes': [('uta', False)],
          'ötlade': [('ötlägga', False)],
          'ötlades': [('ötlägga', False)],
          'ötlas': [('ötlägga', False)],
          'ötnas': [('ötna', False)],
          'öts': [('öta', False)],
          'ött': [('öda', False)],
          'ötta': [('öta', False)],
          'öttades': [('ötta', False)],
          'öttas': [('öta', False)],
          'ötte': [('öta', False)],
          'öttes': [('öta', False)],
          'ötts': [('öda', True)],
          'öv': [('öva', True)],
          'övad': [('öva', False)],
          'övades': [('öva', True)],
          'övande': [('öva', False)],
          'övandes': [('öva', False)],
          'övar': [('öva', False)],
          'övas': [('öva', False)],
          'övats': [('öva', False)],
          'övda': [('öva', False)],
          'övdas': [('öva', False)],
          'öve': [('yva', False)],
          'övel': [('övla', False)],
          'övel-': [('övla', False)],
          'över': [('öva', False)],
          'öves': [('öva', False)],
          'övlas': [('övla', False)],
          'övrades': [('övra', False)],
          'övras': [('övra', False)],
          'övs': [('yva', False)]},
 'VERB_ADJ': {'tt': [('d', False)], 'äst': [('ra', False)], 'ästa': [('ra', False)], 'ättre': [('ra', False)]},
 'VERB_ADV': {'er': [('ycket', False)],
              'era': [('ycket', False)],
              'mindre': [('liten', True), ('lite', True)],
              'minst': [('liten', True), ('lite', True)],
              're': [('e', False)],
              'st': [('e', False)]},
 'VERB_DET': {'allt': [('allt', True), ('all', True)]},
 'VERB_NOUN': {'a': [('um', False)],
               'an': [('an', False)],
               'arna': [('', False)],
               'den': [('de', False)],
               'dern': [('r', False)],
               'derns': [('r', False)],
               'en': [('', False)],
               'engarna': [('engar', False)],
               'ens': [('', False)],
               'erna': [('', False)],
               'et': [('', False)],
               'karna': [('kare', False)],
               'mn': [('mn', False)],
               'ngarna': [('ng', False)],
               'on': [('on', False)],
               'äderna': [('ar', False)],
               'ägarna': [('äg', False)],
               'ödrarna': [('or', False)]},
 'VERB_VERB': {'as': [('as', False)],
               'er': [('a', False)],
               'ns': [('nas', False)],
               'r': [('', False)],
               'tas': [('ta', True)],
               'är': [('vara', True)]},
 '_ADJ': {'are': [('', False)],
          'e': [('', False)],
          'ott': [('ott', False)],
          'tt': [('', False)],
          'ästa': [('ra', False)],
          'ättre': [('ra', False)]},
 '_ADV': {'er': [('ycket', False)], 'mindre': [('liten', True)], 'minst': [('liten', True)]},
 '_DET': {'t': [('', False)]},
 '_NOUN': {'a': [('um', False)],
           'ar': [('', False)],
           'arna': [('', False)],
           'dern': [('r', False)],
           'en': [('', False)],
           'ens': [('', False)],
           'er': [('', False)],
           'erna': [('', False)],
           'gar': [('gar', False)],
           'garna': [('gar', False)],
           'ilbefordran': [('ilbefodran', True), ('ilbefordran', True)],
           'kar': [('ka', False)],
           'kerna': [('ker', False)],
           'ren': [('re', False)],
           'skar': [('sk', False)],
           'sten': [('st', False)],
           'ten': [('te', False)],
           'äderna': [('ar', False)],
           'ägarna': [('äg', False)],
           'ödrar': [('or', False)],
           'öts': [('yta', False)]},
 '_PRON': {'flera': [('mången', True)]},
 '_VERB': {'an': [('unna', False)], 'r': [('', False)], 's': [('as', False)], 'är': [('vara', True)]}}